:root {
  --svgArrow: url('data:image/svg+xml,<svg viewBox="0 0 16 16" xmlns="http://www.w3.org/2000/svg">\
  <path fill="currentColor" d="M8.5 11 4.866 7.366A.8.8 0 0 1 5.43 6h6.138a.8.8 0 0 1 .565 1.366L8.5 11Z"/>\
  </svg>');
}
/* focus debugging
#browser *:focus {
  background-color:rgba(200,0,0,.2) !important;
  outline: 2px solid rgba(200,0,0,.5) !important;
  visibility: visible !important;
  display: initial !important;
  transform: scale(1), translate3D(0,0,0) !important;
}
 */
:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
html {
  box-sizing: border-box;
}
body,
div,
header,
footer,
nav,
main,
aside,
section,
figure,
table,
h1,
h2,
h3,
h4,
h5,
h6,
form,
p,
ul,
ol,
li,
dl,
dd,
dt,
span,
em,
strong,
label,
input,
button,
select,
textarea,
progress,
svg,
img,
iframe {
  box-sizing: inherit;
}
body {
  margin: 0;
}
h1,
h2,
h3,
h4,
h5,
h6,
p,
form {
  -webkit-margin-before: 0;
  -webkit-margin-after: 0;
}
header,
footer,
nav,
section {
  display: block;
}
ul {
  list-style: none;
  -webkit-margin-before: 0;
  -webkit-margin-after: 0;
  -webkit-padding-start: 0;
}
dl {
  -webkit-margin-before: 0;
  -webkit-margin-after: 0;
}
dl dd {
  -webkit-margin-start: 0;
}
iframe {
  border: none;
}
table {
  border-collapse: collapse;
  border-spacing: 0;
  font: inherit;
}
table,
table th,
table td {
  margin: 0;
  padding: 0;
}
button,
input,
select {
  vertical-align: middle;
  font: inherit;
  color: inherit;
}
textarea {
  font: inherit;
  color: inherit;
}
@keyframes move {
  0% {
    background-position: 0 0;
  }
  100% {
    background-position: 16px 0;
  }
}
@keyframes spin {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}
@keyframes slidein {
  0% {
    transform: scale(1, 0);
  }
  100% {
    transform: scale(1, 1);
  }
}
@keyframes unveil {
  0% {
    transform: translateZ(-60px) rotateX(90deg) scale(1, 0);
    opacity: 0;
  }
  100% {
    transform: translateZ(0px) rotateX(0) scale(1, 1);
    opacity: 1;
  }
}
@keyframes flash {
  0% {
    background-color: rgba(255, 255, 255, 0.5);
  }
  100% {
    background-color: rgba(255, 255, 255, 0);
  }
}
@keyframes pulsepermission {
  0%,
  50%,
  70%,
  90% {
    filter: grayscale(100%) brightness(2);
  }
  60%,
  80%,
  100% {
    filter: grayscale(0%);
  }
}
@keyframes pop {
  0% {
    transform: scale(0.7);
  }
  45% {
    transform: scale(1.05);
  }
  80% {
    transform: scale(0.95);
  }
  100% {
    transform: scale(1);
  }
}
@keyframes dropfade {
  0% {
    opacity: 0;
    translate: 0 -10px;
  }
  100% {
    opacity: 1;
    translate: 0 0;
  }
}
@keyframes pullfade {
  0% {
    opacity: 0;
    translate: 0 10px;
  }
  100% {
    opacity: 1;
    translate: 0 0;
  }
}
@keyframes leftfade {
  0% {
    opacity: 0;
    translate: -10px 0;
  }
  100% {
    opacity: 1;
    translate: 0 0;
  }
}
@keyframes rightfade {
  0% {
    opacity: 0;
    translate: 10px 0;
  }
  100% {
    opacity: 1;
    translate: 0 0;
  }
}
@keyframes fade {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
@keyframes soundwave {
  0% {
    transform: scale(0);
    opacity: 1;
    stroke-width: 3;
  }
  60% {
    opacity: 1;
  }
  90% {
    transform: scale(1);
    opacity: 0;
    stroke-width: 1.2;
  }
}
@keyframes delay_visibility {
  0%,
  99.9% {
    visibility: visible;
  }
  100% {
    visibility: hidden;
  }
}
@keyframes wiggle {
  0% {
    transform: rotate(0deg);
  }
  33% {
    transform: rotate(5deg);
  }
  66% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(-5deg);
  }
}
@keyframes animated-stripes {
  0% {
    background-position: 70px 0;
  }
  100% {
    background-position: 0 0;
  }
}
@keyframes horizontal-wiggle {
  0% {
    background-position: 70px 0;
    transform: translateX(0);
  }
  100% {
    background-position: 0 0;
  }
  25% {
    transform: translateX(1px);
  }
  50% {
    transform: translateX(0);
  }
  75% {
    transform: translateX(-1px);
  }
}
#app {
  font-weight: 400;
  font-size: 13px;
  line-height: 1.3;
}
#browser.win,
#browser.win button,
#browser.win input,
#browser.win select,
#browser.win textarea {
  font-family: 'Segoe UI', system-ui, sans-serif;
}
#browser.win:lang(ar),
#browser.win button:lang(ar),
#browser.win input:lang(ar),
#browser.win select:lang(ar),
#browser.win textarea:lang(ar),
#browser.win:lang(fa),
#browser.win button:lang(fa),
#browser.win input:lang(fa),
#browser.win select:lang(fa),
#browser.win textarea:lang(fa) {
  font-family: 'Segoe UI', Tahoma, system-ui, sans-serif;
}
#browser.win:lang(ja),
#browser.win button:lang(ja),
#browser.win input:lang(ja),
#browser.win select:lang(ja),
#browser.win textarea:lang(ja),
#browser.win:lang(ja-KS),
#browser.win button:lang(ja-KS),
#browser.win input:lang(ja-KS),
#browser.win select:lang(ja-KS),
#browser.win textarea:lang(ja-KS) {
  font-family: 'Segoe UI', 'Yu Gothic UI', 'Meiryo UI', Meiryo, system-ui, sans-serif;
}
#browser.win:lang(zh-CN),
#browser.win button:lang(zh-CN),
#browser.win input:lang(zh-CN),
#browser.win select:lang(zh-CN),
#browser.win textarea:lang(zh-CN) {
  /* stylelint-disable-next-line */
  font-family: 'Segoe UI', 'Microsoft YaHei New', 'Microsoft Yahei', 微软雅黑, system-ui, sans-serif;
}
#browser.win:lang(zh-TW),
#browser.win button:lang(zh-TW),
#browser.win input:lang(zh-TW),
#browser.win select:lang(zh-TW),
#browser.win textarea:lang(zh-TW) {
  /* stylelint-disable-next-line */
  font-family: 'Segoe UI', 'Microsoft JhengHei New', 'Microsoft JhengHei', 微软雅黑, system-ui, sans-serif;
}
#browser.mac,
#browser.mac button,
#browser.mac input,
#browser.mac select,
#browser.mac textarea {
  font-family: system-ui, -apple-system, sans-serif;
  font-variation-settings: 'wdth' 96, 'opsz' 19;
}
#browser.mac:lang(ar),
#browser.mac button:lang(ar),
#browser.mac input:lang(ar),
#browser.mac select:lang(ar),
#browser.mac textarea:lang(ar),
#browser.mac:lang(fa),
#browser.mac button:lang(fa),
#browser.mac input:lang(fa),
#browser.mac select:lang(fa),
#browser.mac textarea:lang(fa) {
  font-family: system-ui, -apple-system, Tahoma, sans-serif;
}
#browser.mac:lang(ja),
#browser.mac button:lang(ja),
#browser.mac input:lang(ja),
#browser.mac select:lang(ja),
#browser.mac textarea:lang(ja),
#browser.mac:lang(ja-KS),
#browser.mac button:lang(ja-KS),
#browser.mac input:lang(ja-KS),
#browser.mac select:lang(ja-KS),
#browser.mac textarea:lang(ja-KS) {
  font-family: system-ui, -apple-system, 'Hiragino Kaku Gothic ProN', 'Hiragino Sans', sans-serif;
}
#browser.mac:lang(zh-CN),
#browser.mac button:lang(zh-CN),
#browser.mac input:lang(zh-CN),
#browser.mac select:lang(zh-CN),
#browser.mac textarea:lang(zh-CN) {
  font-family: system-ui, -apple-system, 'PingFang SC', sans-serif;
}
#browser.mac:lang(zh-TW),
#browser.mac button:lang(zh-TW),
#browser.mac input:lang(zh-TW),
#browser.mac select:lang(zh-TW),
#browser.mac textarea:lang(zh-TW) {
  font-family: system-ui, -apple-system, 'PingFang TC', 'PingFang SC', sans-serif;
}
#browser.linux,
#browser.linux button,
#browser.linux input,
#browser.linux select,
#browser.linux textarea {
  font-family: Cantarell, 'Noto Sans', Helvetica, system-ui, sans-serif;
}
textarea.actionlogs {
  font-family: monospace;
}
h1 {
  font-size: 16px;
  font-weight: 400;
}
h2 {
  font-size: inherit;
  font-weight: 700;
}
h3 {
  font-size: inherit;
  font-weight: 600;
}
h1,
h2,
h3,
.info,
.balanced {
  text-wrap: balance;
  font-variation-settings: normal;
}
.faded-text {
  color: var(--colorFgFadedMore);
}
#browser:not(.auto-hide-visible) #header,
#browser:not(.auto-hide-visible) .vivaldi-settings .settings-header h1,
#browser:not(.auto-hide-visible).disable-titlebar.address-top .mainbar:has(.window-buttongroup),
#browser:not(.auto-hide-visible).mac:not(.toolbar-edit-mode) .toolbar-statusbar,
#browser:not(.auto-hide-visible).tabs-top #tabs-subcontainer {
  -webkit-app-region: drag;
}
button,
input,
select,
.tab-strip .tab-position,
#tabs-subcontainer,
.topmenu,
.menu.horizontal > ul > li > .menu,
.tab-group-indicator,
.page-zoom-controls,
.selectable,
.SyncStatus-Warning,
.panel-group,
#browser.native #header,
#browser.no-app-dragging .toolbar-statusbar,
#browser.no-app-dragging #header {
  -webkit-app-region: no-drag;
}
#browser:not(.address-top.mail-bar-top) > #header {
  box-shadow: inset 0 -1px 0 var(--colorBorder);
}
#browser.native {
  box-shadow: none;
}
#browser.native.stacks-off #tabs-tabbar-container {
  padding-top: 0;
  padding-bottom: 0;
}
#browser.native.mac div#titlebar {
  display: none;
}
#browser.native.mac:not(.tabs-top) div#header {
  display: none;
}
#browser.native.mac #tabs-tabbar-container {
  padding-left: 0;
  padding-right: 0;
}
#browser.native.mac.tabs-bottom #tabs-tabbar-container {
  padding-top: 0;
}
#browser.native.linux #browser.native.win.normal #tabs-tabbar-container.top {
  padding-top: 6px;
}
#browser.native.linux #browser.native.win.native.tabs-top.tabs-at-edge #titlebar button,
#browser.native.linux #browser.native.win.tabs-top.stacks-off #titlebar button {
  height: 30px;
}
#browser.native.linux #browser.native.win.normal:not(.alt) #tabs-tabbar-container.top {
  padding-right: 0;
}
#browser.native.linux #browser.native.win.alt #tabs-tabbar-container.top {
  padding-left: 0;
}
#browser.native.linux #browser.native.win.tabs-top #header {
  min-height: 22px;
}
#browser.native.linux #browser.native.win.minimal-ui #header {
  display: none;
}
#browser.native.linux #browser.native.win:not(.address-top):not(.tabs-top) #header {
  min-height: 24px;
}
#browser.native.linux #browser.native.win #pagetitle {
  display: none;
}
#browser.native.linux #browser.native.win .window-buttongroup {
  display: none;
}
#browser.native.linux #browser.native.win .topmenu {
  margin: 0;
}
.tabs-top.stacks-dotted#browser.native.linux #browser.native.win .topmenu,
.tabs-top.substrip-tabs-on#browser.native.linux #browser.native.win .topmenu {
  margin-bottom: 4px;
}
.tabs-top.stacks-off#browser.native.linux #browser.native.win .topmenu {
  margin-bottom: 1px;
}
#app #browser #header:empty {
  display: none;
}
#app #browser #header:focus-within {
  z-index: 6;
}
.auto-hide #browser:not(.win, .fullscreen) .auto-hide-wrapper #titlebar,
.auto-hide-off #browser:not(.win, .fullscreen, .disable-titlebar) #header {
  min-height: calc(30px / var(--uiZoomLevel));
}
.tabs-top.auto-hide #browser:not(.win, .fullscreen) .auto-hide-wrapper #titlebar,
.tabs-top.auto-hide-off #browser:not(.win, .fullscreen, .disable-titlebar) #header {
  min-height: calc((36px + var(--densityGap) * 2) / var(--uiZoomLevel));
}
.tabs-top.address-top.auto-hide #browser:not(.win, .fullscreen) .auto-hide-wrapper #titlebar,
.tabs-top.address-top.auto-hide-off #browser:not(.win, .fullscreen, .disable-titlebar) #header {
  min-height: calc((34px + var(--densityGap) * 2) / var(--uiZoomLevel));
}
.tabs-top.tabs-at-edge.auto-hide #browser:not(.win, .fullscreen) .auto-hide-wrapper #titlebar,
.tabs-top.tabs-at-edge.auto-hide-off #browser:not(.win, .fullscreen, .disable-titlebar) #header {
  min-height: calc((30px + var(--densityGap) * 2) / var(--uiZoomLevel));
}
#browser:is(.popup, .is-settingspage):not(.fullscreen, .disable-titlebar) #header {
  min-height: calc(30px / var(--uiZoomLevel));
}
.native#browser:is(.popup, .is-settingspage):not(.fullscreen, .disable-titlebar) #header {
  display: none;
}
#titlebar {
  display: flex;
  align-items: center;
  position: absolute;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  right: 0;
  pointer-events: none;
}
.auto-hide .auto-hide-wrapper #titlebar {
  position: static;
  background-color: var(--colorBg);
}
#titlebar .window-buttongroup,
#titlebar .vivaldi {
  pointer-events: all;
}
#titlebar #pagetitle {
  display: grid;
  align-items: center;
  height: 24px;
  top: 0;
  left: 0;
  right: 0;
  width: calc(100% * var(--uiZoomLevel));
  text-align: center;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  pointer-events: none;
  scale: calc(1 / var(--uiZoomLevel));
  transform-origin: top left;
}
.win #titlebar #pagetitle {
  font-size: 12px;
}
.mac #titlebar #pagetitle {
  padding: 0 78px;
}
.mac #titlebar #pagetitle,
#titlebar #pagetitle .linux.alt {
  font-size: 13px;
  font-weight: bold;
  height: 28px;
}
#titlebar #pagetitle > span {
  display: block;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.win #titlebar #pagetitle > span,
.linux:not(.alt) #titlebar #pagetitle > span {
  text-align: left;
}
/* The image colors win over other colors if present, so enable only where
 the image is visible. */
#browser .tabbar-wrapper,
#browser.tabs-top #header,
#browser.tabs-bottom #footer {
  display: flex;
  flex-direction: column;
  background-color: var(--colorTabBar);
  justify-content: flex-end;
}
.transparent-tabbar#browser .tabbar-wrapper,
.transparent-tabbar#browser.tabs-top #header,
.transparent-tabbar#browser.tabs-bottom #footer {
  --colorImageFg: var(--colorImageTopFg);
  --colorImageBgAlpha: var(--colorImageTopBgAlpha);
  --colorImageBgAlphaHeavy: var(--colorImageTopBgAlphaHeavy);
}
.color-behind-tabs-on#browser .tabbar-wrapper,
.color-behind-tabs-on#browser.tabs-top #header,
.color-behind-tabs-on#browser.tabs-bottom #footer {
  color: var(--colorImageFg, var(--colorAccentFg));
}
.color-behind-tabs-off#browser .tabbar-wrapper,
.color-behind-tabs-off#browser.tabs-top #header,
.color-behind-tabs-off#browser.tabs-bottom #footer {
  color: var(--colorImageFg, var(--colorFg));
}
.transparent-tabbar.color-accent-from-page.acc-dark.bg-dark.color-behind-tabs-on#browser .tabbar-wrapper,
.transparent-tabbar.color-accent-from-page.acc-dark.bg-dark.color-behind-tabs-on#browser.tabs-top #header,
.transparent-tabbar.color-accent-from-page.acc-dark.bg-dark.color-behind-tabs-on#browser.tabs-bottom #footer {
  color: var(--colorAccentFg);
}
.transparent-tabbar:not(.color-accent-from-page.color-behind-tabs-on)#browser .tabbar-wrapper,
.transparent-tabbar:not(.color-accent-from-page.color-behind-tabs-on)#browser.tabs-top #header,
.transparent-tabbar:not(.color-accent-from-page.color-behind-tabs-on)#browser.tabs-bottom #footer {
  backdrop-filter: var(--backgroundBlur);
}
#browser:not(.is-settingspage, .popup, .native).address-top-off.tabs-off.bookmark-bar-off #header,
#browser:not(.is-settingspage, .popup, .native).address-bottom-off.tabs-off.bookmark-bar-off #header {
  background-color: var(--colorBg);
  color: var(--colorFg);
}
.color-behind-tabs-on#browser:not(.is-settingspage, .popup, .native).address-top-off.tabs-off.bookmark-bar-off #header,
.color-behind-tabs-on#browser:not(.is-settingspage, .popup, .native).address-bottom-off.tabs-off.bookmark-bar-off #header {
  background-color: var(--colorAccentBg);
  color: var(--colorAccentFg);
}
#browser.minimal-ui.disable-titlebar > :not(.auto-hide-wrapper) .vivaldi,
#browser.minimal-ui.disable-titlebar > :not(.auto-hide-wrapper) .window-buttongroup {
  display: none;
}
#browser .window-buttongroup {
  display: flex;
  z-index: 1;
  scale: calc(1 / var(--uiZoomLevel));
  fill: currentColor;
}
.win#browser .window-buttongroup,
.linux:not(.alt)#browser .window-buttongroup {
  transform-origin: top right;
  z-index: 4;
}
.mac#browser .window-buttongroup,
.linux.alt#browser .window-buttongroup {
  transform-origin: top left;
}
#browser .window-buttongroup.on-mainbar {
  background-color: var(--colorBg);
}
.color-behind-tabs-off#browser .window-buttongroup.on-mainbar {
  background-color: var(--colorAccentBg);
}
#browser.biscuit-hide-window-controls#browser .window-buttongroup {
  display: none;
}
#browser .window-buttongroup button {
  width: 25px;
  height: 20px;
  border: 0;
  background-color: transparent;
  margin-right: 0;
}
#browser .window-buttongroup button.window-maximize g {
  display: none;
}
.normal#browser .window-buttongroup button.window-maximize .window-maximize-glyph,
.fullscreen:not(.mac)#browser .window-buttongroup button.window-maximize .window-restore-glyph,
.maximized:not(.mac)#browser .window-buttongroup button.window-maximize .window-restore-glyph {
  display: block;
}
#browser .window-buttongroup button:focus {
  outline: unset;
}
@media (-webkit-min-device-pixel-ratio: 2) {
  #browser .window-buttongroup button .dpi-standard {
    display: none;
  }
}
#browser .window-buttongroup button .dpi-high {
  display: none;
}
@media (-webkit-min-device-pixel-ratio: 2) {
  #browser .window-buttongroup button .dpi-high {
    display: block;
  }
}
#browser.win .topmenu + #tabs-tabbar-container.top,
#browser.linux .topmenu + #tabs-tabbar-container.top {
  padding-left: 0;
  padding-right: 0;
}
#browser.win .toolbar-visible:has(.window-buttongroup.on-mainbar),
#browser.linux .toolbar-visible:has(.window-buttongroup.on-mainbar) {
  min-height: calc(34px / var(--uiZoomLevel));
}
#browser.win.density-on .toolbar-visible:has(.window-buttongroup.on-mainbar),
#browser.linux.density-on .toolbar-visible:has(.window-buttongroup.on-mainbar) {
  min-height: calc(46px / var(--uiZoomLevel));
}
#browser.win.maximized,
#browser.win.fullscreen {
  padding: 0;
  border-width: 0;
}
#browser.win:not(.fullscreen, .disable-titlebar) #header {
  min-height: calc(30px / var(--uiZoomLevel));
}
.tabs-top#browser.win:not(.fullscreen, .disable-titlebar) #header {
  min-height: calc((40px + var(--densityGap) * 2) / var(--uiZoomLevel));
}
.tabs-top.address-top#browser.win:not(.fullscreen, .disable-titlebar) #header {
  min-height: calc((36px + var(--densityGap) * 2) / var(--uiZoomLevel));
}
.tabs-top.tabs-at-edge#browser.win:not(.fullscreen, .disable-titlebar) #header {
  min-height: calc(30px + 2 / var(--uiZoomLevel));
}
#browser.win #titlebar #pagetitle {
  padding: 0 140px 0 0;
  height: 30px;
}
.address-top#browser.win #titlebar #pagetitle {
  top: 0;
}
.popup#browser.win #titlebar #pagetitle {
  display: flex;
  gap: 6px;
  padding-left: 8px;
}
#browser.win.disable-titlebar .window-buttongroup {
  height: 34px;
}
.density-on#browser.win.disable-titlebar .window-buttongroup {
  height: 46px;
}
#browser.win.disable-titlebar .window-buttongroup button {
  height: inherit;
}
#browser.win.disable-titlebar .horizontal-menu-pagetitle + .window-buttongroup {
  height: 24px;
}
#browser.win .window-buttongroup {
  position: absolute;
  right: 0;
  top: 0;
  overflow: hidden;
  line-height: initial;
}
#browser.win .window-buttongroup.disable-transition button {
  transition-duration: 0ms;
}
#browser.win .window-buttongroup button {
  width: 45px;
  height: 30px;
  margin-left: 1px;
  transition: background 0.3s, fill 0.3s;
  border-radius: 0;
  fill: currentColor;
}
.popup#browser.win .window-buttongroup button {
  height: 30px;
}
.tabs-right#browser.win .window-buttongroup button:not(.on-mainbar) .tabs-left#browser.win .window-buttongroup button:not(.on-mainbar),
.tabs-bottom#browser.win .window-buttongroup button:not(.on-mainbar) {
  fill: var(--colorFg);
}
.color-behind-tabs-off.tabs-right#browser.win .window-buttongroup button:not(.on-mainbar) .tabs-left#browser.win .window-buttongroup button:not(.on-mainbar),
.color-behind-tabs-off.tabs-bottom#browser.win .window-buttongroup button:not(.on-mainbar) {
  fill: var(--colorAccentFg);
}
.tabs-top:not(.popup, .horizontal-menu)#browser.win .window-buttongroup button {
  height: calc(36px + var(--densityGap) * 2);
}
#browser:has(#tabs-subcontainer):not(.tabs-at-edge).tabs-top:not(.popup, .horizontal-menu)#browser.win .window-buttongroup button {
  height: calc(36px + var(--densityGap));
}
.fullscreen.tabs-at-edge.tabs-top:not(.popup, .horizontal-menu)#browser.win .window-buttongroup button,
.maximized.tabs-at-edge.tabs-top:not(.popup, .horizontal-menu)#browser.win .window-buttongroup button {
  height: 30px;
}
#browser.win .window-buttongroup button:hover {
  fill: currentColor;
  background-color: rgba(0, 0, 0, 0.1);
  transition-duration: 0s;
}
.theme-dark#browser.win .window-buttongroup button:hover {
  background-color: rgba(255, 255, 255, 0.1);
}
.ismaximized#browser.win .window-buttongroup button:hover,
.isnormal#browser.win .window-buttongroup button:hover,
.minimize#browser.win .window-buttongroup button:hover {
  background-color: var(--colorBg);
}
#browser.win .window-buttongroup button:active {
  filter: brightness(0.93);
}
#browser.win .window-buttongroup button.window-close {
  background-color: transparent;
  border: 0;
  padding: 0;
}
#browser.win .window-buttongroup button.window-close:hover {
  fill: #fff;
  background-color: #c42c1d;
}
#browser.win.address-top .toolbar:has(.window-buttongroup.on-mainbar) {
  padding-right: calc((46px * 3) / var(--uiZoomLevel));
}
.address-top-off.tabs-off.bookmark-bar-off.hasfocus#browser.mac #header {
  background-image: linear-gradient(rgba(255, 255, 255, 0.2), transparent);
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.15), inset 0 -1px 0 rgba(0, 0, 0, 0.05);
}
.color-behind-tabs-on.acc-dark.address-top-off.tabs-off.bookmark-bar-off.hasfocus#browser.mac #header {
  box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.25), inset 0 -1px 0 0 var(--colorAccentBorderDark);
}
#browser.mac .toolbar-visible:has(.window-buttongroup.on-mainbar) {
  padding: 0 calc(12px / var(--uiZoomLevel));
  min-height: calc(53px / var(--uiZoomLevel));
}
#browser.mac:not(.fullscreen) .window-buttongroup {
  position: relative;
  display: inline-flex;
  min-width: calc(54px / var(--uiZoomLevel));
  margin-top: calc(13px / var(--uiZoomLevel));
  margin-left: calc(8px / var(--uiZoomLevel));
}
#browser.mac:not(.fullscreen) .window-buttongroup.on-mainbar {
  margin-top: 0;
  margin-right: 18px;
}
.tabs-top#browser.mac:not(.fullscreen) .window-buttongroup {
  margin-left: calc(13px / var(--uiZoomLevel));
}
#browser.mac.disable-titlebar #header:has(#tabs-tabbar-container.none) {
  display: none;
}
.auto-hide-off #browser.mac.macos26:not(.fullscreen, .disable-titlebar) #header {
  min-height: 32px;
}
.auto-hide-off #browser.mac.macos26:not(.fullscreen, .disable-titlebar) #pagetitle {
  padding: 0 82px;
  text-align: center;
  min-height: 32px;
}
#browser.mac.macos26:is(.popup, .is-settingspage):not(.fullscreen, .disable-titlebar) .settings-header {
  top: calc(8px / var(--uiZoomLevel));
  left: calc(82px / var(--uiZoomLevel));
  justify-content: center;
}
#browser.mac.macos26:not(.RTL, .fullscreen, .native) #tabs-container:not(.none).top .window-buttongroup {
  margin-left: calc(24px / var(--uiZoomLevel));
}
#browser.mac.macos26:not(.fullscreen) .window-buttongroup.on-mainbar {
  margin-right: calc(24px / var(--uiZoomLevel));
}
#browser.linux:not(.native) {
  border: 1px solid var(--colorBorderSubtle);
}
#browser.linux.maximized,
#browser.linux.fullscreen {
  border-width: 0;
}
#browser.linux.address-top.popup #titlebar #pagetitle {
  padding-left: calc(12px / var(--uiZoomLevel));
}
#browser.linux:not(.native).address-top .toolbar:has(.window-buttongroup.on-mainbar),
#browser.linux:not(.native) #titlebar:has(.window-buttongroup) {
  padding-right: calc(100px / var(--uiZoomLevel));
}
.alt#browser.linux:not(.native).address-top .toolbar:has(.window-buttongroup.on-mainbar),
.alt#browser.linux:not(.native) #titlebar:has(.window-buttongroup) {
  padding-left: calc(100px / var(--uiZoomLevel));
  padding-right: calc(var(--menuWidth) + 12px / var(--uiZoomLevel));
}
#browser.linux .window-buttongroup {
  position: absolute;
  right: calc(5px / var(--uiZoomLevel));
  top: calc(5px / var(--uiZoomLevel));
}
#browser.linux .window-buttongroup button {
  margin-left: 2px;
  background-color: rgba(0, 0, 0, 0.05);
  fill: var(--colorImageFg, inherit);
}
#browser.linux .window-buttongroup button:hover {
  background-color: rgba(0, 0, 0, 0.1);
}
#browser.linux .window-buttongroup button:active {
  background-color: rgba(0, 0, 0, 0.2);
}
#browser.linux.alt #titlebar #pagetitle {
  padding-left: 100px;
  padding-right: var(--menuWidth);
  margin-right: var(--menuWidth);
}
#browser.linux.alt .window-buttongroup {
  right: auto;
  left: calc(5px / var(--uiZoomLevel));
}
#browser.linux.alt .window-buttongroup button.window-close {
  order: -1;
}
#browser.linux.alt #header .vivaldi {
  left: auto;
  right: 0;
  transform-origin: top right;
}
#browser.linux.alt .topmenu {
  flex-direction: row-reverse;
}
#browser.linux.alt .topmenu + #tabs-tabbar-container.top {
  padding-left: 6px;
  padding-right: 0;
}
#browser.isblurred.dim-blurred header,
#browser.isblurred.dim-blurred footer,
#browser.isblurred.dim-blurred .topmenu,
#browser.isblurred.dim-blurred .panel-group,
#browser.isblurred.dim-blurred .bookmark-bar,
#browser.isblurred.dim-blurred .manager-editor,
#browser.isblurred.dim-blurred .vivaldi-settings,
#browser.isblurred.dim-blurred .toolbar,
#browser.isblurred.dim-blurred .mainbar,
#browser.isblurred.dim-blurred:not(.is-settingspage) #header,
#browser.isblurred.dim-blurred #switch,
#browser.isblurred.dim-blurred .tabbar-wrapper {
  --colorFg: var(--colorFgFadedMore);
  --colorFgFaded: var(--colorFgFadedMore);
  --colorBg: var(--colorBgLight);
  --colorBgLighter: var(--colorBgLight);
  --colorBgDarker: var(--colorBgDark);
  --colorBgLightIntense: var(--colorBgLight);
  --colorBgIntense: var(--colorBgLight);
  --colorBgIntenser: var(--colorBgLight);
  --colorBgInverse: var(--colorBgLight);
  --colorBgInverser: var(--colorBgLight);
  --colorBgFaded: var(--colorBgLight);
}
#browser.isblurred.dim-blurred header img,
#browser.isblurred.dim-blurred footer img,
#browser.isblurred.dim-blurred .topmenu img,
#browser.isblurred.dim-blurred .panel-group img,
#browser.isblurred.dim-blurred .bookmark-bar img,
#browser.isblurred.dim-blurred .manager-editor img,
#browser.isblurred.dim-blurred .vivaldi-settings img,
#browser.isblurred.dim-blurred .toolbar img,
#browser.isblurred.dim-blurred .mainbar img,
#browser.isblurred.dim-blurred:not(.is-settingspage) #header img,
#browser.isblurred.dim-blurred #switch img,
#browser.isblurred.dim-blurred .tabbar-wrapper img,
#browser.isblurred.dim-blurred header svg,
#browser.isblurred.dim-blurred footer svg,
#browser.isblurred.dim-blurred .topmenu svg,
#browser.isblurred.dim-blurred .panel-group svg,
#browser.isblurred.dim-blurred .bookmark-bar svg,
#browser.isblurred.dim-blurred .manager-editor svg,
#browser.isblurred.dim-blurred .vivaldi-settings svg,
#browser.isblurred.dim-blurred .toolbar svg,
#browser.isblurred.dim-blurred .mainbar svg,
#browser.isblurred.dim-blurred:not(.is-settingspage) #header svg,
#browser.isblurred.dim-blurred #switch svg,
#browser.isblurred.dim-blurred .tabbar-wrapper svg {
  filter: opacity(0.65);
}
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred header,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred footer,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred .topmenu,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred .panel-group,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred .bookmark-bar,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred .manager-editor,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred .vivaldi-settings,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred .toolbar,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred .mainbar,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred:not(.is-settingspage) #header,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred #switch,
.color-behind-tabs-on:not(.transparent-tabbar)#browser.isblurred.dim-blurred .tabbar-wrapper {
  --colorTabBar: var(--colorAccentBgFaded);
}
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred header,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred footer,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred .topmenu,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred .panel-group,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred .bookmark-bar,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred .manager-editor,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred .vivaldi-settings,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred .toolbar,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred .mainbar,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred:not(.is-settingspage) #header,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred #switch,
.color-behind-tabs-off:not(.transparent-tabbar)#browser.isblurred.dim-blurred .tabbar-wrapper {
  --colorTabBar: var(--colorBgFaded);
}
#browser.isblurred.dim-blurred .manager-editor,
#browser.isblurred.dim-blurred .toolbar:not(
    .toolbar-mainbar,
    .toolbar-statusbar,
    .toolbar-insideinput
  ) {
  color: var(--colorFg);
}
.transparent-tabbar #browser.isblurred.dim-blurred .manager-editor,
.transparent-tabbar #browser.isblurred.dim-blurred .toolbar:not(
    .toolbar-mainbar,
    .toolbar-statusbar,
    .toolbar-insideinput
  ) {
  color: var(--colorImageFg, var(--colorFg));
}
#browser.isblurred.dim-blurred #header .window-buttongroup img,
#browser.isblurred.dim-blurred #tabs-tabbar-container .favicon img,
#browser.isblurred.dim-blurred #header .window-buttongroup svg,
#browser.isblurred.dim-blurred #tabs-tabbar-container .favicon svg {
  filter: initial;
}
#browser.isblurred.dim-blurred #pagetitle,
#browser.isblurred.dim-blurred .button-badge,
#browser.isblurred.dim-blurred .settings-header,
#browser.isblurred.dim-blurred .toolbar-statusbar > *:not(.StatusInfo),
#browser.isblurred.dim-blurred #tabs-tabbar-container .favicon,
#browser.isblurred.dim-blurred #tabs-tabbar-container .tab:not(.active) .title,
#browser.isblurred.dim-blurred .tabbar-workspace-button .button-icon,
#browser.isblurred.dim-blurred .tabbar-workspace-button .button-title {
  opacity: 0.65;
}
.file-dropzone {
  position: absolute;
  top: 36px;
  left: 0;
  right: 0;
  bottom: 0;
  padding: 24px;
  background-color: var(--colorBgAlpha);
  z-index: 6;
}
.file-dropzone h1 {
  display: grid;
  align-items: center;
  justify-content: center;
  border: dashed 3px var(--colorHighlightBg);
  border-radius: var(--radius);
  height: 100%;
  font-weight: bold;
  color: var(--colorHighlightBg);
  pointer-events: none;
}
@media (prefers-contrast: more) {
  #browser {
    --border-width: 0.5px;
  }
  #browser.win button,
  #browser.win input,
  #browser.win select,
  #browser.win textarea {
    appearance: auto;
  }
  #browser .button-popup,
  #browser .OmniDropdown,
  #browser .modal-wrapper,
  #browser .HintTooltip__content,
  #browser .tooltip > *,
  #browser .menu {
    border: 1px solid;
  }
  #browser .vivaldi-tree .tree-row[data-selected] {
    border: 1px solid;
    margin-top: -1px;
    margin-left: -1px;
  }
  #browser .button-popup:before {
    border: 1px solid;
    background-color: var(--colorBg);
    rotate: 45deg;
    width: 12px;
    height: 12px;
    z-index: -1;
  }
  #browser .button-popup.button-popup-pos-below:before {
    top: -6px;
  }
  #browser .button-popup.button-popup-pos-above:before {
    bottom: -6px;
  }
  #browser .button-popup.button-popup-pos-left:before {
    right: -6px;
  }
  #browser .button-popup.button-popup-pos-right:before {
    left: -6px;
  }
  #browser.tabs-left .tabbar-wrapper .workspace-popup,
  #browser.tabs-right .tabbar-wrapper .workspace-popup,
  #browser .startpage .startpage-navigation {
    border-bottom: 1px solid;
  }
  #browser .SiteInfoButton,
  #browser .toolbar-insideinput button,
  #browser .toolbar-insideinput .BookmarkButton {
    border: 0;
  }
  #browser > footer .toolbar-statusbar {
    border-top: 1px solid;
  }
  #browser > footer:after {
    content: unset !important;
  }
  #browser #tabs-container .tab.active,
  #browser #tabs-subcontainer .tab.active {
    border: var(--border-width) solid;
    --border-width: 1px;
  }
  .address-top#browser #tabs-container.top,
  .address-top#browser #tabs-subcontainer.top {
    border-bottom: var(--border-width) solid;
  }
  #browser #tabs-container.top .tab,
  #browser #tabs-subcontainer.top .tab {
    border: var(--border-width) solid;
    border-width: var(--border-width) var(--border-width) 0;
    margin-bottom: auto;
  }
  #browser #tabs-container.bottom,
  #browser #tabs-subcontainer.bottom {
    border-top: 0.5px solid;
  }
  #browser #tabs-container.bottom .tab,
  #browser #tabs-subcontainer.bottom .tab {
    border: var(--border-width) solid;
    border-width: 0 var(--border-width) var(--border-width);
    margin-top: auto;
  }
  #browser #tabs-subcontainer.right,
  .tabs-left#browser .tabbar-wrapper {
    border-right: 0.5px solid;
  }
  #browser #tabs-subcontainer.left,
  .tabs-right#browser .tabbar-wrapper {
    border-left: 0.5px solid;
  }
  #mail_detail,
  .panel-group,
  #panels-container.icons:not(:has(.SlideBar)),
  .toolbar-mainbar {
    border-color: #000 !important;
  }
}
.tab-dropzone {
  display: flex;
  position: absolute;
  inset: 0;
  padding: 18px;
  z-index: 6;
}
.tab-dropzone h1 {
  position: absolute;
  inset: 18px;
  display: grid;
  place-items: center;
  text-align: center;
  text-shadow: 0 2px 3px #000c;
  border-radius: var(--radius);
  color: var(--colorHighlightFg);
  pointer-events: none;
  margin: 0;
  background-color: color-mix(in srgb, var(--colorHighlightBg), transparent 10%);
  will-change: inset;
  transition: inset 64ms ease-in-out;
  backdrop-filter: var(--backgroundBlur);
}
.tab-dropzone.movingtile.dropcenter h1 {
  inset: 20%;
  background-color: color-mix(in srgb, var(--colorFg), transparent 20%);
}
.theme-dark .tab-dropzone.movingtile.dropcenter h1 {
  color: var(--colorFg);
  background-color: color-mix(in srgb, var(--colorBg), transparent 20%);
}
.tab-dropzone.dropleft > h1 {
  inset: 18px 70% 18px 18px;
}
.tab-dropzone.dropright > h1 {
  inset: 18px 18px 18px 70%;
}
.tab-dropzone.droptop > h1 {
  inset: 18px 18px 70% 18px;
}
.tab-dropzone.dropbottom > h1 {
  inset: 70% 18px 18px 18px;
}
.tab-dropzone.dropcenter:not(.movingtile) > h1 {
  inset: 20%;
  color: var(--colorFg);
  background-color: color-mix(in srgb, var(--colorBg), transparent 20%);
  border: 2px solid var(--colorFg);
  text-shadow: none;
}
.tab-dropzone .dropzone-title {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  gap: 12px;
}
.tab-dropzone .dropzone-icon {
  fill: currentColor;
}
.dateInput {
  position: relative;
  display: inline-flex;
}
.dateInput .dateInputHidden {
  position: absolute;
  inset: 0;
  background-color: transparent;
  padding-right: 0;
}
.dateInput .dateInputHidden[type=date] {
  background-image: none;
}
.dateInput .dateInputHidden::-webkit-datetime-edit-fields-wrapper {
  display: inline-flex;
  visibility: hidden;
}
.dateInput .dateInputHidden[disabled] {
  background-image: none;
}
.dateInput .dateInputHidden[type=time]:before,
.dateInput .dateInputHidden[type=time]:after {
  display: none;
}
.dateInput.time .dateInputHidden {
  width: 100%;
  box-shadow: none;
}
.dateInput .dateInputMinute,
.dateInput .dateInputHour,
.dateInput .dateInputAmPm,
.dateInput .dateInputDay,
.dateInput .dateInputMonth,
.dateInput .dateInputYear {
  padding: 0;
  border: none;
  height: 26px;
  padding: 0 1px 0 0;
  margin: 0 !important;
  min-width: unset;
  box-shadow: unset;
  background-color: transparent;
  font-variant-numeric: tabular-nums;
  width: 2.2ch;
  cursor: default;
  text-align: right;
  flex: 1;
}
.dateInput .dateInputMinute.dateInputHiddenChild,
.dateInput .dateInputHour.dateInputHiddenChild,
.dateInput .dateInputAmPm.dateInputHiddenChild,
.dateInput .dateInputDay.dateInputHiddenChild,
.dateInput .dateInputMonth.dateInputHiddenChild,
.dateInput .dateInputYear.dateInputHiddenChild {
  visibility: hidden;
}
.dateInput .dateInputMinute:focus,
.dateInput .dateInputHour:focus,
.dateInput .dateInputAmPm:focus,
.dateInput .dateInputDay:focus,
.dateInput .dateInputMonth:focus,
.dateInput .dateInputYear:focus {
  outline: none;
}
.dateInput .dateInputMinute::-webkit-inner-spin-button,
.dateInput .dateInputHour::-webkit-inner-spin-button,
.dateInput .dateInputAmPm::-webkit-inner-spin-button,
.dateInput .dateInputDay::-webkit-inner-spin-button,
.dateInput .dateInputMonth::-webkit-inner-spin-button,
.dateInput .dateInputYear::-webkit-inner-spin-button {
  visibility: hidden;
}
.dateInput .dateInputAmPm {
  width: 3ex;
}
#browser[lang~='ja'] .dateInput .dateInputAmPm {
  width: 4ex;
}
.dateInput .dateInputYear {
  width: 4.2ch;
  flex: 1.5;
}
.dateInput .dateInputSeparator {
  white-space: pre;
}
.vivaldi-settings .setting-single label .dateInput .dateInputSeparator {
  flex: 0 0 auto;
}
.dateInput .placeholder {
  position: absolute;
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  padding-left: 6px;
  z-index: 1;
}
.dateInput .placeholder .dateInputHiddenChild {
  visibility: hidden;
}
.dateInput .arrowDown {
  pointer-events: none;
  display: flex;
  flex: 0 0 16px;
  justify-content: center;
  align-items: center;
  padding-right: 3px;
  z-index: 1;
}
.dateInput .arrowDown svg {
  width: 16px;
  height: 16px;
}
.dateInput input[disabled] ~ .dateInputSeparator {
  opacity: 0.5;
}
.dateInput .faux {
  flex: 1;
  position: relative;
  margin: 1px 1px 0 6px;
  display: flex;
  align-items: baseline;
}
.MarkdownRender {
  margin: 0 0 6px 12px;
  padding-right: 6px;
  overflow: auto;
  scrollbar-gutter: stable;
  user-select: text;
  color: var(--colorFg);
}
.MarkdownRender *:focus-visible {
  outline: 2px solid var(--colorHighlightBgAlpha);
  outline-offset: -1px;
}
.MarkdownRender p,
.MarkdownRender ul,
.MarkdownRender ol,
.MarkdownRender dl,
.MarkdownRender table,
.MarkdownRender pre,
.MarkdownRender blockquote {
  margin-top: 0;
  margin-bottom: 0.67rem;
}
.MarkdownRender ul p:last-child,
.MarkdownRender ul p:only-child {
  margin-bottom: 0;
}
.MarkdownRender h1,
.MarkdownRender h2,
.MarkdownRender h3,
.MarkdownRender h4,
.MarkdownRender h5,
.MarkdownRender h6 {
  margin-top: 0.67em;
  margin-bottom: 0.67em;
}
.MarkdownRender h1,
.MarkdownRender h2,
.MarkdownRender h3,
.MarkdownRender h4,
.MarkdownRender h5,
.MarkdownRender strong,
.MarkdownRender b,
.MarkdownRender dt {
  font-weight: 600;
}
.MarkdownRender h1 {
  font-size: 1.4em;
}
.MarkdownRender h2 {
  font-size: 1.2em;
}
.MarkdownRender h3 {
  font-size: 1.1em;
}
.MarkdownRender h4 {
  font-size: 1em;
}
.MarkdownRender hr {
  border-bottom: 1px solid var(--colorBorder);
}
.MarkdownRender img {
  max-width: 100%;
  height: auto;
}
.MarkdownRender code,
.MarkdownRender pre {
  font-family: monospace;
}
.MarkdownRender code {
  font-weight: 500;
  border-radius: var(--radiusRounded);
}
.MarkdownRender pre code {
  font-weight: inherit;
  background-color: transparent;
  box-shadow: none;
  border-radius: 0;
  white-space: pre-wrap;
  font-size: inherit;
}
.MarkdownRender pre {
  word-break: break-word;
  word-wrap: break-word;
  overflow-x: auto;
  padding: 0.2em;
  margin-right: 1ex;
}
.MarkdownRender blockquote {
  margin: 0 3px 0.67em 0;
  padding: 10px 12px 1px;
  border-left: 3px solid var(--colorFgAlpha);
  background-color: var(--colorBg);
}
.MarkdownRender blockquote blockquote {
  margin-bottom: -1px;
}
.MarkdownRender ul,
.MarkdownRender ol,
.MarkdownRender dd {
  -webkit-padding-start: 1.67em;
}
.MarkdownRender ul {
  list-style: disc;
}
.MarkdownRender li ul,
.MarkdownRender li ol {
  margin-bottom: 0;
}
.MarkdownRender li > p ~ ul,
.MarkdownRender li > p ~ ol {
  margin-bottom: 0.67em;
}
.MarkdownRender li.todo {
  list-style: none;
}
.MarkdownRender li.todo input[type='checkbox'] {
  margin: 0 6px 4px -21px;
}
.MarkdownRender li.todo input[type='checkbox']:disabled {
  opacity: 1;
}
.MarkdownRender li.todo > ul {
  margin-bottom: 0;
}
.MarkdownRender table {
  border-collapse: collapse;
}
.MarkdownRender table th {
  background-color: var(--colorBg);
}
.MarkdownRender table th,
.MarkdownRender table td {
  margin: 0;
  padding: 3px;
  border: 1px solid var(--colorBorder);
  vertical-align: baseline;
}
.hljs {
  display: block;
  overflow-x: auto;
}
.hljs-comment,
.hljs-emphasis {
  font-style: italic;
}
.hljs-section,
.hljs-strong,
.hljs-tag {
  font-weight: bold;
}
pre {
  background-color: rgba(0, 0, 0, 0.04);
}
/* Gray */
.hljs-comment {
  color: rgba(0, 0, 0, 0.65);
}
/* Pink */
.hljs,
.hljs-subst {
  color: #a42c9a;
}
/* Red */
.hljs-deletion,
.hljs-formula,
.hljs-keyword,
.hljs-link,
.hljs-selector-tag {
  color: #a81d22;
}
/* Blue */
.hljs-built_in,
.hljs-emphasis,
.hljs-name,
.hljs-quote,
.hljs-strong,
.hljs-title,
.hljs-variable {
  color: #156a8a;
}
/* Yellow */
.hljs-attr,
.hljs-params,
.hljs-template-tag,
.hljs-type {
  color: #b57614;
}
/* Purple */
.hljs-builtin-name,
.hljs-doctag,
.hljs-link_label,
.hljs-literal,
.hljs-number {
  color: #712f8c;
}
/* Orange */
.hljs-code,
.hljs-meta,
.hljs-regexp,
.hljs-selector-id,
.hljs-template-variable {
  color: #af5900;
}
/* Green */
.hljs-addition,
.hljs-meta-string,
.hljs-section,
.hljs-selector-attr,
.hljs-selector-class,
.hljs-string,
.hljs-symbol {
  color: #4f7509;
}
/* Aqua */
.hljs-attribute,
.hljs-bullet,
.hljs-class,
.hljs-function,
.hljs-function .hljs-keyword,
.hljs-meta-keyword,
.hljs-selector-pseudo,
.hljs-tag {
  color: #189ab6;
}
.theme-dark {
  /* Gray */
  /* Red */
  /* Blue */
  /* Yellow */
  /* Purple */
  /* Orange */
  /* Green */
  /* Aqua */
}
.theme-dark pre {
  background-color: rgba(255, 255, 255, 0.04);
}
.theme-dark .hljs-comment {
  color: rgba(255, 255, 255, 0.65);
}
.theme-dark .hljs,
.theme-dark .hljs-subst {
  color: #c268ba;
}
.theme-dark .hljs-deletion,
.theme-dark .hljs-formula,
.theme-dark .hljs-keyword,
.theme-dark .hljs-link,
.theme-dark .hljs-selector-tag {
  color: #fc4349;
}
.theme-dark .hljs-built_in,
.theme-dark .hljs-emphasis,
.theme-dark .hljs-name,
.theme-dark .hljs-quote,
.theme-dark .hljs-strong,
.theme-dark .hljs-title,
.theme-dark .hljs-variable {
  color: #1787b1;
}
.theme-dark .hljs-attr,
.theme-dark .hljs-params,
.theme-dark .hljs-template-tag,
.theme-dark .hljs-type {
  color: #fecb58;
}
.theme-dark .hljs-builtin-name,
.theme-dark .hljs-doctag,
.theme-dark .hljs-link_label,
.theme-dark .hljs-literal,
.theme-dark .hljs-number {
  color: #8166c7;
}
.theme-dark .hljs-code,
.theme-dark .hljs-meta,
.theme-dark .hljs-regexp,
.theme-dark .hljs-selector-id,
.theme-dark .hljs-template-variable {
  color: #f27e18;
}
.theme-dark .hljs-addition,
.theme-dark .hljs-meta-string,
.theme-dark .hljs-section,
.theme-dark .hljs-selector-attr,
.theme-dark .hljs-selector-class,
.theme-dark .hljs-string,
.theme-dark .hljs-symbol {
  color: #aff40b;
}
.theme-dark .hljs-attribute,
.theme-dark .hljs-bullet,
.theme-dark .hljs-class,
.theme-dark .hljs-function,
.theme-dark .hljs-function .hljs-keyword,
.theme-dark .hljs-meta-keyword,
.theme-dark .hljs-selector-pseudo,
.theme-dark .hljs-tag {
  color: #73d5e9;
}
@media not (prefers-contrast: more) {
  ::-webkit-scrollbar {
    width: var(--scrollbarWidth);
    height: var(--scrollbarWidth);
  }
}
::-webkit-scrollbar-track {
  background-color: var(--colorBg);
}
#browser.mac ::-webkit-scrollbar-track,
#browser.simple-scrollbar ::-webkit-scrollbar-track {
  background-color: transparent;
}
::-webkit-scrollbar-thumb {
  border: solid transparent;
  background-clip: padding-box;
  background-color: var(--colorBorderIntense);
}
::-webkit-scrollbar-thumb:hover,
::-webkit-scrollbar-thumb:active {
  background-color: var(--colorFgFadedMore);
}
.theme-dark ::-webkit-scrollbar-thumb {
  background-color: var(--colorFgFadedMost);
}
.theme-dark ::-webkit-scrollbar-thumb:hover,
.theme-dark ::-webkit-scrollbar-thumb:active {
  background-color: var(--colorFg);
}
#browser:not(.mac, .simple-scrollbar) ::-webkit-scrollbar-thumb:vertical {
  border-top-width: 0;
  border-bottom-width: 0;
}
#browser:not(.mac, .simple-scrollbar) ::-webkit-scrollbar-thumb:horizontal {
  border-left-width: 0;
  border-right-width: 0;
}
#browser.mac ::-webkit-scrollbar-thumb,
#browser.simple-scrollbar ::-webkit-scrollbar-thumb {
  border-width: 3px;
  border-radius: calc(var(--scrollbarWidth) / 2);
}
::-webkit-scrollbar-button {
  display: flex;
  align-items: center;
  justify-content: center;
  width: var(--scrollbarWidth);
  height: var(--scrollbarWidth);
  background-position: center;
  border: none;
}
#browser.mac ::-webkit-scrollbar-button,
#browser.simple-scrollbar ::-webkit-scrollbar-button {
  display: none;
}
::-webkit-scrollbar-button:vertical:decrement {
  background-image: linear-gradient(315deg, transparent 13px, var(--colorBg) 13px), linear-gradient(45deg, transparent 13px, var(--colorBg) 13px), linear-gradient(180deg, var(--colorFgFaded) 10px, var(--colorBg) 10px);
}
::-webkit-scrollbar-button:vertical:decrement:hover {
  background-image: linear-gradient(315deg, transparent 13px, var(--colorBg) 13px), linear-gradient(45deg, transparent 13px, var(--colorBg) 13px), linear-gradient(180deg, var(--colorFgIntense) 10px, var(--colorBg) 10px);
}
::-webkit-scrollbar-button:vertical:decrement:active {
  background-image: linear-gradient(315deg, transparent 13px, var(--colorBgDark) 13px), linear-gradient(45deg, transparent 13px, var(--colorBgDark) 13px), linear-gradient(180deg, var(--colorFgIntense) 10px, var(--colorBgDark) 10px);
}
::-webkit-scrollbar-button:vertical:increment {
  background-image: linear-gradient(135deg, transparent 13px, var(--colorBg) 13px), linear-gradient(225deg, transparent 13px, var(--colorBg) 13px), linear-gradient(0deg, var(--colorFgFaded) 10px, var(--colorBg) 10px);
}
::-webkit-scrollbar-button:vertical:increment:hover {
  background-image: linear-gradient(135deg, transparent 13px, var(--colorBg) 13px), linear-gradient(225deg, transparent 13px, var(--colorBg) 13px), linear-gradient(0deg, var(--colorFgIntense) 10px, var(--colorBg) 10px);
}
::-webkit-scrollbar-button:vertical:increment:active {
  background-image: linear-gradient(135deg, transparent 13px, var(--colorBgDark) 13px), linear-gradient(225deg, transparent 13px, var(--colorBgDark) 13px), linear-gradient(0deg, var(--colorFgIntense) 10px, var(--colorBgDark) 10px);
}
::-webkit-scrollbar-button:horizontal:decrement {
  background-image: linear-gradient(225deg, transparent 13px, var(--colorBg) 13px), linear-gradient(315deg, transparent 13px, var(--colorBg) 13px), linear-gradient(90deg, var(--colorFgFaded) 10px, var(--colorBg) 10px);
}
::-webkit-scrollbar-button:horizontal:decrement:hover {
  background-image: linear-gradient(225deg, transparent 13px, var(--colorBg) 13px), linear-gradient(315deg, transparent 13px, var(--colorBg) 13px), linear-gradient(90deg, var(--colorFgIntense) 10px, var(--colorBg) 10px);
}
::-webkit-scrollbar-button:horizontal:decrement:active {
  background-image: linear-gradient(225deg, transparent 13px, var(--colorBgDark) 13px), linear-gradient(315deg, transparent 13px, var(--colorBgDark) 13px), linear-gradient(90deg, var(--colorFgIntense) 10px, var(--colorBgDark) 10px);
}
::-webkit-scrollbar-button:horizontal:increment {
  background-image: linear-gradient(135deg, transparent 13px, var(--colorBg) 13px), linear-gradient(45deg, transparent 13px, var(--colorBg) 13px), linear-gradient(270deg, var(--colorFgFaded) 10px, var(--colorBg) 10px);
}
::-webkit-scrollbar-button:horizontal:increment:hover {
  background-image: linear-gradient(135deg, transparent 13px, var(--colorBg) 13px), linear-gradient(45deg, transparent 13px, var(--colorBg) 13px), linear-gradient(270deg, var(--colorFgIntense) 10px, var(--colorBg) 10px);
}
::-webkit-scrollbar-button:horizontal:increment:active {
  background-image: linear-gradient(135deg, transparent 13px, var(--colorBgDark) 13px), linear-gradient(45deg, transparent 13px, var(--colorBgDark) 13px), linear-gradient(270deg, var(--colorFgIntense) 10px, var(--colorBgDark) 10px);
}
::-webkit-scrollbar-corner,
::-webkit-scrollbar-resize {
  background-color: var(--colorBg);
}
#browser.mac ::-webkit-scrollbar-corner,
#browser.mac ::-webkit-scrollbar-resize,
#browser.simple-scrollbar ::-webkit-scrollbar-corner,
#browser.simple-scrollbar ::-webkit-scrollbar-resize {
  background-color: transparent;
}
#browser.mac textarea::-webkit-scrollbar-track:vertical,
#browser.mac select::-webkit-scrollbar-track:vertical,
#browser.mac .sortable-list > .master-items::-webkit-scrollbar-track:vertical,
#browser.mac .keyboardShortcutsWrapper > div::-webkit-scrollbar-track:vertical,
#browser.mac .menu-commands > .vivaldi-tree > div::-webkit-scrollbar-track:vertical,
#browser.simple-scrollbar textarea::-webkit-scrollbar-track:vertical,
#browser.simple-scrollbar select::-webkit-scrollbar-track:vertical,
#browser.simple-scrollbar .sortable-list > .master-items::-webkit-scrollbar-track:vertical,
#browser.simple-scrollbar .keyboardShortcutsWrapper > div::-webkit-scrollbar-track:vertical,
#browser.simple-scrollbar .menu-commands > .vivaldi-tree > div::-webkit-scrollbar-track:vertical {
  margin-top: calc(var(--radius) / 3);
}
textarea::-webkit-scrollbar-button:vertical:decrement,
select::-webkit-scrollbar-button:vertical:decrement,
.sortable-list > .master-items::-webkit-scrollbar-button:vertical:decrement,
.keyboardShortcutsWrapper > div::-webkit-scrollbar-button:vertical:decrement,
.menu-commands > .vivaldi-tree > div::-webkit-scrollbar-button:vertical:decrement {
  border-top-right-radius: var(--radius);
}
#browser.mac textarea::-webkit-scrollbar-track:vertical,
#browser.mac select::-webkit-scrollbar-track:vertical,
#browser.mac .keyboardShortcutsWrapper > div::-webkit-scrollbar-track:vertical,
#browser.mac .menu-commands > .vivaldi-tree > div::-webkit-scrollbar-track:vertical,
#browser.simple-scrollbar textarea::-webkit-scrollbar-track:vertical,
#browser.simple-scrollbar select::-webkit-scrollbar-track:vertical,
#browser.simple-scrollbar .keyboardShortcutsWrapper > div::-webkit-scrollbar-track:vertical,
#browser.simple-scrollbar .menu-commands > .vivaldi-tree > div::-webkit-scrollbar-track:vertical {
  margin-bottom: calc(var(--radius) / 3);
}
textarea::-webkit-scrollbar-button:vertical:increment,
select::-webkit-scrollbar-button:vertical:increment,
.keyboardShortcutsWrapper > div::-webkit-scrollbar-button:vertical:increment,
.menu-commands > .vivaldi-tree > div::-webkit-scrollbar-button:vertical:increment {
  border-bottom-right-radius: var(--radius);
}
#browser.mac textarea::-webkit-scrollbar-track:horizontal,
#browser.mac select::-webkit-scrollbar-track:horizontal,
#browser.simple-scrollbar textarea::-webkit-scrollbar-track:horizontal,
#browser.simple-scrollbar select::-webkit-scrollbar-track:horizontal {
  margin-left: calc(var(--radius) / 3);
  margin-right: calc(var(--radius) / 3);
}
textarea::-webkit-scrollbar-button:horizontal:decrement,
select::-webkit-scrollbar-button:horizontal:decrement {
  border-bottom-left-radius: var(--radius);
}
#browser.mac textarea::-webkit-scrollbar-track:horizontal,
#browser.mac select::-webkit-scrollbar-track:horizontal,
#browser.simple-scrollbar textarea::-webkit-scrollbar-track:horizontal,
#browser.simple-scrollbar select::-webkit-scrollbar-track:horizontal {
  margin-left: calc(var(--radius) / 3);
  margin-right: calc(var(--radius) / 3);
}
textarea::-webkit-scrollbar-button:horizontal:increment,
select::-webkit-scrollbar-button:horizontal:increment {
  border-bottom-right-radius: var(--radius);
}
#app #browser .slim-scrollbar::-webkit-scrollbar-corner,
#app #browser .slim-scrollbar::-webkit-scrollbar-resize,
#app #browser .slim-scrollbar::-webkit-scrollbar-track {
  background-color: transparent;
}
#app #browser .slim-scrollbar::-webkit-scrollbar {
  width: 4px;
  height: 4px;
}
#app #browser .slim-scrollbar::-webkit-scrollbar-thumb {
  border-width: 1px;
}
#app #browser .slim-scrollbar::-webkit-scrollbar-button {
  display: none;
}
#browser.mac.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tab-strip::-webkit-scrollbar-thumb,
#browser.simple-scrollbar.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tab-strip::-webkit-scrollbar-thumb,
#browser.mac .welcome-content::-webkit-scrollbar-thumb,
#browser.simple-scrollbar .welcome-content::-webkit-scrollbar-thumb,
#browser.mac .sdwrapper::-webkit-scrollbar-thumb,
#browser.simple-scrollbar .sdwrapper::-webkit-scrollbar-thumb {
  background-color: var(--colorImageCenterFgAlpha, var(--colorFgFadedMost));
}
#browser.mac.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tab-strip::-webkit-scrollbar-thumb:hover,
#browser.simple-scrollbar.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tab-strip::-webkit-scrollbar-thumb:hover,
#browser.mac .welcome-content::-webkit-scrollbar-thumb:hover,
#browser.simple-scrollbar .welcome-content::-webkit-scrollbar-thumb:hover,
#browser.mac .sdwrapper::-webkit-scrollbar-thumb:hover,
#browser.simple-scrollbar .sdwrapper::-webkit-scrollbar-thumb:hover,
#browser.mac.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tab-strip::-webkit-scrollbar-thumb:active,
#browser.simple-scrollbar.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tab-strip::-webkit-scrollbar-thumb:active,
#browser.mac .welcome-content::-webkit-scrollbar-thumb:active,
#browser.simple-scrollbar .welcome-content::-webkit-scrollbar-thumb:active,
#browser.mac .sdwrapper::-webkit-scrollbar-thumb:active,
#browser.simple-scrollbar .sdwrapper::-webkit-scrollbar-thumb:active {
  background-color: var(--colorImageCenterFg, var(--colorFgFaded));
}
#webview-container {
  --mosaicPadding: 4px;
  --n2: calc(var(--mosaicPadding) / 2);
  --n6: calc(var(--n2) * 3);
  --bgCoverShadow: 0 0 0 var(--mosaicPadding) var(--colorBgDarker);
}
#browser:not(.inner, .narrow-tiling) #webpage-stack > .tiled.visible {
  padding: var(--n2);
  box-shadow: inset 0 0 0 var(--n6) var(--colorBgDarker);
}
#browser:not(.inner, .narrow-tiling) .webpageview.tiled {
  border-radius: var(--radiusCap);
}
#browser.narrow-tiling #webview-container {
  --mosaicPadding: 0px;
}
#browser.narrow-tiling #webview-container .tiled {
  overflow: unset;
  box-shadow: 0 0 0 1px var(--colorBgDarker);
}
.webpageview.tiled {
  overflow: hidden;
}
.webpageview.tiled:not(.active) {
  box-shadow: 0 0 0 2px var(--colorBorder), var(--bgCoverShadow);
}
.hasfocus .webpageview.tiled.active {
  box-shadow: 0 0 0 2px var(--colorHighlightBgFaded), var(--bgCoverShadow);
}
.isblurred .webpageview.tiled.active {
  box-shadow: 0 0 0 2px var(--colorBorderIntense), var(--bgCoverShadow);
}
#browser .tiled {
  position: absolute;
  inset: 0;
}
#browser .tiled:not(.webpageview) {
  display: grid;
}
#browser .tile {
  position: relative;
  border-radius: 0;
}
#browser .tile:has(> .tiled.webpageview) {
  border: var(--mosaicPadding) solid var(--colorBgDarker);
}
:not(.narrow-tiling)#browser .tile > .SlideBar--FullWidth {
  bottom: -7px;
}
:not(.narrow-tiling)#browser .tile > .SlideBar--FullHeight {
  right: -7px;
}
#browser.fullscreen.inner #webview-container {
  --mosaicPadding: 0px;
}
#browser.fullscreen.inner .tiled {
  display: flex;
}
#browser.fullscreen.inner .tiled .tile:has(.webpageview.active) {
  position: unset;
}
#browser.fullscreen.inner .tiled .tile:not(:has(.webpageview.active)) {
  visibility: hidden;
  z-index: -1;
}
#browser.fullscreen.inner .tiled {
  border-radius: unset;
}
#browser.fullscreen.inner .tiled .SlideBar {
  display: none;
}
.mosaic-tile {
  display: flex;
  flex-wrap: nowrap;
  align-items: center;
  padding: 6px 6px 6px 12px;
  color: var(--colorFgFaded);
  background-color: var(--colorBgDarker);
}
.webpageview.active .mosaic-tile {
  background-color: var(--colorHighlightBgFaded);
  color: var(--colorFg);
  background-color: var(--colorBg);
}
.mosaic-tile .follower-badge {
  background-color: var(--colorFg);
  color: var(--colorBg);
  font-size: 11.5px;
  padding: 2px 9px;
  border-radius: var(--radius);
  margin-right: 9px;
}
.mosaic-tile .title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  flex: 1;
}
.mosaic-tile .controls svg {
  height: 16px;
  width: 16px;
}
.mosaic-tile .controls button {
  color: var(--colorFg);
  background-color: var(--colorBgDarker);
}
.mosaic-tile .controls button,
.mosaic-tile .controls span {
  display: flex;
  padding: 0;
  align-items: center;
}
/* How to make a toolbar
 * The foundation is a .toolbar. To use default styling, apply use the classes
 * ".toolbar.toolbar-default". By default toolbars will flex to adapt to the
 * size available, but not wrap. To make the toolbar wrap, use the classes
 * ".toolbar.toolbar-wrap". Buttons can be grouped in ".toolbar-group", which
 * will cause them to be displayed without spacing and also prevents wrapping.
 */
:root {
  --ToolbarItemGap: 0;
}
button svg,
button img {
  pointer-events: none;
}
.toolbar,
.toolbar-group,
.toolbar-wrap {
  display: flex;
  gap: var(--ToolbarItemGap);
}
.toolbar-wrap {
  flex-wrap: wrap;
}
.toolbar-center {
  justify-content: center;
}
.full-width {
  width: 100%;
}
.toolbar-back-navigation {
  display: flex;
  justify-content: center;
  align-items: center;
}
.toolbar-back-navigation h1 {
  width: 100%;
}
.toolbar-back-navigation .button-toolbar {
  margin: -12px 6px 0 0;
}
.toolbar {
  align-items: center;
  min-width: 0;
  flex: 0 0 auto;
}
.toolbar:focus-visible {
  outline: none;
}
.toolbar.toolbar-space {
  --ToolbarItemGap: 6px;
}
.toolbar.toolbar-center {
  justify-content: center;
}
.toolbar > .button-toolbar.button-on,
.toolbar > .toolbar-group .button-toolbar.button-on,
.toolbar > .button-toolbar > .button-on.button-on,
.toolbar > .toolbar-group .button-toolbar > .button-on.button-on {
  fill: var(--colorHighlightBg);
  color: var(--colorHighlightBg);
}
.toolbar > .button-textonly {
  position: relative;
  display: flex;
  align-items: center;
}
.toolbar > .button-toolbar,
.toolbar > .toolbar-wrap > .button-toolbar,
.toolbar > .toolbar-group > .button-toolbar,
.toolbar > input {
  flex: 0 1 auto;
}
.toolbar > input[type=range] {
  flex: 1 1 30px;
  width: 100%;
  min-width: 0;
  max-width: 130px;
  align-self: center;
}
.toolbar > div:empty {
  display: none;
}
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar > button[draggable='true'],
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar > button[draggable='true'],
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar[draggable='true'] > button,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar[draggable='true'] > button {
  box-shadow: none;
  background: transparent;
}
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar > button[draggable='true'] > img,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar > button[draggable='true'] > img,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar[draggable='true'] > button > img,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar[draggable='true'] > button > img,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar > button[draggable='true'] > svg,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar > button[draggable='true'] > svg,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar[draggable='true'] > button > svg,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar[draggable='true'] > button > svg {
  opacity: 1;
  fill: var(--colorFgFaded);
  background-color: var(--colorBgDarker);
  box-shadow: inset 0 0 0 1px var(--colorBorder);
}
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar > button[draggable='true'].button-dragged > img,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar > button[draggable='true'].button-dragged > img,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar[draggable='true'] > button.button-dragged > img,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar[draggable='true'] > button.button-dragged > img,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar > button[draggable='true'].button-dragged > svg,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar > button[draggable='true'].button-dragged > svg,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar[draggable='true'] > button.button-dragged > svg,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar[draggable='true'] > button.button-dragged > svg {
  fill: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  box-shadow: 0 0 0 1px var(--colorHighlightBg);
  transform: none;
}
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar > button[draggable='true'].button-dragged .button-badge,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar > button[draggable='true'].button-dragged .button-badge,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .button-toolbar[draggable='true'] > button.button-dragged .button-badge,
.is-dragging-button.is-dragging-button .toolbar-droptarget.toolbar > .toolbar-group > .button-toolbar[draggable='true'] > button.button-dragged .button-badge {
  opacity: 0;
}
.toolbar > .left-gap {
  margin-left: auto;
}
#app .toolbar .toolbar-spacer > button,
#app .toolbar .toolbar-spacer-flexible > button,
#app .toolbar .toolbar-spacer-panel > button,
#app .toolbar .button-toolbar.toolbar-divider > button {
  min-width: auto;
}
#app .toolbar .toolbar-spacer > button:hover,
#app .toolbar .toolbar-spacer-flexible > button:hover,
#app .toolbar .toolbar-spacer-panel > button:hover,
#app .toolbar .button-toolbar.toolbar-divider > button:hover {
  background-color: transparent;
}
#app #browser.toolbar-edit-mode .toolbar .toolbar-spacer-flexible {
  flex-basis: auto !important;
}
.toolbar .toolbar-spacer-panel,
.toolbar .toolbar-spacer {
  flex: 0 1 34px;
}
.toolbar .toolbar-spacer-flexible {
  flex: 1;
  overflow: hidden;
}
.toolbar .toolbar-spacer-panel {
  min-width: 34px;
  overflow: hidden;
}
.toolbar .button-toolbar.toolbar-divider {
  justify-content: center;
}
.toolbar .button-toolbar.toolbar-divider button,
.toolbar .button-toolbar.toolbar-divider svg {
  min-width: 16px;
  max-width: 16px;
}
.toolbar-vertical.toolbar .button-toolbar.toolbar-divider {
  max-height: 16px;
}
.toolbar-vertical.toolbar .button-toolbar.toolbar-divider svg {
  rotate: 90deg;
}
.toolbar.toolbar-align-top {
  align-items: flex-start;
}
#browser .Supporter-Badge {
  position: absolute;
  width: 12px;
  height: auto;
  bottom: 1px;
  right: 1px;
  filter: drop-shadow(1px 0px 0 var(--badgeBorder)) drop-shadow(-1px 0px 0 var(--badgeBorder)) drop-shadow(0px 1px 0 var(--badgeBorder)) drop-shadow(0px -1px 0 var(--badgeBorder)) !important;
}
.density-on#browser .Supporter-Badge {
  bottom: 0;
  right: 0;
}
#browser:not(.toolbar-edit-mode) .button-toolbar.toolbar-spacer span,
#browser:not(.toolbar-edit-mode) .button-toolbar.toolbar-spacer-panel span,
#browser:not(.toolbar-edit-mode) .button-toolbar.toolbar-spacer-flexible span {
  display: none;
}
.toolbar-dropdown-container {
  position: relative;
}
.toolbar-mainbar > .toolbar-dropdown-container > .button-toolbar button {
  border: none;
}
.drop-down-menu svg {
  width: 16px;
  height: 16px;
  stroke: none;
}
.toolbar-group {
  display: flex;
  white-space: nowrap;
  --ToolbarItemGap: 0;
  align-items: center;
}
.toolbar-group > hr {
  margin: 0;
  border-style: solid;
  border-left-width: 0;
  border-color: var(--colorBorder);
  align-self: normal;
}
.toolbar-group > .button-toolbar + .button-toolbar > button,
.toolbar-group hr + .button-toolbar > button {
  border-left-width: 0;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.toolbar-group > .button-toolbar:not(:last-child) > button,
.toolbar-group hr:not(:last-child) > button {
  border-right-width: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.toolbar-default .toolbar-group > .button-toolbar:last-child .button-toolbar-menu-indicator,
.toolbar-default .toolbar-group hr:last-child .button-toolbar-menu-indicator {
  border-top-right-radius: var(--radiusHalf);
  border-bottom-right-radius: var(--radiusHalf);
}
.toolbar-group.equal-width {
  display: grid;
  grid-auto-flow: column;
  grid-auto-columns: minmax(0, 1fr);
}
.button-toolbar {
  --popupWidth: 200px;
  --popupLeftOffset: 0px;
  --strokeWidth: 1.5px;
  display: flex;
  align-items: center;
  position: relative;
}
.button-toolbar:active svg,
.button-toolbar:active img {
  transform: scale(0.9);
  transition-duration: 0s;
}
.button-toolbar > button {
  display: flex;
  flex: 1 1 100%;
  gap: 6px;
  min-width: 0;
  background-color: transparent;
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
  color: inherit;
  text-align: left;
  height: 28px;
  padding: 0 6px;
  align-items: center;
  justify-content: center;
  white-space: nowrap;
  fill: currentColor;
  --buttonHover: 0;
}
.button-toolbar > button:disabled svg,
.button-toolbar > button:disabled img {
  transition: opacity 200ms;
  opacity: 0.65;
}
.toolbar-edit-mode .button-toolbar > button:disabled svg,
.toolbar-edit-mode .button-toolbar > button:disabled img {
  opacity: 1;
}
.button-toolbar > button:hover {
  --buttonHover: 1;
}
.button-toolbar > button:hover,
.button-toolbar > button:active {
  color: var(--colorFg);
  background-color: var(--colorBgDark);
}
.tabs-bottom.color-behind-tabs-on #footer .button-toolbar > button:hover,
.tabs-bottom.color-behind-tabs-on #footer .button-toolbar > button:active {
  background-color: var(--colorAccentBgAlpha);
}
.Dashboard-Widgets .transparent .button-toolbar > button:hover,
.Dashboard-Widgets .transparent .button-toolbar > button:active {
  color: var(--colorImageCenterFg, var(--colorWindowFg));
  background-color: var(--colorBgAlphaHeavier);
}
.button-toolbar > button.active:active {
  background-color: rgba(0, 0, 0, 0.12);
}
.button-toolbar > button:focus-visible {
  outline-offset: -2px;
}
.button-rotateimage.button-toolbar > button svg,
.button-rotateimage.button-toolbar > button img {
  transform: rotate(90deg);
}
.button-circularimage.button-toolbar > button svg,
.button-circularimage.button-toolbar > button img {
  border-radius: var(--radiusRound);
}
.button-cropimage.button-toolbar > button svg,
.button-cropimage.button-toolbar > button img {
  object-fit: cover;
}
.button-disabled-preview.button-toolbar > button svg,
.button-disabled-preview.button-toolbar > button img {
  opacity: 0.65;
  transition-duration: 0s;
}
.button-toolbar > button.button-textonly {
  width: 100%;
  padding-right: 6px;
  padding-left: 6px;
}
.button-toolbar > button.button-textonly .button-title {
  text-align: center;
}
.button-transparent.button-toolbar > button {
  background: transparent;
  border: 1px solid transparent;
}
.button-transparent.button-toolbar > button:active {
  background-color: var(--colorBg);
}
.toolbar-statusbar > .button-toolbar > button,
.toolbar-statusbar .drag-area > .button-toolbar > button,
.toolbar-statusbar .toolbar-extensions .button-toolbar > button,
.toolbar-statusbar .page-zoom-controls .button-toolbar > button {
  min-width: 32px;
  padding: unset;
  background-image: unset;
  border: none;
  gap: 3px;
}
.toolbar-statusbar > .button-toolbar > button:has(.override),
.toolbar-statusbar .drag-area > .button-toolbar > button:has(.override),
.toolbar-statusbar .toolbar-extensions .button-toolbar > button:has(.override),
.toolbar-statusbar .page-zoom-controls .button-toolbar > button:has(.override) {
  padding-left: 2px;
  padding-right: 2px;
}
.toolbar-statusbar > .button-toolbar > button:active,
.toolbar-statusbar .drag-area > .button-toolbar > button:active,
.toolbar-statusbar .toolbar-extensions .button-toolbar > button:active,
.toolbar-statusbar .page-zoom-controls .button-toolbar > button:active,
.toolbar-statusbar > .button-toolbar > button.button-pressed,
.toolbar-statusbar .drag-area > .button-toolbar > button.button-pressed,
.toolbar-statusbar .toolbar-extensions .button-toolbar > button.button-pressed,
.toolbar-statusbar .page-zoom-controls .button-toolbar > button.button-pressed {
  background-color: var(--colorBgDark);
}
.tabs-bottom.color-behind-tabs-on .toolbar-statusbar > .button-toolbar > button:active,
.tabs-bottom.color-behind-tabs-on .toolbar-statusbar .drag-area > .button-toolbar > button:active,
.tabs-bottom.color-behind-tabs-on .toolbar-statusbar .toolbar-extensions .button-toolbar > button:active,
.tabs-bottom.color-behind-tabs-on .toolbar-statusbar .page-zoom-controls .button-toolbar > button:active,
.tabs-bottom.color-behind-tabs-on .toolbar-statusbar > .button-toolbar > button.button-pressed,
.tabs-bottom.color-behind-tabs-on .toolbar-statusbar .drag-area > .button-toolbar > button.button-pressed,
.tabs-bottom.color-behind-tabs-on .toolbar-statusbar .toolbar-extensions .button-toolbar > button.button-pressed,
.tabs-bottom.color-behind-tabs-on .toolbar-statusbar .page-zoom-controls .button-toolbar > button.button-pressed {
  background-color: var(--colorAccentBgDark);
}
.toolbar-panel > .button-toolbar > button,
.toolbar-panel .drag-area > .button-toolbar > button,
.toolbar-panel .toolbar-extensions .button-toolbar > button,
.toolbar-panel .page-zoom-controls .button-toolbar > button {
  border: none;
  box-shadow: unset;
  gap: 3px;
  padding: 0 3px;
}
.toolbar-panel > .button-toolbar > button.button-pressed,
.toolbar-panel .drag-area > .button-toolbar > button.button-pressed,
.toolbar-panel .toolbar-extensions .button-toolbar > button.button-pressed,
.toolbar-panel .page-zoom-controls .button-toolbar > button.button-pressed {
  background-color: var(--colorBgDarker);
}
.toolbar-panel > .button-toolbar > button .button-badge,
.toolbar-panel .drag-area > .button-toolbar > button .button-badge,
.toolbar-panel .toolbar-extensions .button-toolbar > button .button-badge,
.toolbar-panel .page-zoom-controls .button-toolbar > button .button-badge {
  right: 2px;
}
.button-toolbar > button.has-menu {
  min-width: 40px;
}
.button-toolbar > button:disabled {
  border-color: var(--colorBorderDisabled);
}
.button-toolbar > button:disabled > .button-title,
.button-toolbar > button:disabled > .button-toolbar-menu-indicator {
  pointer-events: none;
}
.button-toolbar > button:focus-visible {
  position: relative;
  z-index: 1;
}
.toolbar-statusbar .button-toolbar > button:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
}
.button-toolbar > button > span {
  display: flex;
  flex: 1;
  justify-content: center;
  align-items: center;
  pointer-events: none;
}
.button-toolbar > button > span.button-toolbar-menu-indicator {
  pointer-events: all;
  flex: 0 0 16px;
  margin: 0;
  padding-right: 3px;
  align-items: center;
  height: 34px;
  border-top-right-radius: inherit;
  border-bottom-right-radius: inherit;
}
.toolbar-default .button-toolbar > button > span.button-toolbar-menu-indicator {
  height: 26px;
  margin-left: 3px;
}
.toolbar-medium .button-toolbar > button > span.button-toolbar-menu-indicator {
  height: 28px;
}
.button-toolbar > button > span.button-toolbar-menu-indicator:hover {
  background-color: var(--colorBgDarker);
}
.color-behind-tabs-off .toolbar-mainbar .button-toolbar > button > span.button-toolbar-menu-indicator:hover {
  background-color: rgba(0, 0, 0, 0.1);
}
.button-toolbar > button > span.button-toolbar-menu-indicator svg,
.button-toolbar > button > span.button-toolbar-menu-indicator img {
  width: 13px;
  flex-basis: 10px;
}
.button-toolbar > button > span.panel-audio {
  position: absolute;
  right: -5px;
  top: -5px;
}
.button-toolbar > button > span.panel-audio .audioicon {
  pointer-events: all;
  width: 26px;
  height: 26px;
  background: #fff;
  border-radius: var(--radiusRound);
  transition: transform 100ms ease-in;
  transform: scale(0.5) translateZ(0);
  transform-origin: center center;
}
.button-toolbar > button > span.panel-audio .audioicon:hover {
  transform: scale(0.625);
}
.button-toolbar > button[draggable='false'] .panel-audio {
  pointer-events: none;
}
.button-toolbar > button > .button-badge {
  flex: 0;
}
.toolbar-statusbar .button-toolbar > button > .button-badge {
  position: static;
  right: unset;
  flex: 0 0 auto;
  margin-right: 6px;
}
.toolbar-large .button-toolbar > button > .button-badge {
  top: 2.5px;
  right: 2px;
}
.button-toolbar > button > .button-title + .button-badge {
  left: unset;
  right: 0;
}
.button-toolbar > button > .button-title {
  pointer-events: none;
  display: inline-block;
  flex: 0 1 auto;
  min-width: 3ch;
  margin: 0 9px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.button-toolbar > button .button-icon + .button-title {
  min-width: 0;
  margin-left: 0;
}
.button-toolbar > button .button-title:not(:last-child) {
  margin-right: 0;
}
.button-toolbar > button:disabled {
  opacity: unset;
}
.button-toolbar div.progress {
  --progress-height: 4px;
  contain: strict;
  contain-intrinsic-height: var(--progress-height);
  contain-intrinsic-width: 50% 16px;
  pointer-events: none;
  max-width: 16px;
  width: 50%;
  height: var(--progress-height);
  background-color: var(--colorFgFaded);
  border: 1px solid var(--colorFg);
  border-radius: 2px;
  position: absolute;
  left: 9px;
  top: 21px;
}
.toolbar-statusbar .button-toolbar div.progress {
  left: 7px;
  top: 16px;
  border-radius: 0;
}
.button-toolbar div.progress div.loaded {
  background-color: var(--colorBgLightIntense);
  height: 2px;
  width: 0%;
  min-width: 1px;
}
.button-toolbar.button-menu > button:not(.button-textonly) {
  padding: 0 0 0 3px;
  gap: 3px;
}
.button-toolbar.button-menu > button:not(.button-textonly) .button-title {
  flex-basis: inherit;
  justify-content: flex-start;
}
.toolbar-default .button-toolbar.button-menu > button:not(.button-textonly) {
  padding: 0 0 0 6px;
}
.button-toolbar.button-menu .button-toolbar-menu-indicator svg {
  width: 16px;
  height: 5px;
  margin: 0;
}
.button-toolbar.button-menu .button-toolbar-menu-indicator.disabled {
  opacity: 0.65;
  pointer-events: none;
}
.button-toolbar.btn-toolbar-spinner span:first-of-type {
  animation: spin 1s infinite linear;
}
img.button-icon,
.button-icon svg {
  pointer-events: none;
  display: inline-flex;
  width: 16px;
  height: 16px;
  transform-origin: center;
}
.toolbar-large .button-toolbar .button-icon:not(.favicon),
.toolbar-large .button-toolbar .button-icon svg,
.toolbar-medium .button-toolbar .button-icon:not(.favicon),
.toolbar-medium .button-toolbar .button-icon svg {
  width: 28px;
  height: 28px;
}
.toolbar-divider.button-toolbar .button-icon:not(.favicon),
.toolbar-divider.button-toolbar .button-icon svg,
.toolbar-insideinput .button-toolbar .button-icon:not(.favicon),
.toolbar-insideinput .button-toolbar .button-icon svg {
  width: 16px;
  height: 16px;
}
.button-icon.favicon {
  pointer-events: none;
}
.button-toolbar span.buttontext {
  margin: auto 12px auto 0;
  min-height: 20px;
}
.button-toolbar span.buttontext-noicon {
  margin: auto 12px auto 12px;
}
.button-toolbar.edit.active svg {
  fill: var(--colorHighlightBg);
}
.button-toolbar.is-allowing .permission-denied {
  opacity: 0;
}
.button-dragover-top,
.button-dragover-bottom,
.button-dragover-left,
.button-dragover-right {
  --dropIndicator: 26px;
  position: relative;
}
.button-dragover-top:after,
.button-dragover-bottom:after,
.button-dragover-left:after,
.button-dragover-right:after {
  position: absolute;
  content: '';
  z-index: 1;
  pointer-events: none;
  background: var(--colorHighlightBg);
  box-shadow: 0 0 3px var(--colorHighlightBg);
  border-radius: var(--radius);
}
.toolbar .button-dragover-top:after,
.toolbar .button-dragover-bottom:after,
.toolbar .button-dragover-left:after,
.toolbar .button-dragover-right:after,
.toolbar-medium .button-dragover-top:after,
.toolbar-medium .button-dragover-bottom:after,
.toolbar-medium .button-dragover-left:after,
.toolbar-medium .button-dragover-right:after {
  --dropIndicator: 20px;
}
.color-behind-tabs-off .toolbar-mainbar .button-dragover-top:after,
.color-behind-tabs-off .toolbar-mainbar .button-dragover-bottom:after,
.color-behind-tabs-off .toolbar-mainbar .button-dragover-left:after,
.color-behind-tabs-off .toolbar-mainbar .button-dragover-right:after {
  background: var(--colorHighlightFgAlpha);
  box-shadow: 0 0 3px var(--colorHighlightFgAlpha);
}
.toolbar:not(.toolbar-vertical) .button-dragover-left:after {
  min-height: var(--dropIndicator);
  width: 2px;
  left: -1px;
}
.toolbar:not(.toolbar-vertical) .button-dragover-right:after {
  min-height: var(--dropIndicator);
  width: 2px;
  right: -1px;
}
.toolbar.toolbar-vertical .button-dragover-top:after {
  min-width: var(--dropIndicator);
  height: 2px;
  top: -1px;
}
.toolbar.toolbar-vertical .button-dragover-bottom:after {
  min-width: var(--dropIndicator);
  height: 2px;
  bottom: -1px;
}
.toolbar .button-group {
  display: flex;
  position: relative;
}
.toolbar .button-group > button {
  margin-right: 0;
}
.toolbar .button-group > button.active {
  background-color: var(--colorAccentBgDark);
}
.color-behind-tabs-on .toolbar .button-group > button {
  border-color: var(--colorBorder);
}
.color-behind-tabs-on .toolbar .button-group > button.active {
  background-color: var(--colorBgDarker);
}
.toolbar .button-group > button:first-of-type {
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
}
.toolbar .button-group > button:last-of-type {
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.button-circularimage.button-cropimage.profile-popup button {
  flex-shrink: 0;
}
.toolbar-large .button-circularimage.button-cropimage.profile-popup button img {
  height: 28px;
  width: 28px;
}
.toolbar-medium .button-circularimage.button-cropimage.profile-popup button img {
  height: 22px;
  width: 22px;
}
.toolbar-mainbar .profile-popup:not(:empty),
.toolbar-mainbar .toolbar-extensions:not(:empty),
.toolbar-vertical .profile-popup:not(:empty),
.toolbar-vertical .toolbar-extensions:not(:empty) {
  min-width: 34px;
}
.toolbar-statusbar .profile-popup:not(:empty),
.toolbar-statusbar .toolbar-extensions:not(:empty) {
  min-width: 32px;
}
#app .address-top-off .toolbar-addressbar,
#app .address-bottom-off .toolbar-addressbar {
  padding: 0;
  border: unset;
}
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) > .vivaldi,
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) > .vivaldi,
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) > .drag-area,
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) > .drag-area,
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) > .toolbar-extensions,
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) > .toolbar-extensions,
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) > .page-zoom-controls,
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) > .page-zoom-controls,
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) > .button-toolbar,
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) > .button-toolbar,
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) > .button-textonly:not(.UrlBar-AddressField, .UrlBar-SearchField),
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) > .button-textonly:not(.UrlBar-AddressField, .UrlBar-SearchField),
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) > .UrlBar-PrivateWindowIndicator,
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) > .UrlBar-PrivateWindowIndicator,
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) > .SearchField:not(.UrlBar-SearchField),
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) > .SearchField:not(.UrlBar-SearchField) {
  display: none;
}
#app .mail-bar-off .toolbar-mailbar {
  padding: 0;
  border: unset;
}
#app .mail-bar-off .toolbar-mailbar > .vivaldi,
#app .mail-bar-off .toolbar-mailbar > .drag-area,
#app .mail-bar-off .toolbar-mailbar > .toolbar-extensions,
#app .mail-bar-off .toolbar-mailbar > .page-zoom-controls,
#app .mail-bar-off .toolbar-mailbar > .button-toolbar,
#app .mail-bar-off .toolbar-mailbar > .button-textonly:not(.UrlBar-AddressField, .UrlBar-SearchField),
#app .mail-bar-off .toolbar-mailbar > .UrlBar-PrivateWindowIndicator,
#app .mail-bar-off .toolbar-mailbar > .SearchField:not(.UrlBar-SearchField) {
  display: none;
}
#panels-container.right .toolbar.toolbar-vertical .UrlBar-AddressField.button-dragover-top:after,
#panels-container.right .toolbar.toolbar-vertical .SearchField.button-dragover-top:after,
.toolbar.toolbar-vertical .menu.button-dragover-top:after,
.toolbar.toolbar-vertical .button-menu.button-dragover-top:after,
.toolbar.toolbar-vertical .OmniDropdown .workspace-popup.button-dragover-top:after,
.toolbar.toolbar-vertical .page-zoom-controls.button-dragover-top:after,
#panels-container.right .toolbar.toolbar-vertical .UrlBar-AddressField .button-dragover-top:after,
#panels-container.right .toolbar.toolbar-vertical .SearchField .button-dragover-top:after,
.toolbar.toolbar-vertical .menu .button-dragover-top:after,
.toolbar.toolbar-vertical .button-menu .button-dragover-top:after,
.toolbar.toolbar-vertical .OmniDropdown .workspace-popup .button-dragover-top:after,
.toolbar.toolbar-vertical .page-zoom-controls .button-dragover-top:after {
  min-width: 2px;
  height: 26px;
  left: -1px;
  top: 3px;
  bottom: unset;
}
#panels-container.right .toolbar.toolbar-vertical .UrlBar-AddressField.button-dragover-bottom:after,
#panels-container.right .toolbar.toolbar-vertical .SearchField.button-dragover-bottom:after,
.toolbar.toolbar-vertical .menu.button-dragover-bottom:after,
.toolbar.toolbar-vertical .button-menu.button-dragover-bottom:after,
.toolbar.toolbar-vertical .OmniDropdown .workspace-popup.button-dragover-bottom:after,
.toolbar.toolbar-vertical .page-zoom-controls.button-dragover-bottom:after,
#panels-container.right .toolbar.toolbar-vertical .UrlBar-AddressField .button-dragover-bottom:after,
#panels-container.right .toolbar.toolbar-vertical .SearchField .button-dragover-bottom:after,
.toolbar.toolbar-vertical .menu .button-dragover-bottom:after,
.toolbar.toolbar-vertical .button-menu .button-dragover-bottom:after,
.toolbar.toolbar-vertical .OmniDropdown .workspace-popup .button-dragover-bottom:after,
.toolbar.toolbar-vertical .page-zoom-controls .button-dragover-bottom:after {
  min-width: 2px;
  height: 26px;
  right: -1px;
  top: 3px;
  bottom: unset;
}
#panels-container.left .toolbar.toolbar-vertical .UrlBar-AddressField.button-dragover-top:after,
#panels-container.left .toolbar.toolbar-vertical .SearchField.button-dragover-top:after,
.toolbar.toolbar-vertical .ClockButton.button-dragover-top:after,
#panels-container.left .toolbar.toolbar-vertical .UrlBar-AddressField .button-dragover-top:after,
#panels-container.left .toolbar.toolbar-vertical .SearchField .button-dragover-top:after,
.toolbar.toolbar-vertical .ClockButton .button-dragover-top:after {
  min-width: 2px;
  height: 26px;
  right: -1px;
  top: 3px;
  bottom: unset;
}
#panels-container.left .toolbar.toolbar-vertical .UrlBar-AddressField.button-dragover-bottom:after,
#panels-container.left .toolbar.toolbar-vertical .SearchField.button-dragover-bottom:after,
.toolbar.toolbar-vertical .ClockButton.button-dragover-bottom:after,
#panels-container.left .toolbar.toolbar-vertical .UrlBar-AddressField .button-dragover-bottom:after,
#panels-container.left .toolbar.toolbar-vertical .SearchField .button-dragover-bottom:after,
.toolbar.toolbar-vertical .ClockButton .button-dragover-bottom:after {
  min-width: 2px;
  height: 26px;
  left: -1px;
  top: 3px;
  bottom: unset;
}
#browser .toolbar-mainbar:not(.toolbar-wrap) .button-toolbar:not(:last-of-type),
#browser .toolbar-statusbar .button-toolbar:not(:last-of-type) {
  transition: padding 200ms linear;
}
.density-on#browser .toolbar-mainbar:not(.toolbar-wrap) .button-toolbar:not(:last-of-type),
.density-on#browser .toolbar-statusbar .button-toolbar:not(:last-of-type) {
  padding-right: var(--densityGap);
}
#browser .toolbar-vertical .button-toolbar:not(:last-of-type) {
  transition: border-radius 100ms linear, box-shadow 100ms linear, padding 200ms linear, height 200ms linear;
}
.density-on#browser .toolbar-vertical .button-toolbar:not(:last-of-type) {
  padding-bottom: var(--densityGap);
  height: calc(34px + var(--densityGap));
}
#switch > .toolbar.toolbar-vertical {
  flex: 1;
  flex-direction: column;
  height: auto;
}
#switch > .toolbar.toolbar-vertical .button-toolbar > button {
  width: 34px;
  height: 34px;
}
#browser:not(.density-on) #switch > .toolbar.toolbar-vertical .button-toolbar > button:hover {
  background-color: transparent;
}
#switch > .toolbar.toolbar-vertical .toolbar.toolbar-insideinput .button-toolbar > button {
  width: 16px;
  height: 16px;
}
#switch > .toolbar.toolbar-vertical > .toolbar-spacer-flexible > button {
  height: 100%;
}
#switch > .toolbar.toolbar-vertical > .toolbar-divider > button {
  height: 16px;
  min-width: 34px;
}
#panels-container #switch > .toolbar.toolbar-vertical .pageload-ticker {
  display: none;
}
#switch > .toolbar.toolbar-vertical .ClockButton {
  transform-origin: center;
  overflow: hidden;
}
#switch > .toolbar.toolbar-vertical .ClockButton > button {
  flex: 0 0 auto;
  width: auto;
}
#switch > .toolbar.toolbar-vertical .ClockButton > button span {
  flex: 0 0 auto;
}
#switch > .toolbar.toolbar-vertical .page-zoom-controls {
  margin: 0 0 calc(150px - 34px);
  width: 150px;
  justify-content: space-around;
  font-size: 11.5px;
}
#switch > .toolbar.toolbar-vertical .page-zoom-controls input[type=range] {
  flex: 1;
  min-width: 0;
}
#switch > .toolbar.toolbar-vertical .button-menu {
  --view-width: 60px;
  width: var(--view-width);
  margin: 0 0 calc(var(--view-width) - 34px);
  transform: rotate(90deg) translateX(calc((var(--view-width) - 34px) / 2));
  transform-origin: center;
}
#switch > .toolbar.toolbar-vertical .button-menu.label {
  --view-width: 110px;
}
#switch > .toolbar.toolbar-vertical .button-menu > button {
  width: var(--view-width);
  padding: 0;
}
#switch > .toolbar.toolbar-vertical .button-menu .button-toolbar-menu-indicator {
  flex: 0 0 24px;
}
#panels-container.left #switch > .toolbar.toolbar-vertical .UrlBar-AddressField {
  transform: rotate(270deg) translateX(-136px);
  width: 300px;
  margin: 0 0 272px;
  padding: 0 6px;
  flex: 0 0 auto;
}
#panels-container.left #switch > .toolbar.toolbar-vertical .OmniDropdown {
  rotate: 90deg;
  transform: translateY(-300px);
  transform-origin: 0 0;
  max-height: 300px;
  min-width: 450px;
}
#panels-container.left #switch > .toolbar.toolbar-vertical .SearchField,
#panels-container.left #switch > .toolbar.toolbar-vertical .UrlBar-SearchField {
  transform: rotate(270deg) translateX(-86px);
  width: 200px;
  margin: 0 0 172px !important;
  padding: 0 6px;
  flex: 0 0 auto !important;
}
#panels-container.left #switch > .toolbar.toolbar-vertical .SearchField .OmniDropdown,
#panels-container.left #switch > .toolbar.toolbar-vertical .UrlBar-SearchField .OmniDropdown {
  max-height: 200px;
  transform: translateY(-200px);
}
#panels-container.left #switch > .toolbar.toolbar-vertical .ClockButton {
  transform: rotate(270deg) translateX(calc(-50% + (34px / 2)));
  margin: 0 0 calc(var(--clockWidth) - 34px);
  width: var(--clockWidth);
}
#panels-container.left #switch > .toolbar.toolbar-vertical .ClockButton .button-icon {
  rotate: 90deg;
}
#panels-container.left #switch > .toolbar.toolbar-vertical .page-zoom-controls {
  transform: rotate(270deg) translate(calc(-50% + (34px / 2)), 0);
}
#panels-container.left #switch > .toolbar.toolbar-vertical .button-menu .button-icon {
  rotate: 270deg;
}
#panels-container.left #switch > .toolbar.toolbar-vertical .button-menu .button-title,
#panels-container.left #switch > .toolbar.toolbar-vertical .button-menu .button-toolbar-menu-indicator {
  rotate: 180deg;
}
#panels-container.left #switch > .toolbar.toolbar-vertical .menu {
  rotate: 90deg;
  transform: translateY(-200px);
  transform-origin: 0 0;
}
#panels-container.left #switch > .toolbar.toolbar-vertical .menu ul {
  max-height: 200px;
  max-width: 200px;
}
#panels-container.left #switch > .toolbar.toolbar-vertical .menu:hover,
#panels-container.left #switch > .toolbar.toolbar-vertical .button-menu:hover,
#panels-container.left #switch > .toolbar.toolbar-vertical .ClockButton:hover,
#panels-container.left #switch > .toolbar.toolbar-vertical .OmniDropdown:hover {
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: 0;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .UrlBar-AddressField {
  transform: rotate(90deg) translateX(-136px);
  width: 300px;
  margin: 272px 0 0;
  padding: 0 6px;
  flex: 0 0 auto;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .OmniDropdown {
  rotate: 270deg;
  transform: translateX(-450px);
  transform-origin: 0 0;
  max-height: 300px;
  min-width: 450px;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .SearchField,
#panels-container.right #switch > .toolbar.toolbar-vertical .UrlBar-SearchField {
  transform: rotate(90deg) translateX(-86px);
  width: 200px;
  margin: 172px 0 0 !important;
  padding: 0 6px;
  flex: 0 0 auto !important;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .SearchField .OmniDropdown,
#panels-container.right #switch > .toolbar.toolbar-vertical .UrlBar-SearchField .OmniDropdown {
  transform: translateX(-200px);
  max-height: 200px;
  max-width: 200px;
  min-width: 200px;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .ClockButton {
  transform: rotate(90deg) translateX(calc(50% - (34px / 2)));
  margin: 0 0 calc(var(--clockWidth) - 34px);
  width: var(--clockWidth);
}
#panels-container.right #switch > .toolbar.toolbar-vertical .ClockButton .button-icon {
  rotate: 270deg;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .page-zoom-controls {
  transform: rotate(90deg) translateX(calc(50% - (34px / 2)));
}
#panels-container.right #switch > .toolbar.toolbar-vertical .button-menu .button-icon {
  rotate: 270deg;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .menu {
  rotate: 270deg;
  transform: translateX(-200px);
  transform-origin: 0 0;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .menu ul {
  max-height: 200px;
  max-width: 200px;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .menu:hover,
#panels-container.right #switch > .toolbar.toolbar-vertical .button-menu:hover,
#panels-container.right #switch > .toolbar.toolbar-vertical .ClockButton:hover,
#panels-container.right #switch > .toolbar.toolbar-vertical .OmniDropdown:hover {
  border-top-left-radius: 0;
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
#switch > .toolbar.toolbar-vertical .StatusInfo {
  width: 200px;
  max-height: 34px;
  margin-bottom: calc(200px - 34px);
  transform: translateX(calc(-50% + (34px / 2)));
  rotate: 270deg;
}
#panels-container.right #switch > .toolbar.toolbar-vertical .StatusInfo {
  rotate: 90deg;
  transform: translateX(calc(50% - (34px / 2)));
}
#switch > .toolbar.toolbar-vertical button[name='UpdateButton'] .button-title {
  display: none;
}
#app #panels:has(.menu),
#app #panels-container:not(.resizing, .switcher):has(.menu),
#app #switch:has(.menu),
#app #panels:has(.OmniDropdown),
#app #panels-container:not(.resizing, .switcher):has(.OmniDropdown),
#app #switch:has(.OmniDropdown),
#app #panels:has(.addwebpanelcallout),
#app #panels-container:not(.resizing, .switcher):has(.addwebpanelcallout),
#app #switch:has(.addwebpanelcallout) {
  overflow: visible;
  contain: unset;
  z-index: 6;
}
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) .auto-hide-wrapper.show:not(:has(.OmniDropdown)) .toolbar .toolbar-spacer,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).address-top .toolbar-mainbar .toolbar-spacer,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-mainbar .toolbar-spacer,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-statusbar .toolbar-spacer,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.top .toolbar:not(.expecting-drop) .toolbar-spacer,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.bottom .toolbar:not(.expecting-drop) .toolbar-spacer,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) .auto-hide-wrapper.show:not(:has(.OmniDropdown)) .toolbar .toolbar-spacer-flexible,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).address-top .toolbar-mainbar .toolbar-spacer-flexible,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-mainbar .toolbar-spacer-flexible,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-statusbar .toolbar-spacer-flexible,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.top .toolbar:not(.expecting-drop) .toolbar-spacer-flexible,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.bottom .toolbar:not(.expecting-drop) .toolbar-spacer-flexible,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) .auto-hide-wrapper.show:not(:has(.OmniDropdown)) .toolbar .toolbar-spacer-panel,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).address-top .toolbar-mainbar .toolbar-spacer-panel,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-mainbar .toolbar-spacer-panel,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-statusbar .toolbar-spacer-panel,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.top .toolbar:not(.expecting-drop) .toolbar-spacer-panel,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.bottom .toolbar:not(.expecting-drop) .toolbar-spacer-panel,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) .auto-hide-wrapper.show:not(:has(.OmniDropdown)) .toolbar .toolbar-divider,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).address-top .toolbar-mainbar .toolbar-divider,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-mainbar .toolbar-divider,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-statusbar .toolbar-divider,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.top .toolbar:not(.expecting-drop) .toolbar-divider,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.bottom .toolbar:not(.expecting-drop) .toolbar-divider,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) .auto-hide-wrapper.show:not(:has(.OmniDropdown)) .toolbar .toolbar-spacer button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).address-top .toolbar-mainbar .toolbar-spacer button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-mainbar .toolbar-spacer button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-statusbar .toolbar-spacer button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.top .toolbar:not(.expecting-drop) .toolbar-spacer button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.bottom .toolbar:not(.expecting-drop) .toolbar-spacer button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) .auto-hide-wrapper.show:not(:has(.OmniDropdown)) .toolbar .toolbar-spacer-flexible button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).address-top .toolbar-mainbar .toolbar-spacer-flexible button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-mainbar .toolbar-spacer-flexible button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-statusbar .toolbar-spacer-flexible button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.top .toolbar:not(.expecting-drop) .toolbar-spacer-flexible button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.bottom .toolbar:not(.expecting-drop) .toolbar-spacer-flexible button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) .auto-hide-wrapper.show:not(:has(.OmniDropdown)) .toolbar .toolbar-spacer-panel button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).address-top .toolbar-mainbar .toolbar-spacer-panel button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-mainbar .toolbar-spacer-panel button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-statusbar .toolbar-spacer-panel button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.top .toolbar:not(.expecting-drop) .toolbar-spacer-panel button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.bottom .toolbar:not(.expecting-drop) .toolbar-spacer-panel button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) .auto-hide-wrapper.show:not(:has(.OmniDropdown)) .toolbar .toolbar-divider button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).address-top .toolbar-mainbar .toolbar-divider button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-mainbar .toolbar-divider button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)).mac .toolbar-statusbar .toolbar-divider button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.top .toolbar:not(.expecting-drop) .toolbar-divider button,
#app #browser:not(.toolbar-edit-mode, .fullscreen):not(:has(.toolbar.dragging, #capture-area)) #tabs-tabbar-container.bottom .toolbar:not(.expecting-drop) .toolbar-divider button {
  -webkit-app-region: drag;
}
.toolbar-separator {
  width: 1px;
  border-left: 1px solid var(--colorBgDarker);
}
.theme-dark .toolbar-separator {
  border-color: var(--colorBgLighter);
}
.toolbar-default {
  --ToolbarItemGap: 6px;
}
.toolbar-default .button-toolbar {
  min-width: 28px;
}
.toolbar-default .button-toolbar.button-narrow {
  min-width: 16px;
}
.toolbar-default .button-toolbar.button-narrow > button {
  min-width: 19.6px;
}
.toolbar-default .button-toolbar > button:disabled {
  background-color: var(--colorBgAlpha);
  border-color: var(--colorBorder);
}
.toolbar-default .button-toolbar button svg {
  pointer-events: none;
}
.toolbar-default .button-toolbar > button:enabled {
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgDark));
}
.toolbar-default .button-toolbar > button:enabled:hover:not(:disabled) {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
.toolbar-default .button-toolbar > button:enabled:active:not(:disabled) {
  background-image: linear-gradient(var(--colorBgDark), var(--colorBgDark));
}
.toolbar-default .button-toolbar > button:enabled.button-pressed {
  background-image: linear-gradient(var(--colorBgDarker), var(--colorBgDark));
}
.toolbar-default .button-toolbar > button:enabled.button-pressed:active {
  background-image: linear-gradient(var(--colorBgDarker), var(--colorBgDarker));
}
.toolbar-pills {
  --ToolbarItemGap: 6px;
  justify-content: center;
  padding: 6px;
}
.master-detail .toolbar-pills {
  justify-content: start;
  padding-left: 0;
}
.toolbar-pills > .button-toolbar > button {
  color: var(--colorHighlightBg);
  border-color: var(--colorHighlightBg);
  background-color: transparent;
  background-image: none;
  box-shadow: unset;
  font-weight: 500;
  padding-right: 12px;
  padding-left: 12px;
}
.toolbar-pills > .button-toolbar > button.button-pressed,
.toolbar-pills > .button-toolbar > button:active {
  border-color: var(--colorHighlightBg);
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
}
.toolbar-pills > .button-toolbar > button.button-pressed:active {
  border-color: var(--colorHighlightBgDark);
  background-color: var(--colorHighlightBgDark);
}
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput {
  --ToolbarItemGap: 1px;
}
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > button,
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .toolbar-group > .button-toolbar > button {
  fill: currentColor;
  height: 22px;
  width: 22px;
  padding-left: 0;
  padding-right: unset;
  border-radius: var(--radiusRoundedLess);
}
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > button:not(:hover):not(:active):not(:focus):not(.button-pressed),
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .toolbar-group > .button-toolbar > button:not(:hover):not(:active):not(:focus):not(.button-pressed) {
  border-color: transparent;
  background-color: transparent;
}
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > button:not(:hover):not(:active):not(:focus),
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .toolbar-group > .button-toolbar > button:not(:hover):not(:active):not(:focus) {
  background-image: unset;
}
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > button.button-pressed,
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .toolbar-group > .button-toolbar > button.button-pressed {
  background-color: var(--colorBg);
  border-color: var(--colorBgDarker);
  color: var(--colorFg);
}
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > button.button-pressed:not(:active),
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .toolbar-group > .button-toolbar > button.button-pressed:not(:active) {
  box-shadow: unset;
}
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > button.button-pressed:active,
.toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .toolbar-group > .button-toolbar > button.button-pressed:active {
  background-color: var(--colorBgFaded);
}
.address-top-off .toolbar-mailbar > .toolbar,
.address-bottom-off .toolbar-mailbar > .toolbar {
  display: none;
}
.toolbar-mailbar .send-button,
.toolbar-mailbar .attachment-button {
  padding-right: 9px;
}
.color-behind-tabs-off .toolbar-mailbar .MailSearchField {
  color: var(--colorAccentFg);
  background: var(--colorAccentBg);
  border-color: var(--colorAccentBgDark);
}
.mainbar {
  color: var(--colorFg);
  background-color: var(--colorBg);
  --badgeBorder: var(--colorBg);
  border: 0 var(--colorBorder) solid;
}
.color-behind-tabs-off .mainbar {
  color: var(--colorAccentFg);
  background: var(--colorAccentBg);
  --badgeBorder: var(--colorAccentBg);
  border-color: var(--colorAccentBgDark);
}
.address-top .mainbar:has(.toolbar-addressbar.toolbar-visible),
.mail-bar-top .mainbar:has(.toolbar-mailbar.toolbar-visible) {
  border-bottom-width: 1px;
}
.address-bottom .mainbar:has(.toolbar-addressbar.toolbar-visible),
.mail-bar-bottom .mainbar:has(.toolbar-mailbar.toolbar-visible) {
  padding: var(--densityGap);
  border-top-width: 1px;
}
.auto-hide-wrapper .mainbar {
  border: 0;
}
.mainbar .toolbar-mainbar {
  height: 34px;
  position: relative;
  z-index: 4;
}
.mainbar .toolbar-mainbar.toolbar-required {
  height: 0;
}
.mainbar .toolbar-mainbar.update {
  justify-content: flex-end;
}
.mainbar .toolbar-mainbar.update .button-toolbar {
  top: 30px;
  right: 6px;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 0 6px rgba(0, 0, 0, 0.2);
  background-color: var(--colorBg);
  border-radius: var(--radius);
}
.mainbar .toolbar-mainbar.update .button-toolbar button {
  padding: 0 6px;
}
.address-bottom .mainbar .toolbar-mainbar.update .button-toolbar,
.address-bottom-off .mainbar .toolbar-mainbar.update .button-toolbar {
  top: unset;
  bottom: 30px;
}
.toolbar-mainbar .drag-area,
.toolbar-mainbar .toolbar-extensions,
.toolbar-mainbar .page-zoom-controls,
.toolbar-mainbar {
  --ToolbarItemGap: 0;
  flex-shrink: 0;
}
.address-top-off .toolbar-mainbar .drag-area,
.address-top-off .toolbar-mainbar .toolbar-extensions,
.address-top-off .toolbar-mainbar .page-zoom-controls,
.address-top-off .toolbar-mainbar,
.address-bottom-off .toolbar-mainbar .drag-area,
.address-bottom-off .toolbar-mainbar .toolbar-extensions,
.address-bottom-off .toolbar-mainbar .page-zoom-controls,
.address-bottom-off .toolbar-mainbar {
  z-index: 5;
}
.color-behind-tabs-off .toolbar-mainbar .drag-area > .button-toolbar > button:hover,
.color-behind-tabs-off .toolbar-mainbar .toolbar-extensions > .button-toolbar > button:hover,
.color-behind-tabs-off .toolbar-mainbar .page-zoom-controls > .button-toolbar > button:hover,
.color-behind-tabs-off .toolbar-mainbar > .button-toolbar > button:hover {
  background-color: var(--colorAccentBgDark);
}
.color-behind-tabs-off .toolbar-mainbar .drag-area > .button-toolbar > button:active,
.color-behind-tabs-off .toolbar-mainbar .toolbar-extensions > .button-toolbar > button:active,
.color-behind-tabs-off .toolbar-mainbar .page-zoom-controls > .button-toolbar > button:active,
.color-behind-tabs-off .toolbar-mainbar > .button-toolbar > button:active {
  background-color: var(--colorAccentBgDarker);
}
.color-behind-tabs-off .toolbar-mainbar .drag-area > .button-toolbar > button.button-pressed,
.color-behind-tabs-off .toolbar-mainbar .toolbar-extensions > .button-toolbar > button.button-pressed,
.color-behind-tabs-off .toolbar-mainbar .page-zoom-controls > .button-toolbar > button.button-pressed,
.color-behind-tabs-off .toolbar-mainbar > .button-toolbar > button.button-pressed {
  background-image: linear-gradient(var(--colorAccentBgDarker), var(--colorAccentBgDark));
}
.color-behind-tabs-off .toolbar-mainbar .drag-area > .button-toolbar > button.button-pressed:active,
.color-behind-tabs-off .toolbar-mainbar .toolbar-extensions > .button-toolbar > button.button-pressed:active,
.color-behind-tabs-off .toolbar-mainbar .page-zoom-controls > .button-toolbar > button.button-pressed:active,
.color-behind-tabs-off .toolbar-mainbar > .button-toolbar > button.button-pressed:active {
  background-image: linear-gradient(var(--colorAccentBgDarker), var(--colorAccentBgDarker));
}
.color-behind-tabs-on .toolbar-mainbar .drag-area > .button-toolbar > button.button-pressed,
.color-behind-tabs-on .toolbar-mainbar .toolbar-extensions > .button-toolbar > button.button-pressed,
.color-behind-tabs-on .toolbar-mainbar .page-zoom-controls > .button-toolbar > button.button-pressed,
.color-behind-tabs-on .toolbar-mainbar > .button-toolbar > button.button-pressed {
  background-image: linear-gradient(var(--colorBgDarker), var(--colorBgDark));
}
.color-behind-tabs-on .toolbar-mainbar .drag-area > .button-toolbar > button.button-pressed:active,
.color-behind-tabs-on .toolbar-mainbar .toolbar-extensions > .button-toolbar > button.button-pressed:active,
.color-behind-tabs-on .toolbar-mainbar .page-zoom-controls > .button-toolbar > button.button-pressed:active,
.color-behind-tabs-on .toolbar-mainbar > .button-toolbar > button.button-pressed:active {
  background-image: linear-gradient(var(--colorBgDarker), var(--colorBgDarker));
}
.toolbar-mainbar .drag-area > .button-toolbar > button,
.toolbar-mainbar .toolbar-extensions > .button-toolbar > button,
.toolbar-mainbar .page-zoom-controls > .button-toolbar > button,
.toolbar-mainbar > .button-toolbar > button,
.toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button,
.toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button,
.toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button,
.toolbar-mainbar > .toolbar-group > .button-toolbar > button {
  border: 0;
  border-radius: 0;
  min-width: 34px;
  color: inherit;
  padding: 0;
  height: 34px;
}
.density-on .toolbar-mainbar .drag-area > .button-toolbar > button,
.density-on .toolbar-mainbar .toolbar-extensions > .button-toolbar > button,
.density-on .toolbar-mainbar .page-zoom-controls > .button-toolbar > button,
.density-on .toolbar-mainbar > .button-toolbar > button,
.density-on .toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button,
.density-on .toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button,
.density-on .toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button,
.density-on .toolbar-mainbar > .toolbar-group > .button-toolbar > button,
.disable-titlebar .toolbar-mainbar .drag-area > .button-toolbar > button,
.disable-titlebar .toolbar-mainbar .toolbar-extensions > .button-toolbar > button,
.disable-titlebar .toolbar-mainbar .page-zoom-controls > .button-toolbar > button,
.disable-titlebar .toolbar-mainbar > .button-toolbar > button,
.disable-titlebar .toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button,
.disable-titlebar .toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button,
.disable-titlebar .toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button,
.disable-titlebar .toolbar-mainbar > .toolbar-group > .button-toolbar > button {
  border-radius: var(--radius);
}
.toolbar-mainbar .drag-area > .button-toolbar > button svg,
.toolbar-mainbar .toolbar-extensions > .button-toolbar > button svg,
.toolbar-mainbar .page-zoom-controls > .button-toolbar > button svg,
.toolbar-mainbar > .button-toolbar > button svg,
.toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button svg,
.toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button svg,
.toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button svg,
.toolbar-mainbar > .toolbar-group > .button-toolbar > button svg,
.toolbar-mainbar .drag-area > .button-toolbar > button img,
.toolbar-mainbar .toolbar-extensions > .button-toolbar > button img,
.toolbar-mainbar .page-zoom-controls > .button-toolbar > button img,
.toolbar-mainbar > .button-toolbar > button img,
.toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button img,
.toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button img,
.toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button img,
.toolbar-mainbar > .toolbar-group > .button-toolbar > button img {
  transition: transform 0.2s;
}
.color-behind-tabs-on .toolbar-mainbar .drag-area > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-on .toolbar-mainbar .toolbar-extensions > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-on .toolbar-mainbar .page-zoom-controls > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-on .toolbar-mainbar > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-on .toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-on .toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-on .toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-on .toolbar-mainbar > .toolbar-group > .button-toolbar > button.button-selected.button-selected svg {
  fill: var(--colorHighlightBg);
}
.color-behind-tabs-off .toolbar-mainbar .drag-area > .button-toolbar > button.button-selected.button-selected,
.color-behind-tabs-off .toolbar-mainbar .toolbar-extensions > .button-toolbar > button.button-selected.button-selected,
.color-behind-tabs-off .toolbar-mainbar .page-zoom-controls > .button-toolbar > button.button-selected.button-selected,
.color-behind-tabs-off .toolbar-mainbar > .button-toolbar > button.button-selected.button-selected,
.color-behind-tabs-off .toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button.button-selected.button-selected,
.color-behind-tabs-off .toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button.button-selected.button-selected,
.color-behind-tabs-off .toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button.button-selected.button-selected,
.color-behind-tabs-off .toolbar-mainbar > .toolbar-group > .button-toolbar > button.button-selected.button-selected {
  background-color: var(--colorAccentBg);
}
.color-behind-tabs-off .toolbar-mainbar .drag-area > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-off .toolbar-mainbar .toolbar-extensions > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-off .toolbar-mainbar .page-zoom-controls > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-off .toolbar-mainbar > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-off .toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-off .toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-off .toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button.button-selected.button-selected svg,
.color-behind-tabs-off .toolbar-mainbar > .toolbar-group > .button-toolbar > button.button-selected.button-selected svg {
  filter: drop-shadow(0 0 2px var(--colorAccentFg));
}
.toolbar-mainbar .drag-area > .button-toolbar > button.browserAction-button,
.toolbar-mainbar .toolbar-extensions > .button-toolbar > button.browserAction-button,
.toolbar-mainbar .page-zoom-controls > .button-toolbar > button.browserAction-button,
.toolbar-mainbar > .button-toolbar > button.browserAction-button,
.toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button.browserAction-button,
.toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button.browserAction-button,
.toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button.browserAction-button,
.toolbar-mainbar > .toolbar-group > .button-toolbar > button.browserAction-button {
  position: relative;
  background-size: 100%;
}
.toolbar-mainbar .drag-area > .button-toolbar > button.browserAction-button img,
.toolbar-mainbar .toolbar-extensions > .button-toolbar > button.browserAction-button img,
.toolbar-mainbar .page-zoom-controls > .button-toolbar > button.browserAction-button img,
.toolbar-mainbar > .button-toolbar > button.browserAction-button img,
.toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button.browserAction-button img,
.toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button.browserAction-button img,
.toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button.browserAction-button img,
.toolbar-mainbar > .toolbar-group > .button-toolbar > button.browserAction-button img {
  width: 16px;
  height: 16px;
  border: 0;
}
.toolbar-mainbar .drag-area > .button-toolbar > button.browserAction-button.popup-visible,
.toolbar-mainbar .toolbar-extensions > .button-toolbar > button.browserAction-button.popup-visible,
.toolbar-mainbar .page-zoom-controls > .button-toolbar > button.browserAction-button.popup-visible,
.toolbar-mainbar > .button-toolbar > button.browserAction-button.popup-visible,
.toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button.browserAction-button.popup-visible,
.toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button.browserAction-button.popup-visible,
.toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button.browserAction-button.popup-visible,
.toolbar-mainbar > .toolbar-group > .button-toolbar > button.browserAction-button.popup-visible {
  background-color: var(--colorBgDark);
}
.toolbar-mainbar .drag-area > .button-toolbar > button.browserAction-button:hover,
.toolbar-mainbar .toolbar-extensions > .button-toolbar > button.browserAction-button:hover,
.toolbar-mainbar .page-zoom-controls > .button-toolbar > button.browserAction-button:hover,
.toolbar-mainbar > .button-toolbar > button.browserAction-button:hover,
.toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button.browserAction-button:hover,
.toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button.browserAction-button:hover,
.toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button.browserAction-button:hover,
.toolbar-mainbar > .toolbar-group > .button-toolbar > button.browserAction-button:hover {
  background-color: var(--colorAccentBgDark);
}
.color-behind-tabs-on .toolbar-mainbar .drag-area > .button-toolbar > button.browserAction-button:hover,
.color-behind-tabs-on .toolbar-mainbar .toolbar-extensions > .button-toolbar > button.browserAction-button:hover,
.color-behind-tabs-on .toolbar-mainbar .page-zoom-controls > .button-toolbar > button.browserAction-button:hover,
.color-behind-tabs-on .toolbar-mainbar > .button-toolbar > button.browserAction-button:hover,
.color-behind-tabs-on .toolbar-mainbar .drag-area > .toolbar-group > .button-toolbar > button.browserAction-button:hover,
.color-behind-tabs-on .toolbar-mainbar .toolbar-extensions > .toolbar-group > .button-toolbar > button.browserAction-button:hover,
.color-behind-tabs-on .toolbar-mainbar .page-zoom-controls > .toolbar-group > .button-toolbar > button.browserAction-button:hover,
.color-behind-tabs-on .toolbar-mainbar > .toolbar-group > .button-toolbar > button.browserAction-button:hover {
  background-color: var(--colorBgDark);
}
.win.normal .toolbar-mainbar .drag-area,
.win.normal .toolbar-mainbar .toolbar-extensions,
.win.normal .toolbar-mainbar .page-zoom-controls,
.win.normal .toolbar-mainbar {
  left: 0;
  right: 0;
}
.address-bottom #main > .mainbar,
.address-bottom-off #main > .mainbar {
  order: 2;
}
.toolbar-extensions {
  display: flex;
  flex-shrink: 0;
}
.toolbar-vertical .toolbar-extensions {
  flex-direction: column-reverse;
}
.toolbar-vertical .toolbar-extensions .ExtensionIcon > button {
  animation: dropfade 200ms cubic-bezier(0, 0, 0.25, 1);
}
.mail-bar-off .toolbar-mailbar {
  display: none;
}
.tabs-top .toolbar-mainbar.toolbar-visible {
  padding: var(--densityGap);
  height: auto;
}
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex),
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) {
  position: relative;
  max-height: 0;
  padding: 0;
}
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) .window-buttongroup,
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) .window-buttongroup {
  display: none;
}
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) .addressfield,
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) .addressfield {
  display: flex;
  min-width: 100%;
}
#app .address-top-off .toolbar-addressbar:not(.toolbar-noflex) .addressfield:focus-within,
#app .address-bottom-off .toolbar-addressbar:not(.toolbar-noflex) .addressfield:focus-within {
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  border-color: var(--colorBgDark);
}
#browser .mainbar .toolbar-hidden {
  position: absolute;
  z-index: -1;
  visibility: hidden;
}
.tabs-left .tabbar-wrapper,
.tabs-right .tabbar-wrapper {
  position: relative;
  display: flex;
  flex-direction: column;
  height: 100%;
}
.tabbar-wrapper:empty {
  display: none;
}
#browser.color-behind-tabs-on .tabbar-wrapper .tab-strip::-webkit-scrollbar-thumb {
  background-color: var(--colorAccentFgFaded);
}
.tabs-top .toolbar-tabbar {
  margin-top: auto;
}
.tabs-bottom .toolbar-tabbar {
  margin-bottom: auto;
}
.toolbar-tabbar > .button-toolbar > button,
.toolbar-tabbar > .toolbar-group > .button-toolbar > button {
  border: unset;
  min-width: 30px;
  min-height: 30px;
  padding: 0;
}
.toolbar-tabbar > .button-toolbar > button:hover,
.toolbar-tabbar > .toolbar-group > .button-toolbar > button:hover {
  color: inherit;
  background-color: var(--colorAccentBgAlpha);
}
.toolbar-tabbar > .button-toolbar > button:focus-visible,
.toolbar-tabbar > .toolbar-group > .button-toolbar > button:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
}
.toolbar-tabbar > .button-toolbar.tabs-locked > button,
.toolbar-tabbar > .toolbar-group > .button-toolbar.tabs-locked > button {
  opacity: 1;
}
.toolbar-tabbar > .button-toolbar.tabs-button .toolbar-tabbar > .button-toolbar.toggle-trash,
.toolbar-tabbar > .button-toolbar.tabs-button .toolbar-tabbar > .toolbar-group > .button-toolbar.toggle-trash,
.toolbar-tabbar > .toolbar-group > .button-toolbar.tabs-button .toolbar-tabbar > .button-toolbar.toggle-trash,
.toolbar-tabbar > .toolbar-group > .button-toolbar.tabs-button .toolbar-tabbar > .toolbar-group > .button-toolbar.toggle-trash,
.toolbar-tabbar > .button-toolbar.synced-tabs-button,
.toolbar-tabbar > .toolbar-group > .button-toolbar.synced-tabs-button {
  align-self: flex-end;
}
.toolbar-tabbar > .button-toolbar.toggle-trash.hidden,
.toolbar-tabbar > .toolbar-group > .button-toolbar.toggle-trash.hidden {
  display: none;
}
.toolbar-tabbar > .button-toolbar.horizontal-scroll-arrow > button,
.toolbar-tabbar > .toolbar-group > .button-toolbar.horizontal-scroll-arrow > button {
  transition: transform 100ms linear;
}
.toolbar-tabbar > .button-toolbar.horizontal-scroll-arrow.disabled > button,
.toolbar-tabbar > .toolbar-group > .button-toolbar.horizontal-scroll-arrow.disabled > button {
  opacity: 0.3;
}
.toolbar-tabbar > .button-toolbar.horizontal-scroll-arrow:not(.disabled) > button:hover,
.toolbar-tabbar > .toolbar-group > .button-toolbar.horizontal-scroll-arrow:not(.disabled) > button:hover {
  transform: scale(1.2);
}
.toolbar-tabbar > .button-toolbar.horizontal-scroll-arrow > button svg,
.toolbar-tabbar > .toolbar-group > .button-toolbar.horizontal-scroll-arrow > button svg,
.toolbar-tabbar > .button-toolbar.horizontal-scroll-arrow > button img,
.toolbar-tabbar > .toolbar-group > .button-toolbar.horizontal-scroll-arrow > button img {
  flex: 0 1 16px;
  height: 16px;
  width: 16px;
}
.toolbar-tabbar .tabs-button.receiving button,
.toolbar-tabbar .synced-tabs-button.receiving button {
  opacity: 1;
}
.toolbar-tabbar .newtab > button svg {
  border-radius: var(--radius);
}
#tabs-tabbar-container .toolbar-tabbar-before,
#tabs-tabbar-container .toolbar-tabbar-after {
  --ToolbarItemGap: 0 6px;
  min-width: 6px;
  gap: max(var(--densityGap), 1px);
}
.toolbar-edit-mode #tabs-tabbar-container .toolbar-tabbar-before,
.toolbar-edit-mode #tabs-tabbar-container .toolbar-tabbar-after {
  min-width: 30px;
  min-height: 30px;
  background-color: var(--colorFgAlpha);
}
.tabs-left #tabs-tabbar-container .toolbar-tabbar-before,
.tabs-left #tabs-tabbar-container .toolbar-tabbar-after,
.tabs-right #tabs-tabbar-container .toolbar-tabbar-before,
.tabs-right #tabs-tabbar-container .toolbar-tabbar-after {
  flex-wrap: wrap;
  justify-content: center;
  padding: 0 max(calc(var(--densityGap) * 2), 1px) 3px;
}
.tabs-top #tabs-tabbar-container .toolbar-tabbar-before,
.tabs-top #tabs-tabbar-container .toolbar-tabbar-after,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-before,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-after {
  min-width: min-content;
}
.tabs-top #tabs-tabbar-container .toolbar-tabbar-before:empty,
.tabs-top #tabs-tabbar-container .toolbar-tabbar-after:empty,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-before:empty,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-after:empty {
  padding: 0;
  min-width: 6px;
  height: 100%;
  border-radius: var(--radius);
}
.tabs-top #tabs-tabbar-container .toolbar-tabbar-before:empty.modifier,
.tabs-top #tabs-tabbar-container .toolbar-tabbar-after:empty.modifier,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-before:empty.modifier,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-after:empty.modifier,
.toolbar-edit-mode.tabs-top #tabs-tabbar-container .toolbar-tabbar-before:empty,
.toolbar-edit-mode.tabs-top #tabs-tabbar-container .toolbar-tabbar-after:empty,
.toolbar-edit-mode.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-before:empty,
.toolbar-edit-mode.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-after:empty {
  pointer-events: auto;
}
.toolbar-edit-mode.tabs-top #tabs-tabbar-container .toolbar-tabbar-before:empty,
.toolbar-edit-mode.tabs-top #tabs-tabbar-container .toolbar-tabbar-after:empty,
.toolbar-edit-mode.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-before:empty,
.toolbar-edit-mode.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-after:empty {
  min-width: 30px;
  -webkit-app-region: no-drag;
}
.tabs-top #tabs-tabbar-container .toolbar-tabbar-before .UrlBar-AddressField,
.tabs-top #tabs-tabbar-container .toolbar-tabbar-after .UrlBar-AddressField,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-before .UrlBar-AddressField,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-after .UrlBar-AddressField {
  min-width: 280px;
  max-width: 460px;
  margin-top: auto;
}
.tabs-top #tabs-tabbar-container .toolbar-tabbar-before,
.tabs-top #tabs-tabbar-container .toolbar-tabbar-after {
  margin-top: auto;
}
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-before,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-after {
  margin-bottom: auto;
}
#tabs-tabbar-container .toolbar-tabbar-before > div > .button-toolbar > button,
#tabs-tabbar-container .toolbar-tabbar-after > div > .button-toolbar > button,
#tabs-tabbar-container .toolbar-tabbar-before > .button-toolbar > button,
#tabs-tabbar-container .toolbar-tabbar-after > .button-toolbar > button {
  border: unset;
  height: 30px;
  min-width: 30px;
  padding: 0;
}
#tabs-tabbar-container .toolbar-tabbar-before > .button-toolbar:not(.toolbar-spacer, .toolbar-spacer-flexible) > button:not([disabled]):hover,
#tabs-tabbar-container .toolbar-tabbar-after > .button-toolbar:not(.toolbar-spacer, .toolbar-spacer-flexible) > button:not([disabled]):hover {
  color: inherit;
  background-color: var(--colorAccentBgAlpha);
}
.tabs-left #tabs-tabbar-container .button-toolbar.workspace-popup,
.tabs-right #tabs-tabbar-container .button-toolbar.workspace-popup {
  max-width: unset;
  width: stretch;
}
.tabs-left #tabs-tabbar-container .UrlBar-AddressField,
.tabs-right #tabs-tabbar-container .UrlBar-AddressField,
.tabs-left #tabs-tabbar-container .UrlBar-SearchField,
.tabs-right #tabs-tabbar-container .UrlBar-SearchField {
  min-width: 100%;
  max-width: 0;
  padding: 0;
  z-index: 2;
  padding: 0 3px;
  margin: 0 auto;
}
.tabs-left #tabs-tabbar-container .button-popup,
.tabs-right #tabs-tabbar-container .button-popup,
.tabs-left #tabs-tabbar-container .OmniDropdown,
.tabs-right #tabs-tabbar-container .OmniDropdown,
.tabs-left #tabs-tabbar-container .menu,
.tabs-right #tabs-tabbar-container .menu {
  max-height: 45vh;
}
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField {
  overflow: hidden;
}
#browser:not(.toolbar-edit-mode).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:focus-within,
#browser:not(.toolbar-edit-mode).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:focus-within,
#browser:not(.toolbar-edit-mode).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:focus-within,
#browser:not(.toolbar-edit-mode).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:focus-within {
  z-index: 10;
  min-width: calc(360px - var(--densityGap) * 4);
  box-shadow: 0 0 12px #0004;
  overflow: visible;
}
.tabs-left:not(.toolbar-edit-mode)#browser:not(.toolbar-edit-mode).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:focus-within,
.tabs-left:not(.toolbar-edit-mode)#browser:not(.toolbar-edit-mode).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:focus-within,
.tabs-left:not(.toolbar-edit-mode)#browser:not(.toolbar-edit-mode).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:focus-within,
.tabs-left:not(.toolbar-edit-mode)#browser:not(.toolbar-edit-mode).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:focus-within {
  transform: translateX(50%);
  left: -50%;
}
.tabs-right:not(.toolbar-edit-mode)#browser:not(.toolbar-edit-mode).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:focus-within,
.tabs-right:not(.toolbar-edit-mode)#browser:not(.toolbar-edit-mode).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:focus-within,
.tabs-right:not(.toolbar-edit-mode)#browser:not(.toolbar-edit-mode).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:focus-within,
.tabs-right:not(.toolbar-edit-mode)#browser:not(.toolbar-edit-mode).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:focus-within {
  justify-content: flex-end;
  transform: translateX(-50%);
  right: -50%;
}
#browser:not(.toolbar-edit-mode).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:focus-within:has(.OmniDropdown, .menu),
#browser:not(.toolbar-edit-mode).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:focus-within:has(.OmniDropdown, .menu),
#browser:not(.toolbar-edit-mode).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:focus-within:has(.OmniDropdown, .menu),
#browser:not(.toolbar-edit-mode).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:focus-within:has(.OmniDropdown, .menu) {
  box-shadow: unset;
  outline: unset;
}
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField .UrlBar-UrlObfuscationWarning,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField .UrlBar-UrlObfuscationWarning,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField .UrlBar-UrlObfuscationWarning,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField .UrlBar-UrlObfuscationWarning,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField .pageload-ticker,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField .pageload-ticker,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField .pageload-ticker,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField .pageload-ticker {
  display: none;
}
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within),
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within),
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within),
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) {
  justify-content: flex-start;
}
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlBar-UrlFieldWrapper + .toolbar .button-toolbar:not(
          .permission-popup.is-undecided,
          .permission-popup.is-allowing
        ),
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlBar-UrlFieldWrapper + .toolbar .button-toolbar:not(
          .permission-popup.is-undecided,
          .permission-popup.is-allowing
        ),
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlBar-UrlFieldWrapper + .toolbar .button-toolbar:not(
          .permission-popup.is-undecided,
          .permission-popup.is-allowing
        ),
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlBar-UrlFieldWrapper + .toolbar .button-toolbar:not(
          .permission-popup.is-undecided,
          .permission-popup.is-allowing
        ),
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlFragments > .UrlFragment--Lowlight,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlFragments > .UrlFragment--Lowlight,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlFragments > .UrlFragment--Lowlight,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlFragments > .UrlFragment--Lowlight,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .ContentBlocker-Control:not([aria-expanded='true']),
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .ContentBlocker-Control:not([aria-expanded='true']),
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .ContentBlocker-Control:not([aria-expanded='true']),
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .ContentBlocker-Control:not([aria-expanded='true']),
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .BookmarkButton,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .BookmarkButton,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .BookmarkButton,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .BookmarkButton,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .drop-down-menu,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .drop-down-menu,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .drop-down-menu,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .drop-down-menu {
  display: none;
  scale: 0;
}
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlBar-UrlFieldWrapper,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlBar-UrlFieldWrapper,
.tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlBar-UrlFieldWrapper,
.tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlBar-UrlFieldWrapper {
  min-width: unset;
}
#browser:not(.linux).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlFragment-Wrapper,
#browser:not(.linux).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlFragment-Wrapper,
#browser:not(.linux).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlFragment-Wrapper,
#browser:not(.linux).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlFragment-Wrapper {
  text-overflow: clip;
}
#browser:not(.linux).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlBar-UrlFieldWrapper,
#browser:not(.linux).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-AddressField:not(:focus-within) .UrlBar-UrlFieldWrapper,
#browser:not(.linux).tabs-left #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlBar-UrlFieldWrapper,
#browser:not(.linux).tabs-right #tabs-tabbar-container:not(.wide) .UrlBar-SearchField:not(:focus-within) .UrlBar-UrlFieldWrapper {
  mask-image: -webkit-linear-gradient(180deg, transparent 0, #fff 2ch);
  mask-position: top right;
}
#tabs-tabbar-container .toolbar-tabbar-after {
  position: relative;
  align-content: flex-start;
  flex: 1;
}
.tabs-top #tabs-tabbar-container .toolbar-tabbar-after,
.tabs-bottom #tabs-tabbar-container .toolbar-tabbar-after {
  padding-right: 6px;
}
.tabs-left #tabs-tabbar-container .toolbar-tabbar-after,
.tabs-right #tabs-tabbar-container .toolbar-tabbar-after {
  min-width: min-content;
}
.tabs-left #tabs-tabbar-container .toolbar-tabbar-after .toolbar-spacer-flexible,
.tabs-right #tabs-tabbar-container .toolbar-tabbar-after .toolbar-spacer-flexible {
  min-width: 100%;
  height: calc(100% - var(--densityGap) - var(--spacerRows) * (30px + var(--densityGap)));
  margin: auto 0;
}
.tabs-left #tabs-tabbar-container .toolbar-tabbar-after .toolbar-spacer-flexible button,
.tabs-right #tabs-tabbar-container .toolbar-tabbar-after .toolbar-spacer-flexible button {
  height: 100%;
}
.tabs-left #tabs-tabbar-container .toolbar-tabbar-after .toolbar-spacer-flexible .button-dragover:after,
.tabs-right #tabs-tabbar-container .toolbar-tabbar-after .toolbar-spacer-flexible .button-dragover:after {
  top: 3px;
  bottom: 3px;
}
.tabs-left #tabs-tabbar-container .toolbar-tabbar-after .toolbar-spacer-flexible ~ .toolbar-spacer-flexible,
.tabs-right #tabs-tabbar-container .toolbar-tabbar-after .toolbar-spacer-flexible ~ .toolbar-spacer-flexible {
  min-width: auto;
  height: 30px;
}
.tabs-left #tabs-tabbar-container.narrow .toolbar-tabbar-before .UrlBar-AddressField,
.tabs-right #tabs-tabbar-container.narrow .toolbar-tabbar-before .UrlBar-AddressField,
.tabs-left #tabs-tabbar-container.narrow .toolbar-tabbar-after .UrlBar-AddressField,
.tabs-right #tabs-tabbar-container.narrow .toolbar-tabbar-after .UrlBar-AddressField,
.tabs-left #tabs-tabbar-container.narrow .toolbar-tabbar-before .UrlBar-SearchField,
.tabs-right #tabs-tabbar-container.narrow .toolbar-tabbar-before .UrlBar-SearchField,
.tabs-left #tabs-tabbar-container.narrow .toolbar-tabbar-after .UrlBar-SearchField,
.tabs-right #tabs-tabbar-container.narrow .toolbar-tabbar-after .UrlBar-SearchField {
  flex: 0 0 30px;
  min-width: 30px;
}
.tabs-left #tabs-tabbar-container.narrow .toolbar-tabbar-before .SearchField-SlideBar,
.tabs-right #tabs-tabbar-container.narrow .toolbar-tabbar-before .SearchField-SlideBar,
.tabs-left #tabs-tabbar-container.narrow .toolbar-tabbar-after .SearchField-SlideBar,
.tabs-right #tabs-tabbar-container.narrow .toolbar-tabbar-after .SearchField-SlideBar {
  display: none;
}
.tabs-left .tabbar-workspace-button + .toolbar-divider,
.tabs-right .tabbar-workspace-button + .toolbar-divider {
  width: stretch;
}
.tabs-left .tabbar-workspace-button + .toolbar-divider .ToolbarButton-Button,
.tabs-right .tabbar-workspace-button + .toolbar-divider .ToolbarButton-Button {
  max-width: 100%;
  max-height: 12px;
}
.tabs-left .tabbar-workspace-button + .toolbar-divider .ToolbarButton-Button .button-icon,
.tabs-right .tabbar-workspace-button + .toolbar-divider .ToolbarButton-Button .button-icon {
  overflow: clip;
}
.tabs-left .tabbar-workspace-button + .toolbar-divider .ToolbarButton-Button svg,
.tabs-right .tabbar-workspace-button + .toolbar-divider .ToolbarButton-Button svg {
  rotate: 90deg;
  scale: 1 100;
  transform-origin: center;
}
.drag-area-over button {
  background-color: var(--colorAccentBgAlpha);
}
.toggle-trash.trash-is-empty img,
.toggle-trash.trash-is-empty svg {
  opacity: 0.65;
}
.tabs-left:not(.toolbar-edit-mode) .toolbar-tabbar-before,
.tabs-right:not(.toolbar-edit-mode) .toolbar-tabbar-before {
  container-type: inline-size;
}
.tabs-left:not(.toolbar-edit-mode) .toolbar-tabbar-after,
.tabs-right:not(.toolbar-edit-mode) .toolbar-tabbar-after {
  container-name: narrowToolbar;
  container-type: size;
}
@container narrowToolbar (max-height: 60px) {
  .toolbar-spacer-flexible {
    display: none;
  }
  .toolbar-spacer-flexible ~ .toolbar-spacer-flexible {
    display: flex;
  }
}
.color-behind-tabs-off #tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar,
.color-behind-tabs-off #tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar,
.color-behind-tabs-off #tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar:hover,
.color-behind-tabs-off #tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar:hover {
  color: var(--colorImageFg, var(--colorFg));
}
.color-behind-tabs-on #tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar,
.color-behind-tabs-on #tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar,
.color-behind-tabs-on #tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar:hover,
.color-behind-tabs-on #tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar:hover {
  color: var(--colorImageFg, var(--colorAccentFg));
}
.color-behind-tabs-on.color-accent-from-page #tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar,
.color-behind-tabs-on.color-accent-from-page #tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar,
.color-behind-tabs-on.color-accent-from-page #tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar:hover,
.color-behind-tabs-on.color-accent-from-page #tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar:hover {
  color: var(--colorAccentFg);
}
.color-behind-tabs-on.color-accent-from-page.transparent-tabbar:not(.acc-dark.bg-dark) #tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar,
.color-behind-tabs-on.color-accent-from-page.transparent-tabbar:not(.acc-dark.bg-dark) #tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar,
.color-behind-tabs-on.color-accent-from-page.transparent-tabbar:not(.acc-dark.bg-dark) #tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar:hover,
.color-behind-tabs-on.color-accent-from-page.transparent-tabbar:not(.acc-dark.bg-dark) #tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar:hover {
  color: var(--colorImageFg, var(--colorFg));
}
#tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar > button:active,
#tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar > button:active,
#tabs-tabbar-container .toolbar:not(.toolbar-small) > .button-toolbar:not(.toolbar-spacer, .toolbar-spacer-flexible) > button:not([disabled]):hover,
#tabs-tabbar-container .toolbar:not(.toolbar-small) > div > .button-toolbar:not(.toolbar-spacer, .toolbar-spacer-flexible) > button:not([disabled]):hover {
  color: inherit;
  background-color: var(--colorAccentBgAlpha);
}
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-AddressField:not(:focus-within),
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-SearchField:not(:focus-within),
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .SiteInfoButton.warning:not(:focus-within) {
  background: var(--colorAccentBgDark);
  color: var(--colorAccentFg);
  fill: var(--colorAccentFg);
  border-color: var(--colorAccentBgDarker);
}
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-AddressField:not(:focus-within) .SiteInfoButton.warning:not(:focus-within),
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-SearchField:not(:focus-within) .SiteInfoButton.warning:not(:focus-within),
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .SiteInfoButton.warning:not(:focus-within) .SiteInfoButton.warning:not(:focus-within) {
  border-width: 0;
}
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-AddressField:not(:focus-within) .UrlFragment-Wrapper,
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-SearchField:not(:focus-within) .UrlFragment-Wrapper,
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .SiteInfoButton.warning:not(:focus-within) .UrlFragment-Wrapper,
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-AddressField:not(:focus-within) .UrlFragment-Wrapper--ShouldHighlight,
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-SearchField:not(:focus-within) .UrlFragment-Wrapper--ShouldHighlight,
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .SiteInfoButton.warning:not(:focus-within) .UrlFragment-Wrapper--ShouldHighlight {
  --HighlightColor: var(--colorAccentFg);
  --LowlightColor: var(--colorAccentFgFaded);
}
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-AddressField:not(:focus-within) .BookmarkButton:not(:hover) .bookmark-outline,
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-SearchField:not(:focus-within) .BookmarkButton:not(:hover) .bookmark-outline,
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .SiteInfoButton.warning:not(:focus-within) .BookmarkButton:not(:hover) .bookmark-outline {
  stroke: var(--colorAccentFg);
}
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-AddressField:not(:focus-within) .BookmarkButton:not(:hover) .bookmark-animated-fill,
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .UrlBar-SearchField:not(:focus-within) .BookmarkButton:not(:hover) .bookmark-animated-fill,
#browser.color-behind-tabs-on:not(.transparent-tabbar) #tabs-tabbar-container .SiteInfoButton.warning:not(:focus-within) .BookmarkButton:not(:hover) .bookmark-animated-fill {
  fill: var(--colorAccentFg);
}
.button-popup {
  position: absolute;
  z-index: 10;
  display: flex;
  flex-direction: column;
  width: var(--popupWidth);
  max-height: 65vh;
  color: var(--colorFg);
  background-color: var(--colorBgLight);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  border-radius: var(--radiusCap);
}
.button-popup:focus-visible {
  outline: unset;
}
.button-popup:before {
  content: '';
  position: absolute;
  pointer-events: none;
  filter: drop-shadow(0 -1px var(--colorBorder));
  border: 6px solid transparent;
  z-index: inherit;
}
.button-popup-arrow-light:before {
  border-bottom-color: var(--colorBgLight);
}
.button-popup-arrow-dark:before {
  border-bottom-color: var(--colorBg);
}
.button-popup-pos-above {
  bottom: calc(var(--buttonHeight, 20px) + var(--verticalMargin, 0px) + (6px));
  -webkit-transform-origin-y: 75%;
}
.button-popup-pos-above:before {
  bottom: -12px;
}
.button-popup-pos-below {
  top: calc(var(--buttonHeight, 20px) + var(--verticalMargin, 0px) + (6px));
  -webkit-transform-origin-y: 25%;
}
.button-popup-pos-below:before {
  top: -12px;
}
.button-popup-left.button-popup-pos-left {
  top: 0;
  left: var(--buttonHeight);
  -webkit-transform-origin-y: 50%;
}
.button-popup-left.button-popup-pos-left:before {
  top: var(--anchorPos);
  right: -12px;
  rotate: 90deg;
}
.button-popup-right.button-popup-pos-right {
  top: 0;
  left: var(--buttonHeight);
  -webkit-transform-origin-y: 50%;
}
.button-popup-right.button-popup-pos-right:before {
  filter: drop-shadow(-1px 0 var(--colorBorder));
  top: var(--anchorPos);
  left: -12px;
  rotate: 270deg;
}
.button-popup-right.button-popup-arrow-light:before {
  border-bottom-color: var(--colorBgLight);
}
.button-popup-right.button-popup-arrow-dark:before {
  border-bottom-color: var(--colorBg);
}
.button-popup-left {
  right: var(--edgeMargin);
  -webkit-transform-origin-x: 75%;
}
.button-popup-left:before {
  right: calc((var(--buttonWidth) / 2) - 6px - var(--edgeMargin));
}
.button-popup-right {
  left: var(--edgeMargin);
  -webkit-transform-origin-x: 25%;
}
.button-popup-right:before {
  left: calc((var(--buttonWidth) / 2) - 6px - var(--edgeMargin));
}
.button-popup-center {
  left: 50%;
  margin-left: calc(var(--popupWidth) * -0.5);
}
.button-popup-center:before {
  left: calc(50% - 6px);
}
.button-popup-pos-below:before {
  top: -12px;
}
.button-popup-pos-above:before {
  bottom: -12px;
  rotate: 180deg;
}
.toolbar-insideinput > .button-toolbar > .button-popup {
  --verticalMargin: 6px;
}
.button-popup-header-toolbar {
  margin-top: 6px;
}
.button-popup-header-toolbar > .button-toolbar > button,
.button-popup-header-toolbar > .toolbar-group > .button-toolbar > button {
  height: 24px;
}
.button-popup.ToolbarButtonPopup-DefaultStyles h2 {
  background-color: var(--colorBg);
  border-top-left-radius: var(--radiusCap);
  border-top-right-radius: var(--radiusCap);
  border-bottom: 1px solid var(--colorBorder);
  padding: 6px 12px;
  font-weight: 600;
}
.button-popup.ToolbarButtonPopup-DefaultStyles h2:not(:nth-of-type(1)) {
  border-top: 1px solid var(--colorBorder);
}
.button-popup.ToolbarButtonPopup-DefaultStyles footer {
  background: var(--colorBg);
  border-bottom-left-radius: var(--radiusHalf);
  border-bottom-right-radius: var(--radiusHalf);
  border-top: 1px solid var(--colorBorder);
}
.button-popup.ToolbarButtonPopup-DefaultStyles footer > input:only-child {
  width: 100%;
}
.button-popup.ToolbarButtonPopup-DefaultStyles label {
  display: flex;
  align-items: center;
  margin: 6px 12px;
}
.button-popup.ToolbarButtonPopup-DefaultStyles label:first-of-type {
  margin-top: 12px;
}
.button-popup.ToolbarButtonPopup-DefaultStyles label:last-of-type {
  margin-bottom: 12px;
}
.button-popup.ToolbarButtonPopup-DefaultStyles label input {
  flex-shrink: 0;
  margin-right: 6px;
}
.button-popup.ToolbarButtonPopup-DefaultStyles label span {
  margin-left: 3px;
}
.button-popup.full-height {
  max-height: stretch;
}
.button-popup.full-height.button-popup-pos-above {
  margin-top: 6px;
}
.button-popup.full-height.button-popup-pos-below {
  margin-bottom: 6px;
}
.button-popup .popup-scrollarea {
  display: flex;
  flex-direction: column;
  overflow: auto;
  flex-basis: 100%;
}
.button-popup.button-popup-enter,
.button-popup.button-popup-appear {
  opacity: 0.01;
}
.button-popup.button-popup-enter.button-popup-pos-above,
.button-popup.button-popup-appear.button-popup-pos-above {
  transform: translateY(4px);
}
.button-popup.button-popup-enter.button-popup-pos-below,
.button-popup.button-popup-appear.button-popup-pos-below {
  transform: translateY(-4px);
}
.button-popup.button-popup-enter.button-popup-pos-right,
.button-popup.button-popup-appear.button-popup-pos-right {
  transform: translateX(-4px);
}
.button-popup.button-popup-enter.button-popup-pos-left,
.button-popup.button-popup-appear.button-popup-pos-left {
  transform: translateX(4px);
}
.button-popup.button-popup-enter.button-popup-enter-active,
.button-popup.button-popup-appear.button-popup-enter-active,
.button-popup.button-popup-enter.button-popup-appear-active,
.button-popup.button-popup-appear.button-popup-appear-active {
  opacity: 1;
  transform: translate(0);
  transition: transform 300ms ease-out, opacity 150ms linear;
}
.button-popup.button-popup-exit-active {
  opacity: 0;
  transform: scale(0.95);
  transition: transform 150ms ease-in, opacity 150ms ease-in;
}
.button-popup .resize {
  position: absolute;
  width: 100%;
  height: 6px;
  cursor: ns-resize;
}
.button-popup .resize-pos-above {
  top: -3px;
}
.button-popup .resize-pos-below {
  bottom: -3px;
}
.callout-animation-policy {
  border-top: 1px solid var(--colorBorder);
}
.tilingtoggle .button-popup {
  display: flex;
  flex-direction: column;
}
.PageTiling-Button {
  display: flex;
  gap: 3px;
  align-items: center;
  text-align: left;
  width: 100%;
  padding-top: 0;
  padding-bottom: 0;
  border: 0;
  border-radius: unset;
  background-color: transparent;
}
.PageTiling-Button:hover {
  background-color: var(--colorBgDarker);
}
.PageTiling-Button:first-of-type {
  margin-top: 3px;
}
.PageTiling-Button:last-of-type {
  margin-bottom: 3px;
}
.PageTiling-Button.button-on svg {
  color: var(--colorHighlightBg);
}
.PageTiling-Button svg {
  width: 28px;
  height: 28px;
}
.SyncStatus {
  display: flex;
}
.SyncStatus-Warning {
  display: flex;
  color: #000;
  background: #fc0;
  border-radius: 10%/50%;
  white-space: nowrap;
  font-weight: bold;
  padding: 3px 9px;
  margin: auto 6px auto 0;
}
.SyncStatus > .button-toolbar {
  flex: 0 1 auto;
}
.SyncStatus > .button-toolbar button {
  padding: 0;
  border: none;
}
:not(.topmenu) > .menu > ul,
.menu ul ul {
  list-style: none inside none;
  color: var(--colorFg);
  background-color: var(--colorBg);
  padding: 4px;
  border-radius: var(--radiusCap);
  opacity: 1;
  min-width: 150px;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
:not(.topmenu) > .menu > ul.is-collapsed,
.menu ul ul.is-collapsed {
  opacity: 0;
}
:not(.topmenu) > .menu > ul li a,
.menu ul ul li a {
  cursor: default;
  text-decoration: none;
  display: flex;
  flex: 1;
  gap: 9px;
  height: calc(24px + var(--densityGap));
  align-items: center;
  min-width: 150px;
  padding: 0 9px;
  border-radius: var(--radiusHalf);
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
:not(.topmenu) > .menu > ul li .menu-item-description-container,
.menu ul ul li .menu-item-description-container {
  display: flex;
  flex-wrap: wrap;
  height: auto;
  row-gap: 6px;
  padding: 6px 9px;
}
:not(.topmenu) > .menu > ul li img,
.menu ul ul li img {
  margin: auto 0;
}
:not(.topmenu) > .menu > ul li.selectedItem > a,
.menu ul ul li.selectedItem > a,
:not(.topmenu) > .menu > ul li a:focus,
.menu ul ul li a:focus {
  background-color: var(--colorBgDark);
}
.mac :not(.topmenu) > .menu > ul li.selectedItem > a,
.mac .menu ul ul li.selectedItem > a,
.mac :not(.topmenu) > .menu > ul li a:focus,
.mac .menu ul ul li a:focus,
.linux :not(.topmenu) > .menu > ul li.selectedItem > a,
.linux .menu ul ul li.selectedItem > a,
.linux :not(.topmenu) > .menu > ul li a:focus,
.linux .menu ul ul li a:focus {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
}
:not(.topmenu) > .menu > ul .divider,
.menu ul ul .divider {
  border-bottom: 1px solid rgba(0, 0, 0, 0.1);
  pointer-events: none;
  border-bottom-width: 2px;
  margin-left: 0;
  margin-right: 0;
}
:not(.topmenu) > .menu > ul .divider > *,
.menu ul ul .divider > * {
  display: none;
}
svg.note-icon,
svg.pinned-icon,
svg.folder-icon,
svg.folder-trash {
  flex: 0 0 auto;
}
[data-id='MAIL_LABELS_$label1'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg,
[data-id='MAIL_FLAGS_Red'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg {
  fill: #f01;
}
[data-id='MAIL_LABELS_$label2'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg,
[data-id='MAIL_FLAGS_Orange'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg {
  fill: #f80;
}
[data-id='MAIL_FLAGS_Yellow'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg {
  fill: #fd0;
}
[data-id='MAIL_LABELS_$label3'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg,
[data-id='MAIL_FLAGS_Green'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg {
  fill: #3c0;
}
[data-id='MAIL_LABELS_$label4'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg,
[data-id='MAIL_FLAGS_Blue'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg {
  fill: #08f;
}
[data-id='MAIL_LABELS_$label5'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg,
[data-id='MAIL_FLAGS_Purple'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg {
  fill: #a09;
}
[data-id='MAIL_FLAGS_Gray'] svg.folder-icon > .fill-override.fill-override.fill-override.fill-override > svg {
  fill: #666;
}
svg.folder-icon .folder-evaluating text {
  stroke: none;
  fill: var(--colorHighlightFg);
}
svg.folder-icon .folder-evaluating circle {
  stroke: none;
  fill: var(--colorHighlightBg);
}
.hasfocus .vivaldi-tree:focus-within .folder[data-selected] svg.folder-icon .folder-evaluating text {
  fill: var(--colorHighlightBg);
}
.hasfocus .vivaldi-tree:focus-within .folder[data-selected] svg.folder-icon .folder-evaluating circle {
  fill: var(--colorHighlightFg);
}
svg.folder-icon .folder-error text {
  stroke: none;
  fill: var(--colorHighlightFg);
}
svg.folder-icon .folder-error circle {
  stroke: none;
  fill: var(--colorErrorBg);
}
.hasfocus .vivaldi-tree:focus-within .folder[data-selected] svg.folder-icon .folder-error text {
  fill: var(--colorHighlightBg);
}
.hasfocus .vivaldi-tree:focus-within .folder[data-selected] svg.folder-icon .folder-error circle {
  fill: var(--colorHighlightFg);
}
.item-count,
.tree-item .nickname {
  flex: 0 0 auto;
  background-color: var(--colorFgAlpha);
  height: auto;
  line-height: 1.3;
  padding: 1px 4px;
  border-radius: 3px;
  font-size: 11.5px;
  font-weight: 600;
  margin: auto 0 auto auto;
  overflow: visible;
  min-width: 1.5em;
  text-align: center;
}
.counter-indicator + .item-count,
.counter-indicator + .tree-item .nickname {
  margin-left: 3px;
}
.item-count.counter-unseen,
.tree-item .nickname.counter-unseen {
  color: var(--colorBgIntense);
  background-color: var(--colorFgFadedMore);
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  font-weight: 400;
}
.item-count.counter-unseen + .counter-unread,
.tree-item .nickname.counter-unseen + .counter-unread {
  margin-left: -6px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .item-count,
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .tree-item .nickname {
  background-color: var(--colorHighlightFgAlphaHeavy);
  font-weight: 400;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .item-count.counter-unseen,
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .tree-item .nickname.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
  font-weight: 600;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .item-count,
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .tree-item .nickname {
  background-color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .item-count.counter-unseen,
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .tree-item .nickname.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .item-count.counter-unread,
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .tree-item .nickname.counter-unread {
  background-color: var(--colorHighlightFgAlphaHeavy);
  color: var(--colorHighlightFg);
  font-weight: 400;
}
.vivaldi-tree,
.sortselector {
  --treeViewRowHeight: calc(24px + var(--densityGap));
}
.vivaldi-tree {
  contain: content;
  min-height: var(--treeViewRowHeight);
  overflow: hidden;
  flex: 1;
  position: relative;
  z-index: 1;
}
.vivaldi-tree .nickname {
  text-transform: capitalize;
  font-weight: normal;
}
.vivaldi-tree .info {
  color: inherit;
}
.vivaldi-tree-empty {
  display: flex;
  flex: 1;
  position: relative;
  background-color: var(--colorBgLightIntense);
  padding: 18px;
  z-index: 1;
}
.vivaldi-tree .separator,
.vivaldi-tree .separator-left,
.vivaldi-tree .separator-right {
  display: flex;
  flex: 1;
  margin: auto 6px auto 0;
  border: 1px solid var(--colorFgFadedMost);
  border-width: 1px 0 0;
  width: calc(100% - 12px);
}
.vivaldi-tree .separator-left {
  margin-left: 0;
  margin-right: 6px;
}
.vivaldi-tree .separator-right {
  margin-left: 6px;
  margin-right: 0;
}
.vivaldi-tree:focus-within .tree-row[data-selected] .separator,
.vivaldi-tree:focus-within .tree-row[data-selected] .separator-left,
.vivaldi-tree:focus-within .tree-row[data-selected] .separator-right {
  border-color: var(--colorHighlightFg);
}
.hasfocus .vivaldi-tree.no-selection:focus-within:after {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  outline: 2px solid color-mix(in srgb, var(--colorHighlightBg) 30%, transparent);
  outline-offset: -2px;
  z-index: 1;
  pointer-events: none;
}
.vivaldi-tree .tree-item {
  contain: strict;
  contain-intrinsic-height: var(--treeViewRowHeight);
  contain-intrinsic-width: auto 200px;
  content-visibility: auto;
}
.vivaldi-tree .tree-item .discarded {
  filter: grayscale(70%);
  transition: filter 0.2s ease-in;
  opacity: 0.7;
}
.vivaldi-tree .tree-item:hover .discarded {
  filter: grayscale(0);
  opacity: 1;
}
.win.hasfocus .vivaldi-tree .VivaldiList:focus-within .tree-item[data-lead] .tree-row.tree-row:not(.tree-row-selected),
.linux.hasfocus .vivaldi-tree .VivaldiList:focus-within .tree-item[data-lead] .tree-row.tree-row:not(.tree-row-selected) {
  border-radius: var(--radius);
}
.vivaldi-tree .tree-row[data-cut] .tree-item {
  opacity: 0.5;
}
.vivaldi-tree input {
  background-color: var(--colorBgIntense);
  color: var(--colorFg);
  max-height: 18px;
  max-width: auto;
  padding-top: 0;
  padding-right: 2px;
  padding-bottom: 0;
  padding-left: calc(var(--radiusThird) + 2px);
  line-height: 1.2;
}
.vivaldi-tree input[readonly],
.vivaldi-tree input[readonly]:focus {
  color: inherit;
  background-color: transparent;
  margin: 0 6px;
  padding: 0;
  border: unset;
  box-shadow: unset;
  border-radius: 0;
}
.vivaldi-tree .tree-row {
  display: grid;
  grid-template-columns: var(--gridColumns);
  position: relative;
}
.vivaldi-tree .tree-row img {
  width: 16px;
  height: 16px;
}
.vivaldi-tree .tree-row input {
  flex: 1;
  min-width: 6ch;
}
.vivaldi-tree .tree-row .tab-audio {
  margin-right: 0;
  transform: translate(-1px, 0);
}
.vivaldi-tree .tree-row[data-separator] {
  grid-template-columns: 1fr !important;
}
.vivaldi-tree .tree-row[data-selected] {
  background-color: var(--colorFgAlpha);
}
.vivaldi-tree .tree-row.dragoverAbove {
  box-shadow: 0 1px var(--colorHighlightBg) inset, 0 -1px var(--colorHighlightBg);
}
.vivaldi-tree .tree-row.dragoverBelow {
  box-shadow: 0 -1px var(--colorHighlightBg) inset, 0 1px var(--colorHighlightBg);
}
.panel-group .vivaldi-tree .tree-row-selected--first,
.download-popout .vivaldi-tree .tree-row-selected--first {
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
}
.panel-group .vivaldi-tree .tree-row-selected--last,
.download-popout .vivaldi-tree .tree-row-selected--last {
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.vivaldi-tree .tree-row.dragover {
  border-radius: var(--radius);
}
.vivaldi-tree .tree-row label {
  display: flex;
  flex: 1 1 0;
  gap: 6px;
  align-items: center;
  padding: 0 6px 0 9px;
  line-height: var(--treeViewRowHeight);
  min-height: var(--treeViewRowHeight);
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.vivaldi-tree .tree-row label:last-of-type {
  padding-right: 6px;
}
.vivaldi-tree .tree-row label.right-aligned {
  justify-content: flex-end;
  padding-right: 9px;
}
.vivaldi-tree .tree-row label.center-aligned {
  justify-content: center;
}
.vivaldi-tree .tree-row label span {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.vivaldi-tree .tree-row label span.tree-icon {
  display: flex;
  overflow: visible;
}
.vivaldi-tree .tree-row label > div {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  max-width: 100%;
}
.vivaldi-tree .tree-row label > img,
.vivaldi-tree .tree-row label .tree-row-image,
.vivaldi-tree .tree-row label svg.globe-icon {
  display: flex;
  flex: 0 0 auto;
}
.vivaldi-tree .tree-row label.meta,
.vivaldi-tree .tree-row label.disabled {
  opacity: 0.5;
}
.vivaldi-tree .tree-row label .title {
  flex: 1;
}
.vivaldi-tree .tree-row label .workspace-icon {
  display: flex;
}
.vivaldi-tree .tree-row label .close {
  display: none;
  background-color: transparent;
  max-width: 20px;
}
.vivaldi-tree .tree-row label .close svg {
  width: 20px;
  height: 18px;
  transition: transform 100ms linear;
}
.vivaldi-tree .tree-row label .close svg:hover {
  transform: scale(1.2);
}
.vivaldi-tree .tree-row label .item-count + .close {
  margin-left: 3px;
}
.vivaldi-tree .tree-row:hover .close {
  display: block;
  transform: scale(1);
}
.vivaldi-tree .tree-row .expand-icon {
  min-width: 10px;
  min-height: 16px;
  display: inline-flex;
  align-items: center;
}
.vivaldi-tree .tree-row .expand-icon svg {
  transition: transform 100ms linear;
}
.vivaldi-tree .tree-row.dragover,
.hasfocus .vivaldi-tree:focus-within .tree-row[data-selected] {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
}
.vivaldi-tree .tree-item[data-expanded] > .tree-row.folder .expand-icon svg,
.vivaldi-tree .tree-item[data-expanded] > .tree-row.trash .expand-icon svg,
.vivaldi-tree .tree-row[data-expanded] .expand-icon svg {
  transform: rotate(90deg);
}
.vivaldi-tree .counter-container {
  display: flex;
  gap: 6px;
}
.VivaldiList {
  width: 100%;
  overflow-y: auto;
  scroll-behavior: auto;
  scrollbar-gutter: stable;
  overscroll-behavior: contain;
  content-visibility: auto;
}
.VivaldiList:focus-within {
  outline: none;
}
.VivaldiList-Offset {
  position: absolute;
  left: 0;
  z-index: 1;
  width: 100%;
}
.sortselector {
  display: grid;
  position: relative;
  height: calc(var(--treeViewRowHeight) - 2px);
  background-color: var(--colorBg);
  color: var(--colorFg);
  border-top: 1px solid;
  border-bottom: 1px solid;
  border-color: var(--colorBorder);
  font-size: 11.5px;
  font-weight: 700;
}
.sortselector:not(.sortselector-compact) {
  padding-right: var(--scrollbarWidth);
}
#mail_view .sortselector {
  border-top-width: 0;
  overflow: hidden;
}
.sortselector .sortselector-button,
.sortselector .sortselector-dropdown {
  height: 100%;
  border-radius: 0;
  border-width: 0;
  font: inherit;
  padding: 0 4px 0 4px;
}
.sortselector .sortselector-button:disabled,
.sortselector .sortselector-dropdown:disabled {
  opacity: 1;
}
.sortselector .sortselector-button:hover:not(:disabled),
.sortselector .sortselector-dropdown:hover:not(:disabled),
.sortselector .sortselector-button:focus-visible,
.sortselector .sortselector-dropdown:focus-visible {
  outline: unset;
  background-color: var(--colorBgDark);
}
.sortselector .sortselector-button:active:not(:disabled),
.sortselector .sortselector-dropdown:active:not(:disabled) {
  background-color: var(--colorBgDarker);
}
.sortselector .SlideBar--FullHeight.alternate {
  position: relative;
  background-color: var(--colorFgAlpha);
  border: 0 solid transparent;
  border-width: 0 3px;
  padding: 0;
  margin: 0 -3px;
  width: 7px;
  height: var(--columnHeight);
  max-height: stretch;
  background-clip: content-box;
  left: unset;
  z-index: 1;
}
#browser .sortselector .sortselector-dropdown {
  background-image: none;
  background-color: inherit;
}
#browser .sortselector .sortselector-dropdown:before,
#browser .sortselector .sortselector-dropdown:after {
  display: none;
}
#browser .sortselector .sortselector-dropdown:focus {
  background-color: var(--colorBgDarker);
}
.sortselector .sortselector-button {
  display: flex;
  justify-content: space-between;
  align-items: center;
  position: relative;
  background-color: rgba(0, 0, 0, 0);
  line-height: 1.3;
  text-align: initial;
  height: calc(var(--treeViewRowHeight) - 4px);
}
.sortselector .sortselector-button .column-label {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.sortselector .sortselector-button .column-icon {
  display: flex;
}
.sortselector .sortselector-button .column-icon svg {
  width: 16px;
  height: 16px;
}
.sortselector .sortselector-button .column-sort-order {
  display: flex;
  flex: 0 2 auto;
  height: 6px;
  width: 11px;
  overflow: hidden;
  margin: 0 3px;
}
.sortselector .sortselector-button > svg,
.sortselector .sortselector-button .column-sort-order {
  width: 0;
  transform: scale(0.05);
  opacity: 0;
  transition: transform 0.2s;
}
.sortselector .sortselector-button.direction-ascending > svg,
.sortselector .sortselector-button.direction-ascending .column-sort-order {
  width: auto;
  transform: rotate(0deg);
  opacity: 1;
}
.sortselector .sortselector-button.direction-descending > svg,
.sortselector .sortselector-button.direction-descending .column-sort-order {
  width: auto;
  transform: rotate(-180deg);
  opacity: 1;
}
.sortselector .sortselector-button.over-left {
  box-shadow: inset 2px 0 0 var(--colorHighlightBg), -4px 0 0 var(--colorHighlightBg);
}
.sortselector .sortselector-button.over-right {
  box-shadow: inset -2px 0 0 var(--colorHighlightBg), 4px 0 0 var(--colorHighlightBg);
}
.sortselector .sortselector-button.drag-over + .SlideBar--FullHeight {
  padding-top: calc(var(--treeViewRowHeight) - 4px);
  pointer-events: none;
}
.sortselector.sortselector-compact {
  display: flex;
}
.panel-group .sortselector.sortselector-compact,
.download-popout .sortselector.sortselector-compact {
  margin-bottom: 6px;
  border-radius: var(--radius);
  border: 1px solid var(--colorBorder);
  flex: 0 0 auto;
}
.panel-group .sortselector.sortselector-compact .sortselector-dropdown,
.download-popout .sortselector.sortselector-compact .sortselector-dropdown {
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
}
.sortselector.sortselector-compact:hover {
  color: var(--colorFg);
  background-color: var(--colorBgDark);
}
.sortselector.sortselector-compact .sortselector-area {
  display: flex;
  flex: 1;
  overflow: hidden;
}
.sortselector.sortselector-compact .sortselector-dropdown {
  flex: 1;
  padding: 0 0 0 6px;
}
.sortselector.sortselector-compact .sortselector-button {
  flex: 0 0 auto;
  padding: 0 18px;
  border-left: 1px solid var(--colorBorder);
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.sortselector.sortselector-compact .sortselector-button[disabled] {
  display: none;
}
.sortselector.sortselector-compact .sortselector-button:focus {
  background-color: var(--colorBgDarker);
}
.sortselector.sortselector-compact .sortselector-button .column-sort-order {
  margin-left: -6px;
}
.sortselector.sortselector-tableheader > div {
  display: flex;
  flex: 1 1 auto;
  padding: 0;
  position: relative;
}
.sortselector.sortselector-tableheader > div .sortselector-button {
  left: 0;
  width: 100%;
  padding: 0 6px 0 9px;
  line-height: 1;
}
.sortselector.sortselector-tableheader > div .sortselector-button .column-sort-order {
  right: 6px;
}
.readinglist-listing-large .ActionButton,
.vivaldi-tree .tree-row .ActionButton {
  justify-self: end;
  width: 16px;
  height: 16px;
  border: 0;
  padding: 0;
  display: flex;
  background-color: transparent;
  transition: transform 100ms linear;
}
.readinglist-listing-large .ActionButton:hover,
.vivaldi-tree .tree-row .ActionButton:hover {
  background-color: var(--colorFgAlpha);
  transform: scale(1.125);
  transition-duration: 0ms;
}
.readinglist-listing-large .ActionButton svg,
.vivaldi-tree .tree-row .ActionButton svg {
  fill: var(--colorFg);
  stroke-width: 0;
  width: 16px;
  height: 16px;
  margin: auto;
}
.hasfocus .vivaldi-tree:focus-within .tree-row[data-selected] .ActionButton svg {
  fill: var(--colorHighlightFg);
  stroke-width: 0;
}
.ReactVirtualized__Grid.ReactVirtualized__List:focus {
  outline: none;
}
.close {
  appearance: none;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 18px;
  height: 18px;
  border: 0;
  border-radius: var(--radiusRounded);
  background-color: rgba(0, 0, 0, 0.1);
  opacity: 0.8;
  padding: 0;
  fill: currentColor;
}
.close:hover {
  background-color: rgba(0, 0, 0, 0.2);
  opacity: 1;
}
.close:active {
  background-color: rgba(0, 0, 0, 0.3);
}
.close svg {
  width: 16px;
  height: 16px;
}
.SlideBar {
  touch-action: none;
  position: absolute;
  margin: 0;
  padding: 0;
  border: 0;
  background-color: transparent;
  border-radius: 0;
  z-index: 2;
}
.SlideBar--FullWidth {
  cursor: ns-resize;
  min-width: 100%;
  min-height: 7px;
  right: 0;
  bottom: -3px;
  left: 0;
}
.SlideBar--FullWidth.alternate {
  bottom: auto;
  top: -3px;
}
.SlideBar--FullHeight {
  cursor: ew-resize;
  min-width: 7px;
  min-height: 100%;
  top: 0;
  right: -3px;
  bottom: 0;
}
.SlideBar--FullHeight.alternate {
  right: auto;
  left: -3px;
}
.SlideBar:focus-visible {
  outline: unset;
}
#browser .ShareVivaldiPopup {
  --popupWidth: 460px;
  transform: unset;
  opacity: 1;
  box-shadow: none;
  background: unset;
  place-self: anchor-center;
  margin-left: unset;
  inset: unset !important;
}
#browser .ShareVivaldiPopup:before {
  content: unset;
}
#browser .ShareVivaldiPopup-Content {
  display: flex;
  flex-direction: column;
  gap: 12px;
  align-items: center;
  position: relative;
  z-index: 1;
  height: 500px;
  max-height: 90%;
  overflow: hidden auto;
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.15), 0 28px 50px rgba(0, 0, 0, 0.18);
  padding: 12px 36px 24px;
  text-align: center;
  text-wrap-style: balance;
  background: linear-gradient(var(--colorBgLight) 0 0) padding-box, linear-gradient(45deg, #efaea6, #d39cce, #6992e7) border-box;
  border: 5px solid transparent;
  border-radius: var(--radius);
  animation: opendialog calc(1ms * var(--transitionSpeed)) ease-out;
}
#browser .ShareVivaldiPopup-Content h1 {
  font-size: 18px;
  font-weight: 700;
}
#browser .ShareVivaldiPopup-Content p {
  font-size: 15px;
  margin-bottom: 12px;
}
#browser .ShareVivaldiPopup-Content textarea {
  resize: none;
  width: 100%;
  min-height: 65px;
  field-sizing: content;
  padding: 12px;
  margin-bottom: 12px;
  background-color: var(--colorHighlightBgAlpha);
  font-size: 15px;
  text-wrap-style: auto;
}
#browser .ShareVivaldiPopup-Content img.friends {
  max-width: 40dvw;
  height: auto;
  margin: 18px 0 18px;
}
#browser .ShareVivaldiPopup-Content img.confetti {
  position: absolute;
  bottom: 0;
  left: 175px;
  width: 100px;
  pointer-events: none;
}
#browser .ShareVivaldiPopup-Content:not(.updated).copied .ShareVivaldiPopup-Intro {
  transition: opacity calc(1ms * var(--transitionSpeed) / 3) ease-in;
  opacity: 0;
}
#browser .ShareVivaldiPopup-Intro,
#browser .ShareVivaldiPopup-Success {
  display: flex;
  flex-direction: column;
  gap: 12px;
}
#browser .ShareVivaldiPopup-Success {
  animation: droptext calc(1ms * var(--transitionSpeed));
}
#browser .ShareVivaldiPopup-Footer {
  font-size: 15px;
  min-height: 28px;
  margin-top: auto;
}
#browser .ShareVivaldiPopup-Footer p {
  margin-top: 6px;
}
#browser .ShareVivaldiPopup-Footer button {
  display: flex;
  gap: 6px;
  padding: 9px 18px;
  height: auto;
  background-color: var(--colorBgDark);
  transition: all calc(1ms * var(--transitionSpeed));
}
#browser .ShareVivaldiPopup-Footer button:focus-visible {
  outline-offset: 0;
}
#browser .ShareVivaldiPopup-Footer button.primary {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
#browser .ShareVivaldiPopup-Footer button.primary svg {
  scale: 1.5;
}
#browser .ShareVivaldiPopup-Footer button svg.selectbox-checkmark {
  width: 20px;
  height: 20px;
  border: 1px solid currentColor;
  border-radius: 50%;
  padding: 2px;
}
#browser .ShareVivaldiPopup-Footer button .permission-denied {
  display: none;
}
#browser .ShareVivaldiPopup-Close {
  position: absolute;
  top: 6px;
  right: 6px;
  border: none;
  background-color: unset;
  padding: 6px;
  transition: scale 100ms;
  transform-origin: center;
}
#browser .ShareVivaldiPopup-Close:hover {
  transition: unset;
  scale: 1.2;
}
#browser .ShareVivaldiPopup .share-vivaldi-background.closing {
  transition: opacity 200ms;
  opacity: 0;
}
#browser .ShareVivaldiPopup-Content.closing {
  transition: opacity 200ms, transform 200ms;
  transform: translateY(-20px);
  opacity: 0;
}
.share-vivaldi-background {
  position: fixed;
  inset: 0;
  z-index: -1;
  background: #0004;
  animation: fade 200ms;
  opacity: 1;
}
#modal-bg.share-vivaldi-dialog {
  animation: none;
}
#modal-bg.share-vivaldi-dialog .modal-wrapper {
  display: contents;
}
#modal-bg.share-vivaldi-dialog .modal-wrapper .share-vivaldi-background {
  display: none;
}
#modal-bg.share-vivaldi-dialog .ShareVivaldiPopup-Content {
  max-width: 460px;
  max-height: 65dvh;
  flex: 1;
}
@keyframes opendialog {
  0% {
    opacity: 0;
    translate: 0 30px;
  }
  40% {
    opacity: 1;
    translate: 0 -4px;
  }
  100% {
    translate: 0 0px;
  }
}
@keyframes droptext {
  0% {
    opacity: 0;
    translate: 0 -10px;
  }
  40% {
    opacity: 1;
    translate: 0 4px;
  }
  100% {
    translate: 0 0px;
  }
}
.modal-faded-background {
  position: fixed;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  overflow: clip;
  background-color: var(--colorBgAlphaHeavy);
  z-index: 6;
  animation: fade 100ms ease-in;
}
#modal-bg {
  display: flex;
  position: absolute;
  min-width: 400px;
  max-width: 90vw;
  width: fit-content;
  left: 0;
  right: 0;
  margin: 0 auto;
  perspective-origin: 50% 0;
  z-index: 6;
  border-radius: var(--radiusHalf);
}
#modal-bg:focus-visible {
  outline: unset;
}
#modal-bg .modal-wrapper {
  flex: 1;
  overflow: hidden;
  transform-origin: 50% 0;
  color: var(--colorFg);
  background-color: var(--colorBgLight);
  border-radius: inherit;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
#modal-bg.top {
  z-index: 100;
}
.startpage #modal-bg {
  top: 4.75em;
}
#modal-bg.slide .modal-wrapper,
#modal-bg.slide-in .modal-wrapper {
  animation: unveil 200ms cubic-bezier(0, 0.85, 0.2, 1);
}
#modal-bg.slide {
  top: 0;
}
.button-popup-above #modal-bg.slide {
  top: initial;
  bottom: 0;
}
#modal-bg.slide:not(.float) > div {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.auto-hide-wrapper.top.has-tabbar.has-mainbar ~ #main #modal-bg.slide {
  top: 15vw;
}
.auto-hide-wrapper.top.has-tabbar.has-mainbar ~ #main #modal-bg.slide > div {
  border-radius: var(--radiusHalf);
}
#modal-bg.onboarding {
  top: 10vh;
  max-height: 80vh;
  width: 494px;
}
#modal-bg.onboarding:has(.ShowMailTipsAndTricks) {
  width: 540px;
}
#modal-bg.onboarding .modal-wrapper {
  display: flex;
  overflow: auto;
}
#modal-bg.onboarding .modal-wrapper .modal-wrapper {
  display: block;
}
#modal-bg.float {
  position: fixed;
  top: 20vh;
  max-width: 90vw;
  max-height: 75vh;
  animation: dropfade 200ms ease-in;
}
#modal-bg.anchor {
  top: unset;
}
#modal-bg.modal-tabswitcher {
  top: 50%;
  transform: translate(0, -50%);
}
#modal-bg.calendar-new {
  top: 50vh;
  max-height: 90vh;
  transform: translateY(min(-50%, -30vh));
  animation: dropfadein 200ms ease-in;
}
@keyframes dropfadein {
  0% {
    opacity: 0;
    transform: translateY(min(calc(-50% - 10px), calc(-30vh - 10px)));
  }
  100% {
    opacity: 1;
    transform: translateY(min(-50%, -30vh));
  }
}
#modal-bg.calendar-new h1 {
  margin: 0;
}
#modal-bg.calendar-new .ColorEditor {
  margin-right: auto;
}
#modal-bg.calendar-new .ColorEditor .VivaldiDropdown {
  position: unset;
}
#modal-bg.calendar-new .ColorEditor .VivaldiDropdown .VivaldiDropdown-DropdownMenu {
  left: 18px;
}
#modal-bg.calendar-new .dialog-content {
  gap: 6px;
}
#modal-bg.calendar-new .setting-single {
  width: 100%;
  display: inline-flex;
  margin-bottom: 6px;
  gap: 9px;
}
#modal-bg.calendar-modal {
  top: 50%;
  transform: translateX(-50%) translateY(-50%);
  max-height: 95vh;
}
#modal-bg.calendar-modal > div {
  overflow: initial;
}
#modal-bg.calendar-modal .dialog-content {
  padding: 0;
  overflow: initial;
}
#modal-bg.calendar-alarm {
  height: 100vh;
  width: 100vw;
  max-width: none;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  background-color: var(--colorBgAlphaHeavy);
}
#modal-bg.calendar-alarm > div {
  flex: unset;
  background-color: transparent;
  box-shadow: none;
  overflow: initial;
}
#modal-bg.calendar-alarm canvas {
  position: absolute;
  left: 0;
  top: 0;
}
#modal-bg.calendar-fullscreen-alarm {
  position: fixed;
  left: 0;
  top: 0;
  height: 100vh;
  max-height: 100vh;
  width: 100vw;
  max-width: 100vw;
  transform: none;
}
#modal-bg.calendar-fullscreen-alarm > div {
  background-color: transparent;
}
#modal-bg.calendar-fullscreen-alarm canvas {
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  pointer-events: none;
}
#modal-bg.calendar-fullscreen-alarm .wipe-container {
  background-color: rgba(0, 0, 0, 0.3);
  position: absolute;
  left: 0;
  top: 0;
  right: 0;
  bottom: 0;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
}
#modal-bg.calendar-picker {
  left: 0;
  top: 100%;
  transform: none;
  min-width: 0;
}
#modal-bg.calendar-picker > div {
  overflow: visible;
}
#modal-bg.calendar-dialog .error-message {
  max-width: 400px;
  padding: 6px;
}
#modal-bg.calendar-dialog .show-more {
  align-items: baseline;
  display: flex;
  color: var(--colorHighlightBg);
  gap: 6px;
  text-wrap: nowrap;
  width: max-content;
}
#modal-bg.calendar-dialog .show-more span {
  display: flex;
  align-items: center;
  justify-content: center;
  height: auto;
  width: auto;
}
#modal-bg.calendar-dialog .show-more span.ascending {
  transform: rotate(0deg);
  align-self: center;
}
#modal-bg.calendar-dialog .show-more span.descending {
  transform: rotate(-180deg);
}
#modal-bg.calendar-dialog .dialog-inputs {
  padding-top: 6px;
}
#modal-bg.calendar-dialog .dialog-inputs:first-of-type {
  padding-top: 12px;
}
#modal-bg.calendar-dialog .dialog-inputs:empty {
  display: none;
}
#modal-bg.calendar-dialog .dialog-inputs label {
  display: flex;
  align-items: center;
}
#modal-bg.calendar-dialog .dialog-inputs label span {
  margin-left: 6px;
}
#modal-bg.calendar-dialog .dialog-inputs textarea {
  width: 100%;
  height: 4em;
}
.theme-dark img.tip-image-light,
.theme-light img.tip-image-dark {
  display: none;
}
.button-popup .undo-wrapper {
  display: flex;
  flex-direction: column;
  padding: 6px;
  border-radius: var(--radius);
  background-color: var(--colorBgIntense);
  max-height: 334px;
  overflow: auto;
  gap: 6px;
}
.button-popup .undo-wrapper button {
  background-color: transparent;
  border: 0;
  padding: 0;
}
.button-popup .undo-wrapper .undo-item {
  display: inline-flex;
  flex-direction: row;
  align-items: flex-start;
  width: 100%;
  padding: 6px;
  gap: 6px;
  border-radius: var(--radiusHalf);
  border: 1px solid var(--colorBorderSubtle);
}
.theme-dark .button-popup .undo-wrapper .undo-item {
  border-color: var(--colorBg);
}
.button-popup .undo-wrapper .undo-item .button-icon {
  fill: var(--colorFgFaded);
}
.button-popup .undo-wrapper .undo-item .undo-text {
  display: flex;
  flex-direction: column;
  text-align: left;
  flex-basis: 100%;
  gap: 6px;
  overflow: hidden;
}
.button-popup .undo-wrapper .undo-item .undo-text .action-timestamp {
  display: flex;
  justify-content: space-between;
}
.button-popup .undo-wrapper .undo-item .undo-text .action-timestamp .timestamp {
  font-size: 11.5px;
  color: var(--colorFgFadedMore);
  align-self: center;
}
.button-popup .undo-wrapper .undo-item .undo-text .subject {
  font-size: 11.5px;
  background-color: var(--colorBg);
  color: var(--colorFg);
  border-radius: var(--radius);
  padding: 3px 6px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.button-popup .undo-wrapper .undo-item:hover {
  background-color: var(--colorBg);
}
.button-popup .undo-wrapper .undo-item:hover .undo-text .subject {
  background-color: var(--colorBgDark);
  color: var(--colorFg);
}
/* CHANGED: (miky) removed the following from #modal-bg context
  as some dialogs are not rendered within modal view;
  please shout if you see any issues */
.dialog-header {
  padding: 12px 18px 6px;
}
.dialog-double-header,
.dialog-content,
.dialog-footer {
  padding: 12px 18px;
}
.dialog-double-header.selectable-content,
.dialog-content.selectable-content,
.dialog-footer.selectable-content {
  user-select: text;
}
.dialog-header,
.dialog-footer {
  flex: 0 0 auto;
}
.dialog-header > h1,
.dialog-footer > h1 {
  font-weight: 500;
  word-break: break-word;
}
.dialog-header > .step-counter,
.dialog-footer > .step-counter {
  color: var(--colorFgFadedMore);
  flex: 1;
  align-content: center;
  font-size: 11.5px;
}
.dialog-header.buttons {
  display: flex;
  width: 100%;
  justify-content: left;
  padding-inline: 0 0;
}
.dialog-header.buttons input {
  flex: 1 0 50%;
  padding: 1px 0;
}
.dialog-header.buttons :first-child {
  border-right-width: 0;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.dialog-header.buttons :last-child {
  border-left-width: 0;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.dialog-header.buttons input.active {
  background-image: linear-gradient(var(--colorBgDark), var(--colorBgDark));
}
.import-data-dialog .dialog-content {
  padding: 0;
}
.import-data-dialog .dialog-content > * {
  padding: 0 6px 0 18px;
}
.import-data-dialog .dialog-content .toolbar-default.import {
  margin: 12px 0;
}
.import-data {
  display: flex;
  flex-direction: column;
  max-height: calc(80vh - 180px);
  margin-bottom: 6px;
  padding-right: 6px;
}
.import-data .dialog-header {
  padding: 0 0 6px 0;
}
.import-data .import-status {
  padding: 6px 18px;
}
.import-data .import-status-table {
  justify-content: space-between;
  margin-bottom: 3px;
}
.import-data .import-status-table.capitalized {
  text-transform: capitalize;
}
.import-data .import-notes p {
  max-width: 320px;
  text-wrap: pretty;
}
.dialog-double-header {
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  background-color: var(--colorBg);
  border-bottom: 1px solid var(--colorBgDark);
  margin-bottom: 6px;
  padding-top: 9px;
  padding-bottom: 9px;
}
.dialog-double-header > .header-icon {
  width: 32px;
  height: 32px;
  margin-right: 9px;
}
.dialog-double-header > h1 {
  font-weight: 500;
}
.dialog-title {
  word-break: break-all;
}
.dialog-content {
  padding: 3px calc(6px * 3 - var(--scrollbarWidth)) 12px 18px;
  display: flex;
  flex: 0 1;
  flex-direction: column;
  gap: 9px;
  overflow: auto;
  scrollbar-gutter: stable;
}
.dialog-content .imported-data {
  background-color: var(--colorBgLightIntense);
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
  padding: 0 12px;
}
.dialog-content .imported-data .dialog-title {
  margin-bottom: 6px;
}
.dialog-content .imported-data .FormFeedback {
  margin: 0;
  padding: 0 0 0 28px;
  background-color: unset;
  border: unset;
  animation: unset;
  text-transform: none;
  max-width: 320px;
}
.dialog-content.workspaces li {
  stroke: var(--colorFgFaded);
  border-radius: var(--radius);
  height: 34px;
  aspect-ratio: 1/1;
  display: flex;
  justify-content: center;
  align-items: center;
  font-size: 16px;
  font-family: emoji;
}
.dialog-content.workspaces li:hover {
  background-color: var(--colorBgDark);
}
.dialog-content.workspaces li:hover img {
  scale: 0.9;
}
.dialog-content.workspaces li.active {
  background-color: var(--colorBgDark);
  border: 2px solid var(--colorHighlightBg);
}
.dialog-content.workspaces input {
  margin-top: 12px;
}
.label-list label {
  display: flex;
  margin: 0 auto 3px 0;
}
.label-list label input + span {
  margin-left: 6px;
}
.label-list li span {
  background-color: var(--colorBgDark);
  border-radius: var(--radiusRounded);
  padding: 3px 6px;
  display: inline-flex;
  margin-right: 3px;
  margin-bottom: 3px;
}
.label-list li span.folder-path {
  font-weight: 500;
  background-color: var(--colorBgDarker);
}
.dialog-row {
  display: flex;
  align-items: flex-end;
  gap: 6px;
}
.dialog-row .dialog-column,
.dialog-row .dialog-column label {
  display: flex;
  flex: 1;
  gap: 3px;
}
.dialog-row .description {
  margin-right: 12px;
}
.dialog-checkbox {
  display: flex;
  flex: 0 0 auto;
  gap: 9px;
  margin-top: 6px;
}
.dialog-checkbox input {
  margin-right: 9px;
}
.dialog-footer {
  display: flex;
  flex-wrap: wrap;
  background-color: var(--colorBg);
  border-bottom-right-radius: var(--radiusHalf);
  border-bottom-left-radius: var(--radiusHalf);
  border-top: 1px solid var(--colorBgDark);
  gap: 6px;
}
.dialog-footer:empty {
  display: none;
}
.dialog-footer.tips {
  border-top: none;
  background-color: transparent;
}
#app .dialog-footer.plain {
  background-color: unset;
  border: none;
  justify-content: center;
}
.dialog-footer label {
  margin: 6px auto 6px 0;
  flex: 0 1 auto;
}
.dialog-footer.cardview {
  flex-wrap: wrap;
  overflow: hidden;
  justify-content: center;
}
.dialog-footer.cardview input[type=button] {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  flex: 0 0 auto;
}
.dialog-footer.cardview input[type=button]:last-of-type {
  flex: 0 2 auto;
}
.dialog-footer.dialog-footer-sticky {
  position: absolute;
  bottom: 0;
  right: 0;
  left: 0;
  padding-top: 0;
  padding-bottom: 0;
}
.dialog-add-feed {
  display: grid;
  grid-template-columns: 1fr 1fr auto;
  gap: 6px;
  align-items: baseline;
}
.dialog-add-feed .last-updated-title,
.dialog-add-feed .last-updated-date {
  color: var(--colorFgFaded);
  grid-column: 1 / 4;
  padding-bottom: 12px;
  padding-left: 6px;
}
.dialog-add-feed .last-updated-title {
  color: var(--colorFgFaded);
  max-width: 500px;
  border-radius: var(--radius);
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.dialog-add-feed .last-updated-title:last-of-type {
  padding: 12px;
  background-color: var(--colorBg);
  min-width: 100%;
}
.dialog-add-feed .last-updated-title li {
  list-style: inside;
  font-size: 11.5px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.dialog-add-feed .folder-title,
.dialog-add-feed .last-updated-date-title {
  color: var(--colorFgFadedMost);
  padding-right: 6px;
}
.dialog-add-feed label {
  font-size: 11.5px;
}
.dialog-add-feed .select-wrapper.select-wrapper select {
  margin: 0;
}
.dialog-add-feed .InlineText {
  display: inline-block;
  margin-top: 12px;
}
.dialog-add-feed-footer label {
  display: flex;
  gap: 6px;
  margin: 0 auto 0 0;
  align-items: center;
}
.dialog-add-feed-footer label select {
  width: auto;
}
.in-progress {
  padding-left: 24px;
  position: relative;
}
.in-progress:before {
  content: '';
  position: absolute;
  top: -1px;
  left: 0;
  width: 18px;
  height: 18px;
  background-size: 18px 18px;
  background-repeat: no-repeat;
  background-color: var(--colorFg);
  animation: spin 2s linear infinite;
  opacity: 0.9;
  mask-size: cover;
  mask-image: url('/resources/symbol-reload.svg');
}
.dialog-addsearch {
  flex: 1;
}
.dialog-addsearch .fieldset {
  display: flex;
  margin-bottom: 6px;
  gap: 6px;
}
.dialog-addsearch .fieldset input[type=text] {
  flex: 1 1 100%;
}
.dialog-addsearch .fieldset .searchengine_keyword {
  max-width: 8em;
}
.dialog-addsearch span {
  min-width: 75px;
  align-content: center;
}
.dialog-addsearch label input[type=checkbox] {
  margin-top: -1px;
  margin-right: 6px;
}
#modal-bg.dialog-download {
  background-color: var(--colorBgLightIntense);
  max-width: 500px;
}
#modal-bg.dialog-download .dialog-content {
  gap: 6px;
}
#modal-bg.dialog-download .dialog-content p {
  display: flex;
  margin: 0;
  word-break: break-all;
  max-width: 60ch;
}
#modal-bg.dialog-download .dialog-content p .label {
  display: inline-block;
  min-width: 25%;
  text-align: right;
  margin-right: 1ex;
  color: var(--colorFgFadedMore);
}
#modal-bg.dialog-download .dialog-content p .labelwarning {
  padding-top: 5px;
  color: var(--colorFgIntense);
  max-width: unset;
  text-wrap: initial;
}
#modal-bg.dialog-download .dialog-content .autosave {
  display: flex;
  padding-top: 12px;
}
#modal-bg.dialog-download .dialog-content [type=checkbox] {
  margin-right: 6px;
}
#modal-bg.dialog-download .resize-below {
  bottom: 0;
}
.dialog-javascript {
  flex-flow: column nowrap;
  min-height: auto;
  max-height: 65vh;
}
.dialog-javascript > div {
  overflow: hidden;
  display: flex;
  flex-direction: column;
}
.dialog-javascript form {
  display: flex;
  flex-direction: column;
  flex: 0 1 auto;
  overflow: auto;
}
.dialog-javascript .dialog-content p {
  white-space: pre-line;
  overflow-wrap: break-word;
  padding: 3px 0;
  user-select: text;
  cursor: text;
  -webkit-app-region: no-drag;
}
.dialog-javascript .dialog-content input {
  width: 100%;
}
.dialog-javascript .dialog-footer .label {
  position: absolute;
  right: 10px;
}
.dialog-new-bookmark-folder .dialog-content input {
  width: 100%;
}
.workspace-new.float {
  width: 392px;
}
.workspace-new .create-form label {
  padding: 6px 0;
  line-height: 1.95;
}
.workspace-new .create-form label.disabled {
  opacity: 0.5;
}
.workspace-new .create-form .icon-button {
  display: flex;
  padding: 6px;
  flex: 0 0 32px;
  justify-content: center;
  align-items: center;
  font-size: 16px;
}
.workspace-new .create-form .icon-button svg {
  stroke: var(--colorFgFaded);
  width: 16px;
  height: 16px;
}
.workspace-new .create-form .icon-button:hover svg {
  box-shadow: 0px 0px 0px 2px var(--colorBgDark);
  background-color: var(--colorBgDark);
}
.workspace-new .create-form input[type=checkbox] {
  margin-right: 6px;
}
.workspace-new.inline {
  width: 100%;
  max-width: 475px;
  border: var(--colorBgDark) solid 1px;
  position: relative;
  z-index: 1;
  border-radius: var(--radius);
}
.workspace-new.inline label {
  text-wrap: nowrap;
}
.workspace-new.inline .dialog-footer {
  justify-content: flex-start;
}
.note-selection-dialog {
  top: 10vh;
}
.note-selection-dialog .notes-filter {
  margin-bottom: 12px;
}
.note-selection-dialog .dialog-content {
  min-height: 250px;
  max-height: 400px;
}
.import-calendar input + label,
.import-data input + label,
.import-masterpassword input + label,
.open-session input + label {
  margin-left: 12px;
}
.import-calendar select,
.import-data select,
.import-masterpassword select,
.open-session select {
  margin: 6px 0;
}
.import-calendar .setting-single,
.import-data .setting-single,
.import-masterpassword .setting-single,
.open-session .setting-single {
  display: flex;
  flex-direction: row;
}
.import-calendar .setting-single.import-masterpassword,
.import-data .setting-single.import-masterpassword,
.import-masterpassword .setting-single.import-masterpassword,
.open-session .setting-single.import-masterpassword {
  flex-direction: column;
}
.import-calendar .setting-single.import-masterpassword label,
.import-data .setting-single.import-masterpassword label,
.import-masterpassword .setting-single.import-masterpassword label,
.open-session .setting-single.import-masterpassword label {
  flex: 0 0 auto;
}
.import-calendar fieldset,
.import-data fieldset,
.import-masterpassword fieldset,
.open-session fieldset,
.import-calendar fieldset > div,
.import-data fieldset > div,
.import-masterpassword fieldset > div,
.open-session fieldset > div {
  display: flex;
  flex-direction: column;
  margin: 0 0 6px;
  padding: 0;
  border: 0;
}
.import-calendar .import-pathname,
.import-data .import-pathname,
.import-masterpassword .import-pathname,
.open-session .import-pathname {
  margin-bottom: 6px;
}
.import-calendar .import-pathname input[type=text],
.import-data .import-pathname input[type=text],
.import-masterpassword .import-pathname input[type=text],
.open-session .import-pathname input[type=text] {
  font-size: 11.5px;
  color: var(--colorFg);
  background-color: transparent;
  width: 100%;
  border: 0;
  box-shadow: none;
  outline: 0;
  padding: 0 2px;
}
.import-calendar .import-mail-account:empty,
.import-data .import-mail-account:empty,
.import-masterpassword .import-mail-account:empty,
.open-session .import-mail-account:empty {
  display: none;
}
.import-calendar .import-mail-account .imported-email,
.import-data .import-mail-account .imported-email,
.import-masterpassword .import-mail-account .imported-email,
.open-session .import-mail-account .imported-email {
  text-transform: lowercase;
  margin-left: 18px;
  margin-bottom: 3px;
}
.import-calendar .import-masterpassword input[type=password],
.import-data .import-masterpassword input[type=password],
.import-masterpassword .import-masterpassword input[type=password],
.open-session .import-masterpassword input[type=password] {
  width: 100%;
  margin: 6px 0;
}
.import-calendar .import-result,
.import-data .import-result,
.import-masterpassword .import-result,
.open-session .import-result {
  font-weight: 600;
  margin-left: 0.7ex;
  text-transform: capitalize;
}
.import-calendar .import-result .status-icon,
.import-data .import-result .status-icon,
.import-masterpassword .import-result .status-icon,
.open-session .import-result .status-icon {
  margin-right: 6px;
}
.import-calendar .import-result.numbers .import-success,
.import-data .import-result.numbers .import-success,
.import-masterpassword .import-result.numbers .import-success,
.open-session .import-result.numbers .import-success {
  color: var(--colorFgFadedMore);
  font-weight: 400;
}
.import-calendar .import-failed,
.import-data .import-failed,
.import-masterpassword .import-failed,
.open-session .import-failed {
  display: flex;
  color: var(--colorErrorBg);
  margin-left: 2ex;
}
.import-calendar .import-warning,
.import-data .import-warning,
.import-masterpassword .import-warning,
.open-session .import-warning {
  display: flex;
  color: var(--colorWarningBg);
  margin-left: 2ex;
}
.import-calendar .import-success,
.import-data .import-success,
.import-masterpassword .import-success,
.open-session .import-success {
  display: flex;
  color: var(--colorSuccessBg);
  margin-left: 2ex;
}
.import-calendar .session-list,
.import-data .session-list,
.import-masterpassword .session-list,
.open-session .session-list {
  border: 1px solid var(--colorBorder);
  border-top: 0px;
}
.import-calendar .session-list label,
.import-data .session-list label,
.import-masterpassword .session-list label,
.open-session .session-list label {
  flex: unset;
}
.save-session .error-validation {
  margin-top: 12px;
  color: var(--colorError);
}
.open-session {
  max-height: 60vh;
  overflow: hidden;
  display: flex;
  flex: 1;
  flex-direction: column;
}
.open-session .dialog-session,
.open-session .session-list {
  display: flex;
  flex-direction: column;
  overflow: hidden;
}
.open-session .dialog-content {
  display: flex;
  flex: 1;
  min-height: 60px;
}
.open-session .vivaldi-tree > div {
  overflow: auto;
  scrollbar-gutter: stable;
}
#modal-bg.import-data-dialog,
#modal-bg.welcome-import-data-dialog {
  max-width: 400px;
}
#modal-bg.import-data-dialog:has(.dialog-add-feed),
#modal-bg.welcome-import-data-dialog:has(.dialog-add-feed) {
  max-width: 600px;
}
#modal-bg.import-data-dialog .modal-wrapper,
#modal-bg.welcome-import-data-dialog .modal-wrapper {
  position: relative;
}
#modal-bg.import-data-dialog .import-pathname ol,
#modal-bg.welcome-import-data-dialog .import-pathname ol {
  list-style: none;
  margin-top: 6px;
  counter-reset: steps;
  padding-left: 0;
}
#modal-bg.import-data-dialog .import-pathname ol li,
#modal-bg.welcome-import-data-dialog .import-pathname ol li {
  display: grid;
  grid-template-columns: 16px 1fr;
  gap: 6px;
  counter-increment: steps;
  margin-bottom: 6px;
}
#modal-bg.import-data-dialog .import-pathname ol li:before,
#modal-bg.welcome-import-data-dialog .import-pathname ol li:before {
  content: counter(steps);
  display: flex;
  left: 0;
  width: 15px;
  height: 15px;
  line-height: 15px;
  align-self: flex-start;
  justify-content: center;
  margin-top: 1px;
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  border-radius: 50%;
  font-weight: 900;
  font-size: 10px;
}
#modal-bg.default-browser {
  position: relative;
  width: 100%;
  max-width: unset;
  left: 0;
  transform: none;
  overflow: hidden;
  z-index: unset;
  border-radius: unset;
}
#modal-bg.default-browser > .modal-wrapper {
  animation: dropfade 200ms linear;
}
#modal-bg.default-browser label {
  margin-left: auto;
  margin-right: 6px;
}
#modal-bg.default-browser input[type=checkbox] {
  vertical-align: text-bottom;
  margin-right: 9px;
}
#modal-bg.default-browser .SuggestDefault {
  display: flex;
  align-items: center;
  padding: 6px 12px;
  gap: 6px;
  color: var(--colorFg);
  background-color: var(--colorBg);
  border-bottom: 1px solid var(--colorBorder);
}
#modal-bg.default-browser .SuggestDefault .close {
  background-color: unset;
}
#modal-bg .CrashReporting {
  position: relative;
  display: flex;
  flex-direction: column;
  padding: 12px;
  gap: 6px;
  background-color: rgba(255, 198, 0, 0.16);
  border-bottom: 1px solid var(--colorBorder);
}
.theme-light #modal-bg .CrashReporting {
  color: #111;
}
.theme-dark #modal-bg .CrashReporting {
  color: #f6f6f6;
}
#modal-bg .CrashReporting .close {
  position: absolute;
  background-color: unset;
  top: 6px;
  right: 6px;
}
#modal-bg .CrashReporting-Content {
  flex: 1;
}
#modal-bg .CrashReporting-Content .info {
  font-size: inherit;
  color: inherit;
  max-width: unset;
  margin: 0;
}
#modal-bg .CrashReporting-Buttons {
  display: flex;
  gap: 12px;
  align-items: center;
}
.theme-light #modal-bg .CrashReporting-Buttons input {
  border-color: rgba(0, 0, 0, 0.16);
}
#modal-bg .CrashReporting-Buttons input[type=button]:not(:hover, :active) {
  background-image: linear-gradient(var(--colorBgLightIntense), rgba(255, 198, 0, 0.16));
}
#modal-bg .CrashReporting-Buttons input[type=checkbox]:not(:active, :checked) {
  background-image: linear-gradient(transparent, rgba(255, 198, 0, 0.16));
}
#modal-bg .CrashReporting-Buttons label {
  display: flex;
  margin-left: auto;
}
#modal-bg .CrashReporting .InlineText:is(:hover, :active) {
  color: inherit;
}
.dialog-content input[type=button] {
  display: block;
  margin: 12px 0;
}
.dialog-content input[type=text],
.dialog-content input[type=password] {
  width: stretch;
}
.dialog-content p:not[contenteditable] {
  margin-bottom: 6px;
  text-wrap: unset;
  max-width: fit-content;
  text-wrap: balance;
  word-break: break-word;
}
.dialog-content h3 {
  margin-bottom: 12px;
}
.dialog-content h4 {
  margin-top: 9px;
}
.dialog-caret-browsing label {
  display: flex;
  gap: 9px;
}
#modal-bg.show-keyboard-shortcuts-modal-top {
  top: 10vh;
  min-width: auto;
  max-height: 80vh;
}
#modal-bg.show-keyboard-shortcuts-modal-top > div {
  animation: dropfade 100ms cubic-bezier(0.2, 0.9, 0.6, 1);
  display: flex;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  contain: content;
}
.keyboardShortcutsWrapper {
  width: 700px;
  display: flex;
  flex-flow: column nowrap;
  resize: both;
  color: var(--colorFg);
  fill: var(--colorFg);
}
.keyboardShortcutsWrapper header {
  display: flex;
  flex: 0 0 auto;
  padding: 12px;
  align-items: center;
  border-bottom: 1px solid var(--colorBg);
}
.keyboardShortcutsWrapper header h1 {
  margin-right: auto;
}
.keyboardShortcutsWrapper header input {
  margin: auto 12px auto 6px;
}
.keyboardShortcutsWrapper > div {
  overflow-x: hidden;
  overflow-y: overlay;
  padding: 0;
  max-height: 90vh;
}
.keyboardShortcutsWrapper > div .keycombo {
  justify-content: flex-start;
  flex-wrap: wrap;
  padding-left: 40%;
}
.keyboardShortcutsWrapper > div .keycombo label {
  flex: 0 1 40%;
  margin-left: -40%;
}
.keyboardShortcutsWrapper > div .keycombo input[type=button] {
  margin: 0 3px 3px 0;
}
#modal-bg.page-access-keys {
  top: 20vh;
  max-width: 400px;
}
#modal-bg.page-access-keys > div {
  animation: dropfade 100ms cubic-bezier(0.2, 0.9, 0.6, 1);
}
#modal-bg.page-access-keys .dialog-access-keys {
  display: flex;
  flex-direction: column;
  overflow: auto;
  max-height: 70vh;
}
#modal-bg.page-access-keys .dialog-access-keys h1 span {
  display: block;
  white-space: pre-line;
}
#modal-bg.page-access-keys .dialog-access-keys .keycombo {
  display: flex;
  align-items: baseline;
  word-break: break-word;
  line-height: 1.1;
  margin-bottom: 6px;
}
#modal-bg.page-access-keys .dialog-access-keys .keycombo .item {
  flex: 0 0 20px;
  height: 20px;
  padding: 0;
  margin: 0 6px 0 0;
  text-transform: uppercase;
}
#modal-bg.page-access-keys .dialog-access-keys .keycombo span {
  max-width: 40em;
}
#modal-bg.page-access-keys .dialog-access-keys .dialog-content {
  flex: 1;
}
#modal-bg.page-access-keys .dialog-access-keys .dialog-footer {
  align-items: flex-end;
}
#modal-bg.page-access-keys .dialog-access-keys .dialog-footer p.info {
  flex: 1;
  margin: 0 12px 0 0;
}
.keyboard-shortcut-list .category {
  background-repeat: no-repeat;
  background-position: calc(100% - 12px) 7px;
  background-size: 26px 26px;
  border-top: 1px solid var(--colorBg);
}
.keyboard-shortcut-list .category:first-of-type {
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
}
.keyboard-shortcut-list .category:last-of-type {
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.keyboard-shortcut-list .category > button {
  padding: 6px 12px;
  line-height: 2em;
  font-weight: 600;
  margin: 0;
  background: none;
  border: none;
  width: 100%;
  text-align: left;
  position: relative;
}
.keyboard-shortcut-list .category > button:after {
  content: '';
  border-radius: 50%;
  background-color: var(--colorFgFadedMost);
  position: absolute;
  width: 20px;
  height: 20px;
  top: 9px;
  right: 9px;
  mask-image: url('/resources/mask-add.svg');
  mask-position: 2px;
  pointer-events: none;
}
.keyboard-shortcut-list .category > button:focus-visible {
  color: var(--colorHighlightBg);
  outline: unset;
}
.keyboard-shortcut-list .category > button:focus-visible:after {
  background-color: var(--colorHighlightBg);
}
.keyboard-shortcut-list .category .list {
  display: none;
  overflow: hidden;
  margin: 0 auto 12px;
  padding: 1px 0;
}
.keyboard-shortcut-list .category.show button:after {
  mask-image: url('/resources/mask-remove.svg');
}
.keyboard-shortcut-list .category.show .list {
  display: grid;
  grid-template-columns: repeat(auto-fit, minmax(476px, 1fr));
  height: auto;
  transform-origin: top;
  animation: dropfade 100ms linear;
}
.filtered.keyboard-shortcut-list .category.show .list {
  grid-template-columns: minmax(476px, 1fr);
}
.keyboard-shortcut-list .category.hide {
  background-color: var(--colorBg);
}
.keyboard-shortcut-list .category.hide:hover {
  background-color: var(--colorBgDark);
}
.keyboard-shortcut-list .category.hide .list {
  max-height: 0;
  transition-duration: 150ms;
}
.dialog-clear-data label {
  display: inline-flex;
  align-items: center;
  margin-bottom: 6px;
  gap: 6px;
}
.dialog-clear-data .in-progress {
  margin: 6px 0 0 auto;
}
.mac .dialog-clear-data .in-progress {
  margin: 6px auto 0 0;
  order: -1;
}
.dialog-add-folder-name,
.dialog-delete-folder-name {
  display: flex;
  flex-direction: column;
  max-height: 70vh;
  overflow: hidden;
}
.dialog-add-folder-name .dialog-content,
.dialog-delete-folder-name .dialog-content {
  flex: 1;
  overflow: overlay;
}
.edit-bookmark .dialog-content {
  max-width: 400px;
  gap: 6px;
}
.edit-bookmark .dialog-content input,
.edit-bookmark .dialog-content .select-wrapper,
.edit-bookmark .dialog-content textarea {
  width: 100%;
  min-height: 28px;
  resize: vertical;
}
.edit-bookmark .FormFeedback {
  margin: 0;
}
.MailLabelFlagDlg .TabbedView {
  gap: 3px;
  border: none;
  max-height: 40vh;
}
.MailLabelFlagDlg .TabbedView-List {
  border: none;
  background-color: var(--colorBg);
  border-radius: var(--radius);
}
.MailLabelFlagDlg .dialog-header {
  display: grid;
  grid-template-columns: 1fr auto;
  grid-template-rows: auto auto;
  gap: 6px;
  padding-top: 18px;
  padding-bottom: 12px;
}
.MailLabelFlagDlg-labelWrapper {
  display: flex;
  gap: 6px;
  padding: 6px;
  padding-left: 15px;
  border-radius: var(--radius);
  align-items: center;
}
.MailLabelFlagDlg-labelWrapper:hover {
  background-color: var(--colorBgDark);
}
.MailLabelFlagDlg-labelWrapper:active,
.MailLabelFlagDlg-labelWrapper:focus-within {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
}
.MailLabelFlagDlg-shortcut {
  margin-left: auto;
  background-color: var(--colorFgAlpha);
  display: flex;
  justify-content: center;
  border-radius: 3px;
  width: 19.2px;
  height: 19.2px;
  align-items: center;
}
.MailLabelFlagDlg-tab {
  flex: 0 0 auto;
  flex-direction: row;
  border: solid 1px transparent;
}
.MailLabelFlagDlg-icon {
  height: 19.2px;
  width: 19.2px;
  display: flex;
  background: transparent;
  padding: 0;
  border-color: transparent;
  justify-content: center;
  align-items: center;
}
.modal-overlay {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: 6;
}
/*
TODO: darn, both flex-direction and order property break the tab-order
.mac .dialog-footer { flex-direction: flex-end; }
.mac .dialog-footer input:nth-of-type(1) { order: 2; }
.mac .dialog-footer input:nth-of-type(2) { order: 1; }
*/
.mac .dialog-footer {
  justify-content: flex-end;
}
.import-calendar {
  /* Henrik: This is a magic number, chosen because it felt reasonable. */
  min-width: 440px;
}
.import-calendar .dialog-content > .toolbar {
  margin-bottom: 6px;
}
.import-calendar input[type=button] {
  margin-top: 0;
  margin-bottom: 0;
}
#browser .import-calendar input[type=text] {
  flex: unset;
}
.import-calendar-create {
  background-color: var(--colorBgDark);
  border: 1px solid var(--colorBorder);
  margin-bottom: 12px;
  display: flex;
  padding: 6px;
  align-items: flex-end;
}
.import-calendar-create input[type=button] {
  margin-left: 6px;
}
.import-calendar-icon {
  flex: 0 0 16px;
  margin: auto 6px auto 0;
}
.import-calendar-file {
  background-color: var(--colorBg);
  border: 1px solid var(--colorBorder);
  display: flex;
  flex-direction: column;
  gap: 12px;
  padding: 6px;
}
.import-calendar-file > .floating-label {
  flex: 1;
}
.import-calendar-targets {
  min-height: 100px;
  max-height: calc(80vh - 240px);
  overflow-y: auto;
}
.import-calendar-target {
  display: flex;
  padding: 0 6px;
}
.import-calendar-target > label {
  display: flex;
  flex: 1;
  margin-top: auto;
  margin-bottom: auto;
}
.import-calendar-target > label > span {
  margin-top: auto;
  margin-bottom: auto;
  margin-right: 6px;
}
.import-calendar-target > label > select {
  margin-top: auto;
  margin-bottom: auto;
  margin-left: auto;
}
.import-calendar-target-create {
  display: flex;
  background-color: var(--colorBg);
}
.import-calendar-target-create > span {
  margin: auto 6px;
}
.import-calendar-target-create > input {
  flex: 1;
  padding: 6px;
  margin: 6px 6px 6px 0;
}
.import-calendar-target-create:last-child {
  border-bottom-width: 0;
}
.dialog-add-template fieldset,
.edit-template fieldset {
  border: none;
}
.dialog-add-template fieldset:disabled button,
.edit-template fieldset:disabled button {
  pointer-events: none;
}
.session-dialog .selectable {
  padding: 3px;
  background-color: var(--colorBgInverse);
  border: 1px solid var(--colorBgInverser);
  line-height: calc(1rlh + 6px);
}
#app #modal-bg.context-anchor:not(.no-anchor) {
  top: unset;
  left: unset;
  right: unset;
  bottom: unset;
  margin: unset;
  padding: 6px;
}
#app #modal-bg.context-anchor .dialog-title {
  display: flex;
  justify-content: space-between;
}
#app #modal-bg.context-anchor .dialog-title:has(button.close:only-child) {
  justify-content: flex-end;
}
#app #modal-bg.context-anchor img {
  max-width: 100%;
  margin: 0 auto;
}
#app #modal-bg.context-anchor .update-text {
  padding: 6px;
}
#app #modal-bg.context-anchor.updated {
  transition: opacity 200ms linear 1800ms, transform 200ms linear 1800ms;
  transform: translateY(10px);
  opacity: 0;
}
@position-try --anchor-bottom-right {
  position-area: span-left bottom;
}
@position-try --anchor-bottom-left {
  position-area: span-right bottom;
}
@position-try --anchor-top-right {
  position-area: span-left top;
}
@position-try --anchor-top-left {
  position-area: span-right top;
}
.workspace-anchor {
  anchor-name: --workspace-anchor;
}
#app #modal-bg.anchored-to-workspace {
  position-anchor: --workspace-anchor;
  position-area: span-right bottom;
  position-try-fallbacks: --anchor-bottom-right, --anchor-top-left, --anchor-top-right;
}
.sync-anchor {
  anchor-name: --sync-anchor;
}
#app #modal-bg.anchored-to-sync {
  position-anchor: --sync-anchor;
  position-area: span-left bottom;
  position-try-fallbacks: --anchor-bottom-left, --anchor-top-left, --anchor-top-right;
}
.urlfield-anchor {
  anchor-name: --urlfield-anchor;
}
#app #modal-bg.anchored-to-urlfield {
  position-anchor: --urlfield-anchor;
  position-area: center bottom;
  position-try-fallbacks: flip-block;
}
#modal-bg.search-partner-dialog .modal-wrapper {
  background: linear-gradient(var(--colorBgLight) 0 0) padding-box, linear-gradient(45deg, #efaea6, #d39cce, #6992e7) border-box;
  border: 2px solid transparent;
  overflow-y: auto;
}
#modal-bg.search-partner-dialog .modal-wrapper form {
  border-radius: inherit;
}
#modal-bg.search-partner-dialog .dialog-header {
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 12px;
  margin-top: 6px;
  margin-bottom: 12px;
  text-align: center;
}
#modal-bg.search-partner-dialog .dialog-header h1 {
  font-size: 21px;
  font-weight: 500;
}
#modal-bg.search-partner-dialog .dialog-header img {
  max-width: 100%;
}
#modal-bg.search-partner-dialog .dialog-content {
  margin: 0 18px;
  border: 1px solid var(--colorBorder);
  gap: 0;
  padding: 0;
  scrollbar-gutter: unset;
  border-radius: inherit;
}
#modal-bg.search-partner-dialog .dialog-content .list-item {
  display: grid;
  grid-template-columns: auto 1fr;
  align-items: center;
  gap: 12px;
  padding: 9px 12px;
  position: relative;
}
#modal-bg.search-partner-dialog .dialog-content .list-item:focus-within,
#modal-bg.search-partner-dialog .dialog-content .list-item.selected {
  color: var(--colorHighlightBgDark);
  background-color: var(--colorHighlightBgAlpha);
}
#modal-bg.search-partner-dialog .dialog-content .list-item:focus-within .info,
#modal-bg.search-partner-dialog .dialog-content .list-item.selected .info {
  color: inherit;
}
#modal-bg.search-partner-dialog .dialog-content .list-item div {
  display: flex;
  flex-direction: column;
  gap: 6px / 2;
}
#modal-bg.search-partner-dialog .dialog-content input[type='radio'] {
  position: absolute;
  background: none;
  box-shadow: unset;
  border: none;
  transition-duration: 0ms;
  inset: 0;
  appearance: none;
  width: 100%;
  height: 100%;
}
#modal-bg.search-partner-dialog .dialog-content input[type='radio']:checked {
  box-shadow: unset;
}
#modal-bg.search-partner-dialog .dialog-content input[type='radio']:focus-visible {
  outline: none;
}
#modal-bg.search-partner-dialog .dialog-content label {
  font-size: 14px;
}
#modal-bg.search-partner-dialog .dialog-content p {
  margin-top: 0;
  margin-left: 0;
  line-height: 1;
}
#modal-bg.search-partner-dialog .dialog-footer {
  flex-wrap: wrap;
  text-align: center;
  gap: 21px 6px;
}
.account-dialog {
  display: flex;
  flex-wrap: nowrap;
  flex-direction: column;
  border-radius: var(--radiusHalf);
  background-color: var(--colorBgLightIntense);
  color: var(--colorFg);
  overflow: hidden;
}
.account-dialog header {
  display: flex;
  flex-wrap: wrap;
  flex-direction: row;
  align-items: center;
  gap: 6px;
  padding: 6px 12px 6px 6px;
  background-color: var(--colorBg);
  border-bottom: 1px solid var(--colorBgDark);
}
.account-dialog header:hover {
  background-color: var(--colorBgDark);
}
.account-dialog input[type=text] {
  flex: 0 0 100%;
}
.account-dialog .add-person-button {
  margin: 0 12px 12px;
}
.account-dialog .remove-person-button {
  margin: 12px 0 0;
}
.account-dialog .profile-section-header {
  flex: 0 0 auto;
  font-weight: 700;
  overflow: hidden;
  margin-top: 6px;
  margin-left: 12px;
}
.account-dialog .profile-section-name {
  display: flex;
  margin: 6px 12px;
}
.account-dialog .profile-info-icon {
  position: absolute;
  background-color: transparent;
  margin-left: 40px;
  margin-bottom: 30px;
  border: 0;
}
.account-dialog .profile-info-icon > svg {
  fill: var(--colorFgFaded);
}
.account-dialog .profile-stat {
  display: flex;
  margin: 12px;
  flex-direction: column;
}
.account-dialog .profile-stat .profile-details {
  display: grid;
  grid-template-columns: 78px auto;
  margin-bottom: 12px;
}
.account-dialog .profile-stat .profile-stat-row {
  display: flex;
  justify-content: space-between;
}
.account-dialog .profile-stat .profile-stat-row .profile-category {
  display: flex;
  text-align: left;
  font-weight: 700;
}
.account-dialog .profile-stat .profile-stat-row .profile-count {
  display: flex;
}
.account-dialog .profile-stat .profile-image {
  display: flex;
  width: 72px;
  height: 72px;
  border-radius: 50%;
  background-size: cover;
  background-color: var(--colorBg);
}
.account-dialog .profile-stat .profile-name {
  display: flex;
  align-items: center;
  flex-grow: 1;
  justify-content: center;
  font-size: 16px;
  font-weight: 700;
  overflow: hidden;
}
.account-dialog .profile-stat .FormFeedback {
  margin-bottom: 0;
}
.account-dialog .account-listing-large {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  overflow-y: auto;
  max-height: 500px;
  width: auto;
  height: auto;
  padding: 6px 18px;
  gap: 12px 18px;
}
.account-dialog .account-listing-large .account-item-large {
  display: flex;
  flex-direction: column;
  flex: 0 0 calc(var(--popupWidth) / 2 - @icon-size);
  align-items: center;
  background-color: var(--colorBgDark);
  border-color: var(--colorBgDarker);
  margin-bottom: 6px;
  padding: 3px;
  max-width: 96px;
}
.account-dialog .account-listing-large .account-item-large > img,
.account-dialog .account-listing-large .account-item-large > svg {
  border-radius: var(--radiusRound);
  width: 64px;
  height: 64px;
  margin-right: 12px;
  margin-left: 12px;
}
.account-dialog .account-listing-large .account-item-large > img {
  object-fit: cover;
}
.account-dialog .account-listing-large .account-item-large:hover {
  background-color: var(--colorBg);
}
.account-dialog .account-listing-large .account-item-large .profile-name {
  max-width: 100%;
  font-weight: 700;
  margin-top: 3px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.account-dialog .account-item {
  display: flex;
  flex-direction: row;
  gap: 6px;
  padding: 6px;
  align-items: center;
  text-align: left;
  background-color: transparent;
  border-color: transparent;
}
.account-dialog .account-item > img,
.account-dialog .account-item > svg {
  border-radius: var(--radiusRound);
  width: 24px;
  height: 24px;
}
.account-dialog .account-item > img {
  object-fit: cover;
}
.account-dialog .account-item > svg {
  background-color: var(--colorBgDark);
  fill: var(--colorFgFaded);
  padding: 4px;
}
.account-dialog .account-item .profile-name {
  display: flex;
  align-items: center;
  flex-grow: 1;
  gap: 12px;
}
.account-dialog .account-item.active-profile {
  flex: 1 0;
  padding: 0;
  font-weight: 700;
}
.account-dialog .account-item.active-profile img {
  height: 36px;
  width: 36px;
  border-radius: 50%;
}
.account-dialog .account-item.active-profile span svg {
  width: 16px;
  height: 16px;
}
.account-dialog .account-item.active-profile .active-sync-item-label {
  font-weight: 400;
}
.account-dialog .account-item:not(.active-profile):hover {
  background-color: var(--colorBg);
}
.account-dialog .account-item:not(.active-profile):active {
  background-color: var(--colorBgDarker);
}
.account-dialog .account-item:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
}
.account-dialog .nav-back {
  display: flex;
  flex: 1;
  gap: 6px;
  text-align: left;
  align-items: center;
  padding: 6px;
  background-color: transparent;
  border: 0;
}
.account-dialog .nav-back:hover {
  background-color: var(--colorBg);
}
.account-dialog .nav-back svg {
  width: 16px;
  height: 16px;
}
.account-dialog .avatarlist {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  gap: 12px;
  width: auto;
  height: auto;
  max-height: 250px;
  overflow-y: auto;
  padding: 3px 0 12px 12px;
  scrollbar-gutter: stable;
}
.account-dialog .avatarlist:after {
  clear: left;
  content: '';
  display: block;
}
.account-dialog .avatarbox {
  padding: 0;
  border: 0;
  border-radius: 50%;
  background-color: transparent;
}
.account-dialog .avatarbox .avatarbox-image {
  width: 48px;
  height: 48px;
  position: relative;
  border-radius: 50%;
  background-size: cover;
  background-color: var(--colorBg);
}
.account-dialog .avatarbox .avatarbox-image:hover {
  box-shadow: 0 0 0 2px var(--colorBorder);
}
.account-dialog .avatarbox .avatarbox-image.avatarbox-selected {
  box-shadow: 0 0 0 2px var(--colorHighlightBg);
}
.account-dialog .avatarbox svg {
  width: 48px;
  height: 48px;
  fill: var(--colorBgAlpha);
}
.account-dialog .avatarbox svg:hover {
  fill: var(--colorBg);
}
.account-dialog .avatarbox-custom {
  width: 48px;
  height: 48px;
  position: relative;
  border-radius: 50%;
  background-size: cover;
  background-color: var(--colorFg);
}
.account-dialog .account-create {
  display: flex;
  flex-direction: column;
  text-align: center;
  gap: 12px;
  padding: 12px;
  fill: var(--colorHighlightBg);
  border-bottom: 1px solid var(--colorBorderSubtle);
  margin-bottom: 12px;
}
.create-qr-code button {
  background-color: transparent;
}
.create-qr-code button svg {
  width: 16px;
  height: 16px;
}
.qr-share-dialog .qr-image {
  margin: 18px 0 36px;
  border: solid var(--borderDisabled);
  border-width: 1px 0;
  flex-direction: column;
  width: 100%;
  height: auto;
  background-color: #fff;
  box-shadow: 0 0 0 18px #fff;
  image-rendering: pixelated;
  filter: none !important;
}
.qr-share-dialog .dialog-footer input[type='button'] {
  height: unset;
  min-height: 28px;
  text-wrap: wrap;
}
.reading-list-dialog {
  display: flex;
  flex-direction: column;
  border-radius: var(--radiusHalf);
  background-color: var(--colorBgLightIntense);
  color: var(--colorFg);
  overflow: hidden;
}
.reading-list-dialog header {
  display: flex;
  flex-direction: row;
  padding: 6px 12px;
  background-color: var(--colorBg);
  font-variant-caps: all-small-caps;
}
.reading-list-dialog .dialog-header {
  padding: 12px;
  font-weight: 700;
}
.readinglist-listing-large {
  display: flex;
  flex-direction: column;
  width: auto;
  height: auto;
  overflow: auto;
}
.readinglist-listing-large .comment {
  text-align: center;
  margin: 6px 12px 18px;
}
.readinglist-item-large {
  display: flex;
  gap: 3px 6px;
  align-items: center;
  text-align: left;
  padding: 12px;
  border: 0;
  overflow: hidden;
}
.readinglist-item-large img {
  margin-right: 6px;
}
.readinglist-item-large .mark-item,
.readinglist-item-large .remove-item {
  display: flex;
  color: var(--colorFg);
  background-color: transparent;
  border-color: transparent;
  padding: 0;
  margin: 0;
  height: 16px;
  width: 16px;
  max-width: 16px;
  max-height: 16px;
}
.readinglist-item-large .mark-item > svg,
.readinglist-item-large .remove-item > svg {
  fill: var(--colorFgFaded);
  padding: 0;
}
.readinglist-item-large input[type=button].circular {
  margin: 0;
}
.readinglist-item-large .readinglist-name {
  display: flex;
  flex: 1;
  flex-direction: column;
  overflow: hidden;
}
.readinglist-item-large .readinglist-name .title {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
}
.readinglist-item-large .readinglist-name .info {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 1;
  -webkit-box-orient: vertical;
  opacity: 0.65;
  margin: 2px 0 0;
}
.reading-list-dialog .readinglist-item-large {
  flex: 1 0 auto;
  border-radius: unset;
  background-color: var(--colorBgIntenser);
}
.reading-list-dialog .readinglist-item-large:focus-visible {
  outline-offset: -2px;
}
.reading-list-dialog .readinglist-item-large:hover {
  background-color: var(--colorBg);
}
.reading-list-dialog .readinglist-item-large .title {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
}
.reading-list-dialog .readinglist-item-large .info {
  display: none;
}
#readinglist.panel .vivaldi-tree .tree-item {
  --treeViewRowHeight: 68px;
}
.vivaldi-tree .readinglist-item-large {
  height: var(--treeViewRowHeight);
  border-radius: inherit;
}
.vivaldi-tree .readinglist-item-large img {
  width: 32px;
  height: 32px;
}
.vivaldi-tree .readinglist-item-large .circular + .circular {
  display: none;
}
.TranslatePopup {
  background-color: var(--colorBgLighter);
  border-radius: inherit;
}
.TranslatePopup .dialog-content {
  flex-direction: row;
  align-items: center;
  gap: 6px;
  overflow: hidden;
}
.TranslatePopup .dialog-content select {
  display: flex;
  flex-basis: 100%;
  min-width: 0;
}
.TranslatePopup .dialog-footer {
  justify-content: flex-start;
}
.TranslatePopup-Header {
  padding: 12px 12px 12px 18px;
  display: flex;
  align-items: center;
}
.TranslatePopup-Header h3 {
  flex-grow: 1;
}
.TranslatePopup-Header-CloseButton {
  border-color: transparent;
  background-color: transparent;
  display: flex;
  align-items: center;
  justify-content: center;
  border-radius: var(--radiusRound) !important;
  padding: 4px;
  min-width: 26px;
  min-height: 26px;
}
.TranslatePopup-Header-CloseButton:hover {
  background-color: var(--colorBgDark);
}
.TranslatePopup-Checkbox {
  margin-left: 18px !important;
}
.TranslatePopup-SelectLabel {
  margin-top: 0 !important;
  margin-left: 0 !important;
  margin-bottom: 0 !important;
}
.TranslatePopup-Buttons {
  display: flex;
  align-items: center;
  margin-bottom: 18px;
  gap: 6px;
}
.TranslatePopup-Buttons-Translate,
.TranslatePopup-Buttons-Revert {
  margin-left: 18px;
  flex-grow: 1;
}
.TranslatePopup-Buttons-Revert {
  margin-right: 18px;
}
.TranslatePopup-Buttons-MenuButton {
  display: flex;
  align-items: center;
  flex-grow: 0;
  background-color: transparent;
  margin-right: 18px;
  height: 28px;
}
.TranslatePopup-Buttons-MenuButton:hover {
  background-color: var(--colorBgDark);
}
.TranslatePopup-Buttons-MenuButton svg {
  width: 16px;
  height: 16px;
}
.TranslatePopup-Buttons-MenuButton-Span {
  display: flex;
  align-items: flex-start;
}
.TranslatePopup-Buttons-MenuButton-Label {
  margin: 6px !important;
}
.TranslatePopup-FooterText {
  font-size: 11.5px;
}
.TranslatePopup-ReadMoreLink {
  display: flex;
}
.TranslatePopup-Status {
  margin-top: 0 !important;
  margin-left: 18px !important;
  margin-right: 18px !important;
  flex-direction: column;
  align-items: start !important;
}
.TranslatePopup .FormFeedback {
  margin: 0 18px 6px;
}
.button-toolbar.workspace-popup {
  text-overflow: ellipsis;
  max-width: 160px;
  color: inherit;
}
#app div:not(.draggable-button) > .button-toolbar.workspace-popup button {
  gap: 3px;
  padding: 0 3px;
  border: 0;
}
#app div:not(.draggable-button) > .button-toolbar.workspace-popup button .button-title {
  text-align: start;
  margin-right: 3px;
}
#app div:not(.draggable-button) > .button-toolbar.workspace-popup button:has(.button-icon.override) {
  padding-left: 0;
}
#browser:not(.density-on) .button-toolbar.workspace-popup button {
  padding: 0 3px 0 6px;
  margin-left: 1px;
  margin-right: 1px;
}
.button-toolbar.workspace-popup .button-toolbar-menu-indicator {
  margin-left: auto;
}
.tabbar-wrapper .button-toolbar.workspace-popup.tabbar-workspace-button button {
  z-index: 1;
  height: inherit;
  border: 0;
  border-radius: var(--radiusHalf);
}
.density-on .tabbar-wrapper .button-toolbar.workspace-popup.tabbar-workspace-button button {
  border-radius: var(--radius);
}
.tabbar-wrapper .button-toolbar.workspace-popup.tabbar-workspace-button button:hover {
  opacity: 1;
  color: inherit;
}
.color-behind-tabs-off .tabbar-wrapper .button-toolbar.workspace-popup.tabbar-workspace-button button:hover,
.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tabbar-wrapper .button-toolbar.workspace-popup.tabbar-workspace-button button:hover {
  background-color: var(--colorImageBgAlpha, var(--colorBgAlpha));
}
.color-behind-tabs-on .tabbar-wrapper .button-toolbar.workspace-popup.tabbar-workspace-button button:hover {
  background-color: var(--colorAccentBgAlpha);
}
.tabs-top .button-toolbar.workspace-popup.tabbar-workspace-button,
.tabs-bottom .button-toolbar.workspace-popup.tabbar-workspace-button {
  height: 30px;
  margin-left: 3px;
  margin-right: max(1px, var(--densityGap));
}
.density-on.tabs-top .button-toolbar.workspace-popup.tabbar-workspace-button button,
.density-on.tabs-bottom .button-toolbar.workspace-popup.tabbar-workspace-button button {
  border-radius: var(--radius);
}
.tabs-left .button-toolbar.workspace-popup.tabbar-workspace-button,
.tabs-right .button-toolbar.workspace-popup.tabbar-workspace-button {
  container-type: inline-size;
  container-name: workspace_button;
  max-width: none;
  gap: 4px;
  background-color: var(--colorTabBar);
}
#app .tabs-left .button-toolbar.workspace-popup.tabbar-workspace-button button,
#app .tabs-right .button-toolbar.workspace-popup.tabbar-workspace-button button {
  height: 30px;
}
.tabs-left .button-toolbar.workspace-popup.tabbar-workspace-button:has(.override) button,
.tabs-right .button-toolbar.workspace-popup.tabbar-workspace-button:has(.override) button {
  padding-left: 0;
}
.transparent-tabbar.tabs-top:not(.density-on) .button-toolbar.workspace-popup.tabbar-workspace-button button {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}
.transparent-tabbar.tabs-bottom:not(.density-on) .button-toolbar.workspace-popup.tabbar-workspace-button button {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.button-toolbar.workspace-popup.tabbar-workspace-button .button-toolbar-menu-indicator {
  margin-left: auto;
}
.WorkspacePopup {
  display: inline-flex;
  flex-direction: column;
  border-radius: inherit;
  background-color: var(--colorBgIntense);
  overflow: hidden;
}
.theme-dark .WorkspacePopup {
  background-color: var(--colorBgDark);
}
.WorkspacePopup-Items {
  flex: 1;
  padding: 6px 6px 0;
  overflow-x: hidden;
  overflow-y: auto;
}
.WorkspacePopup-Items .title:not(:has(input)) {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.WorkspacePopup-Items .title input {
  width: 100%;
}
.WorkspacePopup-Items .title p:not(.tab-count) {
  display: contents;
}
.WorkspacePopup-Items .first-workspace-info {
  position: relative;
  top: 2px;
  left: 46px;
  margin: 0 0 6px 0 !important;
}
.WorkspacePopup-Items div.no-workspaces-note {
  padding: 12px 12px 0 12px;
}
.WorkspacePopup-Items div.no-workspaces-note h1 {
  font-weight: 600;
  margin-top: 0;
  padding-bottom: 12px;
}
.WorkspacePopup-Items div.no-workspaces-note p {
  padding-bottom: 6px;
}
.WorkspacePopup-Items .workspace-custom-drag-layer {
  position: fixed;
  pointer-events: none;
  z-index: 100;
  left: 0;
  top: calc(-6px - (2rem / 2));
  width: calc(var(--popupWidth) - 2 * 6px);
}
.WorkspacePopup-Items .workspace-custom-drag-layer.has-scrollbar {
  width: calc(var(--popupWidth) - 2 * 6px - var(--scrollbarWidth));
}
.WorkspacePopup-Items .workspace-item-wrapper,
.WorkspacePopup-Items .this-window {
  display: flex;
  flex-direction: row;
  align-items: center;
  text-align: left;
  justify-content: left;
  border-radius: var(--radius);
  gap: 6px;
  width: 100%;
  padding: 6px;
  background-color: var(--colorBgIntense);
  border: none;
}
.theme-dark .WorkspacePopup-Items .workspace-item-wrapper,
.theme-dark .WorkspacePopup-Items .this-window {
  background-color: var(--colorBgDark);
}
.WorkspacePopup-Items .workspace-item-wrapper.disabled,
.WorkspacePopup-Items .this-window.disabled {
  opacity: 0.5;
}
:not(:active, .workspace-item-wrapper).WorkspacePopup-Items .workspace-item-wrapper:hover,
:not(:active, .workspace-item-wrapper).WorkspacePopup-Items .this-window:hover {
  background-color: var(--colorBg);
}
.WorkspacePopup-Items .workspace-item-wrapper.draggable,
.WorkspacePopup-Items .this-window.draggable {
  position: absolute;
}
.WorkspacePopup-Items .workspace-item-wrapper .controls > button,
.WorkspacePopup-Items .this-window .controls > button {
  padding: 0;
  height: 16px;
  width: 16px;
  background-color: transparent;
}
.WorkspacePopup-Items .workspace-item-wrapper .avatar,
.WorkspacePopup-Items .this-window .avatar {
  display: flex;
  justify-content: center;
  align-items: center;
  flex: 0 0 auto;
  color: var(--colorFgFaded);
  background-color: transparent;
  padding: 6px;
  border-radius: var(--radius);
  font-size: 16px;
  font-family: emoji;
}
.WorkspacePopup-Items .workspace-item-wrapper .avatar span,
.WorkspacePopup-Items .this-window .avatar span {
  display: flex;
  align-items: center;
}
.WorkspacePopup-Items .workspace-item-wrapper .avatar.picker,
.WorkspacePopup-Items .this-window .avatar.picker {
  display: flex;
  padding: 6px;
  border-radius: var(--radius);
}
.WorkspacePopup-Items .workspace-item-wrapper .avatar.picker svg,
.WorkspacePopup-Items .this-window .avatar.picker svg {
  stroke: currentColor;
}
.WorkspacePopup-Items .workspace-item-wrapper.selected:not(.this-window),
.WorkspacePopup-Items .this-window.selected:not(.this-window) {
  background-color: var(--colorBg);
}
.WorkspacePopup-Items .workspace-item-wrapper .title,
.WorkspacePopup-Items .this-window .title {
  flex-basis: 100%;
}
.WorkspacePopup-Items .workspace-item-wrapper .title .tab-count,
.WorkspacePopup-Items .this-window .title .tab-count {
  font-size: 11.5px;
  color: var(--colorFgFadedMost);
}
.WorkspacePopup-Items .workspace-item-wrapper .checkmark,
.WorkspacePopup-Items .this-window .checkmark {
  margin-right: 6px;
  fill: var(--colorHighlightBg);
}
.WorkspacePopup-Items .workspace-item-wrapper .audio-container,
.WorkspacePopup-Items .this-window .audio-container {
  max-width: 16px;
  max-height: 16px;
}
.WorkspacePopup-Items .workspace-item-wrapper .audio-container.workspace-inactive,
.WorkspacePopup-Items .this-window .audio-container.workspace-inactive {
  margin-right: 6px;
}
.WorkspacePopup-Items .workspace-item-wrapper .reorder,
.WorkspacePopup-Items .this-window .reorder {
  flex: 0 0 auto;
  margin-right: 9px;
  height: 4px;
  color: var(--colorFgFadedMost);
  cursor: ns-resize;
}
.WorkspacePopup-Items .workspace-item-wrapper .reorder svg,
.WorkspacePopup-Items .this-window .reorder svg {
  height: 4px;
  width: 12px;
}
.WorkspacePopup-Items .workspace-item-wrapper:focus-visible,
.WorkspacePopup-Items .this-window:focus-visible {
  outline-offset: -2px;
}
.WorkspacePopup-Items .workspace-item-wrapper input,
.WorkspacePopup-Items .this-window input {
  flex: 1;
  box-shadow: none;
  border: 1px solid transparent;
  min-width: 0;
  background-color: var(--colorBgIntense);
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.WorkspacePopup-Items .workspace-item-wrapper input:focus,
.WorkspacePopup-Items .this-window input:focus,
.WorkspacePopup-Items .workspace-item-wrapper input:hover,
.WorkspacePopup-Items .this-window input:hover {
  background-color: var(--colorBgIntense);
}
.WorkspacePopup-Items hr {
  height: 1px;
  border: 0;
  background: var(--colorFgFaded);
  border-radius: var(--radius);
  opacity: 0.15;
  width: 95%;
  margin-top: 8px;
  margin-bottom: 4px;
}
.WorkspacePopup-Items .avatar {
  height: 2rem;
  width: 2rem;
}
.WorkspacePopup-Items .pad-top {
  padding-top: 12px;
}
.WorkspacePopup-DragArea {
  padding: 4px 0;
}
.WorkspacePopup header {
  font-weight: 600;
}
.WorkspacePopup .actions {
  display: flex;
  flex-direction: row;
  gap: 6px;
  padding: 6px 12px 12px;
}
.WorkspacePopup .actions:empty {
  display: none;
}
.WorkspacePopup .actions .button-menu .button-textonly {
  padding: 0 0 0 12px;
  overflow: hidden;
}
.WorkspacePopup .actions .button-menu .button-textonly .button-title {
  margin: 0;
}
.WorkspacePopup .actions .button-menu .button-textonly .button-toolbar-menu-indicator {
  height: 28px;
  padding: 0 6px;
}
.WorkspacePopup-Settings-Button {
  position: absolute;
  top: 12px;
  right: 6px;
}
.WorkspacePopup-Settings-Button button {
  border: 0 !important;
  height: unset !important;
}
#browser .workspace-popup > button,
#browser .WorkspacePopup > button,
#browser .tabbar-workspace-button > button,
#browser .workspace-popup > button:active,
#browser .WorkspacePopup > button:active,
#browser .tabbar-workspace-button > button:active,
#browser .workspace-popup > button.button-pressed,
#browser .WorkspacePopup > button.button-pressed,
#browser .tabbar-workspace-button > button.button-pressed {
  box-shadow: none;
}
#browser .workspace-popup .button-icon,
#browser .WorkspacePopup .button-icon,
#browser .tabbar-workspace-button .button-icon,
#browser .workspace-popup .button-icon svg,
#browser .WorkspacePopup .button-icon svg,
#browser .tabbar-workspace-button .button-icon svg {
  width: auto;
  height: auto;
}
#browser .workspace-popup .button-icon.override,
#browser .WorkspacePopup .button-icon.override,
#browser .tabbar-workspace-button .button-icon.override,
#browser .workspace-popup .button-icon.override svg,
#browser .WorkspacePopup .button-icon.override svg,
#browser .tabbar-workspace-button .button-icon.override svg {
  width: 28px;
  height: 28px;
}
#switch > .toolbar.toolbar-vertical .button-toolbar.workspace-popup {
  --view-width: 34px + 16px;
}
#switch > .toolbar.toolbar-vertical .button-toolbar.workspace-popup:has(.button-title) {
  --view-width: calc(var(--titleChars) + 16px * 4);
}
#switch > .toolbar.toolbar-vertical .button-toolbar.workspace-popup .button-toolbar-menu-indicator {
  padding-right: 0;
  flex-basis: 16px;
}
#switch > .toolbar.toolbar-vertical .button-toolbar.workspace-popup .button-title {
  margin: 0;
  text-align: center;
}
.button-toolbar.workspace-popup .button-icon,
.WorkspacePopup-Items .button-icon,
.workspace-input .avatar {
  display: flex;
  flex: 0 0 28px;
  justify-content: center;
  font-size: 16px;
  font-family: emoji;
}
.Workspace-Editor .workspaces,
.Workspace-Editor .workspace-buttons {
  animation: dropfade 200ms cubic-bezier(0, 0.85, 0.2, 1);
}
.button-popup-pos-above .Workspace-Editor .workspaces,
.button-popup-pos-above .Workspace-Editor .workspace-buttons {
  animation: pullfade 200ms cubic-bezier(0, 0.85, 0.2, 1);
}
.Workspace-Editor.workspace-item-wrapper .workspace-input {
  width: 100%;
  display: flex;
  align-items: center;
  gap: 6px;
}
.Workspace-Editor.workspace-item-wrapper ul {
  display: grid;
  width: 100%;
  gap: 6px;
  padding: 0 0 6px;
  justify-items: center;
  justify-content: center;
  grid-template-columns: repeat(var(--iconColumns), 40px);
}
.workspace-new.float .Workspace-Editor.workspace-item-wrapper ul {
  grid-template-columns: repeat(var(--iconColumns), 30px);
}
.Workspace-Editor.workspace-item-wrapper ul li {
  width: 28px;
  height: 28px;
  padding: 6px 0;
  outline-offset: 0;
  border-radius: var(--radiusHalf);
  text-align: center;
}
.Workspace-Editor.workspace-item-wrapper ul li.active {
  background-color: var(--colorBgIntense);
}
.Workspace-Editor.workspace-item-wrapper ul li[data-emoji] {
  font-size: 16px;
  font-family: emoji;
  line-height: 16px;
}
.Workspace-Editor.workspace-item-wrapper .workspaces input[type='submit'] {
  color: var(--colorFg);
  border-color: var(--colorFgAlpha);
}
.Workspace-Editor.workspace-item-wrapper .workspaces input[type='submit']:hover,
.Workspace-Editor.workspace-item-wrapper .workspaces input[type='submit']:active {
  background-color: var(--colorBgDark);
}
.Workspace-Editor.workspace-item-wrapper .workspaces input[type='text'] {
  border: 1px solid var(--colorFgAlpha);
  background-color: var(--colorBgIntense);
  margin-right: 6px;
  max-width: 5ch;
  font-size: 16px;
  text-align: center;
}
.workspace-new.inline .Workspace-Editor.workspace-item-wrapper .workspaces input[type='text'] {
  display: none;
}
.Workspace-Editor.workspace-item-wrapper .workspace-buttons {
  display: flex;
  width: 100%;
  border: 1px solid var(--colorFgAlpha);
  border-radius: var(--radius);
}
.Workspace-Editor.workspace-item-wrapper .workspace-buttons input {
  flex: 1;
  height: 24px;
  padding: 0 12px;
  background-color: var(--colorBgIntense);
  margin: 0;
}
.Workspace-Editor.workspace-item-wrapper .workspace-buttons input:first-of-type {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}
.Workspace-Editor.workspace-item-wrapper .workspace-buttons input:last-of-type {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.Workspace-Editor.workspace-item-wrapper .workspace-buttons input.active {
  background-color: var(--colorBgDark);
  background-image: none;
}
.Workspace-Editor.workspace-item-wrapper .workspace-buttons input.active:hover {
  background-color: var(--colorBgDark);
  background-image: none;
}
.workspace-new .Workspace-Editor.workspace-item-wrapper .workspace-buttons {
  margin: 12px 0;
}
.WorkspacePopup .Workspace-Editor.workspace-item-wrapper {
  position: absolute;
  padding: 6px;
  flex-direction: column;
  background-color: var(--colorBg);
}
.button-icon > .audioicon {
  transform-origin: center;
}
#browser:has(.WorkspacePopup) webview {
  pointer-events: none;
}
@container workspace_button (max-width: 80px) {
  #app .button-title {
    display: none;
  }
  .tabbar-workspace-button:has(.button-icon.audio) .button-icon:not(.audio) {
    display: none;
  }
}
@container workspace_button (max-width: 54px) {
  #app .button-toolbar-menu-indicator {
    display: none;
  }
}
/*
  The zoom control is a constellation of a range slider, reset button and
  a zoom level indicator (in percent).
*/
.page-zoom-controls {
  display: flex;
  align-items: center;
  gap: 9px;
}
.toolbar .page-zoom-controls > .button-toolbar {
  border-width: 0;
}
#app .page-zoom-controls .button-icon svg {
  width: 16px;
  height: 16px;
}
.tabs-bottom.color-behind-tabs-on #footer .page-zoom-controls .page-zoom-slider {
  background-color: var(--colorAccentBgDarker);
}
.page-zoom-controls .zoom-percent {
  display: flex;
  align-items: center;
  text-align: center;
  text-wrap: nowrap;
  flex: 0 0 auto;
  width: 40px;
  height: 22px;
}
.page-zoom-controls .zoom-percent.disabled {
  opacity: 0.65;
}
.toolbar .page-zoom-controls {
  gap: 6px;
}
.toolbar-large .page-zoom-controls,
.toolbar-medium .page-zoom-controls {
  gap: 0;
}
.toolbar-large .page-zoom-controls input[type=range] + .zoom-percent,
.toolbar-medium .page-zoom-controls input[type=range] + .zoom-percent {
  margin-right: 3px;
  margin-left: 3px;
}
.vivaldi-settings .page-zoom-controls {
  flex-wrap: wrap;
  gap: 9px 6px;
}
.vivaldi-settings .page-zoom-controls .button-textonly {
  padding-left: 18px;
  padding-right: 18px;
}
.button-textonly[draggable=true] .page-zoom-controls {
  pointer-events: none;
}
.selectbox-container {
  display: flex;
  flex-wrap: wrap;
  gap: 18px;
}
.selectbox {
  padding: 0;
  display: inline-block;
  vertical-align: top;
  text-align: center;
  border: none;
  background-color: transparent;
}
.selectbox .selectbox-title {
  white-space: normal;
  overflow: hidden;
  text-overflow: ellipsis;
  font-size: 13px;
}
.selectbox .selectbox-image {
  position: relative;
  overflow: hidden;
  font-size: 0;
  box-shadow: 0 0 0 1px var(--colorBorder);
  border-radius: var(--radiusHalf);
  margin-bottom: 6px;
  contain: content;
}
.selectbox .selectbox-image:before {
  content: '';
  position: absolute;
  transform: scale(0);
  opacity: 0;
  transition: 0.4s;
  transform-origin: 100% 100%;
  top: auto;
  left: auto;
  right: 0;
  bottom: 0;
  background-color: transparent;
  border: 20px solid transparent;
}
.selectbox .selectbox-image .selectbox-checkmark {
  transform: scale(1.5) translateX(2px) translateY(2px);
  opacity: 0;
  transition: 0.4s;
  fill: var(--colorHighlightFg);
  position: absolute;
  height: 16px;
  width: 16px;
  bottom: 5px;
  right: 5px;
}
.selectbox .selectbox-image .tab-preview {
  display: block;
  width: 100%;
  height: auto;
}
.selectbox .selectbox-image .tab-preview .thumb-preview-colorBg {
  fill: var(--colorBg);
}
.selectbox .selectbox-image .tab-preview .thumb-preview-colorAccentBg {
  fill: var(--colorAccentBg);
}
.selectbox .selectbox-image .tab-preview .thumb-preview-colorBgDark {
  fill: var(--colorBgDark);
}
.selectbox .selectbox-image .tab-preview .thumb-preview-colorBgLightIntense {
  fill: var(--colorBgLightIntense);
}
.selectbox .selectbox-image .tab-preview .thumb-preview-non-active-tab {
  fill: #fff;
}
.theme-dark .selectbox .selectbox-image .tab-preview .thumb-preview-non-active-tab {
  fill: rgba(255, 255, 255, 0.2);
}
.selectbox .selectbox-image .website-appearance-preview.background-color {
  fill: var(--colorFgFaded);
}
.theme-dark .selectbox .selectbox-image .website-appearance-preview.background-color {
  fill: var(--colorBgFaded);
}
.selectbox .selectbox-image .website-appearance-preview.foreground-color {
  fill: var(--colorBg);
}
.theme-dark .selectbox .selectbox-image .website-appearance-preview.foreground-color {
  fill: var(--colorFgFaded);
}
.selectbox:focus-visible {
  outline: unset;
}
.selectbox:focus-visible .selectbox-image {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.selectbox.selectbox-selected .selectbox-image {
  box-shadow: 0 0 0 2px var(--colorHighlightBg);
}
.selectbox.selectbox-selected .selectbox-image:before {
  border-bottom-color: var(--colorHighlightBg);
  border-right-color: var(--colorHighlightBg);
  opacity: 1;
  transform: scale(1);
}
.selectbox.selectbox-selected .selectbox-image .selectbox-checkmark {
  opacity: 1;
  transform: none;
}
.tabbar-position .selectbox {
  width: 100px;
}
input[type=color].colorpicker-system {
  width: 28px;
  padding: 0;
  border: 0;
  border-radius: 0;
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
}
input[type=color].colorpicker-system::-webkit-color-swatch-wrapper {
  border: 0;
  padding: 0;
  width: 28px;
  height: 28px;
}
input[type=color].colorpicker-system::-webkit-color-swatch {
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 1px rgba(0, 0, 0, 0.05) inset;
  border-radius: 0;
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
}
.ColorEditor {
  display: inline-grid;
  grid-template-columns: auto auto auto;
  grid-template-rows: auto auto;
  gap: 0 6px;
}
.ColorEditor:not(:last-child) {
  margin-right: 12px;
}
.ColorEditor .color-name {
  grid-column-start: 1;
  grid-column-end: 4;
  padding-bottom: 6px;
  position: relative;
}
.ColorEditor .color-dropdown {
  position: relative;
}
.ColorEditor .color-dropdown button {
  position: relative;
  height: 28px;
  width: 16px;
  margin-right: 6px;
  border-radius: var(--radius);
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBg));
  border-color: var(--colorBorder);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 1px rgba(0, 0, 0, 0.05) inset;
}
.ColorEditor .color-dropdown button:hover {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
.ColorEditor .color-dropdown button svg {
  position: relative;
  left: -3px;
  top: 2px;
}
.ColorEditor .color-dropdown nav.opensubmenu {
  left: -28px;
  top: 28px;
}
.ColorEditor-ColorPickerContainer {
  display: flex;
  flex-direction: row;
}
.ColorEditor-HexTextInput {
  font-family: monospace;
  position: relative;
}
.ColorEditor-HexTextInput-Octothorpe {
  pointer-events: none;
  position: absolute;
  height: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 2ch;
  color: var(--colorFgFadedMore);
  line-height: 1;
}
input[type=text].ColorEditor-HexTextInput-InputField {
  font-family: monospace !important;
  width: 10ch;
  padding-left: 2ch;
}
.ColorEditor-VivaldiDropdown {
  width: 26px;
}
.ColorEditor-VivaldiDropdown .VivaldiDropdown-Button {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.ColorEditor-VivaldiDropdown .VivaldiDropdown-DropdownMenu {
  min-width: 160px;
  left: -24px;
}
.manager {
  display: flex;
  flex-direction: column;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
}
.manager > .toolbar {
  background-color: var(--colorBgLightIntense);
  padding: 6px;
}
.manager > .toolbar + .toolbar:not(.search-options) {
  padding-top: unset;
}
.manager > .toolbar > input {
  flex-basis: 150px;
  min-width: 50px;
}
.manager > .toolbar > h1 {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  font-weight: 400;
}
.manager .manager-content {
  flex: 1 1 0;
  display: flex;
  overflow: hidden;
  background-color: var(--colorBgLightIntense);
}
.manager .manager-content,
.manager .manager-editor {
  display: flex;
  align-items: stretch;
}
.manager .manager-editor {
  border: solid var(--colorBorder);
  border-width: 1px 0 0 0;
}
.manager .manager-content ~ .manager-editor {
  border-width: 1px 0 0 1px;
}
.manager .manager-treeview {
  flex: 1 1 auto;
  display: flex;
  flex-direction: column;
}
.manager .manager-treeview .vivaldi-tree-container {
  flex: 1 1 0;
  display: flex;
  overflow: hidden;
}
.manager .tree-item[data-cut] {
  opacity: 0.5;
}
.manager .tree-row label .secondary {
  opacity: 0.65;
}
.manager .manager-view {
  display: flex;
  flex: 1;
  overflow: hidden;
}
#mail_view.horizontal .vivaldi-tree .ReactVirtualized__List,
#mail_view.vertical_wide .vivaldi-tree .ReactVirtualized__List,
.manager .vivaldi-tree .ReactVirtualized__List {
  scrollbar-gutter: stable;
}
.manager-editor {
  flex: 1;
  position: relative;
  overflow: hidden auto;
}
*:not(.panel-bookmarks-edit) > .manager-editor {
  background-color: var(--colorBgLight);
}
.internal-page .manager-editor {
  display: flex;
  flex: 0 0 270px;
  flex-direction: column;
  justify-content: flex-start;
}
.manager-editor .fieldset {
  position: relative;
  align-items: center;
  display: flex;
}
.manager-editor .fieldset.center {
  align-items: center;
  min-height: 22px;
}
.manager-editor .fieldset.disabled {
  color: #aaaaaa;
}
.manager-editor .fieldset.collapse {
  display: none;
}
.manager-editor .fieldset.resizable {
  flex: 1;
}
.internal-page .manager-editor .fieldset.resizable {
  flex: 0 auto;
}
.manager-editor .fieldset.resizable textarea {
  resize: vertical;
  max-height: 40vh;
}
.manager-editor .fieldset > div {
  display: flex;
  flex: 1;
}
.manager-editor .fieldset > input[type=text],
.manager-editor .fieldset > textarea,
.manager-editor .fieldset > select {
  flex: 1 1 100%;
  display: flex;
  margin-right: 0;
  text-overflow: ellipsis;
}
.manager-editor .fieldset textarea {
  flex: 1;
  resize: none;
}
.manager-editor .fieldset .meta-icon {
  display: flex;
  flex: 0 0 16px;
  height: 16px;
  border: 0;
  margin-left: 6px;
  margin-bottom: 0;
}
.manager-editor .preview {
  position: relative;
  flex: 0 1 50px;
  display: flex;
  transition: height 100ms;
}
.internal-page .manager-editor .preview {
  flex: 0 1 200px;
}
.manager-editor .preview .thumbnail-image {
  display: grid;
}
.manager-editor .preview .thumbnail-image svg {
  height: 100%;
}
.manager-editor .preview .thumbnail-image span {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 4;
  -webkit-box-orient: vertical;
  place-self: center;
  text-align: center;
  text-wrap: balance;
  line-height: normal;
  word-break: break-word;
  font-weight: bold;
  max-width: 100%;
}
.internal-page .manager-editor .preview .thumbnail-image {
  height: 200px;
  font-size: 18px;
}
.manager-editor .preview {
  margin: 0 0 6px;
  overflow: hidden;
}
.manager-editor .preview .update-thumbnail,
.manager-editor .preview .set-custom-thumbnail {
  appearance: none;
  display: flex;
  border: 0;
  width: 20px;
  height: 20px;
  color: transparent;
  fill: #ffffff;
  opacity: 0;
  transition: opacity 100ms;
  overflow: hidden;
  background: #2d2d2d;
  padding: 1px;
}
.manager-editor .preview .update-thumbnail svg,
.manager-editor .preview .set-custom-thumbnail svg {
  margin: auto;
}
.manager-editor .preview .update-thumbnail.updating {
  opacity: 0.95;
}
.manager-editor .preview .update-thumbnail.updating svg {
  animation: spin 2s infinite linear;
}
.manager-editor .preview:hover .update-thumbnail,
.manager-editor .preview:hover .set-custom-thumbnail {
  opacity: 0.8;
}
.manager-editor .preview:hover .update-thumbnail:hover,
.manager-editor .preview:hover .set-custom-thumbnail:hover {
  transition: none;
  opacity: 0.95;
}
.manager-editor .preview:hover .update-thumbnail:active,
.manager-editor .preview:hover .set-custom-thumbnail:active {
  transition: none;
  opacity: 1;
}
.manager-editor .preview img {
  border-radius: var(--radiusHalf);
}
.button-badge {
  position: absolute;
  border: 1px solid rgba(0, 0, 0, 0.1);
  font-size: 10px;
  display: flex;
  justify-content: center;
  align-items: center;
  height: 14px;
  min-width: 14px;
  padding-left: 2px;
  padding-right: 2px;
  font-weight: 600;
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  border-radius: var(--radiusRound);
  pointer-events: none;
  top: 5%;
  right: 5%;
  z-index: 1;
  max-width: 32px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.color-behind-tabs-off .toolbar-mainbar .button-badge {
  color: var(--colorFg);
  background-color: var(--colorBg);
}
.toolbar-extensions .button-badge {
  max-width: unset;
  box-shadow: 0 1px rgba(0, 0, 0, 0.5);
}
.tab .button-badge {
  top: 2px;
  left: 15px;
  right: auto;
}
.HintTooltip {
  position: relative;
  padding-right: 22px;
}
.HintTooltip:before {
  content: '?' / '';
  position: absolute;
  right: 0;
  top: 0;
  display: inline-flex;
  width: 1em;
  height: 1em;
  padding: 1px;
  border: 1px solid currentColor;
  border-radius: 50%;
  color: inherit;
  align-items: center;
  justify-content: center;
  font-weight: bold;
  font-size: 10px;
  opacity: 0.65;
}
.warning.HintTooltip:before {
  content: '!' / '';
}
.HintTooltip__content {
  pointer-events: none;
  position: fixed;
  width: max-content;
  max-width: 232px;
  color: var(--colorFg);
  background-color: var(--colorBgAlpha);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  backdrop-filter: var(--backgroundBlur);
  padding: 6px;
  font-size: 11.5px;
  z-index: 1;
  border-style: none;
  overflow: visible;
  position-anchor: var(--anchor-name);
  inset: auto;
}
.HintTooltip__content:after {
  content: '';
  position: absolute;
  pointer-events: none;
  border: 6px solid transparent;
  border-top-color: var(--colorBgAlpha);
  animation: fade 200ms ease-in;
}
.HintTooltip--top + .HintTooltip__content {
  margin-bottom: 6px;
  animation: pullfade 200ms linear;
  position-area: top;
  position-try-fallbacks: bottom;
}
.HintTooltip--top + .HintTooltip__content:after {
  filter: drop-shadow(0 1px rgba(0, 0, 0, 0.2));
  bottom: -11px;
  right: 50%;
}
.HintTooltip--bottom + .HintTooltip__content {
  margin-top: 6px;
  animation: dropfade 200ms linear;
  position-area: bottom;
}
.HintTooltip--bottom + .HintTooltip__content:after {
  filter: drop-shadow(0 1px rgba(0, 0, 0, 0.2));
  top: -12px;
  transform: rotate(180deg);
  right: 50%;
}
.HintTooltip--left + .HintTooltip__content {
  margin-right: 6px;
  animation: rightfade 200ms linear;
  position-area: left;
}
.HintTooltip--left + .HintTooltip__content:after {
  filter: drop-shadow(-1px 1px rgba(0, 0, 0, 0.2));
  transform: rotate(270deg) translateX(6px);
  right: -12px;
  top: 50%;
}
.HintTooltip--right + .HintTooltip__content {
  margin-left: 6px;
  animation: leftfade 200ms linear;
  position-area: right;
}
.HintTooltip--right + .HintTooltip__content:after {
  filter: drop-shadow(1px 1px rgba(0, 0, 0, 0.2));
  transform: rotate(90deg) translateX(-6px);
  left: -12px;
  top: 50%;
}
#app .floating-label {
  display: flex;
  flex-direction: column;
  position: relative;
  gap: 6px;
}
#app .floating-label span,
#app .floating-label select,
#app .floating-label input {
  margin: 0;
}
#app .floating-label > strong {
  font-weight: 600;
}
#app .floating-label .floating-input {
  padding-right: 16px;
}
#app .floating-label .floating-placeholder {
  margin: 3px 0;
}
#app .floating-label.verified input {
  background-image: url(/resources/check-selected.png);
  background-size: 16px;
  background-repeat: no-repeat;
  background-position: right 3px center;
}
@media (-webkit-min-device-pixel-ratio: 2) {
  #app .floating-label.verified input {
    background-image: url(/resources/check-selected@2x.png);
  }
}
#app .floating-label .error {
  position: absolute;
  bottom: 6px;
  right: 6px;
  height: 16px;
  font-weight: 700;
  fill: var(--colorErrorBg);
}
#app .floating-label.verified:after {
  position: absolute;
  bottom: 6px;
  right: 6px;
  font-weight: 700;
}
#app .floating-label.verified .floating-input {
  opacity: initial;
}
.spinner {
  filter: unset !important;
  height: 16px;
  width: 16px;
  transition: transform 0.2s;
  transform: scale(0);
}
#browser:not(.animation-off) .spinner {
  animation: spin 0.8s steps(8, end) infinite;
  animation-fill-mode: forwards;
}
.spinner:not(.spinner-inactive) .spinner-part1 {
  opacity: 0.7;
}
.spinner:not(.spinner-inactive) .spinner-part2 {
  opacity: 1;
}
.spinner:not(.spinner-inactive) .spinner-part3,
.spinner:not(.spinner-inactive) .spinner-part4,
.spinner:not(.spinner-inactive) .spinner-part5,
.spinner:not(.spinner-inactive) .spinner-part6,
.spinner:not(.spinner-inactive) .spinner-part7 {
  opacity: 0.2;
}
.spinner:not(.spinner-inactive) .spinner-part8 {
  opacity: 0.4;
}
.spinner.spinner-inactive .spinner-part1 {
  opacity: 0.7;
}
.spinner.spinner-inactive .spinner-part2,
.spinner.spinner-inactive .spinner-part3,
.spinner.spinner-inactive .spinner-part4,
.spinner.spinner-inactive .spinner-part5,
.spinner.spinner-inactive .spinner-part6,
.spinner.spinner-inactive .spinner-part7,
.spinner.spinner-inactive .spinner-part8 {
  opacity: 0.2;
}
#browser:not(.animation-off) .spinner.spinner-inactive {
  animation-duration: 2s;
}
.master-detail,
.MailAccountSheet {
  display: flex;
  height: 200px;
}
.master-detail .master,
.MailAccountSheet .master {
  display: flex;
  position: relative;
  flex: 1 1 auto;
  max-width: 219px;
  min-width: 40px;
  flex-direction: column;
  border: 1px solid var(--colorBorder);
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
}
.master-detail .master.master-layout-double .master-items,
.MailAccountSheet .master.master-layout-double .master-items {
  background-size: 100% 88px;
}
.master-detail .master.master-layout-double .master-items .item,
.MailAccountSheet .master.master-layout-double .master-items .item {
  display: block;
  height: 44px;
}
.master-detail .master.master-layout-double .master-items .item .item-title,
.MailAccountSheet .master.master-layout-double .master-items .item .item-title,
.master-detail .master.master-layout-double .master-items .item .item-meta,
.MailAccountSheet .master.master-layout-double .master-items .item .item-meta {
  padding-left: 38px;
}
.master-detail .master.master-layout-single .master-items .item-icon,
.MailAccountSheet .master.master-layout-single .master-items .item-icon {
  position: static;
  width: 16px;
  min-width: 16px;
  height: 16px;
}
.master-detail .master > .master-detail.sortable-list,
.MailAccountSheet .master > .master-detail.sortable-list {
  height: stretch;
}
.master-detail .master > .master-detail.sortable-list .master-items,
.MailAccountSheet .master > .master-detail.sortable-list .master-items,
.master-detail .master > .master-detail.sortable-list .master-toolbar,
.MailAccountSheet .master > .master-detail.sortable-list .master-toolbar {
  border-top-right-radius: unset;
  border-bottom-right-radius: unset;
}
.master-detail .master > .master-detail.sortable-list .master-items,
.MailAccountSheet .master > .master-detail.sortable-list .master-items {
  border-width: 0;
}
.master-detail .master > .master-detail.sortable-list .master-toolbar,
.MailAccountSheet .master > .master-detail.sortable-list .master-toolbar {
  border-width: 1px 0 0;
}
.master-detail .master-toolbar,
.MailAccountSheet .master-toolbar {
  border-top: 1px solid var(--colorBorder);
  background-color: var(--colorBgLight);
  display: flex;
  height: 20px;
  border-bottom-left-radius: var(--radius);
}
.master-detail .master-toolbar .button-toolbar,
.MailAccountSheet .master-toolbar .button-toolbar {
  background-color: var(--colorBgLight);
  border-width: 0;
  border-right-width: 1px;
  display: flex;
  width: 30px;
  height: 19px;
  padding-left: 0;
  padding-right: 0;
  border-radius: 0;
}
.master-detail .master-toolbar .button-toolbar:not(.button-move-up):first-child,
.MailAccountSheet .master-toolbar .button-toolbar:not(.button-move-up):first-child {
  border-bottom-left-radius: var(--radius);
  background-position: 5px 1px;
}
.master-detail .master-toolbar .button-toolbar:hover,
.MailAccountSheet .master-toolbar .button-toolbar:hover {
  background-color: var(--colorBgLighter);
}
.master-detail .master-toolbar .button-toolbar:active,
.MailAccountSheet .master-toolbar .button-toolbar:active {
  background-color: var(--colorBgDark);
}
.master-detail .master-toolbar .button-toolbar:focus-visible,
.MailAccountSheet .master-toolbar .button-toolbar:focus-visible {
  z-index: 1;
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
  position: relative;
  border-color: var(--colorBgLight);
}
.master-detail .master-toolbar .button-toolbar:focus-visible:active,
.MailAccountSheet .master-toolbar .button-toolbar:focus-visible:active {
  border-color: var(--colorBgDark);
}
.master-detail .master-toolbar .button-toolbar:disabled,
.MailAccountSheet .master-toolbar .button-toolbar:disabled {
  background-color: var(--colorBg);
}
.master-detail .master-toolbar .button-toolbar:disabled > svg,
.MailAccountSheet .master-toolbar .button-toolbar:disabled > svg {
  opacity: 0.45;
}
.master-detail .master-toolbar .button-toolbar.button-move-up,
.MailAccountSheet .master-toolbar .button-toolbar.button-move-up {
  margin-left: auto;
  border-left-width: 1px;
}
.master-detail .master-toolbar .button-toolbar.button-move-down,
.MailAccountSheet .master-toolbar .button-toolbar.button-move-down {
  border-right-width: 0;
}
.master-detail .master-toolbar .button-toolbar.primary,
.MailAccountSheet .master-toolbar .button-toolbar.primary {
  color: var(--colorHighlightBg);
  fill: var(--colorHighlightBg);
  outline: 1px solid var(--colorHighlightBg);
  z-index: 1;
}
.master-detail .master-toolbar .button-toolbar.primary,
.MailAccountSheet .master-toolbar .button-toolbar.primary,
.master-detail .master-toolbar .button-toolbar.primary:focus-visible,
.MailAccountSheet .master-toolbar .button-toolbar.primary:focus-visible,
.master-detail .master-toolbar .button-toolbar.primary:active,
.MailAccountSheet .master-toolbar .button-toolbar.primary:active,
.master-detail .master-toolbar .button-toolbar.primary:focus-visible:active,
.MailAccountSheet .master-toolbar .button-toolbar.primary:focus-visible:active {
  border-color: transparent;
}
.master-detail .master-toolbar .button-toolbar.primary:hover:not([disabled]),
.MailAccountSheet .master-toolbar .button-toolbar.primary:hover:not([disabled]) {
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
  background: var(--colorHighlightBg);
}
.master-detail .master-toolbar .button-toolbar.primary:active,
.MailAccountSheet .master-toolbar .button-toolbar.primary:active {
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
  background: var(--colorHighlightBg);
}
.master-detail .master-toolbar .button-toolbar > svg,
.MailAccountSheet .master-toolbar .button-toolbar > svg {
  height: 16px;
  width: 16px;
  margin: auto;
}
.master-detail .master-items,
.MailAccountSheet .master-items {
  flex: 1;
  overflow: auto;
  outline: none;
}
.master-detail .master-items:not(:has(.master-items-empty)),
.MailAccountSheet .master-items:not(:has(.master-items-empty)) {
  background-image: linear-gradient(180deg, var(--colorBgAlpha) 0, var(--colorBgAlpha) 50%, transparent 50%, transparent 100%);
  background-size: 100% 56px;
  background-attachment: local;
  background-repeat: repeat-y;
  border-top-left-radius: var(--radius);
}
.master-detail .master-items-empty,
.MailAccountSheet .master-items-empty {
  text-align: center;
  width: 120px;
  height: 140px;
  position: absolute;
  top: 50%;
  left: 50%;
  margin-left: -60px;
  margin-top: -75px;
}
.master-detail .master-items-empty > svg,
.MailAccountSheet .master-items-empty > svg {
  display: block;
  margin-left: auto;
  margin-right: auto;
  height: 72px;
  width: 72px;
  margin-bottom: 12px;
  fill: var(--colorFgAlpha);
}
.master-detail .master-items-empty > div,
.MailAccountSheet .master-items-empty > div {
  font-size: 15px;
  opacity: 0.3;
}
.master-detail .master-items .item,
.MailAccountSheet .master-items .item {
  display: flex;
  gap: 6px;
  background-color: transparent;
  border-radius: 0;
  text-align: left;
  border-width: 0;
  width: 100%;
  position: relative;
  height: 28px;
  align-items: center;
}
.master-detail .master-items .item.dragoverAbove,
.MailAccountSheet .master-items .item.dragoverAbove {
  box-shadow: 0 1px var(--colorHighlightBg) inset, 0 -1px var(--colorHighlightBg);
}
.master-detail .master-items .item.dragoverBelow,
.MailAccountSheet .master-items .item.dragoverBelow {
  box-shadow: 0 -1px var(--colorHighlightBg) inset, 0 1px var(--colorHighlightBg);
}
.master-detail .master-items .item:focus,
.MailAccountSheet .master-items .item:focus {
  box-shadow: none;
}
.master-detail .master-items .item.item-selected,
.MailAccountSheet .master-items .item.item-selected {
  color: var(---colorFg);
  background-color: var(--colorBgDark);
}
.master-detail .master-items .item.item-selected span:not(.item-badge),
.MailAccountSheet .master-items .item.item-selected span:not(.item-badge) {
  pointer-events: none;
}
.hasfocus .master-detail .master-items .item.item-selected:focus-within input[type=radio]:checked,
.hasfocus .MailAccountSheet .master-items .item.item-selected:focus-within input[type=radio]:checked,
.hasfocus .master-detail .master-items .item.item-selected:focus-within input[type=checkbox]:checked,
.hasfocus .MailAccountSheet .master-items .item.item-selected:focus-within input[type=checkbox]:checked {
  background-color: var(--colorHighlightFg);
  border-color: var(--colorHighlightFg);
}
.hasfocus .master-detail .master-items .item.item-selected:focus-within input[type=radio]:checked:before,
.hasfocus .MailAccountSheet .master-items .item.item-selected:focus-within input[type=radio]:checked:before,
.hasfocus .master-detail .master-items .item.item-selected:focus-within input[type=checkbox]:checked:before,
.hasfocus .MailAccountSheet .master-items .item.item-selected:focus-within input[type=checkbox]:checked:before,
.hasfocus .master-detail .master-items .item.item-selected:focus-within input[type=radio]:checked:after,
.hasfocus .MailAccountSheet .master-items .item.item-selected:focus-within input[type=radio]:checked:after,
.hasfocus .master-detail .master-items .item.item-selected:focus-within input[type=checkbox]:checked:after,
.hasfocus .MailAccountSheet .master-items .item.item-selected:focus-within input[type=checkbox]:checked:after {
  background-color: var(--colorHighlightBg);
}
.master-detail .master-items .item .item-icon,
.MailAccountSheet .master-items .item .item-icon {
  position: absolute;
  left: 6px;
  top: 6px;
  height: 32px;
  width: 32px;
}
.master-detail .master-items .item .item-title,
.MailAccountSheet .master-items .item .item-title,
.master-detail .master-items .item .item-meta,
.MailAccountSheet .master-items .item .item-meta {
  pointer-events: none;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.master-detail .master-items .item .item-badge,
.MailAccountSheet .master-items .item .item-badge {
  opacity: 0.4;
  font-size: 10px;
  font-weight: 700;
  text-transform: uppercase;
  border: 1px solid;
  line-height: 1;
  padding: 0 3px 1px;
  border-radius: var(--radiusRounded);
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.master-detail .master-items .item.item-default .item-title,
.MailAccountSheet .master-items .item.item-default .item-title {
  font-weight: 700;
}
.master-detail .master-items .item .item-meta,
.MailAccountSheet .master-items .item .item-meta {
  flex: 0 0 auto;
  margin: 0 6px 0 auto;
  opacity: 0.6;
  font-size: 11.5px;
}
.master-detail .master-items:focus-within .item.item-selected,
.MailAccountSheet .master-items:focus-within .item.item-selected {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
}
.master-detail .master-items:focus-within .item.item-selected .item-badge,
.MailAccountSheet .master-items:focus-within .item.item-selected .item-badge {
  opacity: 1;
}
.master-detail .master-items:focus-within .item.item-selected svg,
.MailAccountSheet .master-items:focus-within .item.item-selected svg {
  fill: var(--colorHighlightFg);
}
.master-detail.allowOverflow,
.MailAccountSheet.allowOverflow,
.master-detail.tall,
.MailAccountSheet.tall {
  height: 280px;
}
.master-detail.giant,
.MailAccountSheet.giant {
  height: 380px;
}
.master-detail .detail,
.MailAccountSheet .detail {
  flex: 1;
  position: relative;
  display: flex;
  flex-direction: column;
  border: 1px solid var(--colorBorder);
  border-left-width: 0;
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.master-detail .detail .detail-content,
.MailAccountSheet .detail .detail-content {
  flex: 1;
  overflow-x: hidden;
  overflow-y: auto;
  padding-left: 18px;
  padding-right: 18px;
  padding-top: 18px;
  padding-bottom: 12px;
  margin: 0;
}
.allowOverflow.master-detail .detail .detail-content,
.allowOverflow.MailAccountSheet .detail .detail-content {
  overflow: visible;
}
.master-detail .detail .detail-content > p,
.MailAccountSheet .detail .detail-content > p {
  max-width: 36em;
}
.master-detail .detail .detail-content .detail-content-link,
.MailAccountSheet .detail .detail-content .detail-content-link {
  color: var(--colorHighlightBg);
  cursor: pointer;
}
.master-detail .detail .detail-content .detail-content-link:active,
.MailAccountSheet .detail .detail-content .detail-content-link:active,
.master-detail .detail .detail-content .detail-content-link:hover,
.MailAccountSheet .detail .detail-content .detail-content-link:hover {
  outline: 2px solid var(--colorHighlightBgAlpha);
}
.master-detail .detail .detail-content .dropfade,
.MailAccountSheet .detail .detail-content .dropfade {
  animation: dropfade 200ms ease-in;
}
.master-detail .detail .detail-content .setting-group,
.MailAccountSheet .detail .detail-content .setting-group {
  margin: 0 18px 12px 0;
}
.master-detail .detail .detail-content .setting-group:last-child,
.MailAccountSheet .detail .detail-content .setting-group:last-child {
  margin-right: 0;
}
.master-detail .detail .detail-content .setting-single:not(label),
.MailAccountSheet .detail .detail-content .setting-single:not(label) {
  margin-bottom: 12px;
}
.master-detail .detail .detail-content .setting-single:not(label):last-child,
.MailAccountSheet .detail .detail-content .setting-single:not(label):last-child {
  margin-bottom: 0;
}
.master-detail .detail .detail-content-static,
.MailAccountSheet .detail .detail-content-static {
  flex: 0;
  padding: 6px 0 6px 18px;
}
.master-detail .detail .detail-toolbar,
.MailAccountSheet .detail .detail-toolbar {
  display: flex;
  flex-wrap: wrap;
  flex: 0 0 auto;
  align-items: center;
  border-top: 1px solid var(--colorBorder);
  padding: 12px 18px;
  gap: 6px;
}
.master-detail .detail .detail-toolbar > *,
.MailAccountSheet .detail .detail-toolbar > * {
  margin: 0;
}
.master-detail.sortable-list,
.MailAccountSheet.sortable-list {
  flex-direction: column;
  position: relative;
}
.master-detail.sortable-list > .master-items,
.MailAccountSheet.sortable-list > .master-items {
  border: 1px solid var(--colorBorder);
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
}
.master-detail.sortable-list > .master-items:only-child,
.MailAccountSheet.sortable-list > .master-items:only-child {
  border-radius: var(--radius);
}
.master-detail.sortable-list > .master-toolbar,
.MailAccountSheet.sortable-list > .master-toolbar {
  border: 1px solid var(--colorBorder);
  border-top-width: 0;
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.master-detail.sortable-list > .master-toolbar > button.button-toolbar:not(.button-move-up):first-of-type,
.MailAccountSheet.sortable-list > .master-toolbar > button.button-toolbar:not(.button-move-up):first-of-type {
  border-bottom-left-radius: var(--radius);
}
.master-detail.sortable-list > .master-toolbar > button.button-toolbar.button-move-down:last-of-type,
.MailAccountSheet.sortable-list > .master-toolbar > button.button-toolbar.button-move-down:last-of-type {
  border-bottom-right-radius: var(--radius);
}
.master-detail .sortable-list-options,
.MailAccountSheet .sortable-list-options {
  max-width: 30px;
  max-height: 19px;
  position: absolute;
  color: var(--colorFg);
  background: none;
  text-indent: 100px;
  outline-offset: 0;
}
#browser .master-detail .sortable-list-options:hover,
#browser .MailAccountSheet .sortable-list-options:hover,
#browser .master-detail .sortable-list-options:active,
#browser .MailAccountSheet .sortable-list-options:active,
#browser .master-detail .sortable-list-options:focus-visible,
#browser .MailAccountSheet .sortable-list-options:focus-visible {
  position: absolute;
  background-color: transparent;
  background-image: unset;
}
.master-detail .sortable-list-options.button-toolbar,
.MailAccountSheet .sortable-list-options.button-toolbar {
  padding: 3px 6px;
}
#modal-bg.toolbar-editor {
  animation: dropfade 200ms linear;
  top: 16vh;
  width: 654px;
  max-width: 80vw;
  max-height: 70vh;
  z-index: 11;
}
#modal-bg.toolbar-editor > .modal-wrapper > .dialog-header {
  margin-bottom: 6px;
}
#modal-bg.toolbar-editor > .modal-wrapper > .dialog-header h1 {
  display: flex;
  justify-content: space-between;
  margin: 6px 0 12px;
}
#modal-bg.toolbar-editor > .modal-wrapper > .dialog-header p {
  margin-bottom: 12px;
  text-wrap: balance;
  font-variation-settings: normal;
}
#modal-bg.toolbar-editor > .modal-wrapper > .dialog-header .HintTooltip__content {
  position-area: bottom span-left;
}
#modal-bg.toolbar-editor > .modal-wrapper > .dialog-header .HintTooltip__content p {
  margin-bottom: 6px;
}
#modal-bg.toolbar-editor > .modal-wrapper > .dialog-header .HintTooltip__content:after {
  right: 1px;
}
#modal-bg.toolbar-editor > .modal-wrapper {
  display: flex;
  flex-direction: column;
}
#modal-bg.toolbar-editor > .modal-wrapper > .dialog-content {
  display: grid;
  flex: 1;
  grid-template-columns: repeat(auto-fill, 72px);
  grid-template-rows: minmax(72px, auto);
  justify-content: center;
  align-items: flex-start;
  grid-gap: 6px;
  margin-bottom: 6px;
  padding: 3px 6px 12px 18px;
}
#modal-bg.toolbar-editor .button-toolbar button {
  min-width: 36px;
  min-height: 36px;
}
#modal-bg.toolbar-editor .draggable-button {
  display: flex;
  flex: 0 0 auto;
  flex-direction: column;
  text-align: center;
  align-items: center;
  overflow-wrap: anywhere;
}
#modal-bg.toolbar-editor .draggable-button > * {
  max-height: inherit;
  overflow: hidden;
}
#modal-bg.toolbar-editor .draggable-button > .toolbar {
  display: contents;
}
#modal-bg.toolbar-editor .default-toolbar {
  pointer-events: none;
  display: flex;
  justify-content: center;
}
#modal-bg.toolbar-editor h3 {
  margin: 12px 18px 6px;
  text-align: center;
  font-weight: 400;
}
#modal-bg.toolbar-editor section.dialog-content .toolbar,
#modal-bg.toolbar-editor section.dialog-preview .toolbar {
  width: unset !important;
  margin-left: unset !important;
  margin-right: unset !important;
  background-color: inherit;
  flex-wrap: wrap;
  max-width: 100%;
  justify-content: center;
  height: auto;
}
#modal-bg.toolbar-editor section.dialog-content .searchfield,
#modal-bg.toolbar-editor section.dialog-preview .searchfield {
  min-width: unset;
  flex: 0 0 auto;
}
#modal-bg.toolbar-editor section.dialog-content .searchfield input,
#modal-bg.toolbar-editor section.dialog-preview .searchfield input {
  padding: 0 3px;
  width: 80px;
}
#modal-bg.toolbar-editor section.dialog-content .searchfield .toolbar,
#modal-bg.toolbar-editor section.dialog-preview .searchfield .toolbar {
  display: none;
}
#modal-bg.toolbar-editor section.dialog-preview {
  cursor: not-allowed;
  animation: slidein 50ms linear;
  transform-origin: 0 0;
  display: flex;
  flex-direction: column;
  justify-content: center;
  background-color: var(--colorBgDark);
  border: solid var(--colorBorder);
  border-width: 1px 0;
  padding: 0 6px;
}
#modal-bg.toolbar-editor section.dialog-preview > .toolbar {
  justify-content: center;
  opacity: 0.65;
}
#modal-bg.toolbar-editor section.dialog-preview > input {
  margin: 1px auto;
}
#modal-bg.toolbar-editor section.dialog-preview .button-toolbar > button {
  border: 0;
}
#modal-bg.toolbar-editor section.dialog-controls {
  margin: 0 18px 12px;
}
#modal-bg.toolbar-editor > .modal-wrapper > .dialog-footer {
  justify-content: space-between;
}
.panel-group,
#webview-container {
  transition: filter 200ms ease-in, background-color 200ms ease-in;
}
.toolbar-edit-mode .panel-group,
.toolbar-edit-mode #webview-container {
  pointer-events: none;
  filter: brightness(0.7) contrast(0.7);
  transition-duration: 800ms;
  background-color: rgba(0, 0, 0, 0.4);
}
.toolbar-edit-mode button[name='UpdateButton'] .button-title {
  display: none;
}
#browser .toolbar-editor .button-toolbar {
  align-self: center;
}
#browser .toolbar-editor .button-toolbar button {
  padding: 0;
  background-color: transparent;
  background-image: unset;
}
#browser .toolbar-editor .button-toolbar button .progress,
#browser .toolbar-editor .button-toolbar button .button-title,
#browser .toolbar-editor .button-toolbar button .button-toolbar-menu-indicator {
  display: none;
}
#browser .toolbar-editor .button-toolbar button:disabled {
  border-color: var(--colorBorder);
}
#browser .toolbar-editor .button-toolbar img,
#browser .toolbar-editor .button-toolbar svg {
  opacity: 1 !important;
}
#browser .toolbar-editor .UrlBar-PrivateWindowIndicator,
#browser .toolbar-editor .SearchField .toolbar-insideinput {
  display: none;
}
#browser .toolbar-editor .StatusInfo button span {
  max-width: 90px;
  display: grid;
  grid-template-columns: auto 1fr;
}
#browser .toolbar-editor .biscuit-setting-version {
  display: none;
}
#browser .toolbar-editor .ToolbarButton-Button:active {
  background-color: var(--colorBgAlpha);
  color: var(--colorFg);
}
#browser .toolbar-editor .ToolbarButton-Button:active svg,
#browser .toolbar-editor .ToolbarButton-Button:active img {
  transform: scale(1);
}
#browser .toolbar-editor .toolbar-mainbar:after {
  content: unset !important;
}
#browser .toolbar-editor .dialog-preview .toolbar.button-textonly,
#browser .toolbar-editor .dialog-preview .toolbar-spacer-flexible {
  max-width: 34px !important;
  min-width: 34px !important;
}
#browser .toolbar-editor .toolbar-mainbar .toolbar-extensions {
  background-color: transparent;
}
#browser .toolbar-editor .toolbar-mainbar .toolbar-extensions:after {
  content: unset;
}
#browser .toolbar-editor input[readOnly][type='text'] {
  color: var(--colorFgFadedMost);
  background-color: transparent;
  box-shadow: unset;
  height: 24px;
  line-height: 24px;
  margin: 9px 2px;
  max-width: 90px;
  cursor: default;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
#browser .toolbar-editor input[readOnly][type='text']:active {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
#browser .toolbar-editor input[readOnly][type='text']:focus-visible {
  outline: unset;
}
#browser .toolbar-editor input[readOnly][type='range'] {
  max-width: 42px;
  margin: 19px 0;
}
#browser .toolbar-editor input[readOnly][type='range']:active {
  background-color: var(--colorHighlightBg);
}
#browser .toolbar-editor input[readOnly][type='range']:active::-webkit-slider-thumb {
  border-color: var(--colorHighlightBg);
  background-color: var(--colorHighlightBg);
}
#browser .toolbar-editor .dialog-content .draggable-button {
  font-size: 11.5px;
  line-height: 1.1;
}
#browser .toolbar-editor .dialog-content .draggable-button > span {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
}
#browser .toolbar-editor .dialog-content .button-toolbar {
  margin-bottom: 6px;
  flex-basis: 36px;
}
#browser .toolbar-editor .dialog-content p {
  margin: 0;
}
#browser .toolbar-editor .dialog-content .button-badge {
  display: none;
}
.toolbar-edit-mode.hasfocus .toolbar {
  overflow: hidden;
}
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-mainbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-panel > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-statusbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ) svg,
.toolbar-edit-mode.hasfocus #tabs-container .toolbar-droptarget > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-mainbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ) img,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-panel > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ) img,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-statusbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ) img,
.toolbar-edit-mode.hasfocus #tabs-container .toolbar-droptarget > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ) img {
  animation: horizontal-wiggle 700ms linear infinite;
}
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-mainbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(2n) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-panel > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(2n) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-statusbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(2n) svg,
.toolbar-edit-mode.hasfocus #tabs-container .toolbar-droptarget > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(2n) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-mainbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(2n) img,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-panel > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(2n) img,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-statusbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(2n) img,
.toolbar-edit-mode.hasfocus #tabs-container .toolbar-droptarget > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(2n) img {
  animation-delay: 300ms;
}
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-mainbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(3n) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-panel > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(3n) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-statusbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(3n) svg,
.toolbar-edit-mode.hasfocus #tabs-container .toolbar-droptarget > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(3n) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-mainbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(3n) img,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-panel > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(3n) img,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-statusbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(3n) img,
.toolbar-edit-mode.hasfocus #tabs-container .toolbar-droptarget > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(3n) img {
  animation-delay: 500ms;
}
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-mainbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(4n) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-panel > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(4n) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-statusbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(4n) svg,
.toolbar-edit-mode.hasfocus #tabs-container .toolbar-droptarget > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(4n) svg,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-mainbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(4n) img,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-panel > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(4n) img,
.toolbar-edit-mode.hasfocus .toolbar-droptarget.toolbar-statusbar > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(4n) img,
.toolbar-edit-mode.hasfocus #tabs-container .toolbar-droptarget > *:not(
    .toolbar-divider,
    .toolbar-spacer,
    .toolbar-spacer-flexible,
    .toolbar-spacer-panel,
    .UrlBar-AddressField,
    .UrlBar-SearchField,
    .StatusInfo,
    .biscuit-setting-version,
    .button-textonly
  ):nth-child(4n) img {
  animation-delay: 100ms;
}
.toolbar-edit-mode .toolbar:not(.toolbar-droptarget) .button-toolbar > button:disabled svg,
.toolbar-edit-mode .toolbar:not(.toolbar-droptarget) .button-toolbar > button:disabled img {
  opacity: 0;
}
.thumbnail-image {
  display: grid;
  flex: 1;
  line-height: 0;
  width: 100%;
  overflow: hidden;
  border-radius: var(--radius);
}
.thumbnail-image span {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 4;
  -webkit-box-orient: vertical;
  width: 100%;
  max-width: 100%;
  place-self: center;
  text-align: center;
  line-height: normal;
  word-break: break-word;
}
.thumbnail-image img {
  height: 100%;
  object-position: top;
  object-fit: cover;
}
.thumbnail-image svg {
  width: 40%;
  height: auto;
  margin: 0 auto;
  place-self: center;
}
.notes-cardwrapper,
.addbookmark-cardwrapper {
  display: flex;
  flex: 1;
  flex-flow: column nowrap;
  border-radius: var(--radiusRounded);
  border-radius: var(--radiusHalf);
}
.notes-cardwrapper .upper-half,
.addbookmark-cardwrapper .upper-half {
  display: flex;
  flex-direction: row;
  margin-top: 6px;
  flex-shrink: 0;
}
.internal-page .notes-cardwrapper .upper-half,
.internal-page .addbookmark-cardwrapper .upper-half {
  padding: 6px 6px 0;
  flex-direction: column;
}
.notes-cardwrapper .upper-half .UrlField,
.addbookmark-cardwrapper .upper-half .UrlField {
  min-width: 0;
}
.notes-cardwrapper .upper-half .preview,
.addbookmark-cardwrapper .upper-half .preview {
  display: flex;
  flex: 0 0 110px;
  height: 90px;
  margin: 6px 0;
  border: 1px solid var(--colorBgDarker);
  border-radius: var(--radius);
}
.internal-page .notes-cardwrapper .upper-half .preview,
.internal-page .addbookmark-cardwrapper .upper-half .preview {
  flex: 0 1 200px;
  margin: 0 6px;
}
.notes-cardwrapper .upper-half .title-and-address,
.addbookmark-cardwrapper .upper-half .title-and-address {
  flex: 1;
  padding: 6px 6px 0 2px;
  overflow: hidden;
}
.internal-page .notes-cardwrapper .upper-half .title-and-address,
.internal-page .addbookmark-cardwrapper .upper-half .title-and-address {
  overflow: visible;
  padding: 6px 0 0;
  order: 2;
}
.notes-cardwrapper .lower-half,
.addbookmark-cardwrapper .lower-half {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  flex-shrink: 0;
  padding: 0 2px;
}
.internal-page .notes-cardwrapper .lower-half,
.internal-page .addbookmark-cardwrapper .lower-half {
  padding: 6px;
}
.notes-cardwrapper .lower-half .speeddial-bookmarksbar,
.addbookmark-cardwrapper .lower-half .speeddial-bookmarksbar {
  display: flex;
}
.notes-cardwrapper {
  padding: 6px;
}
.cb-form-row {
  display: flex;
  padding-top: 6px;
}
.cb-form-row .vivaldi-tree {
  border-radius: var(--radiusHalf);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset;
  border: 1px solid #f7f7f7;
  height: 100px;
  overflow-y: auto;
}
.cb-form-row .bookmark-folder-picker {
  display: flex;
  flex: 1;
  max-width: 100%;
}
.cb-form-row .bookmark-folder-picker select {
  min-width: 100%;
}
.cb-form-row .bookmark-folder-picker:hover select,
.cb-form-row .bookmark-folder-picker:hover input {
  background-color: var(--colorBgLight);
}
.cb-form-row .bookmark-folder-picker input[type=text] {
  background-color: var(--colorBgIntense);
}
.fieldset,
fieldset {
  padding: 2px 0;
}
.fieldset.cardview,
fieldset.cardview {
  padding-left: 6px;
}
.cardview label {
  display: flex;
  align-content: center;
}
.cardview label > input[type=checkbox] + span {
  padding-left: 6px;
}
.cardview input[type=text],
.cardview input[type=date],
.cardview input[type=email],
.cardview input[type=tel],
.cardview textarea {
  flex: 1;
  box-shadow: none;
  border: 1px solid transparent;
  align-self: stretch;
  min-width: 0;
  background-color: transparent;
}
.cardview input[type=text]:focus,
.cardview input[type=date]:focus,
.cardview input[type=email]:focus,
.cardview input[type=tel]:focus,
.cardview textarea:focus,
.cardview input[type=text]:hover,
.cardview input[type=date]:hover,
.cardview input[type=email]:hover,
.cardview input[type=tel]:hover,
.cardview textarea:hover {
  background-color: var(--colorBgIntense);
}
.cardview input[type=text],
.cardview input[type=email],
.cardview input[type=tel] {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.cardview input[type=text].downloads,
.cardview input[type=email].downloads,
.cardview input[type=tel].downloads {
  margin-bottom: 6px;
  width: 100%;
}
.cardview textarea {
  resize: vertical;
  flex-grow: 1;
  min-height: 28px;
}
.cardview .downloads-panel-actions input {
  margin-left: 0;
  margin-bottom: 3px;
}
.cardview .downloads-panel-actions .download-panel {
  display: inline-flex;
  margin: 6px;
}
.cardview .downloads-panel-actions .download-panel.title {
  display: grid;
  grid-template-columns: auto 1fr;
  margin-top: 12px;
  margin-left: 6px;
  font-weight: 700;
}
.cardview .downloads-panel-actions .download-panel.title .DownloadItem-FileName-Name {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.cardview .dateCreated {
  display: flex;
  font-size: 11.5px;
  text-align: left;
  width: 100%;
  margin-top: 6px;
  margin-bottom: 6px;
  margin-left: 0;
  background-color: transparent;
  color: var(--colorFg);
}
.cardview .dateCreated.bookmark {
  margin-left: 6px;
}
.cardview .dateModified {
  display: flex;
  font-size: 11.5px;
  text-align: left;
  width: 100%;
  margin-top: 6px;
  margin-bottom: 6px;
  margin-left: 0;
  background-color: transparent;
  color: var(--colorFg);
}
.cardview .dateModified.bookmark {
  margin-left: 6px;
}
.cardview .meta-icon {
  display: flex;
  width: 16px;
  height: 16px;
  background-color: transparent;
  background-repeat: no-repeat;
  background-position: 50%;
  border: 0;
  margin-right: 6px;
  margin-left: 6px;
  padding: 0;
}
.cardview .meta-icon.speed {
  margin: auto 6px;
}
.cardview .meta-icon.url {
  margin: auto 0 auto 6px;
  cursor: pointer;
}
.cardview .meta-icon.url svg {
  margin-top: -5px;
}
.cardview .meta-icon.url svg:hover {
  opacity: 1;
}
.TabbedView {
  margin-bottom: 12px;
  max-width: 660px;
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
  overflow: auto;
}
.TabbedView:has(.TabbedView-Content) {
  display: flex;
  flex-direction: column;
  overflow: hidden;
}
.TabbedView-List {
  display: flex;
  gap: 6px;
  padding: 6px;
  background-color: var(--colorBgLight);
  border-bottom: 1px solid var(--colorBorderDisabled);
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
}
.TabbedView-List button {
  display: flex;
  gap: 6px;
  padding: 6px;
  background-color: transparent;
  border-color: transparent;
  color: var(--colorFgFaded);
  align-items: center;
  text-align: left;
  line-height: 1;
}
.TabbedView-List button:hover:not(.active) {
  background-color: var(--colorBgLighter);
  box-shadow: 0 0 2px rgba(0, 0, 0, 0.2);
}
.Dashboard-Widgets .transparent .TabbedView-List button:hover:not(.active) {
  color: var(--colorImageCenterFg, var(--colorWindowFg));
  background: var(--colorBgAlphaHeavier);
}
.TabbedView-List button.active {
  background-color: var(--colorBgLighter);
  box-shadow: 0 0 2px rgba(0, 0, 0, 0.2), 0 2px 3px rgba(0, 0, 0, 0.1);
  border: 1px solid transparent;
  color: var(--colorHighlightBg);
}
.TabbedView-List button.error {
  background-color: var(--colorBgError);
  color: var(--colorErrorBg);
}
.TabbedView-List button.error.active {
  background: var(--colorErrorBgAlpha);
}
.TabbedView-List button svg {
  pointer-events: none;
  height: 16px;
  width: 16px;
  flex: 0 0 auto;
}
.TabbedView--Padded {
  padding: 12px;
}
.TabbedView-Content {
  overflow: auto;
}
.TabbedView-Footer {
  display: flex;
  flex-wrap: wrap;
  justify-content: flex-end;
  gap: 6px;
  padding: 6px 12px;
  background-color: var(--colorBgLight);
  border-top: 1px solid var(--colorBorderDisabled);
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.TabbedView-Footer .InlineText {
  display: flex;
  align-items: center;
  margin-right: auto;
}
.TabbedView-Footer input[type=submit] {
  margin-left: auto;
}
.HUD {
  display: flex;
  flex-direction: column;
  justify-content: center;
  font-size: 100px;
  align-items: center;
  background-color: var(--colorBgAlphaHeavy);
  color: var(--colorFg);
  backdrop-filter: var(--backgroundBlur);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 5px 12px rgba(0, 0, 0, 0.25);
  border-radius: 50%;
  corner-shape: superellipse(var(--cornerShape));
  border: none;
  position: fixed;
  left: 50%;
  top: 50%;
  margin-top: -100px;
  margin-left: -100px;
  scale: 1;
  /* Starts from the first exhalation.
     Exhalation should be twice as long as inhalation (2:1). */
  /* Starts from the first inhalation. */
}
@property --cornerShape {
  syntax: '<number>';
  initial-value: 2;
  inherits: false;
}
.HUD > svg {
  height: 156px;
  width: 156px;
}
.HUD-enter {
  transform: scale(1.4);
  opacity: 0;
}
.HUD-enter-active {
  opacity: 0.75;
  transform: none;
  transition: transform 200ms ease-out, opacity 300ms ease-out;
}
.HUD-enter-done {
  --breathing-rate: 10s;
  --breathing-start-delay: 2s;
  transition-duration: 200ms, 200ms;
  opacity: 0.75;
  /* 6 breaths per minute */
  animation: var(--breathing-rate) breathing-pause linear infinite;
  animation-delay: var(--breathing-start-delay);
}
.HUD-enter-done:after {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  border-radius: inherit;
  corner-shape: inherit;
  border: solid 6px var(--colorFgAlpha);
  animation: var(--breathing-rate) breathing-pause-blip linear infinite;
  animation-delay: calc(var(--breathing-start-delay) + calc(var(--breathing-rate) * 0.6));
  opacity: 0;
}
.HUD-enter-done:hover,
.HUD-enter-done:focus-visible {
  opacity: 1;
  transform: scale(1.01);
}
.HUD-enter-done:active {
  transform: none;
}
@keyframes breathing-pause {
  0%,
  2%,
  98%,
  100% {
    --cornerShape: 2;
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 5px 12px rgba(0, 0, 0, 0.25);
    scale: 1;
  }
  60%,
  64% {
    --cornerShape: 1;
    box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 2px 8px rgba(0, 0, 0, 0.35);
    scale: 0.95;
  }
}
@keyframes breathing-pause-blip {
  0%,
  12%,
  40%,
  52%,
  100% {
    opacity: 0;
    scale: 1.1;
  }
  1%,
  41% {
    opacity: 0.75;
    scale: 1.1;
  }
  11%,
  51% {
    opacity: 0;
    scale: 1.35;
  }
}
.HUD-exit {
  opacity: 0.75;
}
.HUD-exit-active {
  opacity: 0;
  transition: opacity 80ms ease-out;
}
.HUD-exit-done {
  opacity: 0;
}
.VivaldiSvgIcon {
  height: calc(var(--IconSize, 16) * 1px);
  width: calc(var(--IconSize, 16) * 1px);
  display: inline-flex;
}
.VivaldiSvgIcon svg {
  height: 100%;
  width: 100%;
}
html {
  height: 100vh;
  max-height: 100vh;
  fill: currentColor;
}
html,
body,
#browser,
#main {
  display: flex;
  flex: 1 1 auto;
  overflow: hidden;
}
#app {
  display: flex;
  flex: 1;
}
a:-webkit-any-link {
  color: var(--colorHighlightBg);
}
a:-webkit-any-link:hover {
  color: var(--colorHighlightBgDark);
}
a:-webkit-any-link.external-link svg {
  margin-left: 6px;
  fill: var(--colorHighlightBg);
}
#browser {
  display: flex;
  flex-flow: column nowrap;
  position: relative;
  max-width: 100vw;
  max-height: 100vh;
  animation: fade 200ms ease-out;
  background-position: center;
  background-color: var(--colorWindowBg);
  color: var(--colorFg);
  fill: currentColor;
}
#browser.fullscreen:not(.mac),
#browser.fullscreen.mac.inner {
  box-shadow: none;
}
#browser.fullscreen:not(.mac) #header,
#browser.fullscreen.mac.inner #header,
#browser.fullscreen:not(.mac) #footer,
#browser.fullscreen.mac.inner #footer {
  min-height: 0;
  border: 0 !important;
}
#browser.fullscreen:not(.mac).minimal-ui .topmenu,
#browser.fullscreen.mac.inner.minimal-ui .topmenu {
  display: none;
}
#browser.fullscreen.inner #header,
#browser.fullscreen.inner .mainbar,
#browser.fullscreen.inner .bookmark-bar,
#browser.fullscreen.inner .find-in-page,
#browser.fullscreen.inner .tabbar-wrapper,
#browser.fullscreen.inner #panels-container,
#browser.fullscreen.inner .toolbar-statusbar {
  display: none;
}
#browser.win.normal {
  padding-right: 0;
  padding-left: 0;
  padding-bottom: 0;
  height: 100%;
}
#webpage-stack {
  display: flex;
  flex: 1;
  contain: strict;
}
.webpageview:not(.internal) .internal-page,
.webpageview:not(.active):not(.tiled) .internal-page {
  content-visibility: hidden;
  z-index: -1;
}
#browser.touch-support:has(.button-popup-appear-done) webview {
  pointer-events: none;
}
#browser.win.fullscreen .webpageview .startpage {
  top: 0;
}
#main {
  position: relative;
  flex-direction: column;
}
#main > .inner {
  display: flex;
  flex: 1 1 0;
  position: relative;
  overflow: hidden;
}
#main > .inner.justify-end {
  justify-content: flex-end;
}
#header {
  position: relative;
  flex: 0 0 auto;
}
#browser:not(.tabs-top) #header {
  color: var(--colorFg);
  background-color: var(--colorBg);
}
.color-behind-tabs-off:not(.is-settingspage)#browser:not(.tabs-top) #header {
  color: var(--colorAccentFg);
  background-color: var(--colorAccentBg);
}
.auto-hide-wrapper.top:has(.mainbar):not(.has-tabbar) .topmenu {
  color: var(--colorFg);
  background-color: var(--colorBg);
}
.color-behind-tabs-off .auto-hide-wrapper.top:has(.mainbar):not(.has-tabbar) .topmenu {
  color: var(--colorAccentFg);
  background-color: var(--colorAccentBg);
}
.auto-hide-wrapper.top.has-tabbar .topmenu {
  color: var(--colorImageFg, var(--colorAccentFg));
  background-color: var(--colorTabBar);
}
.color-behind-tabs-off .auto-hide-wrapper.top.has-tabbar .topmenu {
  color: var(--colorImageFg, var(--colorFg));
}
.auto-hide-wrapper.top .topmenu {
  color: var(--colorFg);
  background-color: var(--colorBg);
}
#browser:not(.is-settingspage).color-accent-from-page.color-behind-tabs-on.transparent-tabbar.tabs-top #header:before,
#browser:not(.is-settingspage).color-accent-from-page.color-behind-tabs-on.transparent-tabbar.tabs-left .inner > .tabbar-wrapper:before,
#browser:not(.is-settingspage).color-accent-from-page.color-behind-tabs-on.transparent-tabbar.tabs-right .inner > .tabbar-wrapper:before,
#browser:not(.is-settingspage).color-accent-from-page.color-behind-tabs-on.transparent-tabbar.tabs-bottom > footer:before {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  mix-blend-mode: multiply;
  backdrop-filter: var(--backgroundBlur);
  pointer-events: none;
  background-color: var(--colorAccentBg);
  z-index: 0;
  contain: content;
}
#webview-container {
  --anchor-name: --webview-container-anchor;
  display: flex;
  flex: 1;
  position: relative;
}
.webpageview {
  position: absolute;
  display: flex;
  inset: 0;
}
.popup.is-settingspage .webpageview {
  position: relative;
  height: 100%;
}
#browser:not(.is-settingspage) .webpageview {
  flex-flow: column nowrap;
}
.webpageview.internal > div .webpage {
  flex: 0;
}
.webpageview.internal.visible .internal-page {
  position: absolute;
  inset: 0;
}
.active-pane-selection .webpageview.pagefocusstop:focus-within webview:after {
  animation: fade 400ms ease-in 400ms 1 reverse, delay_visibility 800ms linear;
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  opacity: 1;
  visibility: hidden;
  pointer-events: none;
}
.webpageview > .row-wrapper {
  display: flex;
  flex: 1;
  overflow: hidden;
  position: relative;
}
.webpageview > .row-wrapper .webpage {
  position: absolute;
  inset: 0;
}
.webpageview > .pageload {
  display: contents;
}
.webpageview > .pageload .pageload-indicator {
  width: 100%;
  max-height: 3px;
  position: absolute;
  z-index: 1;
  border-radius: 0;
}
.webpageview > .pageload .pageload-indicator::-webkit-progress-value {
  background-color: var(--colorHighlightBg);
}
.webpageview > .pageload .pageload-indicator::-webkit-progress-bar {
  background-color: var(--colorFgAlpha);
}
.webpageview > .pageload .pageload-indicator.rainbow::-webkit-progress-bar {
  background-image: linear-gradient(270deg, #fd747f80 0%, #f8cf3d80 25%, #fee86180 50%, #29f6a380 75%, #39dffd80 100%);
}
.webpageview > .pageload > div {
  display: none;
}
.webpageview .mosaic-tile + .pageload .pageload-indicator {
  top: 30px;
}
.webpageview > .pageload:is(.progress-done, .unstarted) {
  display: none;
}
.devtools-container {
  display: flex;
  flex: 1;
  overflow: hidden;
  background-color: transparent;
  position: relative;
}
.devtools-content {
  position: absolute;
  inset: 0;
  background-color: var(--colorBg);
}
.webpageview .webpage {
  background-color: var(--colorBg);
}
webview,
#mail_view,
#mail_composer {
  position: absolute;
  inset: 0;
  width: auto;
  height: auto;
  outline: none;
}
.internal.webpageview .webpage {
  visibility: hidden;
}
.input-dropdown:hover:not(:disabled) svg,
.password-icon:hover:not(:disabled) svg {
  fill: var(--colorFg);
}
.selectable {
  user-select: text;
  cursor: text;
  -webkit-app-region: no-drag;
}
.no-events {
  pointer-events: none;
  overflow: hidden;
}
.error-boundary {
  flex: 1;
  padding: 12px;
  max-width: 100%;
  overflow: hidden;
  background: var(--colorBgAlphaBlur);
}
.error-boundary pre {
  overflow: auto;
  max-width: fit-content;
  padding: 6px;
  user-select: text;
}
.error-boundary h1,
.error-boundary p {
  margin-bottom: 6px;
}
span.focus_anchor {
  position: absolute;
}
.SearchField,
.MailSearchField-Inner,
.UrlBar-AddressField {
  border-radius: var(--radius);
  border: 1px solid var(--colorBgDark);
  color: var(--colorFg);
  background-color: var(--colorBgIntense);
  align-items: center;
  display: flex;
}
.dim-blurred:not(.hasfocus) .SearchField,
.dim-blurred:not(.hasfocus) .MailSearchField-Inner,
.dim-blurred:not(.hasfocus) .UrlBar-AddressField {
  border: 1px solid var(--colorBorder);
}
.color-behind-tabs-on .SearchField:focus-within,
.color-behind-tabs-on .MailSearchField-Inner:focus-within,
.color-behind-tabs-on .UrlBar-AddressField:focus-within {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
}
.color-behind-tabs-off .SearchField,
.color-behind-tabs-off .MailSearchField-Inner,
.color-behind-tabs-off .UrlBar-AddressField {
  border: 1px solid var(--colorBgIntense);
}
.color-behind-tabs-off .SearchField:focus-within,
.color-behind-tabs-off .MailSearchField-Inner:focus-within,
.color-behind-tabs-off .UrlBar-AddressField:focus-within {
  outline: 2px solid var(--colorAccentBgFadedMost);
  outline-offset: -2px;
}
.color-behind-tabs-on .SearchField.SearchField--DropdownOpen,
.color-behind-tabs-on .UrlBar-AddressField:has(div.OmniDropdown) {
  outline: none;
  border-color: transparent;
  box-shadow: none;
}
.focus-anchor {
  position: absolute;
  place-self: center;
  top: -40px;
  opacity: 0;
  max-width: fit-content;
  margin: 0 auto;
  padding: 3px 12px;
  color: #efefef;
  background-color: rgba(0, 0, 0, 0.8);
  font-size: 16px;
  border: 2px solid #efefef;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  z-index: 102;
  transition: opacity 64ms ease-in;
}
.focus-anchor:focus {
  top: 6px;
  opacity: 1;
}
.focus-anchor:focus-visible {
  outline: none;
}
.insecure-indicator {
  opacity: 0;
  position: absolute;
  bottom: 6px;
  left: 6px;
  display: flex;
  align-items: center;
  padding: 3px 6px;
  pointer-events: none;
  color: var(--colorFg);
  background-color: var(--colorBg);
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
}
.insecure-indicator.visible {
  opacity: 1;
}
.insecure-indicator svg {
  width: 16px;
  height: 16px;
  margin-right: 6px;
}
.tabbar-wrapper {
  --currentRadius: var(--radiusHalf);
}
.density-on:not(.tabs-at-edge) .tabbar-wrapper {
  --currentRadius: var(--radius);
}
.tab-position {
  position: absolute;
  display: flex;
  transform: translateX(var(--PositionX)) translateY(var(--PositionY));
  opacity: var(--Opacity);
  height: var(--Height);
  width: var(--Width);
  z-index: var(--ZIndex);
}
.tabs-left #tabs-tabbar-container.resizing .tab-position:not(.accordion-toggle-arrow),
.tabs-right #tabs-tabbar-container.resizing .tab-position:not(.accordion-toggle-arrow) {
  width: 100%;
}
.tabs-top #tabs-tabbar-container.resizing .tab-position:not(.accordion-toggle-arrow),
.tabs-bottom #tabs-tabbar-container.resizing .tab-position:not(.accordion-toggle-arrow) {
  height: 100%;
}
.tab-position.is-substack > .tab.active {
  border-top-left-radius: var(--currentRadius);
  border-top-right-radius: var(--currentRadius);
  border-bottom-left-radius: var(--currentRadius);
  border-bottom-right-radius: var(--currentRadius);
}
.page-progress-indicator {
  --currentAlphaLow: color-mix(in srgb, currentColor 40%, transparent);
  --currentAlphaHigh: color-mix(in srgb, currentColor 60%, transparent);
  --progress-height: 2px;
  --progress-width: calc(var(--Width) - calc(6px * 2));
  contain: strict;
  contain-intrinsic-height: var(--progress-height);
  contain-intrinsic-width: var(--progress-width);
  position: absolute;
  right: 6px;
  bottom: var(--progress-height);
  left: 6px;
  height: var(--progress-height);
  width: var(--progress-width);
  opacity: 0;
  visibility: hidden;
}
.page-progress-indicator.progress-visible {
  opacity: 1;
  visibility: visible;
}
.page-progress-indicator::-webkit-progress-inner-element,
.page-progress-indicator::-webkit-progress-bar {
  background-color: transparent;
}
.page-progress-indicator::-webkit-progress-value {
  transition: width 500ms;
  background-color: var(--currentAlphaHigh);
}
.page-progress-indicator.progress-done {
  transition: opacity 200ms ease-out 500ms;
}
.page-progress-indicator[value] {
  background-color: transparent;
}
.page-progress-indicator:not([value]) {
  background-color: transparent;
  background-position: 0 0;
  background-image: linear-gradient(-45deg, var(--currentAlphaLow) 5px, var(--currentAlphaHigh) 6px, var(--currentAlphaHigh) 14px, var(--currentAlphaLow) 15px);
  background-size: 24px 6px;
  animation: animated-stripes 5s linear infinite;
}
.periodic-reload .page-progress-indicator::-webkit-progress-value {
  transition: width 1s linear;
  /* time in sync with PeriodicReloadStore.js */
}
.tab {
  display: flex;
  flex: 1;
  flex-flow: column;
  overflow: hidden;
  font-size: 12px;
  user-select: none;
  position: relative;
}
.tabs-top.density-on.tabs-at-edge .tab:not(.tab-in-accordion).active,
.tabs-top:not(.density-on) .tab:not(.tab-in-accordion).active,
.tabs-bottom.density-on.tabs-at-edge .tab:not(.tab-in-accordion).active,
.tabs-bottom:not(.density-on) .tab:not(.tab-in-accordion).active {
  overflow: visible;
}
.color-behind-tabs-on .tab {
  color: var(--colorAccentFg);
}
:not(.ui-transparent-tabs).color-behind-tabs-on .tab {
  background-color: var(--colorAccentBgAlphaHeavy);
}
#browser.color-behind-tabs-on .tab.active.active {
  background-color: var(--colorBg);
  color: var(--colorFg);
}
.color-behind-tabs-on .tab-wrapper:hover .tab:not(.active) {
  background-color: var(--colorAccentBgAlpha);
}
.color-behind-tabs-off .tab {
  color: var(--colorFg);
}
:not(.ui-transparent-tabs).color-behind-tabs-off .tab {
  background-color: var(--colorBgDark);
}
#browser.color-behind-tabs-off .tab.active.active {
  color: var(--colorAccentFg);
}
.color-behind-tabs-off .tab-wrapper:hover .tab:not(.active) {
  background-color: var(--colorBgDarker);
}
.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tab {
  color: var(--colorImageFg, var(--colorFg));
}
:not(.ui-transparent-tabs).transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tab {
  background-color: var(--colorImageBgAlphaHeavy, var(--colorBgAlphaHeavier));
}
.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .tab-wrapper:hover .tab:not(.active) {
  background-color: var(--colorImageBgAlpha, var(--colorBgAlpha));
}
#browser#browser .tab.tab-acceptsdrop {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  transition: background-color 200ms linear;
  filter: contrast(1.2);
}
#browser#browser .tab.tab-acceptsdrop:after {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  border-radius: var(--currentRadius);
  outline: var(--colorHighlightFg) 2px solid;
  outline-offset: -2px;
}
.tabs-top:not(.density-on)#browser#browser .tab.tab-acceptsdrop.active:after {
  bottom: 1px;
}
.tabs-bottom:not(.density-on)#browser#browser .tab.tab-acceptsdrop.active:after {
  top: 1px;
}
.tab .spinner {
  transform: scale(1);
}
.ui-transparent-tabs .tab {
  background-color: rgba(0, 0, 0, 0.001);
}
#browser .tab.active {
  background-color: var(--colorAccentBg);
  color: var(--colorAccentFg);
}
.color-behind-tabs-off#browser .tab.active.insubstrip {
  color: var(--colorAccentFg);
  background-color: var(--colorAccentBg);
}
.tab-wrapper:hover .tab:not(.active) {
  background-color: var(--colorImageBgAlpha, var(--colorBgAlphaHeavy));
}
.tab-wrapper[aria-hidden=true] .tab {
  overflow: hidden;
}
.tabs-top.tabs-at-edge .tab-position:not(.is-substack) .tab.active,
.tabs-top:not(.density-on) .tab-position:not(.is-substack) .tab.active {
  height: calc(var(--Height) + 1px);
}
.tabs-bottom.tabs-at-edge .tab-position:not(.is-substack) .tab.active,
.tabs-bottom:not(.density-on) .tab-position:not(.is-substack) .tab.active {
  height: calc(var(--Height) + 1px);
  padding-top: 1px;
  top: -1px !important;
}
.tabs-top .tab:not(.active),
.tabs-bottom .tab:not(.active) {
  max-height: var(--Height);
}
.tabs-top:not(.density-on) .tab,
.tabs-bottom:not(.density-on) .tab {
  max-width: calc(var(--Width) - 1px);
}
.tabs-top.density-on .tab:not(.tab-in-accordion, .tab-accordion),
.tabs-bottom.density-on .tab:not(.tab-in-accordion, .tab-accordion) {
  max-width: calc(var(--Width) - var(--densityGap));
}
.tabs-top.density-on .tab:not(.tab-in-accordion, .tab-accordion).tab-small,
.tabs-bottom.density-on .tab:not(.tab-in-accordion, .tab-accordion).tab-small {
  max-width: calc(var(--Width) - 1px);
}
.tabs-bottom .is-substack .tab.active,
.tabs-bottom .tab:not(.tab-in-accordion, .tab-accordion, .active),
.tabs-bottom.density-on:not(.tabs-at-edge) .tab:not(.tab-in-accordion, .tab-accordion),
.tabs-top .tab:not(.tab-in-accordion, .tab-accordion) {
  border-top-left-radius: var(--currentRadius);
  border-top-right-radius: var(--currentRadius);
}
.tabs-top .is-substack .tab.active,
.tabs-top .tab:not(.tab-in-accordion, .tab-accordion, .active),
.tabs-top.density-on:not(.tabs-at-edge) .tab:not(.tab-in-accordion, .tab-accordion),
.tabs-bottom .tab:not(.tab-in-accordion, .tab-accordion) {
  border-bottom-left-radius: var(--currentRadius);
  border-bottom-right-radius: var(--currentRadius);
}
.tabs-left .tab:not(.tab-in-accordion, .tab-accordion),
.tabs-right .tab:not(.tab-in-accordion, .tab-accordion) {
  border-radius: var(--currentRadius);
}
.tabs-left .tab.tab-in-accordion.tab-first-in-group,
.tabs-right .tab.tab-in-accordion.tab-first-in-group,
.tabs-left .tab.tab-accordion,
.tabs-right .tab.tab-accordion {
  border-top-left-radius: var(--currentRadius);
  border-top-right-radius: var(--currentRadius);
}
.tabs-left .tab:is(.tab-accordion, .tab-in-accordion) .tab-header,
.tabs-right .tab:is(.tab-accordion, .tab-in-accordion) .tab-header {
  padding-top: var(--densityGap);
}
.tabs-left .tab:not(.tab-accordion, .tab-in-accordion),
.tabs-right .tab:not(.tab-accordion, .tab-in-accordion) {
  max-height: calc(var(--Height) - max(var(--densityGap), 1px));
}
.tab.insubstrip {
  border-radius: var(--currentRadius);
}
.tabs-top.tabs-at-edge .tab.insubstrip.active:not(.marked),
.tabs-top:not(.density-on) .tab.insubstrip.active:not(.marked) {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}
.tabs-bottom.tabs-at-edge .tab.insubstrip.active:not(.marked),
.tabs-bottom:not(.density-on) .tab.insubstrip.active:not(.marked) {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.tab:not(.active) .svg-tab-selection .inner {
  fill: var(--colorHighlightBgAlpha);
}
.tab.tab-in-accordion .svg-tab-selection .inner {
  fill: url(#diagonalLinePattern);
  fill-opacity: 0.2;
}
.tab.marked:not(.tab-first-in-group):not(.tab-accordion) {
  position: relative;
}
.tab.pinned .close,
.tab.pinned:hover .close {
  display: none !important;
}
.tab.pinned .favicon,
.tab.pinned:hover .favicon {
  visibility: visible !important;
}
.tab.unread {
  background-image: linear-gradient(-135deg, color-mix(in srgb, var(--colorImageFg, var(--colorFg)), transparent) calc(6px + var(--currentRadius) / 4), transparent calc(6px + var(--currentRadius) / 4));
  background-position: top right;
  background-repeat: no-repeat;
}
.color-behind-tabs-on .tab.unread {
  background-image: linear-gradient(-135deg, color-mix(in srgb, var(--colorAccentFg), transparent) calc(6px + var(--currentRadius) / 4), transparent calc(6px + var(--currentRadius) / 4));
}
.tabs-bottom .tab.unread {
  background-image: linear-gradient(-45deg, color-mix(in srgb, var(--colorImageFg, var(--colorFg)), transparent) calc(6px + var(--currentRadius) / 4), transparent calc(6px + var(--currentRadius) / 4));
}
.color-behind-tabs-on.tabs-bottom .tab.unread {
  background-image: linear-gradient(-45deg, color-mix(in srgb, var(--colorAccentFg), transparent) calc(6px + var(--currentRadius) / 4), transparent calc(6px + var(--currentRadius) / 4));
}
.tabs-bottom .tab.unread .thumbnail-image {
  mask-image: linear-gradient(-45deg, transparent calc(6px + var(--currentRadius) / 4), #000 calc(6px + var(--currentRadius) / 4));
}
.tab .tab-header {
  display: flex;
  flex: 0 0 30px;
  position: relative;
  padding-left: 6px;
  overflow: hidden;
  align-items: center;
}
.tab .tab-header.expecting-drop {
  pointer-events: none;
}
.tab .favicon,
.tab .close {
  min-width: 18px;
  min-height: 18px;
  overflow: hidden;
}
.tab .stack-counter {
  height: auto;
  line-height: 1.3;
  padding: 1px 4px;
  border-radius: var(--radiusHalf);
  font-size: 11.5px;
  font-weight: 400;
  overflow: visible;
  min-width: 1.5em;
  text-align: center;
  margin-right: 6px;
  align-self: center;
}
.color-behind-tabs.on .tab .stack-counter {
  background-color: var(--colorImageBg, var(--colorAccentBgAlpha));
  color: var(--colorImageFg, var(--colorAccentFg));
}
.color-behind-tabs-off .tab .stack-counter {
  background-color: var(--colorImageBg, var(--colorBgDarker));
  color: var(--colorImageFg, var(--colorFg));
}
.tab.active .stack-counter {
  background-color: var(--colorBgDarker);
  color: var(--colorFg);
}
.color-behind-tabs-off .tab.active .stack-counter {
  background-color: var(--colorAccentBgAlpha);
  color: var(--colorAccentFg);
}
.tab.tab-small .stack-counter {
  display: none;
}
.tab .favicon.progress {
  --currentAlpha: color-mix(in srgb, currentColor 20%, transparent);
  filter: unset !important;
  max-width: 16px;
  min-width: 16px;
  min-height: 16px;
  max-height: 16px;
  margin: 1px;
  border-radius: 50%;
  background-image: conic-gradient(currentColor var(--progressInPercent), var(--currentAlpha) 0%);
  transition: --progressInPercent 300ms linear;
  mask-image: -webkit-gradient(radial, 8 8, 5, 8 8, 5.5, from(transparent), to(#000));
  animation-fill-mode: forwards;
}
@property --progressInPercent {
  syntax: '<percentage>';
  inherits: false;
  initial-value: 0%;
}
.tab .favicon.progress.infinite-spin {
  background-image: conic-gradient(currentColor 0%, currentColor 20%, var(--currentAlpha) 20% 50%, currentColor 50%, currentColor 70%, var(--currentAlpha) 70% 100%);
  animation: spin 1s linear infinite;
}
.tab .favicon {
  pointer-events: none;
  flex: 0 0 18px;
  border-radius: var(--radiusRounded);
  min-width: 18px;
  height: 18px;
  padding: 1px;
  filter: unset;
  fill: currentColor;
}
.tab .favicon.hidden {
  visibility: hidden !important;
}
.tab .favicon.svg span {
  width: 16px;
  height: 16px;
}
.tab .close {
  display: none;
  border-radius: var(--currentRadius);
}
.alt-tabs .tab .close {
  order: -1;
}
.tab .close svg {
  margin: auto;
}
.tab .title {
  display: flex;
  flex: 1;
  align-items: center;
  margin-right: 3px;
  padding-left: 4px;
  height: 100%;
  overflow: hidden;
  white-space: nowrap;
  line-height: 13px;
}
.tab .title:not(.editing) {
  mask-image: -webkit-linear-gradient(180deg, transparent 0, #fff 12px);
  mask-position: top right;
}
.tab .title input {
  background-color: #f6f6f6;
  color: #111;
  width: stretch;
  height: 22px;
  margin-right: 1px;
}
.linux .tab .title {
  mask: unset;
  display: inline-block;
  height: 29px;
  line-height: 29px;
}
.linux .tab:not(.tab-small, .active) .title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.tab .progress-indicator[value='0']::-webkit-progress-value {
  transition: unset;
}
.tab .thumbnail-image {
  flex: 1;
  margin: 0 2px 2px;
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.1);
  transition: background-image 0.3s;
  width: auto;
  border-radius: 0;
  border-bottom-left-radius: inherit;
  border-bottom-right-radius: inherit;
  color: var(--colorFg);
  background-color: var(--colorBg);
}
.tab .thumbnail-image svg {
  min-width: 16px;
  min-height: 16px;
  height: 50%;
}
.tab.highlighted:focus-visible,
.tab.uifocusstop:not(.marked):focus-visible,
.tab:focus-visible:not(.marked) {
  border-radius: var(--radiusHalf);
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.tabs-left .tab.highlighted:focus-visible,
.tabs-left .tab.uifocusstop:not(.marked):focus-visible,
.tabs-left .tab:focus-visible:not(.marked),
.tabs-right .tab.highlighted:focus-visible,
.tabs-right .tab.uifocusstop:not(.marked):focus-visible,
.tabs-right .tab:focus-visible:not(.marked) {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
}
.tab:hover,
.tab.force-hover {
  /* hide close buttons in small tabs */
  /* show close button */
  /* gradually cover favicon with close button in small tabs */
}
.tab:hover.tab-small .close,
.tab.force-hover.tab-small .close,
.tab:hover.tab-mini:not(.button-off).active .favicon,
.tab.force-hover.tab-mini:not(.button-off).active .favicon,
.tab:hover.tab-mini:not(.button-off).active .button-badge,
.tab.force-hover.tab-mini:not(.button-off).active .button-badge,
#browser:not(.alt-tabs) .tab:hover.tab:not(.button-off, .force-hover) .stack-counter,
#browser:not(.alt-tabs) .tab.force-hover.tab:not(.button-off, .force-hover) .stack-counter,
.alt-tabs .tab:hover.tab:not(.button-off) .favicon,
.alt-tabs .tab.force-hover.tab:not(.button-off) .favicon,
.alt-tabs .tab:hover.tab:not(.button-off) .button-badge,
.alt-tabs .tab.force-hover.tab:not(.button-off) .button-badge {
  display: none;
}
.tab:hover .close,
.tab.force-hover .close,
.tab:hover.active.tab-small .close,
.tab.force-hover.active.tab-small .close,
.tab:hover.tab.pinned .favicon,
.tab.force-hover.tab.pinned .favicon,
.alt-tabs .tab:hover.tab.pinned .favicon,
.alt-tabs .tab.force-hover.tab.pinned .favicon,
.alt-tabs .tab:hover.tab-small:not(.active) .favicon,
.alt-tabs .tab.force-hover.tab-small:not(.active) .favicon {
  display: flex;
}
#browser:not(.alt-tabs) .tab:hover.tab-small:not(.tab-mini).active .favicon,
#browser:not(.alt-tabs) .tab.force-hover.tab-small:not(.tab-mini).active .favicon {
  flex: 0 1 100%;
  margin-right: auto;
  min-width: 0;
  max-width: 18px;
  background-position: 1px 50%;
}
#browser:not(.alt-tabs) .tab:hover.tab-small:not(.tab-mini).active .title,
#browser:not(.alt-tabs) .tab.force-hover.tab-small:not(.tab-mini).active .title {
  display: none;
}
#browser:not(.alt-tabs) .tab:hover.tab-small:not(.tab-mini).active .close,
#browser:not(.alt-tabs) .tab.force-hover.tab-small:not(.tab-mini).active .close {
  flex: 0 0 auto;
}
.tab.active .tab-header input.tab-title-edit {
  line-height: 1;
  color: var(--colorAccentFg);
  background-color: var(--colorAccentBgDark);
  border-color: rgba(0, 0, 0, 0.15);
  box-shadow: none;
  border-width: 1px;
  margin-left: -3px;
}
.color-behind-tabs-on .tab.active .tab-header input.tab-title-edit {
  color: var(--colorFg);
  background-color: var(--colorBgDark);
  border-color: rgba(0, 0, 0, 0.1);
}
.transparent-tabbar .tab.active .tab-header .favicon:not(.svg),
.theme-dark .tab.active .tab-header .favicon:not(.svg),
.acc-dark.color-behind-tabs-off .tab.active .tab-header .favicon:not(.svg) {
  filter: drop-shadow(1px 0 0 rgba(246, 246, 246, 0.75)) drop-shadow(-1px 0 0 rgba(246, 246, 246, 0.75)) drop-shadow(0 1px 0 rgba(246, 246, 246, 0.75)) drop-shadow(0 -1px 0 rgba(246, 246, 246, 0.75));
}
.tab.active .thumbnail-image {
  border-color: rgba(0, 0, 0, 0.1);
}
.tab.active:not(.marked, .tab-mini):after {
  transform: unset;
}
.density-on:not(.tabs-at-edge) .tab.active:not(.tab-in-accordion, .tab-accordion) {
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
}
.tab-strip {
  flex: 1 1 auto;
  position: relative;
}
.tab-strip > span {
  display: contents;
}
.tabs-top.density-on:not(.tabs-at-edge) #tabs-subcontainer .tab-strip,
.tabs-bottom.density-on:not(.tabs-at-edge) #tabs-subcontainer .tab-strip {
  margin: var(--densityGap);
}
.tab-strip.horizontal-scrolling {
  overflow-x: scroll;
  overflow-y: clip;
  justify-content: flex-start;
}
.tab-strip.horizontal-scrolling.horizontal-scrolling-smooth {
  scroll-behavior: smooth;
}
.stacks-substrip.tabs-top #tabs-container .tab-strip.horizontal-scrolling,
.stacks-dotted.tabs-top #tabs-container .tab-strip.horizontal-scrolling {
  padding-top: 6px;
  margin-top: -6px;
}
.stacks-substrip.tabs-bottom #tabs-container .tab-strip.horizontal-scrolling,
.stacks-dotted.tabs-bottom #tabs-container .tab-strip.horizontal-scrolling {
  margin-bottom: -6px;
}
.stacks-substrip.tabs-bottom #tabs-container .tab-strip.horizontal-scrolling .tab-position,
.stacks-dotted.tabs-bottom #tabs-container .tab-strip.horizontal-scrolling .tab-position {
  margin-bottom: 6px;
}
.tab-strip.horizontal-scrolling::-webkit-scrollbar {
  display: none;
}
.svg-tab-stack,
.svg-tab-selection {
  position: absolute;
  pointer-events: none;
  width: var(--Width);
  height: var(--Height);
  border-radius: var(--currentRadius);
}
.tab-indicator .svg-tab-stack,
.tab-indicator .svg-tab-selection {
  border-radius: 0;
}
.svg-tab-stack line,
.svg-tab-selection line,
.svg-tab-stack rect,
.svg-tab-selection rect {
  fill: none;
  stroke-width: 4.001px;
}
.svg-tab-stack rect,
.svg-tab-selection rect {
  rx: var(--currentRadius);
  ry: var(--currentRadius);
}
.tabs-top .svg-tab-stack,
.tabs-top .svg-tab-selection,
.tabs-bottom .svg-tab-stack,
.tabs-bottom .svg-tab-selection {
  max-height: 100%;
  max-width: calc(var(--Width) - var(--densityGap));
}
.tabs-top .tab-small + .svg-tab-stack,
.tabs-top .tab-small + .svg-tab-selection,
.tabs-bottom .tab-small + .svg-tab-stack,
.tabs-bottom .tab-small + .svg-tab-selection {
  max-width: calc(var(--Width) - 1px);
}
.tabs-top .tab:is(.tab-accordion, .tab-in-accordion) + .svg-tab-stack,
.tabs-top .tab:is(.tab-accordion, .tab-in-accordion) + .svg-tab-selection,
.tabs-bottom .tab:is(.tab-accordion, .tab-in-accordion) + .svg-tab-stack,
.tabs-bottom .tab:is(.tab-accordion, .tab-in-accordion) + .svg-tab-selection {
  max-width: unset;
}
.tabs-left .svg-tab-stack,
.tabs-left .svg-tab-selection,
.tabs-right .svg-tab-stack,
.tabs-right .svg-tab-selection {
  width: 100%;
  max-width: 100%;
  height: calc(var(--Height) - var(--densityGap));
}
.tabs-left .tab:not(.tab-accordion, .tab-in-accordion) + .svg-tab-stack,
.tabs-left .tab:not(.tab-accordion, .tab-in-accordion) + .svg-tab-selection,
.tabs-right .tab:not(.tab-accordion, .tab-in-accordion.tab-first-in-group) + .svg-tab-stack,
.tabs-right .tab:not(.tab-accordion, .tab-in-accordion.tab-first-in-group) + .svg-tab-selection {
  max-height: calc(var(--Height) - 1px);
}
.density-on.tabs-left .tab:not(.tab-accordion, .tab-in-accordion) + .svg-tab-stack,
.density-on.tabs-left .tab:not(.tab-accordion, .tab-in-accordion) + .svg-tab-selection,
.density-on.tabs-right .tab:not(.tab-accordion, .tab-in-accordion.tab-first-in-group) + .svg-tab-stack,
.density-on.tabs-right .tab:not(.tab-accordion, .tab-in-accordion.tab-first-in-group) + .svg-tab-selection {
  max-height: calc(var(--Height) - var(--densityGap));
}
.tabs-left .tab.tab-group + .svg-tab-stack,
.tabs-left .tab.tab-group + .svg-tab-selection,
.tabs-right .tab.tab-group + .svg-tab-stack,
.tabs-right .tab.tab-group + .svg-tab-selection {
  max-height: calc(var(--Height) - var(--densityGap) - 6px);
}
.svg-tab-stack .stack-frame,
.svg-tab-selection .stack-frame {
  stroke: var(--colorBgAlpha);
}
.color-behind-tabs-off .svg-tab-stack .stack-frame,
.color-behind-tabs-off .svg-tab-selection .stack-frame {
  stroke: var(--colorAccentBg);
}
.svg-tab-stack:not(.svg-tab-selection) .inner,
.svg-tab-selection:not(.svg-tab-selection) .inner,
.svg-tab-stack:not(.svg-tab-selection) .outer,
.svg-tab-selection:not(.svg-tab-selection) .outer {
  display: none;
}
#app .svg-tab-selection .stack-frame,
#app .svg-tab-selection .inner {
  stroke: var(--colorHighlightBg);
}
#app .svg-tab-selection .outer {
  stroke-dasharray: 5, 5;
  stroke-dashoffset: 2;
  stroke: var(--colorHighlightFg);
}
#app .svg-tab-selection:not(.svg-tab-stack) {
  top: 0;
}
#app .svg-tab-selection:not(.svg-tab-stack) .stack-frame {
  display: none;
}
#app .svg-tab-selection:not(.svg-tab-stack) line {
  stroke-width: 5px;
}
#app .tab-indicator .svg-tab-selection:not(.svg-tab-stack) {
  max-width: 100%;
  max-height: 6px;
}
#app .tab-indicator .svg-tab-selection:not(.svg-tab-stack) .stack-frame {
  display: none;
}
#app .tab-indicator .svg-tab-selection:not(.svg-tab-stack) line {
  stroke-width: 6px;
}
.subcontainer-lock {
  flex-wrap: wrap;
  flex: 1 0;
  align-items: center;
  justify-content: space-between;
  height: auto;
  overflow: hidden;
  padding-bottom: 3px;
}
.tabs-left .subcontainer-lock,
.tabs-right .subcontainer-lock {
  flex-direction: column;
}
.tabs-top:not(.tabs-at-edge) #tabs-subcontainer,
.tabs-bottom:not(.tabs-at-edge) #tabs-subcontainer {
  padding: 0 var(--densityGap);
}
.tabs-top:not(.tabs-at-edge) #tabs-subcontainer .toolbar.toolbar-tabbar,
.tabs-bottom:not(.tabs-at-edge) #tabs-subcontainer .toolbar.toolbar-tabbar {
  flex-direction: row;
  align-items: center;
  padding: var(--densityGap) 0;
}
.tab-audio {
  contain: strict;
  height: 16px;
  width: 16px;
  margin-top: auto;
  margin-bottom: auto;
}
.tabs-left .tab-audio,
.tabs-right .tab-audio {
  margin-left: 3px;
}
.alt-tabs .tab-audio,
.alt-tabs .tab-audio {
  margin-right: 6px;
}
#app #browser .tab-audio:hover {
  transform: scale(1.24);
}
.audioicon {
  transform: scale(0.5) translateZ(0);
  transform-origin: left 2px;
}
#tabs-container {
  min-height: 30px;
}
#tabs-container .resize {
  position: relative;
  pointer-events: none;
  display: flex;
  flex: 1 1 100%;
  overflow: visible;
}
.tabs-top #tabs-container .resize,
.tabs-bottom #tabs-container .resize {
  margin-right: 3px;
}
#tabs-container .resize .tab-strip,
#tabs-container .resize .tab-position,
#tabs-container .resize .toolbar-tabbar {
  pointer-events: auto;
  -webkit-app-region: no-drag;
}
#tabs-container.left .resize,
#tabs-container.right .resize {
  flex-direction: column;
  min-height: 36px;
  max-height: 100%;
}
#tabs-container:not(.top) {
  position: relative;
}
#tabs-container .tab-captured .audio-on .tab-audio,
#tabs-container .audio-muted .tab-audio.tab-audio {
  transform: none;
}
#tabs-container .tab.isdiscarded .favicon {
  filter: grayscale(50%) opacity(0.5);
  transition: filter 0.2s ease-in;
}
#tabs-container .tab.isdiscarded:hover .favicon {
  filter: grayscale(0) opacity(1);
}
#tabs-container .tab.iscut {
  opacity: 0.5;
}
#browser:not(.alt-tabs) #tabs-container .tab-audio,
#browser:not(.alt-tabs) #tabs-container .tab.pinned:not(.active) .tab-audio {
  position: absolute;
  transition: transform 100ms ease-in;
  transition-delay: 0ms;
  top: 6px;
}
#browser:not(.alt-tabs) #tabs-container .tab:not(.audio-on, .tab-captured) .tab-audio {
  transform: scale(0);
}
#browser:not(.alt-tabs) #tabs-container .favicon,
#browser:not(.alt-tabs) #tabs-container .tab.pinned:not(.active) .favicon {
  transition: transform 100ms ease-in;
  transition-delay: 50ms;
  transform: scale(1);
}
#browser:not(.alt-tabs) #tabs-container .tab:not(.tab-mini) .close {
  margin-right: 6px;
}
#browser:not(.alt-tabs) #tabs-container .tab:not(.pinned, .tab-small).audio-on .tab-audio,
#browser:not(.alt-tabs) #tabs-container .tab:not(.pinned, .tab-small).audio-muted .tab-audio,
#browser:not(.alt-tabs) #tabs-container .tab:not(.pinned, .tab-small).tab-captured .tab-audio {
  transition-delay: 50ms;
  transform: scale(1);
}
#browser:not(.alt-tabs) #tabs-container .tab:not(.pinned, .tab-small).audio-on .favicon,
#browser:not(.alt-tabs) #tabs-container .tab:not(.pinned, .tab-small).audio-muted .favicon,
#browser:not(.alt-tabs) #tabs-container .tab:not(.pinned, .tab-small).tab-captured .favicon {
  transition-delay: 0ms;
  transform: scale(0);
}
.alt-tabs #tabs-container .tab-audio {
  transition: transform 100ms ease-in, margin-left 100ms ease-in;
  transform: scale(0);
}
.alt-tabs #tabs-container .tab.audio-on .tab-audio,
.alt-tabs #tabs-container .tab.audio-muted .tab-audio .tab-captured {
  transform: scale(1);
  margin-left: 0;
}
#browser #tabs-container .tab.tab-small.audio-on .tab-audio,
#browser #tabs-container .tab.pinned.audio-on .tab-audio,
#browser #tabs-container .tab.tab-small.audio-muted .tab-audio,
#browser #tabs-container .tab.pinned.audio-muted .tab-audio,
#browser #tabs-container .tab.tab-small.tab-captured .tab-audio,
#browser #tabs-container .tab.pinned.tab-captured .tab-audio {
  position: absolute;
  left: 0;
  top: 11px;
  padding: 2px;
  margin-left: 0;
  transition: transform 100ms ease-in;
  transition-delay: 0ms;
  height: 20px;
  width: 20px;
  border-radius: var(--radiusRound);
  transform: scale(0.625);
  background-color: #fff;
}
#browser #tabs-container .tab.tab-small.audio-on .tab-audio:hover,
#browser #tabs-container .tab.pinned.audio-on .tab-audio:hover,
#browser #tabs-container .tab.tab-small.audio-muted .tab-audio:hover,
#browser #tabs-container .tab.pinned.audio-muted .tab-audio:hover,
#browser #tabs-container .tab.tab-small.tab-captured .tab-audio:hover,
#browser #tabs-container .tab.pinned.tab-captured .tab-audio:hover {
  transform: scale(0.87);
}
#tabs-container .tab.tab-small.tab-mini .tab-header,
#tabs-container .tab.pinned.tab-mini .tab-header {
  justify-content: center;
  padding-left: 0;
  padding-right: 0;
  border-left: 1px solid transparent;
  border-right: 1px solid transparent;
}
#tabs-container .tab.tab-small.tab-mini .tab-header .stack-counter,
#tabs-container .tab.pinned.tab-mini .tab-header .stack-counter,
#tabs-container .tab.tab-small.tab-mini .tab-header .title,
#tabs-container .tab.pinned.tab-mini .tab-header .title {
  display: none;
}
#tabs-container .tab.tab-small.tab-mini .tab-header .tab-audio,
#tabs-container .tab.pinned.tab-mini .tab-header .tab-audio {
  left: 0;
}
#tabs-container .SlideBar--FullWidth {
  top: unset;
  bottom: unset;
}
#tabs-container.none + .SlideBar--FullWidth {
  display: none;
}
.tabs-right .tabbar-wrapper {
  background-color: var(--colorImageRightFgAlphaHeavy);
}
.tabs-left .tabbar-wrapper {
  background-color: var(--colorImageLeftFgAlphaHeavy);
}
.tabbar-wrapper > div:not(.tabbar-wrapper, .window-buttongroup) {
  padding-top: 1px;
}
.density-on .tabbar-wrapper > div:not(.tabbar-wrapper, .window-buttongroup) {
  padding-top: calc(var(--densityGap) * 2);
}
#tabs-tabbar-container {
  position: relative;
  display: flex;
  box-sizing: content-box;
  /* The image colors win over other colors if present, so enable only where
   the image is visible. */
  /* border at inner edge */
}
#tabs-tabbar-container.none {
  padding: 0;
}
#tabs-tabbar-container #tabs-container,
#tabs-tabbar-container #tabs-subcontainer,
#tabs-tabbar-container .SlideBar,
#tabs-tabbar-container .separator {
  box-sizing: border-box;
}
.tabs-top:not(.density-on) #tabs-tabbar-container #tabs-container,
.tabs-top.tabs-at-edge #tabs-tabbar-container #tabs-container {
  padding-bottom: 1px;
}
.tabs-bottom:not(.density-on) #tabs-tabbar-container #tabs-container,
.tabs-bottom.tabs-at-edge #tabs-tabbar-container #tabs-container {
  padding-top: 1px;
}
.tabs-top.density-on:not(.tabs-at-edge) #tabs-tabbar-container:not(:has(#tabs-subcontainer)) {
  padding-top: 6px;
  padding-bottom: 6px;
}
.tabs-bottom.density-on:not(.tabs-at-edge) #tabs-tabbar-container:not(:has(#tabs-subcontainer)) {
  padding-top: 6px;
}
#browser:not(.transparent-tabbar) #tabs-tabbar-container {
  background-color: var(--colorTabBar, transparent);
}
.color-behind-tabs-off.transparent-tabbar #tabs-tabbar-container {
  color: var(--colorImageFg, var(--colorFg));
}
.color-behind-tabs-on.transparent-tabbar #tabs-tabbar-container {
  color: var(--colorImageFg, var(--colorAccentFg));
}
.color-behind-tabs-on.color-accent-from-page.transparent-tabbar #tabs-tabbar-container {
  color: var(--colorAccentFg);
}
.color-behind-tabs-on.color-accent-from-page.transparent-tabbar:not(.acc-dark.bg-dark).transparent-tabbar #tabs-tabbar-container {
  color: var(--colorImageFg, var(--colorFg));
}
#tabs-tabbar-container.top {
  flex-direction: column;
  padding-top: calc(6px / var(--uiZoomLevel));
}
.tabs-at-edge #tabs-tabbar-container.top {
  min-height: 31px;
  padding-top: 0;
}
.win.normal .topmenu + #tabs-tabbar-container.top,
.linux.normal .topmenu + #tabs-tabbar-container.top {
  padding-top: 6px;
}
#tabs-tabbar-container.bottom {
  flex-direction: column-reverse;
  order: 3;
  flex: 0 1 auto;
  padding: 0 0 6px 0;
}
.tabs-at-edge #tabs-tabbar-container.bottom {
  min-height: 31px;
  padding-bottom: 0;
}
#tabs-tabbar-container.left,
#tabs-tabbar-container.right {
  max-width: 60vw;
}
#tabs-tabbar-container.left .tab-position:not(.accordion-toggle-arrow),
#tabs-tabbar-container.right .tab-position:not(.accordion-toggle-arrow) {
  width: 100%;
}
#browser.transparent-tabbar #tabs-tabbar-container.left #tabs-container,
#browser.transparent-tabbar #tabs-tabbar-container.right #tabs-container {
  backdrop-filter: var(--backgroundBlur);
}
.tabbar-workspace-button + #tabs-tabbar-container.left,
.tabbar-workspace-button + #tabs-tabbar-container.right {
  padding-top: 18px;
}
#tabs-tabbar-container.right {
  flex-direction: row-reverse;
}
#browser:not(.theme-dark) #tabs-tabbar-container.top {
  box-shadow: inset 0 -1px 0 0 rgba(0, 0, 0, 0.1);
}
#browser:not(.theme-dark) #tabs-tabbar-container.top.color-behind-tabs-off {
  box-shadow: inset 0 -1px 0 0 var(--colorAccentBgDarker);
}
#browser:not(.theme-dark) #tabs-tabbar-container.right {
  box-shadow: inset 1px 0 0 0 rgba(0, 0, 0, 0.1);
}
#browser:not(.theme-dark) #tabs-tabbar-container.bottom {
  box-shadow: inset 0 1px 0 0 rgba(0, 0, 0, 0.1);
}
#browser:not(.theme-dark) #tabs-tabbar-container.bottom.color-behind-tabs-off {
  box-shadow: inset 0 1px 0 0 var(--colorAccentBgDarker);
}
#browser:not(.theme-dark) #tabs-tabbar-container.left {
  box-shadow: inset -1px 0 0 0 rgba(0, 0, 0, 0.1);
}
/* The image colors win over other colors if present, so enable only where
the image is visible. */
#browser.transparent-tabbar.tabs-top {
  --colorImageFg: var(--colorImageTopFg);
  --colorImageFgHeaviest: var(--colorImageTopFgAlphaHeavy);
  --colorImageBg: var(--colorImageTopBg);
  --colorImageBgAlpha: var(--colorImageTopBgAlpha);
  --colorImageBgAlphaHeavy: var(--colorImageTopBgAlphaHeavy);
}
#browser.transparent-tabbar.tabs-left {
  --colorImageFg: var(--colorImageLeftFg);
  --colorImageFgHeaviest: var(--colorImageLeftFgAlphaHeavy);
  --colorImageBg: var(--colorImageLeftBg);
  --colorImageBgAlpha: var(--colorImageLeftBgAlpha);
  --colorImageBgAlphaHeavy: var(--colorImageLeftBgAlphaHeavy);
}
#browser.transparent-tabbar.tabs-right {
  --colorImageFg: var(--colorImageRightFg);
  --colorImageFgHeaviest: var(--colorImageRightFgAlphaHeavy);
  --colorImageBg: var(--colorImageRightBg);
  --colorImageBgAlpha: var(--colorImageRightBgAlpha);
  --colorImageBgAlphaHeavy: var(--colorImageRightBgAlphaHeavy);
}
/* The #tabs-container is responsible for positioning the tabbar
   Toolbar layout constraints are handled here. */
.win .tabbar-wrapper:has(.window-buttongroup) #tabs-container:not(.none).top {
  padding-right: calc(140px / var(--uiZoomLevel));
}
.linux .tabbar-wrapper:has(.window-buttongroup) #tabs-container:not(.none).top {
  padding-right: calc(90px / var(--uiZoomLevel));
}
.alt #tabs-container:not(.none).top {
  padding-left: calc(100px / var(--uiZoomLevel));
  padding-right: calc(var(--menuWidth) / var(--uiZoomLevel));
}
.horizontal-menu #tabs-container:not(.none).top {
  padding-left: 0;
  padding-right: 0;
}
.mac.native #tabs-container:not(.none).top {
  padding-left: 0;
}
.native #tabs-container:not(.none).top {
  padding-right: 0;
}
.native.alt #tabs-container:not(.none).top {
  padding-left: 0;
  padding-right: calc(38px / var(--uiZoomLevel));
}
#tabs-container:not(.none).bottom {
  padding: 0;
}
#tabs-container {
  display: flex;
  flex: 1 1 auto;
}
#tabs-container.none {
  display: none;
}
#tabs-container.bottom {
  order: 3;
}
#tabs-container.left,
#tabs-container.right {
  flex-direction: column;
}
#tabs-container.left:has(.tab-strip.overflow),
#tabs-container.right:has(.tab-strip.overflow) {
  padding-right: 0;
}
#tabs-container.left .tab-strip,
#tabs-container.right .tab-strip {
  margin: 0 max(calc(var(--densityGap) * 2), 1px);
  max-width: calc(100% - var(--densityGap) * 2);
  padding: 0;
  overflow-x: hidden;
  overflow-y: auto;
}
#tabs-container.left .tab-strip .thumbnail-image,
#tabs-container.right .tab-strip .thumbnail-image {
  margin-bottom: 2px;
  background-position: 0 0;
}
#tabs-container.left .tab-strip.overflow,
#tabs-container.right .tab-strip.overflow {
  margin: 0 0 0 max(calc(var(--densityGap) * 2), 1px);
  min-width: calc(30px + var(--scrollbarWidth));
  max-width: calc(100% - var(--densityGap) * 1);
}
#tabs-container.left:focus-within,
#tabs-container.right:focus-within {
  z-index: 3;
}
#tabs-container.left > .toolbar > *:focus-within,
#tabs-container.right > .toolbar > *:focus-within {
  z-index: 3;
}
#tabs-container.left > .toolbar > *:focus-within ~ .SlideBar,
#tabs-container.right > .toolbar > *:focus-within ~ .SlideBar {
  z-index: 2;
}
#tabs-container.bottom:focus-within {
  z-index: 6;
}
#tabs-container.top > .toolbar > *:focus-within,
#tabs-container.bottom > .toolbar > *:focus-within {
  z-index: 6;
}
#tabs-container.top > .toolbar > *:focus-within ~ .SlideBar,
#tabs-container.bottom > .toolbar > *:focus-within ~ .SlideBar {
  z-index: 5;
}
.tabs-top:not(.tabs-at-edge) #tabs-container:has(~ #tabs-subcontainer) {
  padding-bottom: var(--densityGap);
}
.tabs-bottom:not(.tabs-at-edge) #tabs-container:has(~ #tabs-subcontainer) {
  padding-top: var(--densityGap);
}
#tabs-subcontainer {
  min-height: 30px;
  display: flex;
  flex: 1 1 auto;
  margin: 0;
  display: none;
  border-radius: inherit;
}
#tabs-subcontainer .resize {
  position: relative;
  pointer-events: none;
  display: flex;
  flex: 1 1 100%;
  overflow: visible;
}
.tabs-top #tabs-subcontainer .resize,
.tabs-bottom #tabs-subcontainer .resize {
  margin-right: 3px;
}
#tabs-subcontainer .resize .tab-strip,
#tabs-subcontainer .resize .tab-position,
#tabs-subcontainer .resize .toolbar-tabbar {
  pointer-events: auto;
  -webkit-app-region: no-drag;
}
#tabs-subcontainer.left .resize,
#tabs-subcontainer.right .resize {
  flex-direction: column;
  min-height: 36px;
  max-height: 100%;
}
#tabs-subcontainer:not(.top) {
  position: relative;
}
#tabs-subcontainer .tab-captured .audio-on .tab-audio,
#tabs-subcontainer .audio-muted .tab-audio.tab-audio {
  transform: none;
}
#tabs-subcontainer .tab.isdiscarded .favicon {
  filter: grayscale(50%) opacity(0.5);
  transition: filter 0.2s ease-in;
}
#tabs-subcontainer .tab.isdiscarded:hover .favicon {
  filter: grayscale(0) opacity(1);
}
#tabs-subcontainer .tab.iscut {
  opacity: 0.5;
}
#browser:not(.alt-tabs) #tabs-subcontainer .tab-audio,
#browser:not(.alt-tabs) #tabs-subcontainer .tab.pinned:not(.active) .tab-audio {
  position: absolute;
  transition: transform 100ms ease-in;
  transition-delay: 0ms;
  top: 6px;
}
#browser:not(.alt-tabs) #tabs-subcontainer .tab:not(.audio-on, .tab-captured) .tab-audio {
  transform: scale(0);
}
#browser:not(.alt-tabs) #tabs-subcontainer .favicon,
#browser:not(.alt-tabs) #tabs-subcontainer .tab.pinned:not(.active) .favicon {
  transition: transform 100ms ease-in;
  transition-delay: 50ms;
  transform: scale(1);
}
#browser:not(.alt-tabs) #tabs-subcontainer .tab:not(.tab-mini) .close {
  margin-right: 6px;
}
#browser:not(.alt-tabs) #tabs-subcontainer .tab:not(.pinned, .tab-small).audio-on .tab-audio,
#browser:not(.alt-tabs) #tabs-subcontainer .tab:not(.pinned, .tab-small).audio-muted .tab-audio,
#browser:not(.alt-tabs) #tabs-subcontainer .tab:not(.pinned, .tab-small).tab-captured .tab-audio {
  transition-delay: 50ms;
  transform: scale(1);
}
#browser:not(.alt-tabs) #tabs-subcontainer .tab:not(.pinned, .tab-small).audio-on .favicon,
#browser:not(.alt-tabs) #tabs-subcontainer .tab:not(.pinned, .tab-small).audio-muted .favicon,
#browser:not(.alt-tabs) #tabs-subcontainer .tab:not(.pinned, .tab-small).tab-captured .favicon {
  transition-delay: 0ms;
  transform: scale(0);
}
.alt-tabs #tabs-subcontainer .tab-audio {
  transition: transform 100ms ease-in, margin-left 100ms ease-in;
  transform: scale(0);
}
.alt-tabs #tabs-subcontainer .tab.audio-on .tab-audio,
.alt-tabs #tabs-subcontainer .tab.audio-muted .tab-audio .tab-captured {
  transform: scale(1);
  margin-left: 0;
}
#browser #tabs-subcontainer .tab.tab-small.audio-on .tab-audio,
#browser #tabs-subcontainer .tab.pinned.audio-on .tab-audio,
#browser #tabs-subcontainer .tab.tab-small.audio-muted .tab-audio,
#browser #tabs-subcontainer .tab.pinned.audio-muted .tab-audio,
#browser #tabs-subcontainer .tab.tab-small.tab-captured .tab-audio,
#browser #tabs-subcontainer .tab.pinned.tab-captured .tab-audio {
  position: absolute;
  left: 0;
  top: 11px;
  padding: 2px;
  margin-left: 0;
  transition: transform 100ms ease-in;
  transition-delay: 0ms;
  height: 20px;
  width: 20px;
  border-radius: var(--radiusRound);
  transform: scale(0.625);
  background-color: #fff;
}
#browser #tabs-subcontainer .tab.tab-small.audio-on .tab-audio:hover,
#browser #tabs-subcontainer .tab.pinned.audio-on .tab-audio:hover,
#browser #tabs-subcontainer .tab.tab-small.audio-muted .tab-audio:hover,
#browser #tabs-subcontainer .tab.pinned.audio-muted .tab-audio:hover,
#browser #tabs-subcontainer .tab.tab-small.tab-captured .tab-audio:hover,
#browser #tabs-subcontainer .tab.pinned.tab-captured .tab-audio:hover {
  transform: scale(0.87);
}
#tabs-subcontainer .tab.tab-small.tab-mini .tab-header,
#tabs-subcontainer .tab.pinned.tab-mini .tab-header {
  justify-content: center;
  padding-left: 0;
  padding-right: 0;
  border-left: 1px solid transparent;
  border-right: 1px solid transparent;
}
#tabs-subcontainer .tab.tab-small.tab-mini .tab-header .stack-counter,
#tabs-subcontainer .tab.pinned.tab-mini .tab-header .stack-counter,
#tabs-subcontainer .tab.tab-small.tab-mini .tab-header .title,
#tabs-subcontainer .tab.pinned.tab-mini .tab-header .title {
  display: none;
}
#tabs-subcontainer .tab.tab-small.tab-mini .tab-header .tab-audio,
#tabs-subcontainer .tab.pinned.tab-mini .tab-header .tab-audio {
  left: 0;
}
#tabs-subcontainer .SlideBar--FullWidth {
  top: unset;
  bottom: unset;
}
#tabs-subcontainer.none + .SlideBar--FullWidth {
  display: none;
}
#tabs-subcontainer.none {
  display: none;
}
#tabs-subcontainer.bottom {
  order: 3;
}
#tabs-subcontainer.left,
#tabs-subcontainer.right {
  flex-direction: column;
}
#tabs-subcontainer.left:has(.tab-strip.overflow),
#tabs-subcontainer.right:has(.tab-strip.overflow) {
  padding-right: 0;
}
#tabs-subcontainer.left .tab-strip,
#tabs-subcontainer.right .tab-strip {
  margin: 0 max(calc(var(--densityGap) * 2), 1px);
  max-width: calc(100% - var(--densityGap) * 2);
  padding: 0;
  overflow-x: hidden;
  overflow-y: auto;
}
#tabs-subcontainer.left .tab-strip .thumbnail-image,
#tabs-subcontainer.right .tab-strip .thumbnail-image {
  margin-bottom: 2px;
  background-position: 0 0;
}
#tabs-subcontainer.left .tab-strip.overflow,
#tabs-subcontainer.right .tab-strip.overflow {
  margin: 0 0 0 max(calc(var(--densityGap) * 2), 1px);
  min-width: calc(30px + var(--scrollbarWidth));
  max-width: calc(100% - var(--densityGap) * 1);
}
#tabs-subcontainer.left:focus-within,
#tabs-subcontainer.right:focus-within {
  z-index: 3;
}
#tabs-subcontainer.left > .toolbar > *:focus-within,
#tabs-subcontainer.right > .toolbar > *:focus-within {
  z-index: 3;
}
#tabs-subcontainer.left > .toolbar > *:focus-within ~ .SlideBar,
#tabs-subcontainer.right > .toolbar > *:focus-within ~ .SlideBar {
  z-index: 2;
}
#tabs-subcontainer.bottom:focus-within {
  z-index: 6;
}
#tabs-subcontainer.top > .toolbar > *:focus-within,
#tabs-subcontainer.bottom > .toolbar > *:focus-within {
  z-index: 6;
}
#tabs-subcontainer.top > .toolbar > *:focus-within ~ .SlideBar,
#tabs-subcontainer.bottom > .toolbar > *:focus-within ~ .SlideBar {
  z-index: 5;
}
#tabs-subcontainer .tab-strip {
  flex: 0 0 auto;
}
.color-behind-tabs-on #tabs-subcontainer {
  background-color: var(--colorAccentBgDark);
}
.color-behind-tabs-off #tabs-subcontainer,
.transparent-tabbar #tabs-subcontainer {
  background-color: rgba(0, 0, 0, 0.1);
}
.theme-dark.color-behind-tabs-off #tabs-subcontainer,
.theme-dark.transparent-tabbar #tabs-subcontainer {
  background-color: rgba(255, 255, 255, 0.05);
  backdrop-filter: saturate(1.1);
}
#tabs-subcontainer.visible {
  display: flex;
}
#browser.tabs-at-edge #tabs-subcontainer.top,
#browser:not(.density-on) #tabs-subcontainer.top,
#browser.tabs-at-edge #tabs-subcontainer.bottom,
#browser:not(.density-on) #tabs-subcontainer.bottom {
  padding: 1px;
}
#tabs-subcontainer.top,
#tabs-subcontainer.bottom {
  flex: 0 0 auto;
}
#tabs-subcontainer.left {
  border-top-left-radius: var(--currentRadius);
  border-bottom-left-radius: var(--currentRadius);
}
#tabs-subcontainer.right {
  border-top-right-radius: var(--currentRadius);
  border-bottom-right-radius: var(--currentRadius);
}
.density-on #tabs-subcontainer.left,
.density-on #tabs-subcontainer.right {
  padding-top: var(--densityGap);
  margin-top: calc(-1 * var(--densityGap));
  flex-grow: 0;
}
#tabs-subcontainer.left,
#tabs-subcontainer.right {
  max-width: calc(60vw - 32px);
}
.density-on #tabs-subcontainer.left,
.density-on #tabs-subcontainer.right {
  max-width: calc(60vw - 42px);
}
.tabs-top:not(.density-on) .tab-strip:not(.horizontal-scrolling) .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.tabs-top:not(.density-on) .tab-strip:not(.horizontal-scrolling) .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):before,
.tabs-top.density-on.tabs-at-edge .tab-strip:not(.horizontal-scrolling) .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.tabs-top.density-on.tabs-at-edge .tab-strip:not(.horizontal-scrolling) .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):before,
.tabs-bottom:not(.density-on) .tab-strip:not(.horizontal-scrolling) .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.tabs-bottom:not(.density-on) .tab-strip:not(.horizontal-scrolling) .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):before,
.tabs-bottom.density-on.tabs-at-edge .tab-strip:not(.horizontal-scrolling) .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.tabs-bottom.density-on.tabs-at-edge .tab-strip:not(.horizontal-scrolling) .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):before {
  contain: strict;
  content: '';
  position: absolute;
  width: var(--radiusHalf);
  height: var(--radiusHalf);
  background-color: inherit;
}
.tabs-top .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.tabs-top .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):before {
  bottom: 0;
  mask-image: radial-gradient(circle at 0 0, rgba(0, 0, 0, 0) 70%, #000 73%);
}
.tabs-bottom .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.tabs-bottom .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):before {
  top: 0;
  mask-image: radial-gradient(circle at 0 100%, rgba(0, 0, 0, 0) 70%, #000 73%);
}
.is-substack .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.is-substack .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):before {
  display: none;
}
.tab.active:before {
  animation: rightfade 64ms linear;
}
.tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after {
  animation: leftfade 64ms linear;
}
.tab.tab-accordion.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after {
  right: calc(1px - var(--currentRadius));
}
.tabs-top .tab.tab-accordion.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.tabs-top .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after {
  transform: rotate(90deg);
}
.tabs-bottom .tab.tab-accordion.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after,
.tabs-bottom .tab.active:not(.marked, .tab-mini, .tab-in-accordion, .tab-acceptsdrop):after {
  transform: rotate(-90deg);
}
.tab.active:not(.marked):not(.tab-mini):before {
  left: calc(0px - var(--radiusHalf));
}
.tab.active:not(.marked):not(.tab-mini).insubstrip:before {
  left: calc(2px - var(--radiusHalf));
}
.tab-yield-space {
  border: dashed var(--colorHighlightBg) 2px;
  background-color: var(--colorHighlightBgAlpha);
  border-radius: var(--radiusHalf);
  animation: fade 200ms linear;
  z-index: 0;
}
.separator {
  position: absolute;
  display: flex;
  transform: translateX(var(--PositionX)) translateY(var(--PositionY));
  height: var(--Height);
  width: var(--Width);
  z-index: var(--ZIndex);
}
.separator hr {
  height: 0;
  border: 1px solid var(--colorImageFg, var(--colorAccentFg));
  background: var(--colorImageFg, var(--colorAccentFg));
  border-radius: var(--radius);
  opacity: 0.15;
  width: calc(100% - 6px * 3);
  margin-top: 8px;
}
.color-behind-tabs-off .separator hr {
  border-color: var(--colorImageFg, var(--colorFg));
}
.separator.separator-wsbutton {
  top: 9px;
  width: 100%;
}
.separator.separator-wsbutton hr {
  margin-block: 0;
}
.scroll-arrow {
  padding: 5px;
}
.synced-tab-dialog {
  display: flex;
  flex-direction: column;
  text-align: center;
  gap: 12px;
  padding: 12px;
  fill: var(--colorHighlightBg);
}
.tab-sync-qr-code {
  width: 60%;
  margin: auto;
  padding: 6px;
  border: 1px solid;
  border-color: var(--colorBgDark);
  border-radius: 6px;
  background-color: #fff;
}
.tab-wrapper {
  display: flex;
  width: 100%;
  max-height: var(--Height);
  position: relative;
  border-radius: var(--currentRadius);
}
.tab-wrapper:focus-visible {
  outline: none;
}
.tabs-left .tab-wrapper,
.tabs-right .tab-wrapper {
  min-width: 30px;
}
.tabs-top .tab-wrapper,
.tabs-bottom .tab-wrapper {
  height: 100%;
}
#browser.maximized:not(.mac) .accordion-toggle-arrow:before,
#browser.fullscreen .accordion-toggle-arrow:before,
#browser.maximized:not(.mac) .tab-wrapper.extended:before,
#browser.fullscreen .tab-wrapper.extended:before {
  content: '';
  position: absolute;
  -webkit-app-region: no-drag;
}
.tabs-top#browser.maximized:not(.mac) .accordion-toggle-arrow:before,
.tabs-top#browser.fullscreen .accordion-toggle-arrow:before,
.tabs-top#browser.maximized:not(.mac) .tab-wrapper.extended:before,
.tabs-top#browser.fullscreen .tab-wrapper.extended:before {
  width: 100%;
  height: 7px;
  top: -7px;
  left: 0;
}
.tabs-bottom#browser.maximized:not(.mac) .accordion-toggle-arrow:before,
.tabs-bottom#browser.fullscreen .accordion-toggle-arrow:before,
.tabs-bottom#browser.maximized:not(.mac) .tab-wrapper.extended:before,
.tabs-bottom#browser.fullscreen .tab-wrapper.extended:before {
  width: 100%;
  height: 7px;
  bottom: -7px;
  left: 0;
}
.tabs-left#browser.maximized:not(.mac) .accordion-toggle-arrow:before,
.tabs-left#browser.fullscreen .accordion-toggle-arrow:before,
.tabs-left#browser.maximized:not(.mac) .tab-wrapper.extended:before,
.tabs-left#browser.fullscreen .tab-wrapper.extended:before {
  width: 4px;
  height: 100%;
  top: 0;
  left: -4px;
}
.tabs-right#browser.maximized:not(.mac) .accordion-toggle-arrow:before,
.tabs-right#browser.fullscreen .accordion-toggle-arrow:before,
.tabs-right#browser.maximized:not(.mac) .tab-wrapper.extended:before,
.tabs-right#browser.fullscreen .tab-wrapper.extended:before {
  width: 4px;
  height: 100%;
  top: 0;
  right: -4px;
}
#browser.density-on:not(.tabs-at-edge) {
  --verticalTabSpace: 6px;
}
#browser.density-on:not(.tabs-at-edge) #tabs-tabbar-container:has(#tabs-subcontainer) {
  --verticalTabSpace: 3px;
}
#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .accordion-toggle-arrow:after,
#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .tab-wrapper:after {
  content: '';
  position: absolute;
  -webkit-app-region: no-drag;
}
.tabs-top#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .accordion-toggle-arrow:after,
.tabs-top#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .tab-wrapper:after {
  width: 100%;
  height: var(--verticalTabSpace);
  bottom: calc(-1 * var(--verticalTabSpace));
}
.tabs-bottom#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .accordion-toggle-arrow:after,
.tabs-bottom#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .tab-wrapper:after {
  width: 100%;
  height: var(--verticalTabSpace);
  top: calc(-1 * var(--verticalTabSpace));
}
.tabs-left#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .accordion-toggle-arrow:after,
.tabs-left#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .tab-wrapper:after {
  width: 3px;
  height: 100%;
  top: 0;
  right: -3px;
}
.tabs-right#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .accordion-toggle-arrow:after,
.tabs-right#browser.density-on:not(.tabs-at-edge):not(.tabs-at-edge) .tab-wrapper:after {
  width: 3px;
  height: 100%;
  top: 0;
  left: -3px;
}
#browser .tab-position.colored.accordion-toggle-arrow,
#browser .tab-position.colored .tab:not(.active) {
  background-color: var(--stackColorBg);
  color: var(--stackColorFg);
}
#browser .tab-position.colored.accordion-toggle-arrow:hover,
#browser .tab-position.colored .tab:not(.active):hover {
  background-color: color-mix(in srgb, var(--stackColorBg), #fff 20%);
}
#browser .tab-position.colored .tab:not(.marked) + svg .stack-frame {
  stroke: var(--stackColorBg);
}
#browser .tab-position.colored .tab + .tab-group-indicator .tab-indicator:not(:hover) {
  background-color: var(--stackColorBg);
}
.tabs-at-edge:is(.fullscreen, .maximized)#browser .tab-position.colored .tab:not(.active) + .tab-group-indicator .tab-indicator:not(:hover, .active) {
  background-color: var(--stackColorFg);
}
#browser .tab-position.colored .stack-counter {
  background-color: var(--stackColorBg);
  color: var(--stackColorFg);
}
#browser .tab-position.colored .tab.active + .tab-group-indicator .tab-indicator.active {
  background-color: var(--colorAccentBg);
}
.color-behind-tabs-on#browser .tab-position.colored .tab.active + .tab-group-indicator .tab-indicator.active {
  background-color: var(--colorBg);
}
#browser .tab-position.colored .tab-wrapper.accordion,
#browser .tab-position.colored .tab-wrapper.in-accordion {
  margin: 0;
}
.tabs-top#browser .tab-position.colored .tab-wrapper.accordion .tab,
.tabs-top#browser .tab-position.colored .tab-wrapper.in-accordion .tab,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.accordion .tab,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.in-accordion .tab {
  max-width: var(--Width);
}
.tabs-top#browser .tab-position.colored .tab-wrapper.accordion .tab:not(.active),
.tabs-top#browser .tab-position.colored .tab-wrapper.in-accordion .tab:not(.active),
.tabs-bottom#browser .tab-position.colored .tab-wrapper.accordion .tab:not(.active),
.tabs-bottom#browser .tab-position.colored .tab-wrapper.in-accordion .tab:not(.active) {
  box-shadow: 3px 0 0 var(--stackColorBg);
}
.tabs-top#browser .tab-position.colored .tab-wrapper.accordion .tab.active.tab-accordion,
.tabs-top#browser .tab-position.colored .tab-wrapper.in-accordion .tab.active.tab-accordion,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.accordion .tab.active.tab-accordion,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.in-accordion .tab.active.tab-accordion {
  max-height: var(--Height);
}
.tabs-top#browser .tab-position.colored .tab-wrapper.accordion .tab:before,
.tabs-top#browser .tab-position.colored .tab-wrapper.in-accordion .tab:before,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.accordion .tab:before,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.in-accordion .tab:before,
.tabs-top#browser .tab-position.colored .tab-wrapper.accordion .tab:after,
.tabs-top#browser .tab-position.colored .tab-wrapper.in-accordion .tab:after,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.accordion .tab:after,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.in-accordion .tab:after {
  content: unset;
}
.tabs-left.density-on#browser .tab-position.colored .tab-wrapper.accordion .tab-header,
.tabs-left.density-on#browser .tab-position.colored .tab-wrapper.in-accordion .tab-header,
.tabs-right.density-on#browser .tab-position.colored .tab-wrapper.accordion .tab-header,
.tabs-right.density-on#browser .tab-position.colored .tab-wrapper.in-accordion .tab-header {
  margin-top: 2px;
}
.tabs-top#browser .tab-position.colored .tab-wrapper.accordion .tab-accordion,
.tabs-top#browser .tab-position.colored .tab-wrapper.in-accordion .tab-accordion,
.tabs-top#browser .tab-position.colored .tab-wrapper.accordion .tab-first-in-group:not(.active),
.tabs-top#browser .tab-position.colored .tab-wrapper.in-accordion .tab-first-in-group:not(.active) {
  border-bottom-left-radius: var(--currentRadius);
}
.tabs-bottom#browser .tab-position.colored .tab-wrapper.accordion .tab-accordion,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.in-accordion .tab-accordion,
.tabs-bottom#browser .tab-position.colored .tab-wrapper.accordion .tab-first-in-group:not(.active),
.tabs-bottom#browser .tab-position.colored .tab-wrapper.in-accordion .tab-first-in-group:not(.active) {
  border-top-left-radius: var(--currentRadius);
}
#browser .tab-position.colored.accordion-toggle-arrow {
  background-clip: padding-box;
  border-bottom-right-radius: var(--currentRadius);
}
.tabs-top#browser .tab-position.colored.accordion-toggle-arrow,
.tabs-bottom#browser .tab-position.colored.accordion-toggle-arrow {
  border-top: 1px solid transparent;
  border-bottom: 1px solid transparent;
  border-top-right-radius: var(--currentRadius);
}
:root #browser {
  --stackBgAlpha: 0.2;
}
:root #browser .color1 {
  --stackColorBg: #606469;
  --stackColorBgAlpha: rgba(96, 100, 105, var(--stackBgAlpha));
  --stackColorFg: #fff;
}
:root #browser .color2 {
  --stackColorBg: #1a73e9;
  --stackColorBgAlpha: rgba(26, 115, 233, var(--stackBgAlpha));
  --stackColorFg: #fff;
}
:root #browser .color3 {
  --stackColorBg: #e3000e;
  --stackColorBgAlpha: rgba(227, 0, 14, var(--stackBgAlpha));
  --stackColorFg: #fff;
}
:root #browser .color4 {
  --stackColorBg: #faab00;
  --stackColorBgAlpha: rgba(250, 171, 0, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root #browser .color5 {
  --stackColorBg: #178038;
  --stackColorBgAlpha: rgba(23, 128, 56, var(--stackBgAlpha));
  --stackColorFg: #fff;
}
:root #browser .color6 {
  --stackColorBg: #d01884;
  --stackColorBgAlpha: rgba(208, 24, 132, var(--stackBgAlpha));
  --stackColorFg: #fff;
}
:root #browser .color7 {
  --stackColorBg: #a242f4;
  --stackColorBgAlpha: rgba(162, 66, 244, var(--stackBgAlpha));
  --stackColorFg: #fff;
}
:root #browser .color8 {
  --stackColorBg: #007d85;
  --stackColorBgAlpha: rgba(0, 125, 133, var(--stackBgAlpha));
  --stackColorFg: #fff;
}
:root #browser .color9 {
  --stackColorBg: #fa903e;
  --stackColorBgAlpha: rgba(250, 144, 62, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root .theme-dark#browser .color1 {
  --stackColorBg: #dbdde0;
  --stackColorBgAlpha: rgba(219, 221, 224, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root .theme-dark#browser .color2 {
  --stackColorBg: #7eb6fe;
  --stackColorBgAlpha: rgba(126, 182, 254, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root .theme-dark#browser .color3 {
  --stackColorBg: #ff847e;
  --stackColorBgAlpha: rgba(255, 132, 126, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root .theme-dark#browser .color4 {
  --stackColorBg: #ffd447;
  --stackColorBgAlpha: rgba(255, 212, 71, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root .theme-dark#browser .color5 {
  --stackColorBg: #67cb90;
  --stackColorBgAlpha: rgba(103, 203, 144, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root .theme-dark#browser .color6 {
  --stackColorBg: #ff83ce;
  --stackColorBgAlpha: rgba(255, 131, 206, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root .theme-dark#browser .color7 {
  --stackColorBg: #cf87ff;
  --stackColorBgAlpha: rgba(207, 135, 255, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root .theme-dark#browser .color8 {
  --stackColorBg: #4cdcee;
  --stackColorBgAlpha: rgba(76, 220, 238, var(--stackBgAlpha));
  --stackColorFg: #000;
}
:root .theme-dark#browser .color9 {
  --stackColorBg: #ffa963;
  --stackColorBgAlpha: rgba(255, 169, 99, var(--stackBgAlpha));
  --stackColorFg: #000;
}
.color-behind-tabs-off:not(.transparent-tabbar) .tab-in-accordion {
  background-color: var(--colorBg);
}
.tabs-top .tab-accordion {
  border-top-left-radius: var(--currentRadius);
}
.density-on:not(.tabs-at-edge).tabs-top .tab-accordion {
  border-bottom-left-radius: var(--currentRadius);
}
.tabs-bottom .tab-accordion {
  border-bottom-left-radius: var(--currentRadius);
}
.density-on:not(.tabs-at-edge).tabs-bottom .tab-accordion {
  border-top-left-radius: var(--currentRadius);
}
.tabs-top .tab-accordion.active,
.tabs-top .tab-in-accordion.tab-first-in-group {
  border-top-left-radius: var(--currentRadius);
}
.density-on:not(.tabs-at-edge).tabs-top .tab-accordion.active,
.density-on:not(.tabs-at-edge).tabs-top .tab-in-accordion.tab-first-in-group {
  border-bottom-left-radius: var(--currentRadius);
}
.tabs-bottom .tab-accordion.active,
.tabs-bottom .tab-in-accordion.tab-first-in-group {
  border-bottom-left-radius: var(--currentRadius);
}
.density-on:not(.tabs-at-edge).tabs-bottom .tab-accordion.active,
.density-on:not(.tabs-at-edge).tabs-bottom .tab-in-accordion.tab-first-in-group {
  border-top-left-radius: var(--currentRadius);
}
.tabs-left .tab-accordion.active,
.tabs-left .tab-in-accordion.tab-first-in-group,
.tabs-right .tab-accordion.active,
.tabs-right .tab-in-accordion.tab-first-in-group {
  border-top-left-radius: var(--currentRadius);
  border-top-right-radius: var(--currentRadius);
}
.tabs-top .tab-in-accordion:not(.tab-first-in-group),
.tabs-bottom .tab-in-accordion:not(.tab-first-in-group) {
  border-radius: 0;
}
.tabs-top .tab.active.tab-accordion,
.tabs-bottom .tab.active.tab-accordion {
  margin-right: 0;
}
.tabs-top .tab.active.tab-accordion:after,
.tabs-bottom .tab.active.tab-accordion:after {
  right: calc(-16px - var(--currentRadius)) !important;
}
.tabs-left .tab.active.tab-accordion,
.tabs-right .tab.active.tab-accordion {
  margin-bottom: 0;
}
.tab-in-accordion + .svg-tab-selection .inner,
.tab-in-accordion + .svg-tab-selection .outer {
  stroke-width: 2px;
}
.tabs-top .tab-in-accordion + .svg-tab-selection .inner,
.tabs-top .tab-in-accordion + .svg-tab-selection .outer,
.tabs-bottom .tab-in-accordion + .svg-tab-selection .inner,
.tabs-bottom .tab-in-accordion + .svg-tab-selection .outer {
  x: 1px;
  y: 3px;
  width: calc(100% - 2px);
  height: calc(100% - 6px);
}
.tabs-left .tab-in-accordion + .svg-tab-selection .inner,
.tabs-left .tab-in-accordion + .svg-tab-selection .outer,
.tabs-right .tab-in-accordion + .svg-tab-selection .inner,
.tabs-right .tab-in-accordion + .svg-tab-selection .outer {
  x: 3px;
  y: 1px;
  width: calc(100% - 6px);
  height: calc(100% - 2px);
}
.tabs-top .tab-first-in-group.tab-in-accordion + .svg-tab-selection .inner,
.tabs-top .tab-first-in-group.tab-in-accordion + .svg-tab-selection .outer,
.tabs-bottom .tab-first-in-group.tab-in-accordion + .svg-tab-selection .inner,
.tabs-bottom .tab-first-in-group.tab-in-accordion + .svg-tab-selection .outer {
  x: 3px;
  y: 3px;
  width: calc(var(--Width) - 5px) !important;
  height: calc(100% - 6px);
}
.tabs-left .tab-first-in-group.tab-in-accordion + .svg-tab-selection .inner,
.tabs-left .tab-first-in-group.tab-in-accordion + .svg-tab-selection .outer,
.tabs-right .tab-first-in-group.tab-in-accordion + .svg-tab-selection .inner,
.tabs-right .tab-first-in-group.tab-in-accordion + .svg-tab-selection .outer {
  x: 3px;
  y: 3px;
  width: calc(100% - 6px) !important;
  height: calc(var(--Height) - 6px) !important;
}
.tab-in-accordion + .svg-tab-selection .svg-tab-stack {
  height: calc(var(--Height) - 1px);
}
.accordion-toggle-arrow {
  border-color: var(--colorFgDark);
  fill-opacity: 0.7;
  justify-content: center;
  color: var(--colorFg);
}
.color-behind-tabs-on .accordion-toggle-arrow {
  color: var(--colorAccentFg);
}
.transparent-tabbar .accordion-toggle-arrow:not(.closed.active) {
  color: var(--colorImageFg);
}
.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on.transparent-tabbar .accordion-toggle-arrow:not(.closed.active) {
  color: currentColor;
}
.accordion-toggle-arrow:hover {
  transition-duration: 0s, 0s;
  fill-opacity: 1;
}
.accordion-toggle-arrow.closed.active {
  color: var(--colorFg);
  background-color: var(--colorBg);
}
.color-behind-tabs-off .accordion-toggle-arrow.closed.active {
  color: var(--colorAccentFg);
  background-color: var(--colorAccentBg);
}
.tabs-top:not(.density-on) .accordion-toggle-arrow,
.tabs-top.density-on.tabs-at-edge .accordion-toggle-arrow {
  width: calc(var(--Width) - max(1px, var(--densityGap)));
}
.tabs-bottom:not(.density-on) .accordion-toggle-arrow,
.tabs-bottom.tabs-at-edge .accordion-toggle-arrow {
  width: calc(var(--Width) - max(1px, var(--densityGap)));
  top: -1px;
}
.tabs-top .accordion-toggle-arrow {
  max-width: 16px;
  border-top-right-radius: var(--currentRadius);
}
.density-on:not(.tabs-at-edge).tabs-top .accordion-toggle-arrow {
  border-bottom-right-radius: var(--currentRadius);
}
.tabs-bottom .accordion-toggle-arrow {
  max-width: 16px;
  border-bottom-right-radius: var(--currentRadius);
}
.density-on:not(.tabs-at-edge).tabs-bottom .accordion-toggle-arrow {
  border-top-right-radius: var(--currentRadius);
}
.tabs-left .accordion-toggle-arrow,
.tabs-right .accordion-toggle-arrow {
  width: 100%;
  max-height: 16px;
  border-bottom-left-radius: var(--currentRadius);
  border-bottom-right-radius: var(--currentRadius);
}
.accordion-toggle-arrow .VivaldiSvgIcon {
  align-self: center;
  justify-content: center;
  height: unset;
  width: unset;
}
.accordion-toggle-arrow .VivaldiSvgIcon.left {
  transform: rotate(180deg);
}
.accordion-toggle-arrow .VivaldiSvgIcon.down {
  transform: rotate(90deg);
}
.accordion-toggle-arrow .VivaldiSvgIcon.up {
  transform: rotate(-90deg);
}
.tab-group-indicator {
  position: absolute;
  left: 0;
  right: 0;
  padding-right: calc(var(--radiusHalf) + var(--densityGap));
  padding-left: calc(var(--radiusHalf) + var(--densityGap));
  display: flex;
  flex: 1;
}
.tabs-top .tab-group-indicator,
.tabs-left .tab-group-indicator,
.tabs-right .tab-group-indicator {
  top: -7px;
}
.tabs-bottom .tab-group-indicator {
  bottom: -7px;
}
.tab-indicator {
  flex: 1 1 100%;
  height: 12px;
  border-top: 3px solid transparent;
  border-bottom: 6px solid transparent;
  background-clip: content-box;
  position: relative;
}
.tab-indicator + .tab-indicator {
  margin-left: 1px;
}
.tabs-bottom .tab-indicator {
  border-top: 6px solid transparent;
  border-bottom: 3px solid transparent;
}
.tab-indicator:first-of-type {
  border-top-left-radius: var(--radiusHalf);
}
.tabs-bottom .tab-indicator:first-of-type {
  border-top-left-radius: unset;
  border-bottom-left-radius: var(--radiusHalf);
}
.tab-indicator:last-of-type {
  border-top-right-radius: var(--radiusHalf);
}
.tabs-bottom .tab-indicator:last-of-type {
  border-top-right-radius: unset;
  border-bottom-right-radius: var(--radiusHalf);
}
.tabs-top .tab-indicator:last-of-type,
.tabs-bottom .tab-indicator:last-of-type {
  margin-right: 1px;
}
.tab-indicator.active {
  height: 9px;
  border-bottom-width: 2px;
}
.tabs-bottom .tab-indicator.active {
  border-top-width: 5px;
  border-bottom-width: 0;
}
.tab-indicator.marked {
  position: relative;
  border-radius: 0;
  background-color: var(--colorHighlightBgAlpha);
}
.tabs-bottom .tab-indicator.marked + .tab-group-indicator .svg-tab-selection {
  bottom: 0;
}
.tab-indicator.marked.active.tab-indicator.marked:after {
  content: '';
  position: absolute;
  z-index: 1;
  top: 2px;
  left: 2px;
  right: 2px;
  height: 4px;
  background-color: inherit;
}
.tabs-bottom .tab-indicator.marked.active.tab-indicator.marked:after {
  top: -2px;
}
.tab.marked:not(.active) + .tab-group-indicator .tab-indicator.marked.active.tab-indicator.marked:after {
  background-color: var(--colorHighlightBgAlpha);
}
.tab-indicator.hidden-for-drag {
  visibility: hidden;
}
#app .tab-indicator .svg-tab-selection {
  stroke-width: 5px;
}
#app .tab-indicator .svg-tab-selection .outer {
  stroke: unset;
}
.stacks-dotted.tabs-right .tab-wrapper.group,
.substrip-tabs-on.tabs-right .tab-wrapper.group,
.stacks-dotted.tabs-left .tab-wrapper.group,
.substrip-tabs-on.tabs-left .tab-wrapper.group {
  margin-top: 7px;
  background-clip: content-box;
}
.color-behind-tabs-off .tab-indicator {
  background-color: var(--colorFgFadedMore);
}
.color-behind-tabs-off .tab-indicator:hover {
  background-color: var(--colorFgFaded);
}
.color-behind-tabs-off .tab-indicator.active {
  background-color: var(--colorBgAlphaHeavier);
}
.color-behind-tabs-off .tab.active + .tab-group-indicator .tab-indicator.active {
  background-color: var(--colorAccentBg);
}
.color-behind-tabs-on .tab-indicator {
  background-color: var(--colorBgAlpha);
}
.color-behind-tabs-on .tab-indicator:hover {
  background-color: var(--colorHighlightFg);
}
.color-behind-tabs-on .tab-indicator.active {
  background-color: var(--colorImageBgAlphaHeavy, var(--colorAccentBgAlphaHeavy));
}
.color-behind-tabs-on .tab.active + .tab-group-indicator .tab-indicator.active {
  background-color: var(--colorBg);
}
.color-behind-tabs-on .tab:not(.active):hover .tab-indicator.active {
  background-color: var(--colorImageBgAlpha, var(--colorAccentBgAlpha));
}
.tabs-at-edge.stacks-dotted.tabs-bottom .tab-group-indicator,
.tabs-at-edge.substrip-tabs-on.tabs-bottom .tab-group-indicator {
  bottom: 0;
}
.tabs-at-edge.stacks-dotted.tabs-bottom .tab-group-indicator .tab-indicator,
.tabs-at-edge.substrip-tabs-on.tabs-bottom .tab-group-indicator .tab-indicator {
  border-bottom: 0;
  padding-top: 3px;
  padding-bottom: 3px;
  translate: 0 2px;
  height: 15px;
}
.tabs-at-edge.stacks-dotted:not(.tabs-bottom) .tab-group-indicator,
.tabs-at-edge.substrip-tabs-on:not(.tabs-bottom) .tab-group-indicator {
  top: 0;
}
.tabs-at-edge.stacks-dotted:not(.tabs-bottom) .tab-group-indicator .tab-indicator,
.tabs-at-edge.substrip-tabs-on:not(.tabs-bottom) .tab-group-indicator .tab-indicator {
  border-top: 0;
  padding-top: 3px;
  padding-bottom: 3px;
  translate: 0 -2px;
  height: 15px;
}
.tabs-at-edge.stacks-dotted .tab-group-indicator,
.tabs-at-edge.substrip-tabs-on .tab-group-indicator {
  padding-right: var(--densityGap);
  padding-left: var(--densityGap);
}
.color-behind-tabs-on.tabs-at-edge.stacks-dotted .tab-indicator,
.color-behind-tabs-on.tabs-at-edge.substrip-tabs-on .tab-indicator {
  background-color: var(--colorFgFaded);
}
.color-behind-tabs-off.tabs-at-edge.stacks-dotted .tab-indicator,
.color-behind-tabs-off.tabs-at-edge.substrip-tabs-on .tab-indicator {
  background-color: var(--colorHighlightFgAlpha);
}
.tabs-at-edge.stacks-dotted .tab-indicator.active,
.tabs-at-edge.substrip-tabs-on .tab-indicator.active {
  background-color: transparent;
}
.StackEditor {
  display: flex;
  gap: 9px;
  flex-direction: column;
  padding: 12px;
}
.StackEditor .tab-title-edit {
  padding: 3px 6px;
}
.StackEditor-Colors {
  display: flex;
  gap: 6px;
  padding: 6px 0;
}
.StackEditor-Colors input[type=radio] {
  width: 18px;
  height: 18px;
  box-shadow: inset 0 0 0 12px var(--stackColorBg);
  border-width: 0;
}
.StackEditor-Colors input[type=radio]:checked {
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, inset 0 0 0 5px var(--stackColorBg);
}
.StackEditor-Colors input[type=radio].StackEditor-Color-Reset {
  border: var(--colorErrorBg) 2px solid;
  background: linear-gradient(var(--colorErrorBg), var(--colorErrorBg)) no-repeat 6px / 2px;
  rotate: 45deg;
}
.StackEditor-Colors input[type=radio].StackEditor-Color-Reset:active {
  scale: 1.2;
}
.StackEditor-Submit {
  margin-right: auto;
}
/* INFO: Tooltips are created close to the document root.  */
#vivaldi-tooltip:hover:not(:empty) {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  height: 100vh;
  background-color: transparent;
  overflow-y: auto;
}
.no-app-dragging#vivaldi-tooltip:hover:not(:empty) {
  pointer-events: none;
}
#vivaldi-tooltip .tooltip {
  transition: top 150ms ease 0s, left 150ms ease 0s;
  display: flex;
  align-items: flex-start;
  position: absolute;
  top: 0;
  left: 0;
  z-index: 6;
}
#browser .auto-hide-wrapper.has-tabbar ~ #vivaldi-tooltip .tooltip,
#browser.tabs-top > #vivaldi-tooltip .tooltip {
  z-index: 16;
}
#browser.tabs-bottom > #vivaldi-tooltip .tooltip {
  align-items: flex-end !important;
}
#vivaldi-tooltip .tooltip .tooltip-item {
  display: flex;
  position: relative;
  background-color: var(--colorBg);
  color: var(--colorFg);
  fill: var(--colorFg);
  z-index: 0;
}
#vivaldi-tooltip .tooltip .tooltip-item:hover {
  z-index: 1;
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-image {
  flex: 0 0 182px;
  border-bottom: 1px solid var(--colorBgDark);
  border-radius: var(--radiusHalf);
  background-size: cover;
  transition: background-image 0.3s;
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-caption {
  display: flex;
  height: 100%;
  padding: 6px;
  overflow: hidden;
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-text {
  display: flex;
  gap: 3px;
  flex-direction: column;
  flex: 1;
  margin: 0;
  max-width: 100%;
  overflow-wrap: break-word;
  padding: 0;
  font-size: 12px;
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-text .title {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 4;
  -webkit-box-orient: vertical;
  font-weight: 600;
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-text .title:has(~ .info.size) {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-text .url {
  color: var(--colorFgFaded);
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-text .url:empty {
  display: none;
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-text .size {
  display: flex;
  gap: 3px;
  margin: auto 0 0;
  color: var(--colorFgFadedMore);
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-text .size span {
  opacity: 0.8;
  max-height: 16px;
  line-height: 16px;
}
#vivaldi-tooltip .tooltip .tooltip-item .thumbnail-text .size.off svg .ram {
  opacity: 0.5;
}
#vivaldi-tooltip .tooltip .tooltip-item .tooltip-audio-button {
  pointer-events: all;
  appearance: none;
  flex: 0 0 auto;
  padding: 1px;
  height: 18px;
  width: 18px;
  border: 0;
  border-radius: var(--radiusRounded);
  background-color: var(--colorBg);
  opacity: 0.8;
}
#vivaldi-tooltip .tooltip .tooltip-item .tooltip-audio-button:hover {
  background-color: var(--colorBgDark);
  opacity: 1;
}
#vivaldi-tooltip .tooltip .tooltip-item .tooltip-audio-button:active {
  background-color: var(--colorBgDarker);
}
#vivaldi-tooltip .tooltip .tooltip-item .tooltip-audio-button .audioicon {
  transform-origin: 0 0;
  transform: scale(0.5);
}
#vivaldi-tooltip .tooltip .tooltip-item .close {
  pointer-events: all;
  flex: 0 0 auto;
}
#vivaldi-tooltip .tooltip .tab-solo .tooltip-item {
  flex-direction: column;
  width: 222px;
  border-radius: var(--radiusHalf);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
#vivaldi-tooltip .tooltip .tab-solo .tooltip-item .close {
  display: none;
  left: 0;
}
#vivaldi-tooltip .tooltip .tab-solo .tooltip-item .thumbnail-image {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
#vivaldi-tooltip .tooltip .tab-group {
  display: flex;
  flex-wrap: wrap;
  filter: drop-shadow(0 3px 5px rgba(0, 0, 0, 0.2)) drop-shadow(-1px 0 0 rgba(0, 0, 0, 0.1)) drop-shadow(1px 0 0 rgba(0, 0, 0, 0.1));
}
#vivaldi-tooltip .tooltip .tab-group .tooltip-item {
  flex-direction: row;
  flex: 0 0 auto;
  width: 340px;
  height: 104px;
  align-items: flex-start;
  gap: 12px;
  padding: 9px;
  border-radius: var(--radiusHalf);
  box-shadow: inset -1px 0 0 0 var(--colorBorder), inset 0 -1px 0 0 var(--colorBorder);
  overflow: hidden;
}
#vivaldi-tooltip .tooltip .tab-group .tooltip-item > * {
  pointer-events: none;
}
#vivaldi-tooltip .tooltip .tab-group .thumbnail-image {
  flex: 0 0 104px;
  height: 85px;
  border: 1px solid var(--colorBorderDisabled);
}
#vivaldi-tooltip .tooltip .tab-group .thumbnail-caption {
  flex: 1;
  padding: 0;
  gap: 6px;
}
#vivaldi-tooltip .tooltip .tab-group .thumbnail-buttons {
  display: flex;
  flex: 0 0 18px;
  flex-direction: column;
  align-items: flex-end;
  gap: 6px;
}
#vivaldi-tooltip .tooltip .tab-group .thumbnail-buttons .favicon {
  margin: 1px;
  z-index: 1;
}
#vivaldi-tooltip .tooltip .tab-group .thumbnail-buttons .close {
  position: absolute;
  display: none;
}
#vivaldi-tooltip .tooltip .tab-group .tooltip-item:hover .favicon {
  display: none;
}
#vivaldi-tooltip .tooltip .tab-group .tooltip-item:hover .close {
  position: relative;
  display: flex;
}
#vivaldi-tooltip .tooltip .tab-group .thumbnail-text {
  white-space: normal;
  padding: 0;
  margin: 0;
}
#vivaldi-tooltip .tooltip .tab-group .close {
  order: unset !important;
}
.tabs-right #vivaldi-tooltip .tooltip .tab-group {
  justify-content: flex-end;
}
.tabs-bottom #vivaldi-tooltip .tooltip .tab-group {
  align-items: flex-end;
}
#browser.alt-tabs #vivaldi-tooltip .tooltip .tab-group .thumbnail-image {
  order: 3;
}
#browser.alt-tabs #vivaldi-tooltip .tooltip .tab-group .thumbnail-buttons {
  order: -1;
}
#vivaldi-tooltip .tooltip .tab-group .tooltip-item:hover,
#vivaldi-tooltip .tooltip .tab-group .tooltip-item:active,
#vivaldi-tooltip .tooltip .tab-group .tooltip-item.active,
#vivaldi-tooltip .tooltip .tab-group .tooltip-item.last-active {
  background-color: var(--colorBgLighter);
}
#vivaldi-tooltip .tooltip .tab-group .tooltip-item:hover .thumbnail-image,
#vivaldi-tooltip .tooltip .tab-group .tooltip-item:active .thumbnail-image,
#vivaldi-tooltip .tooltip .tab-group .tooltip-item.active .thumbnail-image,
#vivaldi-tooltip .tooltip .tab-group .tooltip-item.last-active .thumbnail-image {
  opacity: 0.9;
}
#vivaldi-tooltip .tooltip .tab-group .tooltip-item.last-active .thumbnail-image,
#vivaldi-tooltip .tooltip .tab-group .tooltip-item.active .thumbnail-image {
  opacity: 1;
}
#panels-container {
  display: flex;
  flex: 0 0 auto;
  max-width: 61.8%;
  overflow: visible;
  position: relative;
  color: var(--colorFg);
  border: 0 solid var(--colorBorder);
  background-color: var(--colorBgAlphaBlur);
  z-index: 1;
}
.auto-hide-wrapper #panels-container {
  height: 100%;
  max-width: 100%;
}
#panels-container.overlay {
  position: absolute;
  top: 0;
  bottom: 0;
}
#panels-container.overlay.left {
  left: 0;
}
#panels-container.overlay.right {
  right: 0;
}
#panels-container.overlay:not(.switcher) {
  z-index: 3;
}
#panels-container.overlay:not(.switcher) #panels {
  overflow: visible;
}
#panels-container.overlay:after {
  content: unset;
}
#panels-container.overlay .panel-group {
  position: absolute;
  top: 0;
  width: auto;
  bottom: 0;
  background-color: var(--colorBgAlphaBlur);
}
:not(.resizing)#panels-container.overlay .panel-group {
  transition: width var(--duration) ease-out;
}
#panels-container.overlay.minimized {
  position: relative;
}
#panels-container.overlay:not(.minimized).button.left ~ div:not(:empty) {
  margin-left: 10px;
}
.mac #panels-container.overlay:not(.minimized).button.left ~ div:not(:empty) {
  margin-left: 6px;
}
#panels-container.overlay:not(.minimized).button.left ~ div:not(:empty) ~ div:not(:empty) {
  margin-left: 0;
}
#panels-container.overlay:not(.minimized).button.right ~ div:last-of-type {
  margin-right: 10px;
}
.mac #panels-container.overlay:not(.minimized).button.right ~ div:last-of-type {
  margin-right: 6px;
}
.auto-hide-wrapper #panels-container.overlay #panel_switch {
  align-self: center;
}
#panels-container.left:not(.icons) .panel-group,
#panels-container.left.icons:not(:has(.SlideBar)) {
  border-right: 1px solid rgba(0, 0, 0, 0.1);
}
#panels-container.left:not(.icons).overlay .panel-group {
  box-shadow: 4px 0 8px -4px rgba(0, 0, 0, 0.25);
}
#browser .auto-hide-wrapper #panels-container .panel-group {
  border: 0;
}
#panels-container.right {
  z-index: 3;
}
#panels-container.right:not(.icons) .panel-group,
#panels-container.right.icons:not(:has(.SlideBar)) {
  border-left: 1px solid rgba(0, 0, 0, 0.1);
}
#panels-container.right:not(.icons).overlay .panel-group {
  box-shadow: -4px 0 8px -4px rgba(0, 0, 0, 0.25);
}
#panels {
  display: flex;
  flex: 1;
  max-width: 100%;
  position: relative;
  overflow: hidden;
  contain: content;
}
#panels-container:not(.icons).overlay #panels {
  contain: unset;
}
#panels-container.switcher #switch {
  visibility: hidden;
}
.inner:has( #panels-container.overlay:not(.minimized) .toolbar-panel.dragging) #webview-container {
  pointer-events: none;
}
#panel_switch {
  display: flex;
  justify-content: center;
  align-items: center;
  flex: 0 0 10px;
  background-color: var(--colorBg);
  background-repeat: no-repeat;
  background-position: 50% 50%;
  background-size: 4px 8px;
  overflow: visible;
}
#panel_switch svg polygon {
  fill: var(--colorFg);
}
.mac #panel_switch {
  flex: 0 0 6px;
}
#panel_switch.off {
  border: 0;
}
#panel_switch:hover {
  background-color: var(--colorBgLighter);
}
#panels-container.left.button.switcher #panel_switch {
  border-right: 1px solid var(--colorBorder);
}
#panels-container.right.button.switcher #panel_switch {
  border-left: 1px solid var(--colorBorder);
}
#switch {
  display: flex;
  flex: 0 0 34px;
  max-width: 34px;
  flex-direction: column;
  position: relative;
  contain: strict;
  padding-top: 6px;
  backdrop-filter: var(--backgroundBlur);
  overflow-y: hidden;
  overflow-x: hidden;
  scrollbar-gutter: stable;
}
.density-on #switch {
  flex: 0 0 calc(34px + var(--densityGap) * 2);
  max-width: calc(34px + var(--densityGap) * 2);
}
#switch:hover {
  overflow-y: auto;
}
#switch > .toolbar-panel {
  margin-right: -4px;
}
#switch button.webviewbtn img {
  background-color: transparent;
  padding: 2px;
  border-radius: 2px;
  width: 20px;
  height: 20px;
}
#switch .addwebpanel-wrapper > button,
#switch > .button-toolbar,
#switch > * > .button-toolbar,
#switch > button {
  display: flex;
  justify-content: center;
  align-items: center;
  width: 34px;
  height: 34px;
  border: 0;
  border-radius: 0;
  background-color: transparent;
  position: relative;
  padding-left: 0;
  padding-right: 0;
  padding-bottom: 0;
}
#browser:not(.density-on) .left #switch .addwebpanel-wrapper > button,
#browser:not(.density-on) .left #switch > .button-toolbar,
#browser:not(.density-on) .left #switch > * > .button-toolbar,
#browser:not(.density-on) .left #switch > button {
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
#browser:not(.density-on) .right #switch .addwebpanel-wrapper > button,
#browser:not(.density-on) .right #switch > .button-toolbar,
#browser:not(.density-on) .right #switch > * > .button-toolbar,
#browser:not(.density-on) .right #switch > button {
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
}
#browser:not(.density-on) .icons #switch .addwebpanel-wrapper > button,
#browser:not(.density-on) .icons #switch > .button-toolbar,
#browser:not(.density-on) .icons #switch > * > .button-toolbar,
#browser:not(.density-on) .icons #switch > button {
  border-radius: 0;
}
#browser:not(.density-on) #switch .addwebpanel-wrapper > button:not(
    .toolbar-spacer,
    .toolbar-spacer-panel,
    .toolbar-spacer-flexible,
    .toolbar-divider):hover,
#browser:not(.density-on) #switch > .button-toolbar:not(
    .toolbar-spacer,
    .toolbar-spacer-panel,
    .toolbar-spacer-flexible,
    .toolbar-divider):hover,
#browser:not(.density-on) #switch > * > .button-toolbar:not(
    .toolbar-spacer,
    .toolbar-spacer-panel,
    .toolbar-spacer-flexible,
    .toolbar-divider):hover,
#browser:not(.density-on) #switch > button:not(
    .toolbar-spacer,
    .toolbar-spacer-panel,
    .toolbar-spacer-flexible,
    .toolbar-divider):hover,
#browser:not(.density-on) #switch .addwebpanel-wrapper > button:not(
    .toolbar-spacer,
    .toolbar-spacer-panel,
    .toolbar-spacer-flexible,
    .toolbar-divider):active,
#browser:not(.density-on) #switch > .button-toolbar:not(
    .toolbar-spacer,
    .toolbar-spacer-panel,
    .toolbar-spacer-flexible,
    .toolbar-divider):active,
#browser:not(.density-on) #switch > * > .button-toolbar:not(
    .toolbar-spacer,
    .toolbar-spacer-panel,
    .toolbar-spacer-flexible,
    .toolbar-divider):active,
#browser:not(.density-on) #switch > button:not(
    .toolbar-spacer,
    .toolbar-spacer-panel,
    .toolbar-spacer-flexible,
    .toolbar-divider):active {
  background-color: var(--colorBgDark);
}
#switch .addwebpanel-wrapper > button.active:not(:focus),
#switch > .button-toolbar.active:not(:focus),
#switch > * > .button-toolbar.active:not(:focus),
#switch > button.active:not(:focus) {
  position: relative;
}
#browser:not(.density-on) #switch .addwebpanel-wrapper > button.active,
#browser:not(.density-on) #switch > .button-toolbar.active,
#browser:not(.density-on) #switch > * > .button-toolbar.active,
#browser:not(.density-on) #switch > button.active {
  background-color: var(--colorHighlightBgAlpha);
}
#browser:not(.density-on) .left #switch .addwebpanel-wrapper > button.active,
#browser:not(.density-on) .left #switch > .button-toolbar.active,
#browser:not(.density-on) .left #switch > * > .button-toolbar.active,
#browser:not(.density-on) .left #switch > button.active {
  box-shadow: inset 2px 0 0 var(--colorHighlightBg);
}
#browser:not(.density-on) .right #switch .addwebpanel-wrapper > button.active,
#browser:not(.density-on) .right #switch > .button-toolbar.active,
#browser:not(.density-on) .right #switch > * > .button-toolbar.active,
#browser:not(.density-on) .right #switch > button.active {
  box-shadow: inset -2px 0 0 var(--colorHighlightBg);
}
.density-on #switch .addwebpanel-wrapper > button.active button,
.density-on #switch > .button-toolbar.active button,
.density-on #switch > * > .button-toolbar.active button,
.density-on #switch > button.active button {
  background-color: var(--colorHighlightBgAlpha);
}
#switch .addwebpanel-wrapper > button:active > span svg,
#switch > .button-toolbar:active > span svg,
#switch > * > .button-toolbar:active > span svg,
#switch > button:active > span svg {
  transform: scale(0.85);
  transition-duration: 0s;
}
#switch .addwebpanel-wrapper > button:focus-visible:not(.button-badge),
#switch > .button-toolbar:focus-visible:not(.button-badge),
#switch > * > .button-toolbar:focus-visible:not(.button-badge),
#switch > button:focus-visible:not(.button-badge) {
  box-shadow: none;
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.full-key-access.hasfocus #switch:focus-within > button:focus,
.active-pane-selection.hasfocus #switch:focus-within > button:focus {
  z-index: 1;
}
.panel-group {
  display: flex;
  flex-flow: column nowrap;
  flex: 1;
  overflow: hidden;
  contain: strict;
  color: var(--colorFg);
  backdrop-filter: var(--backgroundBlur);
}
.panel-group .panel-collapse-guard {
  display: flex;
  flex: 1;
  width: 100%;
  contain: strict;
}
.left .panel-group .panel-collapse-guard {
  align-self: flex-end;
}
.panel-group .panel {
  display: flex;
  flex-flow: column nowrap;
  flex: 1;
  width: 100%;
  padding-top: 12px;
}
.panel {
  padding-right: var(--scrollbarWidth);
}
#panels-container.left .panel {
  padding-left: 9px;
}
#panels-container.right .panel {
  padding-left: 12px;
}
.panel .outerScrollbar {
  margin-right: calc(var(--scrollbarWidth) * -1);
}
.panel .outerScrollbar .TranslatePanel,
.panel .outerScrollbar .ReactVirtualized__Grid.ReactVirtualized__List {
  scrollbar-gutter: stable;
}
.panel > header {
  min-height: 34px;
  margin-bottom: 6px;
  flex: 0 0 auto;
}
.panel > header input[type=text],
.panel > header input[type=search] {
  flex: 1 0 100px;
  min-width: 100px;
}
.panel > header h1 {
  display: flex;
  align-items: center;
  margin: 0 auto 12px 0;
}
.panel > header h1 > span:first-child {
  margin-right: auto;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.panel > header h1 .close {
  margin-left: 6px;
  align-self: flex-start;
}
.panel > header > .toolbar + .toolbar {
  margin-top: 6px;
}
.panel > footer {
  padding: 12px 0;
  border-top: 1px solid var(--colorBorder);
}
.panel > footer label {
  display: flex;
}
.panel > footer input {
  margin-right: 6px;
}
.panel section {
  display: flex;
  flex-direction: column;
  flex: 1 1 auto;
  overflow-x: hidden;
  overflow-y: auto;
  position: relative;
}
.panel#mail_panel .tree-row label:last-of-type {
  padding-right: unset;
}
.panel#mail_panel .tree-row:has(.last-in-group) {
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
  padding-block-end: 3px;
}
.panel#mail_panel .tree-row:has(.mail-panel-category) {
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
  padding-block: 3px;
}
.panel#mail_panel .tree-row {
  padding-inline: 3px;
  background-color: var(--colorBgLighter);
  border-radius: unset;
}
.theme-dark .panel#mail_panel .tree-row {
  background-color: var(--colorBgDark);
}
.panel#mail_panel .tree-item {
  display: flex;
  align-items: flex-end;
}
.panel#mail_panel .tree-item:not([data-selected]) .tree-row {
  background-color: var(--colorBgLighter);
  color: var(--colorFg);
  fill: var(--colorFg);
  padding-inline: 3px;
}
.theme-dark .panel#mail_panel .tree-item:not([data-selected]) .tree-row {
  background-color: var(--colorBgDark);
}
.panel#mail_panel .tree-item:not([data-selected]) .tree-row.dragover .mail_panel_node,
.panel#mail_panel .tree-item:not([data-selected]) .tree-row.dragover .mail-panel-category {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
  border-radius: var(--radius);
}
.panel#mail_panel .tree-item:last-of-type {
  margin-bottom: 12px;
}
.panel#mail_panel .tree-item:is([data-selected]) .tree-row .mail_panel_node,
.panel#mail_panel .tree-item:is([data-selected]) .tree-row .mail-panel-category {
  background-color: var(--colorFgAlpha);
  border-radius: var(--radius);
}
.panel#mail_panel .tree-item:not([data-selected]) .mail-panel-category {
  background-color: var(--colorBgLighter);
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
  color: var(--colorFg);
  fill: var(--colorFg);
}
.panel#mail_panel .tree-item:not([data-selected]) .mail-panel-category.last-in-group {
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.theme-dark .panel#mail_panel .tree-item:not([data-selected]) .mail-panel-category {
  background-color: var(--colorBgDark);
}
.panel#mail_panel .tree-item:not([data-selected]) .mail-panel-category:hover {
  background-color: var(--colorBgDark);
}
.theme-dark .panel#mail_panel .tree-item:not([data-selected]) .mail-panel-category:hover {
  background-color: var(--colorFgAlpha);
}
.hasfocus .panel#mail_panel:focus-within .tree-row[data-selected] .mail_panel_node,
.hasfocus .panel#mail_panel:focus-within .tree-row[data-selected] .mail-panel-category {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
}
.hasfocus .panel#mail_panel:focus-within .tree-row[data-selected] .mail_panel_node .display-hint:hover,
.hasfocus .panel#mail_panel:focus-within .tree-row[data-selected] .mail-panel-category .display-hint:hover {
  fill: var(--colorHighlightBg);
}
.panel#mail_panel .display-hint {
  margin: 6px;
  border-radius: 100%;
  align-items: center;
  min-width: 16px;
  justify-content: center;
}
.panel#mail_panel .counter-container,
.panel#mail_panel label > .item-count:last-child {
  margin-right: 6px;
}
.panel#mail_panel .mail-panel-category-container {
  flex: 1;
}
.panel#mail_panel .mail-panel-category-container .display-hint:hover {
  background-color: var(--colorBgLighter);
  fill: var(--colorFg);
}
.theme-dark .panel#mail_panel .mail-panel-category-container .display-hint:hover {
  background-color: var(--colorBgDark);
  fill: var(--colorFg);
}
.panel#mail_panel .tree-row-selected .mail-panel-category-container .display-hint,
.panel#mail_panel .mail-panel-category-container:hover .display-hint {
  display: inline-flex;
}
.panel#mail_panel .tree-row-selected .mail-panel-category-container .item-count,
.panel#mail_panel .mail-panel-category-container:hover .item-count {
  display: none;
}
.panel#mail_panel label.mail_panel_node {
  padding-left: 0 !important;
}
.panel#mail_panel label.mail-panel-category {
  font-weight: 600;
  padding: 0;
  gap: 0;
}
.panel .panel-empty-state {
  margin: 18px 12px;
  text-align: center;
}
.panel .panel-empty-state h1 {
  font-weight: 600;
  margin-top: 18px;
  padding-bottom: 12px;
}
.panel .panel-empty-state p {
  margin-bottom: 6px;
}
.panel .panel-empty-state > input[type='button'] {
  margin-top: 12px;
}
.panel .tree-row {
  min-width: 100%;
}
.panel .tree-row label {
  padding-left: 6px;
}
.panel .SlideBar--FullWidth.alternate {
  top: 0;
  border-top: 2px solid var(--colorBorderIntense);
  position: sticky;
}
.theme-dark .panel .SlideBar--FullWidth.alternate {
  border-color: var(--colorFgFadedMost);
}
.panel .SlideBar--FullWidth.alternate:hover,
.panel .SlideBar--FullWidth.alternate:active {
  border-color: var(--colorFgFadedMore);
}
.theme-dark .panel .SlideBar--FullWidth.alternate:hover,
.theme-dark .panel .SlideBar--FullWidth.alternate:active {
  border-color: var(--colorFg);
}
.panel .collapsed .SlideBar--FullWidth.alternate {
  cursor: n-resize;
}
.panel .collapsed .SlideBar--FullWidth.alternate + div {
  visibility: collapse;
  overflow: hidden;
}
div#main.right #panels-container,
.auto-hide-wrapper.right #panels-container {
  order: 2;
}
div#main.right #panels-container #panels,
.auto-hide-wrapper.right #panels-container #panels {
  flex-direction: row-reverse;
}
#window-panel .sortselector + p {
  margin: 6px 12px;
  opacity: 0.6;
}
#window-panel .vivaldi-tree .tab-audio {
  margin-right: 10px;
}
#window-panel .vivaldi-tree .title {
  display: flex;
  align-items: center;
}
#window-panel .vivaldi-tree .title.active {
  font-weight: 600;
}
#window-panel .vivaldi-tree .title.active:before {
  content: '•';
  position: absolute;
  margin-left: -36px;
}
#window-panel .vivaldi-tree .title.unread {
  font-style: italic;
}
#window-panel .vivaldi-tree .title .text {
  flex-shrink: 1;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
#window-panel .vivaldi-tree .title .pill {
  flex: 0 0 auto;
  background-color: var(--colorFgAlpha);
  height: auto;
  line-height: 1.3;
  padding: 1px 4px;
  border-radius: 3px;
  font-size: 11.5px;
  font-weight: 600;
  margin: auto 0 auto auto;
  overflow: visible;
  min-width: 1.5em;
  text-align: center;
  margin-left: 6px;
  border-radius: var(--radius);
}
.counter-indicator + #window-panel .vivaldi-tree .title .pill {
  margin-left: 3px;
}
#window-panel .vivaldi-tree .title .pill.counter-unseen {
  color: var(--colorBgIntense);
  background-color: var(--colorFgFadedMore);
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  font-weight: 400;
}
#window-panel .vivaldi-tree .title .pill.counter-unseen + .counter-unread {
  margin-left: -6px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] #window-panel .vivaldi-tree .title .pill {
  background-color: var(--colorHighlightFgAlphaHeavy);
  font-weight: 400;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] #window-panel .vivaldi-tree .title .pill.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
  font-weight: 600;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container #window-panel .vivaldi-tree .title .pill {
  background-color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container #window-panel .vivaldi-tree .title .pill.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container #window-panel .vivaldi-tree .title .pill.counter-unread {
  background-color: var(--colorHighlightFgAlphaHeavy);
  color: var(--colorHighlightFg);
  font-weight: 400;
}
#window-panel .vivaldi-tree .svg-icon {
  width: 16px;
  display: flex;
  justify-content: center;
}
#window-panel .vivaldi-tree .svg-icon svg {
  fill: currentColor;
  stroke: none;
}
#window-panel .vivaldi-tree .workspace-icon svg {
  fill: none;
  stroke: currentColor;
}
#window-panel .vivaldi-tree .tree-row {
  height: 100%;
  padding-inline: 3px;
  border-radius: unset;
}
#window-panel .vivaldi-tree .tree-row:not(.dragover) {
  background-color: var(--colorBgLighter);
}
.theme-dark #window-panel .vivaldi-tree .tree-row:not(.dragover) {
  background-color: var(--colorBgDark);
}
#window-panel .vivaldi-tree .tree-item:not(:first-child) .tree-row:has(.window-parent:not(.window-child)) {
  margin-top: 7px;
}
#window-panel .vivaldi-tree .tree-item .tree-row:has(.window-parent:not(.window-child)) {
  margin-top: 1px;
  padding-block: 3px;
  height: calc(var(--treeViewRowHeight) + 6px);
  border-radius: var(--radius);
}
#window-panel .vivaldi-tree .tree-item[data-expanded] .tree-row {
  border-bottom-left-radius: 0 !important;
  border-bottom-right-radius: 0 !important;
}
#window-panel .vivaldi-tree input[type='button'] {
  max-height: 100%;
  max-width: fit-content;
}
#window-panel .vivaldi-tree .tree-row:has(.last-window-child) {
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
  padding-bottom: 3px;
}
#window-panel .vivaldi-tree .tree-row:has(.is-cut) {
  opacity: 0.5;
}
#window-panel .vivaldi-tree .tree-item:last-of-type {
  min-height: 31px;
  margin-bottom: 12px;
}
#window-panel .vivaldi-tree .tree-item:last-of-type label {
  margin-bottom: 3px;
}
#window-panel .vivaldi-tree .window-entry-button {
  padding: 6px;
  height: 100%;
}
#window-panel .vivaldi-tree .window-entry-button.selected > input {
  outline: 2px solid var(--colorHighlightBg);
}
#window-panel .vivaldi-tree .VivaldiList .tree-row .window-entry.colored {
  background-color: var(--stackColorBgAlpha);
  border-radius: var(--radius);
  border: solid transparent;
  border-width: 1px 0;
  background-clip: padding-box;
}
#window-panel .vivaldi-tree .VivaldiList .tree-row .window-entry.colored:before {
  content: '';
  position: absolute;
  width: 8px;
  height: 8px;
  border: 1px solid var(--colorBg);
  border-radius: 50%;
  background-color: var(--stackColorBg);
}
#window-panel .vivaldi-tree .VivaldiList .tree-row[data-selected] {
  box-shadow: unset;
}
#window-panel .vivaldi-tree .VivaldiList .tree-row[data-selected] .window-entry:not(.window-entry-button) {
  background-color: var(--colorFgAlpha);
}
.hasfocus #window-panel .vivaldi-tree .VivaldiList:focus-within .tree-row[data-selected] .window-entry:not(.window-entry-button) {
  background-color: var(--colorHighlightBg);
}
#window-panel .vivaldi-tree .VivaldiList .tree-row[data-selected].tree-row-selected--first .window-entry {
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
}
#window-panel .vivaldi-tree .VivaldiList .tree-row[data-selected].tree-row-selected--last .window-entry {
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
#window-panel .workspace-button > button {
  max-width: 100%;
  margin-bottom: 12px;
}
.download-popout {
  min-height: 270px;
  max-height: 90vh;
  height: var(--popupHeight);
}
.download-popout .panel {
  padding: 12px 12px 6px 12px;
  display: flex;
  flex-direction: column;
  flex: 1;
  overflow: hidden;
}
.download-popout .panel.isEmpty header,
.download-popout .panel.isEmpty .outerScrollbar {
  display: none;
}
.download-popout .panel .download-empty-state {
  margin: auto 12px;
}
.download-popout .outerScrollbar {
  min-height: 52px;
}
.download-popout .resize-below {
  bottom: 0;
}
.download-popout .downloads:disabled {
  box-shadow: unset;
}
.download-popout .close {
  display: none;
  visibility: hidden;
}
/* STYLING/OVERRIDES FOR TAB-LESS WINDOWS */
#browser.tabs-off.popup:not(.fullscreen) #header {
  position: relative;
}
#browser.tabs-off.popup.is-settingspage #header {
  box-shadow: inset 0 -1px 0 var(--colorBorder);
}
#browser.tabs-off.popup.is-settingspage #pagetitle,
#browser.tabs-off.popup.native #header,
#browser.tabs-off.popup.native .settings-header {
  display: none;
}
#browser.tabs-off.popup .webpageview {
  flex: 1;
  background-color: transparent;
}
#browser.tabs-off.popup .internal.webpageview {
  flex: 0;
}
#browser.tabs-off.popup .toolbar-mainbar:not(.toolbar-wrap) {
  padding-left: 3px;
}
#browser.tabs-off.popup .toolbar-mainbar:not(.toolbar-wrap):only-child {
  padding-right: 3px;
}
.win#browser.tabs-off.popup #titlebar {
  height: calc(30px / var(--uiZoomLevel));
  line-height: 30px;
  box-shadow: none;
  margin-right: calc(140px / var(--uiZoomLevel));
}
.win#browser.tabs-off.popup #titlebar img {
  overflow: hidden;
  max-width: 100%;
  object-fit: cover;
  flex: 0 0.1 16px;
}
.mac#browser.tabs-off.popup #titlebar,
.mac#browser.tabs-off.popup #header,
.mac#browser.tabs-off.popup .settings-header {
  height: calc(32px / var(--uiZoomLevel));
  line-height: 32px;
}
.mac:not(.macos26)#browser.tabs-off.popup #titlebar,
.mac:not(.macos26)#browser.tabs-off.popup #header,
.mac:not(.macos26)#browser.tabs-off.popup .settings-header {
  height: calc(28px / var(--uiZoomLevel));
  line-height: 28px;
}
#browser.tabs-off.popup .toolbar-extensions:hover {
  background-color: transparent;
}
#browser.tabs-off.popup .button-popup {
  max-height: 90vh;
}
#browser.mail-composer #mail_composer .toolbar-mailbar {
  padding: 6px 6px 0;
}
.Bookmark-Added-Popup {
  display: flex;
  align-items: center;
  border-radius: var(--radius);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  position: absolute;
  top: 36px;
  right: 12px;
  z-index: 100;
  background-color: var(--colorBgLightIntense);
}
.Bookmark-Added-Popup .BookmarkButton {
  height: 28px;
  padding: 6px;
  border: none;
}
.Bookmark-Added-Popup .BookmarkButton .ToolbarButton-Button {
  padding: 0 6px;
}
.Bookmark-Added-Popup-enter {
  transition: transform 300ms ease-in, opacity 300ms ease-in;
  transform: translateY(-10px);
  opacity: 0;
}
.Bookmark-Added-Popup-enter-active {
  transform: translateY(0);
  opacity: 1;
}
.Bookmark-Added-Popup-exit-active {
  transition: transform 150ms linear, opacity 150ms linear;
  transform: translateY(-10px);
  opacity: 0;
}
.auto-hide {
  flex: 1;
  display: grid;
  grid-template-columns: 6px [content] 1fr 6px;
  grid-template-rows: 6px [content] 1fr 6px;
  grid-template-areas: 'top top top' 'left content right' 'bottom bottom bottom';
}
.auto-hide:has(#browser.fullscreen),
.auto-hide:has(:not(.mac).maximized) {
  grid-template-columns: 0 [content] 1fr 0;
  grid-template-rows: 0 [content] 1fr 0;
}
.auto-hide #browser {
  grid-area: content;
  border-radius: var(--radiusWindow);
}
.auto-hide #browser.fullscreen,
.auto-hide #browser:not(.mac).maximized {
  border-radius: 0;
}
.auto-hide > .top {
  grid-area: top;
  z-index: 4;
}
.auto-hide > .right {
  grid-area: right;
  z-index: 4;
}
.auto-hide > .bottom {
  grid-area: bottom;
  z-index: 4;
}
.auto-hide > .left {
  grid-area: left;
  z-index: 4;
}
.auto-hide-off {
  display: flex;
  flex: 1;
}
/**
 * AutoHide drag-region
 */
.auto-hide #browser .auto-hide-wrapper.show {
  -webkit-app-region: drag;
}
.auto-hide #browser .auto-hide-wrapper.show.top #titlebar,
.auto-hide #browser .auto-hide-wrapper.show.bottom > div {
  anchor-name: --auto-hide;
}
.auto-hide #browser.transparent-tabbar.color-behind-tabs-on .auto-hide-wrapper.has-tabbar {
  background-color: var(--colorAccentBgAlphaBlur);
}
.auto-hide #browser.transparent-tabbar.color-behind-tabs-off .auto-hide-wrapper.has-tabbar {
  background: var(--colorBg);
}
.auto-hide #browser.transparent-tabbar.color-behind-tabs-off .auto-hide-wrapper.has-tabbar,
.auto-hide #browser.transparent-tabbar.color-behind-tabs-off .auto-hide-wrapper.has-tabbar .button-toolbar {
  --colorImageFg: var(--colorFg);
}
/**
 * AutoHideWrapper
 */
.auto-hide-wrapper {
  position: fixed;
  display: flex;
  z-index: 5;
  border-radius: var(--radiusWindow);
  transition: transform 64ms cubic-bezier(1, 0, 1, 1);
}
.auto-hide-wrapper.show {
  transition-duration: 100ms;
  transition-timing-function: cubic-bezier(0, 1, 1, 1);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.auto-hide-wrapper.show:before {
  content: '';
  position: absolute;
  background-color: transparent;
}
.auto-hide-wrapper.top,
.auto-hide-wrapper.bottom {
  left: 6px;
  width: calc(100% - (6px * 2));
  flex-direction: column;
}
.auto-hide-wrapper.left,
.auto-hide-wrapper.right {
  top: 6px;
  height: calc(100% - (6px * 2));
  flex-direction: row;
}
.auto-hide-wrapper.top {
  top: 6px;
  transform: translateY(calc(-100% - (6px * 2)));
}
.auto-hide-wrapper.top.show {
  transform: translateY(0);
}
.auto-hide-wrapper.top.show:before {
  inset: -6px 0 0 0;
}
#browser.mac-menubar-permanent .auto-hide-wrapper.top.show,
#browser.mac-fullscreen-hover-notch .auto-hide-wrapper.top.show {
  transform: translateY(32px);
}
#browser.mac-fullscreen-hover .auto-hide-wrapper.top.show {
  transform: translateY(62px);
}
#browser:not(.macos26).mac-menubar-permanent .auto-hide-wrapper.top.show,
#browser:not(.macos26).mac-fullscreen-hover-notch .auto-hide-wrapper.top.show {
  transform: translateY(24px);
}
#browser:not(.macos26).mac-fullscreen-hover .auto-hide-wrapper.top.show {
  transform: translateY(52px);
}
.auto-hide-wrapper.right {
  right: 6px;
  transform: translateX(calc(100% + (6px * 2)));
}
.auto-hide-wrapper.right.show {
  transform: translateX(0);
}
.auto-hide-wrapper.right.show:before {
  inset: 0 -6px 0 0;
}
.auto-hide-wrapper.bottom {
  bottom: 6px;
  transform: translateY(calc(100% + (6px * 2)));
}
.auto-hide-wrapper.bottom.show {
  transform: translateY(0);
}
.auto-hide-wrapper.bottom.show:before {
  inset: 0 0 -6px 0;
}
.auto-hide-wrapper.left {
  left: 6px;
  transform: translateX(calc(-100% - (6px * 2)));
}
.auto-hide-wrapper.left.show {
  transform: translateX(0);
}
.auto-hide-wrapper.left.show:before {
  inset: 0 0 0 -6px;
}
.auto-hide .auto-hide-wrapper.top > div:only-child,
.auto-hide .auto-hide-wrapper.bottom > div:only-child,
.auto-hide .auto-hide-wrapper.top > div:first-child,
.auto-hide .auto-hide-wrapper.bottom > div:first-child {
  border-top-left-radius: var(--radiusWindow);
  border-top-right-radius: var(--radiusWindow);
}
.auto-hide .auto-hide-wrapper.top > div:only-child,
.auto-hide .auto-hide-wrapper.bottom > div:only-child,
.auto-hide .auto-hide-wrapper.top > div:last-child,
.auto-hide .auto-hide-wrapper.bottom > div:last-child {
  border-bottom-left-radius: var(--radiusWindow);
  border-bottom-right-radius: var(--radiusWindow);
}
.auto-hide .auto-hide-wrapper.left > div:only-child,
.auto-hide .auto-hide-wrapper.right > div:only-child,
.auto-hide .auto-hide-wrapper.left > div:first-child,
.auto-hide .auto-hide-wrapper.right > div:first-child {
  border-top-left-radius: var(--radiusWindow);
  border-bottom-left-radius: var(--radiusWindow);
}
.auto-hide .auto-hide-wrapper.left > div:only-child,
.auto-hide .auto-hide-wrapper.right > div:only-child,
.auto-hide .auto-hide-wrapper.left > div:last-child,
.auto-hide .auto-hide-wrapper.right > div:last-child {
  border-top-right-radius: var(--radiusWindow);
  border-bottom-right-radius: var(--radiusWindow);
}
.auto-hide .auto-hide-wrapper #tabs-tabbar-container,
.auto-hide .auto-hide-wrapper #panels {
  border-radius: inherit;
}
.about-page {
  display: flex;
  flex-direction: column;
  flex: 1;
  width: 100%;
  margin: 0 auto;
  overflow-y: auto;
  box-sizing: border-box;
  padding: 36px 36px;
}
.about-page:focus-visible {
  outline: none;
}
.about-page h1 {
  font-size: 21px;
  font-weight: 600;
  color: var(--colorFg);
  margin: 0;
}
.about-page h2 {
  font-size: 16px;
  margin-bottom: 15px;
}
.about-page .about-page-content {
  display: flex;
  flex-direction: column;
  flex: 1;
  width: 100%;
  margin: 0 auto;
  z-index: 2;
}
.about-page .header-section,
.about-page .info-cards-container,
.about-page .helpful-links-card,
.about-page .footer-credits {
  max-width: 900px;
  width: 100%;
  margin: 0 auto;
}
.about-page .header-section {
  flex-wrap: wrap;
  width: 100%;
  background-color: var(--colorBgLight);
  border-radius: var(--radius);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 0 6px rgba(0, 0, 0, 0.2);
  padding: 18px;
  margin-bottom: 18px;
  display: flex;
  align-items: center;
  gap: 18px;
}
.about-page .header-section .logo-container {
  width: 60px;
  height: 60px;
  flex-shrink: 0;
}
.about-page .header-section .logo-container img {
  width: 60px;
  height: 60px;
}
.about-page .header-section .update-status {
  flex-grow: 1;
}
.about-page .header-section .update-status p {
  font-size: 13px;
  color: var(--colorFg);
  margin: 0;
}
.about-page .header-section .header-actions {
  display: flex;
  gap: 6px;
  align-items: center;
}
.about-page .info-cards-container {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 18px;
  margin-bottom: 18px;
}
.about-page .info-cards-container .card {
  background-color: var(--colorBgLight);
  border-radius: var(--radius);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 0 6px rgba(0, 0, 0, 0.2);
  padding: 18px 22.5px;
}
.about-page .info-cards-container .card .card-header {
  display: flex;
  align-items: baseline;
}
.about-page .info-cards-container .card .card-content {
  display: flex;
  flex-direction: column;
  gap: 10px;
  user-select: text;
  cursor: text;
}
.about-page .info-cards-container .card .card-content .info-row {
  display: flex;
  flex-direction: column;
}
.about-page .info-cards-container .card .card-content .info-row .label {
  font-weight: 600;
  color: var(--colorFg);
  margin-bottom: 3px;
}
.about-page .info-cards-container .card .card-content .info-row .value {
  display: flex;
  color: var(--colorFgFaded);
  word-break: break-all;
}
.about-page .helpful-links-card {
  background-color: var(--colorBgLight);
  border-radius: var(--radius);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 0 6px rgba(0, 0, 0, 0.2);
  padding: 18px;
  margin-bottom: 18px;
}
.about-page .helpful-links-card .links-grid {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  gap: 18px;
  justify-items: center;
}
.about-page .helpful-links-card .links-grid .link-item {
  width: fit-content;
}
.about-page .link-button {
  background: none;
  border: none;
  padding: 0;
  color: var(--colorHighlightBg);
  margin-top: 6px;
  cursor: pointer;
  align-self: flex-start;
}
.about-page .link-button:hover {
  text-decoration: underline;
}
.about-page .link-button + button {
  margin-left: 15px;
}
.about-page .shortcut-button {
  border: none;
  cursor: pointer;
  background: none;
}
.about-page .shortcut-button:hover {
  background-color: var(--colorBgDarker);
  border-radius: var(--radiusRound);
}
.about-page .shortcut-button:active {
  background-color: var(--colorBgLight);
}
.about-page .footer-credits {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 36px;
  padding: 18px;
  font-size: 11.5px;
  color: var(--colorFgFaded);
  background-color: var(--colorBgLight);
  border-radius: var(--radius);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 0 6px rgba(0, 0, 0, 0.2);
  z-index: 2;
}
.about-page .footer-credits h3 {
  font-size: 13px;
  margin-bottom: 6px;
}
.about-page .footer-credits p {
  margin: 6px 0;
}
.about-page .in-progress {
  padding-left: 24px;
  position: relative;
}
.about-page .in-progress:before {
  content: '';
  top: -6px;
  left: 0;
  width: 16px;
  height: 16px;
  background-size: 16px 16px;
  background-repeat: no-repeat;
  background-color: var(--colorFg);
  animation: spin 2s linear infinite;
  opacity: 0.9;
  mask-size: cover;
  mask-image: url('/resources/symbol-reload.svg');
}
.about-page .spinner {
  width: 16px;
  height: 16px;
  display: inline-block;
  overflow: hidden;
}
#modal-bg.PrivacyDash {
  top: 8vh;
  max-height: 87vh;
}
#modal-bg.PrivacyDash .modal-wrapper {
  display: flex;
  flex-direction: column;
  max-width: 600px;
  border-radius: var(--radius);
}
.PrivacyDash .dialog-header {
  position: relative;
  padding-top: 6px;
  padding-bottom: 22px;
  background: linear-gradient(98deg, #f9e3d7, #e7cceb 50%, #d0eaf6);
}
.theme-dark .PrivacyDash .dialog-header {
  background: linear-gradient(98deg, #893e15, #582560 50%, #185c7c);
}
.PrivacyDash .dialog-content {
  display: grid;
  overflow-y: auto;
  flex: 1 1 auto;
  min-height: 300px;
  background-color: var(--colorBgIntense);
  padding: 0 0 12px 0;
  scrollbar-gutter: auto;
  gap: 12px;
}
#modal-bg.PrivacyDash .select-wrapper {
  margin: -12px 18px 0;
  width: max-content;
}
.PrivacyDash .dialog-footer {
  justify-content: center;
  border: none;
  background-color: var(--colorBgIntense) !important;
}
.PrivacyDash .close {
  background: none;
}
.PrivacyDash-Section--Overview {
  grid-column: 1 / 2;
  grid-row-start: 3;
}
.PrivacyDash-Section--Stats {
  grid-column: 1 / 2;
  grid-row-start: 4;
}
.PrivacyDash-Loading {
  margin: 0 18px;
  grid-column: 1 / 2;
  grid-row: 3 / span 2;
  background: var(--colorBgIntense);
  z-index: 1;
  display: grid;
  gap: 12px;
  grid-template-columns: repeat(4, 1fr);
  grid-template-rows: min-content min-content auto;
}
.PrivacyDash-Loading-Block {
  animation: skeletonBackground 1s infinite alternate;
  height: 95px;
  border-radius: var(--radius);
}
@keyframes skeletonBackground {
  from {
    background-color: var(--colorBg);
  }
  to {
    background-color: var(--colorBgDarker);
  }
}
.PrivacyDash-Loading-Tip {
  animation: skeletonBackground 1s infinite alternate;
  grid-column-start: span 4;
  height: 45px;
  border-radius: var(--radius);
}
@keyframes skeletonBackground {
  from {
    background-color: var(--colorBg);
  }
  to {
    background-color: var(--colorBgDarker);
  }
}
.PrivacyDash-Loading-Stats {
  animation: skeletonBackground 1s infinite alternate;
  grid-column-start: span 4;
  max-height: 250px;
  border-radius: var(--radius);
}
@keyframes skeletonBackground {
  from {
    background-color: var(--colorBg);
  }
  to {
    background-color: var(--colorBgDarker);
  }
}
.PrivacyDash-User {
  display: grid;
  grid-template-columns: 1fr min-content;
  margin: 12px 0;
  min-height: 30px;
  align-items: center;
}
.theme-dark .PrivacyDash-User {
  color: var(--colorFgIntense);
}
.PrivacyDash-User--loggedOut {
  grid-template-columns: auto;
}
.PrivacyDash-User h2 {
  font-size: 16px;
}
.PrivacyDash-User p {
  font-size: 11.5px;
}
.PrivacyDash-User img {
  display: block;
  grid-row: span 2;
  width: 60px;
  height: 60px;
  border: 2px solid var(--colorAccentFg);
  border-radius: 50%;
}
.PrivacyDash-User-Top {
  position: absolute;
  bottom: 0;
  left: 0;
  height: 16px;
  width: 100%;
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
  background-color: var(--colorBgIntense);
}
.PrivacyDash-Title {
  display: flex;
  justify-content: space-between;
  font-size: 13px;
  font-weight: 600;
  margin: 0;
  padding: 12px 18px;
  background-color: var(--colorBgIntense);
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
}
.PrivacyDash-SectionContent {
  visibility: visible;
}
.PrivacyDash-SectionContent--collapsed {
  height: 0;
  overflow: hidden;
  visibility: hidden;
  padding: 0;
}
.PrivacyDash-Section {
  margin: 0 18px;
}
.PrivacyDash-Section > p {
  margin-bottom: 6px;
}
.PrivacyDash-Section--Commitment {
  background-color: var(--colorBg);
  border-radius: var(--radius);
}
.PrivacyDash-Section--Commitment .PrivacyDash-SectionContent {
  padding: 0 12px;
}
.PrivacyDash-Section--Commitment p {
  margin-bottom: 6px;
}
.PrivacyDash-Section--Commitment .PrivacyDash-SectionContent:not(.PrivacyDash-SectionContent--collapsed) {
  padding-bottom: 12px;
}
.PrivacyDash-Section--Commitment .PrivacyDash-SectionTitle {
  padding-left: 12px;
}
.PrivacyDash-SectionTitle {
  display: flex;
  justify-content: space-between;
  width: 100%;
  background: none;
  border: none;
  font-weight: 600;
  padding: 12px 12px 12px 6px;
  cursor: pointer;
}
.PrivacyDash-SectionTitle--expanded svg {
  transform: rotate(90deg);
}
.PrivacyDash-Blocks {
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  column-gap: 6px;
  row-gap: 12px;
}
.PrivacyDash-Blocks--disabled .PrivacyDash-StatusBlock {
  background: var(--colorBg);
}
.PrivacyDash-Blocks--disabled .PrivacyDash-StatusBlock svg {
  color: var(--colorFgFaded);
}
.PrivacyDash-StatusBlock {
  border-radius: var(--radius);
  font-size: 11.5px;
  padding: 12px;
  flex: 0 1 25%;
  display: flex;
  flex-direction: column;
  gap: 3px;
}
.PrivacyDash-StatusBlock--Saved {
  background: var(--colorSuccessBgAlpha);
}
.PrivacyDash-StatusBlock--Saved svg {
  color: var(--colorSuccessBg);
}
.PrivacyDash-StatusBlock--Count {
  background: var(--colorHighlightBgAlpha);
}
.PrivacyDash-StatusBlock--Count svg {
  color: var(--colorHighlightBg);
}
.PrivacyDash-StatusBlock--Fact {
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgDark));
  grid-column-start: span 4;
  display: flex;
  flex-direction: row;
  gap: 12px;
  align-items: center;
  border: 1px solid var(--colorBorder);
  vertical-align: baseline;
}
.PrivacyDash-StatusBlock--Fact:hover:not(:disabled) {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
.PrivacyDash-StatusBlock--Fact:active:not(:disabled) {
  background-image: linear-gradient(var(--colorBgDark), var(--colorBgDark));
}
.theme-dark .PrivacyDash-StatusBlock--Fact {
  background: var(--colorWarningBgAlpha);
}
.PrivacyDash-StatusBlock--Fact > div {
  font-size: 26px;
}
.PrivacyDash-StatusBlock--Fact p {
  flex: 1 1 auto;
}
.PrivacyDash-StatusBlock-Icon {
  width: 32px;
  height: 32px;
}
.PrivacyDash-StatusBlock-Value {
  font-size: 16px;
  font-weight: 600;
}
.PrivacyDash-Stats-Board {
  height: 242px;
  border-radius: var(--radius);
}
.PrivacyDash-Stats-Board .VivaldiList {
  overscroll-behavior: auto;
}
.PrivacyDash-Stats-Board .TabbedView-List {
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
  background: var(--colorBgDark);
}
.PrivacyDash-Stats-Board .TabbedView-Content {
  display: flex;
  flex-direction: column;
  overflow: hidden;
  background: var(--colorBg);
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.PrivacyDash-Stats-Board button {
  flex: 1 1 auto;
  justify-content: center;
  border-radius: var(--radius);
}
.PrivacyDash-Stats-Board .sortselector {
  border: none;
  margin: 3px 0;
}
.PrivacyDash-Stats-Board .sortselector .SlideBar {
  background: none;
}
.PrivacyDash-Stats-Board .sortselector .SlideBar--FullHeight {
  height: auto;
}
.PrivacyDash-Stats-Board label.count {
  justify-content: flex-end;
}
.PrivacyDash-Stats-Board .vivaldi-tree {
  padding: 0;
}
.PrivacyDash-Section--Off h2 {
  font-size: 16px;
  margin-bottom: 6px;
}
.PrivacyDash-Section--Off > p {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: 12px;
  color: var(--colorFgFaded);
}
.PrivacyDash-Shield {
  flex: 0 0 auto;
  width: 64px;
  height: 64px;
  margin: 0 12px;
  display: flex;
  justify-content: center;
  align-items: center;
  background-image: linear-gradient(var(--colorBgDarker), var(--colorFgFadedMost));
  border-radius: 16px;
}
.PrivacyDash-Shield svg {
  color: var(--colorBgIntense);
  fill: var(--colorBgIntense);
}
.PrivacyDash-Section--Advantages {
  padding: 0 18px 6px 18px;
}
.PrivacyDash-Section--Advantages svg {
  color: var(--colorHighlightBgDark);
  width: 16px;
  height: 16px;
}
.PrivacyDash-Advantages-Item {
  display: flex;
  flex-direction: row;
  gap: 6px;
  margin: 9px 0;
}
/* Overrides when break mode is enabled */
#browser.break-mode {
  --colorAccentBg: var(--colorBgDarker);
  --colorAccentBgDark: var(--colorFgFadedMore);
  --colorAccentBgDarker: var(--colorFgFadedMost);
  --colorAccentBgAlpha: var(--colorBgAlpha);
  --colorAccentBgAlphaHeavy: var(--colorBgAlpha);
  --colorAccentBgFaded: var(--colorBgDark);
  --colorAccentBgFadedMore: var(--colorBg);
  --colorAccentBgFadedMost: var(--colorBgFaded);
  --colorAccentBorder: var(--colorBorder);
  --colorAccentBorderDark: var(--colorBorderIntense);
  --colorAccentFg: var(--colorFgIntense);
  --colorAccentFgFaded: var(--colorFgFaded);
  --colorAccentFgAlpha: var(--colorFgAlpha);
}
#browser.break-mode #pagetitle,
#browser.break-mode #webpage-stack,
#browser.break-mode #panels .button-toolbar-webpanel,
#browser.break-mode .bookmarkbarItem span,
#browser.break-mode .bookmarkbarItem img,
#browser.break-mode .bookmarkbarItem svg,
#browser.break-mode .button-badge,
#browser.break-mode .panel,
#browser.break-mode .pageload,
#browser.break-mode .webpanel-title,
#browser.break-mode .siteinfo-text,
#browser.break-mode .SiteInfoButton-Favicon,
#browser.break-mode .OmniDropdown,
#browser.break-mode .tab-header progress,
#browser.break-mode .tab-header .title,
#browser.break-mode .tab-header .stack-counter,
#browser.break-mode .tab-header .favicon svg,
#browser.break-mode .tab-header .favicon img,
#browser.break-mode .tabbar-workspace-button .button-title,
#browser.break-mode .workspace-popup .button-title,
#browser.break-mode .tabbar-workspace-button .button-icon,
#browser.break-mode .workspace-popup .button-icon,
#browser.break-mode .toolbar .toolbar-extensions,
#browser.break-mode .toolbar .profile-popup img,
#browser.break-mode .thumbnail-image img,
#browser.break-mode .thumbnail-image svg,
#browser.break-mode .UrlBar-UrlField,
#browser.break-mode .UrlBar-SearchField .searchfield-input,
#browser.break-mode .UrlFragment-Wrapper,
#browser.break-mode .button-popup:not(.BreakModePopup),
#browser.break-mode .MailSearchField .searchfield-input,
#browser.break-mode .StatusInfo,
#browser.break-mode .ClockButton,
#browser.break-mode .modal-faded-background,
#browser.break-mode .modal-wrapper {
  visibility: hidden;
  pointer-events: none;
}
#browser.break-mode .button-textonly,
#browser.break-mode .button-toolbar:not(.break-mode) {
  pointer-events: none;
}
#browser.break-mode .button-textonly button,
#browser.break-mode .button-toolbar:not(.break-mode) button {
  opacity: 0.65;
}
#browser.break-mode .tab-position {
  color: transparent;
  pointer-events: none;
}
#browser.break-mode .bookmarkbarItem {
  background: transparent;
  box-shadow: 1px 0 var(--colorBorder);
  pointer-events: none;
}
/* Style for the BreakMode Button / Popup component */
.BreakModePopup {
  font-size: 13px;
}
.BreakModePopup--Graphic {
  width: 78px;
  margin-left: auto;
  margin-right: auto;
  margin-top: 12px;
}
.BreakModePopup--Graphic svg {
  width: 78px;
  height: 78px;
}
.BreakModePopup h1 {
  margin-bottom: 18px;
  text-align: center;
}
.BreakModePopup h3 {
  padding-left: 12px;
  padding-right: 6px;
  margin: 12px 0 6px;
}
.BreakModePopup-Intro {
  padding-right: 15px;
  padding-left: 12px;
  text-wrap: balance;
}
.BreakModePopup.ToolbarButtonPopup-DefaultStyles label {
  align-items: flex-start;
}
.BreakModePopup .toolbar {
  padding-left: 12px;
  padding-right: 12px;
}
.addressfield-popup-container h1 {
  font-size: inherit;
  word-break: break-word;
  flex: 1;
}
.addressfield-popup-container a {
  font-size: 11.5px;
  text-decoration: none;
}
.addressfield-popup-container .geo-notice {
  display: flex;
  align-items: center;
  padding: 0 6px;
}
#browser:not(.mac) .addressfield-popup-container .geo-notice {
  order: 3;
  margin-left: auto;
}
#browser.mac .addressfield-popup-container .geo-notice {
  margin-right: auto;
}
.addressfield-popup-container .addressfield-popup {
  display: flex;
  overflow: hidden;
  flex-direction: column;
}
.addressfield-popup-container .addressfield-popup .addressfield-popup-header {
  align-items: center;
}
.addressfield-popup-container .addressfield-popup .addressfield-popup-header span {
  display: flex;
}
.addressfield-popup-container .addressfield-popup .addressfield-popup-header svg {
  width: 26px;
  height: 26px;
  margin: 0 6px 0 0;
}
.addressfield-popup-container .addressfield-popup .addressfield-popup-header svg .permission-denied {
  display: none;
}
.addressfield-popup-container .addressfield-popup .addressfield-popup-header,
.addressfield-popup-container .addressfield-popup .dialog-footer {
  color: var(--colorFg);
  background-color: var(--colorBg);
  border-top-right-radius: var(--radiusHalf);
  border-top-left-radius: var(--radiusHalf);
  border-bottom: 1px solid var(--colorBgDark);
  padding: 12px;
  display: flex;
  flex-wrap: wrap;
}
.addressfield-popup-container .addressfield-popup .addressfield-popup-header label,
.addressfield-popup-container .addressfield-popup .dialog-footer label {
  margin: 0 6px 0 0;
}
.addressfield-popup-container .addressfield-popup .addressfield-popup-content {
  padding: 6px 12px;
  overflow: auto;
}
.addressfield-popup-container .addressfield-popup .fieldset {
  display: block;
  padding-top: 6px;
  padding-bottom: 6px;
}
.addressfield-popup-container .addressfield-popup .popupblocker-blocked-pages .popupblocker-blocked-page {
  display: block;
  margin: 6px 0;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.addressfield-popup-container .addressfield-popup label {
  flex: auto;
  display: flex;
  align-items: center;
  font-size: 11.5px;
}
.addressfield-popup-container .addressfield-popup .blocked-content input[type=button] {
  margin-bottom: 6px;
  float: right;
}
.addressfield-popup-container .addressfield-popup .blocked-content input[type=button].category {
  float: none;
}
.addressfield-popup-container .addressfield-popup .blocked-content svg .permission-denied {
  display: block;
}
.addressfield-popup-container .addressfield-popup .blocked-content .blocked-section + .blocked-section {
  border-top: 1px solid var(--colorBgDark);
  margin-top: 6px;
  padding-top: 6px;
}
.addressfield-popup-container .addressfield-popup .blocked-content div.clickable {
  color: var(--colorHighlightBg);
  text-decoration: underline;
}
.addressfield-popup-container .addressfield-popup .blocked-content div.clickable:hover {
  cursor: pointer;
}
.addressfield-popup-container .addressfield-popup.system-location-service h1 {
  margin-top: 12px;
  font-weight: 600;
}
.addressfield-popup-container.permission-popup .addressfield-popup-header {
  gap: 6px;
  align-items: flex-start;
}
.addressfield-popup-container input[type=radio] {
  margin-right: 3px;
  transform: scale(0.75);
}
.protonVPN svg .inactive {
  opacity: 1;
}
.protonVPN.online svg {
  animation: pop 300ms linear;
}
.protonVPN.online svg .online {
  opacity: 1;
}
.protonVPN.online svg .inactive {
  opacity: 0;
}
.protonVPN.offline svg {
  animation: pop 300ms linear;
}
.protonVPN.offline svg .offline {
  opacity: 1;
}
.protonVPN.offline svg .inactive {
  opacity: 0;
}
#popup-vpn-intro {
  border-radius: inherit;
  padding: 24px;
}
#popup-vpn-intro .proton-vpn-intro {
  display: grid;
  place-content: end center;
  height: 100%;
  gap: 12px;
  text-align: center;
}
#popup-vpn-intro .proton-vpn-intro .spinner {
  place-self: center;
}
#popup-vpn-intro .proton-vpn-error {
  display: grid;
  gap: 6px;
  text-align: left;
}
#popup-vpn-intro button {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  border: 0;
  padding: 6px 18px;
  margin: 0 auto;
}
#popup-vpn-intro a {
  text-decoration: underline;
}
.extension-popup {
  z-index: 7;
  position: absolute;
  box-shadow: 0 0 0 1px var(--colorBorder), 0 2px 8px rgba(0, 0, 0, 0.25);
  border-radius: var(--radiusHalf);
  right: 0;
  opacity: 1;
}
.extensionIconPopupMenu + .extension-popup {
  z-index: 10;
}
.extension-popup > webview {
  border-radius: var(--radiusHalf);
  overflow: hidden;
}
.extension-popup:before,
.extension-popup:after {
  content: '';
  position: absolute;
  border: 6px solid transparent;
  pointer-events: none;
}
.extension-popup.top {
  top: 40px;
  animation: dropfade 300ms ease-out;
}
.extension-popup.top:before {
  top: -13px;
  left: var(--anchorPosition);
  border-bottom-color: var(--colorBorder);
}
.extension-popup.top:after {
  top: -12px;
  left: var(--anchorPosition);
  border-bottom-color: var(--colorBgLight);
}
.extension-popup.bottom {
  bottom: 40px;
  animation: pullfade 300ms ease-out;
}
.extension-popup.bottom:before {
  bottom: -13px;
  left: var(--anchorPosition);
  border-top-color: var(--colorBorder);
}
.extension-popup.bottom:after {
  bottom: -12px;
  left: var(--anchorPosition);
  border-top-color: var(--colorBgLight);
}
.extension-popup.right {
  top: 40px;
}
.extension-popup.right:before {
  top: var(--anchorPosition);
  left: -13px;
  border-bottom-color: var(--colorBorder);
  rotate: -90deg;
}
.extension-popup.right:after {
  top: var(--anchorPosition);
  left: -12px;
  border-bottom-color: var(--colorBgLight);
  rotate: -90deg;
}
.extension-popup.left {
  top: 40px;
}
.extension-popup.left:before {
  top: var(--anchorPosition);
  left: calc(100% + 1px);
  border-bottom-color: var(--colorBorder);
  rotate: 90deg;
}
.extension-popup.left:after {
  top: var(--anchorPosition);
  left: 100%;
  border-bottom-color: var(--colorBgLight);
  rotate: 90deg;
}
#browser .toolbar-extensions .ExtensionIcon img {
  width: 16px;
  height: 16px;
  flex-basis: 16px;
}
.ExtensionToggleIcon.ExtensionToggleIcon--Expanded {
  background-color: var(--colorBgDarker);
}
.color-behind-tabs-off .ExtensionToggleIcon.ExtensionToggleIcon--Expanded {
  background-color: var(--colorAccentBgDarker);
}
.ExtensionIcon--Hidden {
  background-color: var(--colorBgDark);
}
.ExtensionIcon--Hidden > button {
  background-color: transparent !important;
}
.color-behind-tabs-off .ExtensionIcon--Hidden {
  background-color: var(--colorAccentBgDark);
}
.ExtensionIcon--Hidden:hover,
.ExtensionIcon--Hidden:active {
  background-color: var(--colorBgDarker);
}
.color-behind-tabs-off .ExtensionIcon--Hidden:hover,
.color-behind-tabs-off .ExtensionIcon--Hidden:active {
  background-color: var(--colorAccentBgDarker);
}
.ExtensionDropdownIcon:focus-visible {
  outline: unset;
}
.ExtensionDropdownIcon img {
  max-width: 16px;
  max-height: 16px;
}
.extensionIconPopupMenu > .toolbar {
  background-color: transparent;
  height: auto;
  justify-content: center;
  border-radius: inherit;
  overflow: hidden;
}
.disabledExtensionsPopup .dialog-content {
  gap: 6px;
}
.disabledExtensionsPopup .new-extension {
  display: grid;
  grid-template-columns: 36px 1fr;
  gap: 6px;
  align-items: center;
}
.disabledExtensionsPopup .list-item {
  display: flex;
  align-items: baseline;
  gap: 6px;
}
.disabledExtensionsPopup button {
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgDark));
}
.disabledExtensionsPopup button:hover:not(:disabled) {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
.disabledExtensionsPopup button:active:not(:disabled) {
  background-image: linear-gradient(var(--colorBgDark), var(--colorBgDark));
}
#app .ContentBlocker .dialog-content {
  padding: 0;
  gap: 12px;
  scrollbar-gutter: auto;
}
#app .ContentBlocker .dialog-content h3 {
  margin: 0;
}
#app .ContentBlocker-Header {
  display: flex;
  flex-direction: row;
  align-items: center;
  flex: 0 0 auto;
  overflow: hidden;
  gap: 6px;
  padding: 12px 15px;
  border-bottom: 1px solid var(--colorBorder);
}
#app .ContentBlocker-Header .favicon {
  width: 20px;
  height: 20px;
  margin-bottom: auto;
  text-align: center;
}
#app .ContentBlocker-Header .info {
  flex: 1;
  padding-inline: 6px;
  margin: 0;
  font-weight: 400;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
#app .ContentBlocker-Header strong {
  line-break: anywhere;
}
#app .ContentBlocker-Field {
  display: flex;
  flex-direction: column;
}
#app .ContentBlocker-Field p {
  margin-bottom: 6px;
}
#app .ContentBlocker-Field input[type=button] {
  white-space: break-spaces;
  min-height: 32px;
  padding: 6px 12px;
  width: fit-content;
}
#app .ContentBlocker-Counter {
  display: flex;
}
#app .ContentBlocker-Counter--Block {
  display: flex;
  width: 50%;
  align-items: center;
  margin-right: 6px;
}
#app .ContentBlocker-Counter--Block > p {
  margin-bottom: 0;
}
#app .ContentBlocker-Counter--Block:hover div {
  background-color: var(--colorHighlightBg);
}
#app .ContentBlocker-Counter--Number {
  display: flex;
  justify-content: center;
  padding: 9px;
  margin-right: 6px;
  font-size: 16px;
  font-weight: 600;
  min-width: 36px;
  text-align: center;
  color: var(--colorBg);
  background-color: var(--colorFg);
  border-radius: var(--radius);
}
#app .ContentBlocker-Label {
  display: flex;
  gap: 6px;
  align-items: flex-start;
  padding: 3px;
  border-radius: var(--radius);
  background-color: transparent;
  border: 0;
}
#app .ContentBlocker-Label:focus-visible {
  background-color: var(--colorBgDark);
}
#app .ContentBlocker-Label--Active {
  color: var(--colorHighlightBg);
  background-color: var(--colorHighlightBgAlpha);
}
#app .ContentBlocker-Label--Active svg {
  color: var(--colorHighlightBg);
}
#app .ContentBlocker-Label--Active svg .outline {
  vector-effect: non-scaling-stroke;
  stroke: var(--colorHighlightBg);
}
#app .ContentBlocker-Label-Icon,
#app .ContentBlocker-Label-Icon svg {
  align-self: center;
  width: 20px;
  height: 20px;
}
#app .ContentBlocker-Label-Text {
  margin: 2px 0 0;
  text-align: left;
}
#app .ContentBlocker-Label .keep-ea-words {
  margin-left: 1/8em;
}
#app .ContentBlocker-Label:hover:not(#app .ContentBlocker-Label--Active) {
  background-color: var(--colorBg);
}
#app .ContentBlocker--Blocked {
  animation: dropfade 100ms ease-out;
  margin-top: 12px;
}
#app .ContentBlocker-Blocked {
  display: flex;
  flex-direction: column;
  background-color: var(--colorBgDark);
  border-radius: var(--radius);
}
#app .ContentBlocker-Blocked:empty {
  display: none;
}
#app .ContentBlocker-Blocked h3 {
  padding: 3px 6px;
}
#app .ContentBlocker-Blocked ul {
  padding: 3px 0 3px 6px;
  animation: dropfade 100ms linear;
  max-height: 90px;
  background-color: var(--colorBg);
  overflow: auto;
}
#app .ContentBlocker-Blocked ul li {
  display: flex;
  padding-right: 6px;
  justify-content: space-between;
}
#app .ContentBlocker-Blocked ul li span {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  font-weight: 300;
}
#app .ContentBlocker-Blocked ul li span + span {
  flex: 0 0 auto;
  margin-left: 6px;
}
#app .ContentBlocker-Blocked label {
  margin: 6px;
}
#app .ContentBlocker-Import .FormFeedback,
#app .ContentBlocker-Import .dialog-row:not(.input) {
  display: flow-root;
  margin-top: 6px;
}
#app .ContentBlocker-Import .dialog-row.input {
  margin-bottom: 6px;
}
#app .ContentBlocker-Info {
  display: flex;
  padding: 9px 9px 3px;
  position: relative;
  background-color: var(--colorBg);
  border-radius: var(--radius);
  flex-direction: column;
  font-size: 11.5px;
}
#app .ContentBlocker-Info h3 {
  padding-bottom: 6px;
}
#app .ContentBlocker-Info a {
  font-weight: 400;
  color: inherit;
}
#app .ContentBlocker-Close {
  position: absolute;
  top: 6px;
  right: 6px;
  width: 16px;
  height: 16px;
  scale: 0.8;
  padding: 0;
  background-color: transparent;
  background: none;
  border: none;
}
#app .ContentBlocker-Close:hover {
  scale: 1;
}
#app .ContentBlocker .blocking-exception-wrapper {
  position: relative;
  display: flex;
  background-color: var(--colorBgDarker);
  align-items: center;
  padding: 6px 12px;
  border-radius: var(--radius);
}
#app .ContentBlocker .blocking-exception-wrapper p {
  margin: 0;
}
#app .ContentBlocker .blocking-exception-wrapper:after {
  content: '';
  position: absolute;
  width: 16px;
  height: 16px;
  right: 6px;
  background-color: currentColor;
  mask-image: var(--svgArrow);
  mask-repeat: no-repeat;
  mask-position: 0 0;
  mask-size: 16px 16px;
  pointer-events: none;
  transform: rotate(270deg);
}
#app .ContentBlocker .content-wrapper {
  display: flex;
  flex-wrap: nowrap;
  flex-direction: row;
  overflow-x: hidden;
}
#app .ContentBlocker .content-wrapper .dialog-content {
  padding: 12px;
  transition: transform 100ms ease-out;
  min-width: var(--popupWidth);
}
#app .ContentBlocker .dialog-content input[type=button] {
  margin: 6px 0 0;
}
.ad-attribution-wrapper {
  padding: 12px 0 0 12px;
}
.ad-attribution-wrapper .ad-attribution-domains {
  position: relative;
  padding: 6px 12px;
  margin-top: 12px;
  max-height: 200px;
  overflow: overlay;
  background-color: var(--colorBgDarker);
  border-radius: var(--radius);
}
.ad-attribution-wrapper .ad-attribution-domains .ad-attribution-domain-header {
  display: flex;
  padding-bottom: 6px;
}
.ad-attribution-wrapper .ad-attribution-domains .ad-attribution-domain-header:after {
  content: '';
  position: absolute;
  width: 16px;
  height: 16px;
  right: 6px;
  background-color: currentColor;
  mask-image: var(--svgArrow);
  mask-repeat: no-repeat;
  mask-position: 0 0;
  mask-size: 16px 16px;
  pointer-events: none;
}
.ad-attribution-wrapper .ad-attribution-domains .domain-wrapper {
  font-size: 11.5px;
}
.ad-attribution-wrapper .ad-attribution-domains .domain-wrapper p {
  margin: 0;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.vivaldi-settings .ContentBlocker-Setting {
  display: inline-flex;
  flex-direction: column;
  align-items: stretch;
  width: 96px;
  text-align: center;
  margin-right: 12px;
}
.vivaldi-settings .ContentBlocker-Setting button {
  height: 64px;
  padding-top: 6px;
  border-width: 2px;
  background-color: transparent;
}
.vivaldi-settings .ContentBlocker-Setting button svg {
  width: 32px;
  height: 32px;
  pointer-events: none;
}
.vivaldi-settings .ContentBlocker-Setting--Active {
  color: var(--colorHighlightBg);
}
.vivaldi-settings .ContentBlocker-Setting--Active button {
  border-color: var(--colorHighlightBg);
}
.vivaldi-settings .ContentBlocker-Setting--Active button svg .outline {
  vector-effect: non-scaling-stroke;
  stroke: var(--colorHighlightBg);
}
.vivaldi-settings .ContentBlocker > .setting-single:first-of-type {
  margin-bottom: 18px;
}
.vivaldi-settings .ContentBlocker .setting-single:last-of-type {
  margin-bottom: 0;
}
.vivaldi-settings .ContentBlocker .sortable-list {
  min-height: 180px;
}
.vivaldi-settings .ContentBlocker-Exceptions {
  margin-bottom: 12px;
}
.vivaldi-settings .ContentBlocker-Exceptions .item {
  padding: 0 6px;
  height: 28px;
  align-items: center;
  display: flex;
}
.vivaldi-settings .ContentBlocker-Exceptions .item span {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.vivaldi-settings .ContentBlocker-Exceptions .item select {
  width: auto;
  text-align-last: right;
  margin-left: auto;
  height: auto;
  border: unset !important;
  box-shadow: unset !important;
  padding: 0 24px 0 6px;
  color: inherit;
  background-color: inherit;
  background-image: unset;
}
.vivaldi-settings .ContentBlocker-Exceptions .item select[tabindex='-1']:focus-visible {
  outline: none;
}
.vivaldi-settings .ContentBlocker-Exceptions .item select[name]:hover,
.vivaldi-settings .ContentBlocker-Exceptions .item select[name]:active {
  background-color: transparent;
  background-image: unset;
}
.vivaldi-settings .ContentBlocker-Exceptions .item select option {
  color: var(--colorFg);
  background-color: var(--colorBgIntenser);
  text-align: left;
}
.vivaldi-settings .ContentBlocker-Exceptions .item:after {
  content: '';
  position: absolute;
  width: 16px;
  height: 16px;
  right: 6px;
  background-color: currentColor;
  mask-image: var(--svgArrow);
  mask-repeat: no-repeat;
  mask-position: 0 0;
  mask-size: 16px 16px;
  right: 9px;
  pointer-events: none;
}
.vivaldi-settings .ContentBlocker-Sources .master-items {
  background-size: 100% 88px;
}
.vivaldi-settings .ContentBlocker-Sources .item {
  padding: 0 6px;
  height: 44px;
}
.vivaldi-settings .ContentBlocker-Sources .item .ContentBlocker-SourceItem {
  display: grid;
  pointer-events: none;
  grid-template-columns: 28px auto;
}
.vivaldi-settings .ContentBlocker-Sources .item .ContentBlocker-SourceItem input[type=checkbox] {
  grid-column: 1;
  grid-row: 1 / 3;
  align-self: center;
  pointer-events: all;
}
.vivaldi-settings .ContentBlocker-Sources .item .ContentBlocker-SourceItem .title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.vivaldi-settings .ContentBlocker-Sources .item .ContentBlocker-SourceItem .title,
.vivaldi-settings .ContentBlocker-Sources .item .ContentBlocker-SourceItem .info {
  margin: 0;
}
.vivaldi-settings .ContentBlocker-Sources:focus-within .item-selected .info {
  color: var(--colorHighlightFgAlpha);
}
.vivaldi-settings .ContentBlocker-Exception .dialog-content {
  flex-direction: row;
  gap: 6px;
}
.vivaldi-settings .ContentBlocker-Exception .dialog-content .select-wrapper {
  flex: 0 0 auto;
}
.vivaldi-settings .ContentBlocker-Exception .dialog-row {
  display: flex;
}
.vivaldi-settings .ContentBlocker-Exception .dialog-row button {
  margin-left: 6px;
}
#browser.mac .vivaldi-settings .ContentBlocker-Exception .dialog-footer .info {
  margin-right: auto;
}
#browser:not(.mac) .vivaldi-settings .ContentBlocker-Exception .dialog-footer .info {
  margin-left: auto;
  order: 3;
}
.ContentBlocker-Label-Icon,
.ContentBlocker-Control {
  --ads: 0;
  --trackers: 0;
  --blocking: 0;
  --blocking-fill: 0;
  --no-blocking: 0;
  --base: 1;
}
@keyframes blocker-flash {
  0% {
    opacity: 0;
  }
  10% {
    opacity: var(--blocking);
  }
  100% {
    opacity: 0;
  }
}
@keyframes blocker-invert {
  0% {
    scale: 1.25;
    fill: var(--colorFg);
  }
  10% {
    scale: 1.2;
    fill: var(--colorBg);
  }
  100% {
    scale: 1;
    fill: var(--colorFg);
  }
}
.ContentBlocker-Control svg .blocking-fill {
  opacity: 0;
}
.ContentBlocker-Control--Active.ContentBlocker-Control svg .blocking-fill {
  animation: blocker-flash 1s ease-out;
}
.ContentBlocker-Control svg .blocking {
  transform-origin: center;
}
.ContentBlocker-Control--Active.ContentBlocker-Control svg .blocking {
  animation: blocker-invert 1s ease-out;
}
button.privacy-btn-icon {
  background-image: linear-gradient(var(--colorBgLightIntense) 0%, var(--colorBg) 100%);
  padding: 0 18px 0 12px;
  margin-right: auto;
  text-align: left;
}
button.privacy-btn-icon:hover {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
#app .ContentBlocker button.privacy-btn-icon {
  padding: 6px 12px;
}
button.privacy-btn-icon svg {
  color: var(--colorFgFaded);
  width: 16px;
  height: 16px;
  padding: 0;
  margin: 0 4px -4px 0;
}
.panel-bookmarks .panel-bookmarks-edit {
  position: relative;
  min-height: 5px;
  max-height: 600px;
  margin-top: 0;
  flex: 0;
  scrollbar-gutter: stable;
}
.panel-bookmarks .panel-bookmarks-edit .manager-editor {
  display: flex;
  flex: 1;
  overflow: unset;
}
.panel-bookmarks .panel-bookmarks-tree {
  overflow: hidden;
}
.panel-bookmarks .vivaldi-tree .tree-row label {
  min-width: 0;
}
.panel-bookmarks .tree-item[data-cut] {
  opacity: 0.5;
}
.panel-bookmarks .FormFeedback {
  margin: 0;
}
p.warning {
  animation: dropfade 100ms cubic-bezier(0.2, 0.9, 0.6, 1);
  position: absolute;
  top: 6px;
  right: 6px;
  left: 6px;
  padding: 6px;
  color: #fff;
  background-color: var(--colorError);
  border: 1px solid rgba(0, 0, 0, 0.15);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.bookmark.manager .manager-treeview {
  overflow: hidden;
}
.bookmark.manager .vivaldi-tree .tree-row label {
  flex: unset;
}
.bookmark.manager .manager-editor {
  border-width: 1px 0 0 1px;
}
.bookmark.manager .button-toolbar.add {
  margin-left: auto;
}
.bookmark.manager .FormFeedback {
  margin: 0 6px;
}
section.hide-bookmark-tree {
  display: none;
}
.bookmark-bar {
  display: flex;
  flex: 0 0 auto;
  overflow: visible;
  height: 28px;
  font-size: 11.5px;
  border: 0 solid var(--colorAccentBgDark);
  background-color: var(--colorAccentBg);
  color: var(--colorAccentFg);
  fill: var(--colorAccentBg);
  stroke: var(--colorAccentFgFaded);
  --yield: 60px;
}
.bookmark-bar.iconexceptfolders,
.bookmark-bar.icon {
  --yield: 28px;
}
.color-behind-tabs-on .bookmark-bar {
  background-color: var(--colorBg);
  border-color: var(--colorBorder);
  color: var(--colorFg);
  fill: var(--colorFgAlpha);
  stroke: var(--colorFgFadedMore);
}
.bookmark-bar-top .bookmark-bar {
  height: 29px;
  border-bottom-width: 1px;
}
.bookmark-bar-top .bookmark-bar.address-top {
  border-top-width: 1px;
}
.bookmark-bar-top .auto-hide-wrapper .bookmark-bar {
  border-top-width: 1px;
  border-bottom-left-radius: var(--radiusWindow);
  border-bottom-right-radius: var(--radiusWindow);
}
.bookmark-bar-bottom .bookmark-bar {
  order: 1;
  height: 29px;
  border-top-width: 1px;
}
.bookmark-bar-bottom .bookmark-bar.address-bottom {
  border-bottom-width: 1px;
}
.bookmark-bar-bottom .auto-hide-wrapper .bookmark-bar {
  border-bottom-width: 1px;
  order: initial;
}
.auto-hide-wrapper .bookmark-bar:first-child {
  border-top-left-radius: var(--radiusWindow);
  border-top-right-radius: var(--radiusWindow);
}
.bookmark-bar-bottom .auto-hide-wrapper .bookmark-bar:last-child {
  border-bottom-left-radius: var(--radiusWindow);
  border-bottom-right-radius: var(--radiusWindow);
}
.bookmark-bar .observer {
  position: relative;
  display: flex;
  flex: 1 1 100%;
  flex-flow: row nowrap;
  width: 100%;
  background-color: inherit;
  border-radius: inherit;
  padding: 0 3px;
}
.bookmark-bar .marker {
  background-color: var(--colorFg);
}
.bookmark-bar button {
  display: inline-flex;
  align-items: center;
  flex: 0 0 auto;
  gap: 6px;
  max-width: 120px;
  padding: 0 6px 0 0;
  margin-left: 0;
  border-radius: 0;
  border: 0;
  position: relative;
}
.bookmark-bar button:has(.separator) {
  padding-left: 5px;
}
.bookmark-bar button .separator {
  height: 28px;
  border-left: 1px solid var(--colorBorder);
}
.color-behind-tabs-off .bookmark-bar button {
  background-color: var(--colorAccentBg);
  color: var(--colorAccentFg);
}
.color-behind-tabs-off .bookmark-bar button .separator {
  border-left: 1px solid var(--colorAccentBorder);
}
.color-behind-tabs-on .bookmark-bar button {
  background-color: var(--colorBg);
}
.bookmark-bar button.data-cut {
  opacity: 0.5;
}
.bookmark-bar button.chevron {
  position: absolute;
  right: 0;
  top: 0;
  width: 28px;
  height: 28px;
  padding: 0 6px;
  justify-content: center;
  stroke-opacity: 0;
}
.color-behind-tabs-off .bookmark-bar button:focus-visible,
.color-behind-tabs-off .bookmark-bar button:hover {
  background-color: var(--colorAccentBgDark);
}
.color-behind-tabs-on .bookmark-bar button:focus-visible,
.color-behind-tabs-on .bookmark-bar button:hover {
  background-color: var(--colorBgDark);
}
.bookmark-bar button:focus-visible img.icon,
.bookmark-bar button:hover img.icon {
  background-color: transparent;
  border-radius: 3px;
}
.bookmark-bar button img,
.bookmark-bar button svg {
  pointer-events: none;
  margin: auto 0;
  flex: 0 0 auto;
  width: 16px;
  height: 16px;
  stroke: none;
  fill: currentColor;
}
.bookmark-bar button img.icon,
.bookmark-bar button svg.icon {
  border-radius: 3px;
}
.bookmark-bar button .VivaldiSvgIcon svg {
  opacity: 0.65;
  width: initial;
  height: initial;
  rotate: 180deg;
}
.bookmark-bar button span {
  display: flex;
  order: 1;
}
.bookmark-bar button span.VivaldiSvgIcon {
  order: 2;
}
.bookmark-bar button .title {
  display: inline-block;
  pointer-events: none;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.bookmark-bar button input {
  background-color: var(--colorBgIntense);
  color: var(--colorFg);
  max-height: 18px;
  max-width: 90px;
  padding: 0 2px;
  line-height: 1.2;
}
.bookmark-bar button > .menu {
  top: 100%;
  left: 0;
}
.bookmark-bar button:not(.chevron):before {
  content: '';
  position: relative;
  width: 0;
  height: 28px;
  background-color: transparent;
  transition: width 50ms linear 50ms;
}
.bookmark-bar button.dragging:active {
  opacity: 0.5;
  box-shadow: none;
}
.bookmark-bar button.dragover.folder {
  box-shadow: 0 0 60px 0 rgba(0, 0, 0, 0.15) inset;
}
.active-pane-selection.hasfocus .bookmark-bar button:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
}
.active-pane-selection.hasfocus .bookmark-bar button:focus-visible.dragging,
.active-pane-selection.hasfocus .bookmark-bar button:focus-visible.dragoverLeft,
.active-pane-selection.hasfocus .bookmark-bar button:focus-visible.dragoverRight {
  outline: none;
}
.addwebpanelcallout {
  min-width: 246px;
  min-height: 80px;
  padding: 12px;
}
.addwebpanelcallout form {
  flex: 1;
  flex-direction: column;
}
.addwebpanelcallout form header {
  margin-bottom: 6px;
}
.addwebpanelcallout form .webpanel-input {
  margin-bottom: 6px;
  display: grid;
  gap: 6px;
  grid-template-columns: 1fr auto;
}
.addwebpanelcallout form .address {
  flex: 1;
  width: 100%;
}
.addwebpanelcallout .webpanel-suggestion {
  display: flex;
  align-items: center;
  justify-content: center;
  height: 32px;
  width: 32px;
  padding: 0;
  margin: 0;
  background-color: var(--colorBg);
}
.addwebpanelcallout .webpanel-suggestion:hover {
  background-color: var(--colorBgDark);
}
.addwebpanelcallout .webpanel-suggestion:active {
  background-color: var(--colorBgDarker);
}
.addwebpanelcallout .webpanel-suggestion.add {
  height: 28px;
  width: 28px;
}
.addwebpanelcallout .webpanel-suggestion img,
.addwebpanelcallout .webpanel-suggestion svg {
  width: 16px;
  height: 16px;
}
.addwebpanelcallout .webpanel-suggestions {
  margin-bottom: 6px;
}
.addwebpanelcallout .webpanel-suggestions .suggestions-list {
  display: grid;
  grid-template-columns: repeat(6, 32px);
  grid-gap: 6px;
}
#panels .webpanel-stack {
  position: relative;
  display: flex;
  flex: 1;
}
#panels .webpanel-stack.hidden {
  visibility: hidden;
  flex: 0;
}
#panels .webpanel-stack .pad-right {
  margin-right: 6px;
}
#panels .webpanel-stack .webpanel {
  display: flex;
  visibility: hidden;
  position: absolute;
  padding: 0;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
}
#panels .webpanel-stack .webpanel .webpanel-header {
  display: flex;
  align-items: center;
  padding: 6px 12px 7px 9px;
  box-shadow: inset 0 -1px 0 0 var(--colorBorder);
  margin-bottom: 0;
  min-height: 43px;
}
#panels .webpanel-stack .webpanel .webpanel-header .webpanel-title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  font-size: 13px;
  margin-top: 0;
  margin-bottom: 0;
  flex: 1;
}
#panels .webpanel-stack .webpanel .webpanel-header .button-toolbar {
  padding: 0;
}
#panels .webpanel-stack .webpanel .webpanel-header .close {
  margin-left: 6px;
}
#panels .webpanel-stack .webpanel.visible {
  visibility: visible;
}
#panels .webpanel-stack .webpanel .webpanel-content {
  margin-top: 0;
  position: relative;
  overflow: hidden;
}
#session-panel .vivaldi-tree .fav-icon {
  display: flex;
  justify-content: center;
}
#session-panel .SessionItem {
  padding: 0 12px;
  display: flex;
}
#session-panel .SessionItem-Wrapper {
  display: flex;
  flex: 1;
  line-height: 1.3;
  align-items: center;
  overflow: hidden;
}
#session-panel .SessionItem-Entry {
  display: flex;
  flex: 1;
  flex-direction: column;
}
#session-panel .SessionItem-Trashed {
  padding-left: 6px;
}
#session-panel .SessionItem-Title {
  font-weight: bold;
}
#session-panel .SessionItem-Date {
  opacity: 0.65;
  font-size: 11.5px;
}
#session-panel .SessionItem-Trash {
  display: flex;
  align-items: center;
  gap: 3px;
  height: auto;
}
#session-panel .SessionItem input {
  min-height: 24px;
}
#session-panel .SessionItem--Simple {
  height: auto;
  padding: 0 6px 0 0;
}
#session-panel .SessionItem--Simple.SessionItem-Trashed,
#session-panel .SessionItem-Trash {
  padding: 0 6px;
}
#session-panel > .button-toolbar {
  margin: 12px 0;
}
#session-panel .ActionButton {
  transition: rotate 100ms linear;
}
#session-panel .tree-item:not([data-expanded]) .ActionButton {
  rotate: 90deg;
}
.session-recovery {
  position: absolute;
  display: flex;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: transparent;
  color: var(--colorFg);
  overflow: overlay;
  contain: strict;
}
.session-recovery .session-recovery-background {
  position: absolute;
  top: 0;
  bottom: 0;
  right: 0;
  width: auto;
  height: 100%;
  pointer-events: none;
}
.session-recovery .session-recovery-wrapper {
  flex-direction: column;
  display: flex;
  flex: 1;
  max-width: 530px;
  min-height: 380px;
  margin: auto;
  position: relative;
  background-color: var(--colorBgIntense);
  border-radius: var(--radius);
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.15), 0 28px 50px rgba(0, 0, 0, 0.18);
}
.session-recovery .session-recovery-wrapper .session-recovery-content {
  flex: 1 1 auto;
  padding: 18px;
}
.session-recovery .session-recovery-wrapper .session-recovery-content .crash-recovery-option {
  font-size: 13px;
  padding: 12px;
  background: var(--colorBg);
  border-radius: var(--radius);
  margin-bottom: 12px;
}
.session-recovery .session-recovery-wrapper .session-recovery-content .crash-recovery-option span {
  width: 100%;
}
.session-recovery .session-recovery-wrapper .session-recovery-content .crash-recovery-option label {
  display: inline-flex;
  gap: 6px;
  font-weight: 600;
  width: 100%;
}
.session-recovery .session-recovery-wrapper .session-recovery-content .crash-recovery-info {
  padding-right: 48px;
}
.session-recovery .session-recovery-wrapper .session-recovery-content h1 {
  margin-bottom: 6px;
  font-size: 23px;
  font-weight: 500;
}
.session-recovery .session-recovery-wrapper .session-recovery-content h2 {
  margin-top: 60px;
  margin-bottom: 6px;
  font-size: 21px;
  font-weight: 600;
}
.session-recovery .session-recovery-wrapper .session-recovery-content h3 {
  margin-top: 12px;
  margin-bottom: 6px;
}
.session-recovery .session-recovery-wrapper .session-recovery-content .session-recovery-blurb {
  min-height: 60px;
  max-width: 60ch;
}
.session-recovery .session-recovery-wrapper .session-recovery-content a {
  margin-top: 6px;
  font-weight: 400;
}
.session-recovery .session-recovery-wrapper .session-recovery-content a:focus-visible {
  outline: 1px solid;
  outline-offset: 2px;
}
.session-recovery .session-recovery-wrapper .session-recovery-content .session-recovery-icon {
  fill: var(--colorFg);
  height: auto;
  width: 60px;
  position: absolute;
  margin-left: -90px;
  margin-top: -55px;
}
.session-recovery .session-recovery-disable {
  display: block;
  margin-top: 36px;
}
.session-recovery .session-recovery-disable > input {
  border-color: var(--colorBorderIntense);
  margin-right: 6px;
  vertical-align: -4px;
}
.SpeedDials {
  display: grid;
  height: 100%;
  min-width: 100%;
  gap: 42px;
  grid-template-columns: 1fr;
  grid-template-rows: min-content 1fr;
}
.SpeedDials .topsites-emptystate {
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  padding: 18px;
  max-width: 500px;
  width: 100%;
  background-color: var(--colorBgAlphaBlur);
  border-radius: var(--radius);
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 2px 4px 0 rgba(0, 0, 0, 0.2);
}
.SpeedDials .topsites-emptystate h1 {
  font-weight: 600;
  padding-bottom: 12px;
}
.SpeedDialsOld {
  flex: 0 0 auto;
  justify-content: flex-start;
  flex-wrap: wrap;
  height: initial;
}
.SpeedDial {
  contain: style;
  outline: 0;
  touch-action: none;
  width: var(--thumbnailWidth);
  position: absolute;
  transition: margin 200ms ease-out, box-shadow 200ms ease-out;
}
.SpeedDials-Wrapper:not(.dragging-disabled).dragover .SpeedDial,
.SpeedDials-Wrapper:not(.dragging-disabled) .SpeedDial:focus {
  margin-top: -1px;
}
.SpeedDial > .thumbnail-title {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 0 6px;
}
.SpeedDial .preview {
  pointer-events: none;
  display: grid;
  grid-template-columns: repeat(2, 1fr);
  grid-template-rows: repeat(2, 1fr);
  gap: 5%;
  padding: 5%;
  height: 100%;
}
.SpeedDial .preview .Mini-Thumbnail {
  display: grid;
  background-color: var(--colorBgLightIntense);
  box-shadow: 0 0 0 1px var(--colorBorder);
  border-radius: var(--radiusHalf);
  overflow: hidden;
}
.SpeedDial .preview .Mini-Thumbnail img {
  border-radius: var(--radiusHalf);
  aspect-ratio: 16 / 14;
}
.SpeedDial .editable-title-container {
  display: flex;
  overflow: hidden;
}
.SpeedDial .button-title {
  border-width: 0;
  border-radius: unset;
  padding: 0;
  background-color: transparent;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.sd-titles-onhover.SpeedDial .button-title {
  color: var(--colorFgIntense);
}
.SpeedDial .close,
.SpeedDial .update-thumbnail,
.SpeedDial .set-custom-thumbnail {
  appearance: none;
  display: flex;
  border: 0;
  width: 20px;
  height: 20px;
  color: transparent;
  fill: #ffffff;
  opacity: 0;
  visibility: hidden;
  overflow: hidden;
  background: #2d2d2d;
  padding: 1px;
  transition: opacity 100ms;
}
.SpeedDial .close:hover,
.SpeedDial .update-thumbnail:hover,
.SpeedDial .set-custom-thumbnail:hover {
  background-color: #2d2d2d;
}
.SpeedDial .close svg,
.SpeedDial .update-thumbnail svg,
.SpeedDial .set-custom-thumbnail svg {
  margin: auto;
  pointer-events: none;
}
.SpeedDial .close {
  top: 9px;
  position: absolute;
  right: 8px;
}
.SpeedDial .update-thumbnail {
  bottom: 9px;
}
.SpeedDial .update-thumbnail.updating {
  opacity: 0.8;
  animation: spin 2s linear infinite;
}
.SpeedDial .set-custom-thumbnail {
  bottom: 32px;
}
.SpeedDial:not(.dragging, .dragover):hover .close,
.SpeedDial:not(.dragging, .dragover):active .close,
.SpeedDial:not(.dragging, .dragover):hover .update-thumbnail,
.SpeedDial:not(.dragging, .dragover):active .update-thumbnail,
.SpeedDial:not(.dragging, .dragover):hover .set-custom-thumbnail,
.SpeedDial:not(.dragging, .dragover):active .set-custom-thumbnail {
  visibility: visible;
  opacity: 0.8;
  transition: opacity 50ms linear 400ms;
}
.SpeedDial:not(.dragging, .dragover):hover .close:hover,
.SpeedDial:not(.dragging, .dragover):active .close:hover,
.SpeedDial:not(.dragging, .dragover):hover .update-thumbnail:hover,
.SpeedDial:not(.dragging, .dragover):active .update-thumbnail:hover,
.SpeedDial:not(.dragging, .dragover):hover .set-custom-thumbnail:hover,
.SpeedDial:not(.dragging, .dragover):active .set-custom-thumbnail:hover {
  transition: none;
  opacity: 0.95;
}
.SpeedDial:not(.dragging, .dragover):hover .close:active,
.SpeedDial:not(.dragging, .dragover):active .close:active,
.SpeedDial:not(.dragging, .dragover):hover .update-thumbnail:active,
.SpeedDial:not(.dragging, .dragover):active .update-thumbnail:active,
.SpeedDial:not(.dragging, .dragover):hover .set-custom-thumbnail:active,
.SpeedDial:not(.dragging, .dragover):active .set-custom-thumbnail:active {
  transition: none;
  opacity: 1;
}
.SpeedDial.isCut {
  opacity: 0.5 !important;
}
.SpeedDial.empty .thumbnail-image {
  background-color: rgba(0, 0, 0, 0.7);
}
.SpeedDial .thumbnail-title {
  gap: 6px;
  height: 33px;
}
.SpeedDial .thumbnail-image > img {
  position: fixed;
}
.SpeedDial .thumbnail-image span {
  padding: 0 10%;
  font-weight: bold;
}
.SpeedDial--Thumbnail {
  height: var(--backgroundHeight);
  overflow: hidden;
  background-color: var(--colorBgAlphaBlur);
  backdrop-filter: var(--backgroundBlur);
  border-radius: var(--radius);
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 2px 4px 0 rgba(0, 0, 0, 0.2);
}
.SpeedDials-Wrapper:not(.dragging-disabled) .SpeedDial--Thumbnail:hover {
  transition-duration: 0ms;
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 3px 7px 0 rgba(0, 0, 0, 0.2);
}
.SpeedDial--Thumbnail.dragging {
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 6px 10px 0 rgba(0, 0, 0, 0.15);
}
.theme-light .SpeedDial--Thumbnail.dragover {
  color: var(--colorBg);
  background-color: var(--colorFgFaded);
}
.theme-light .SpeedDial--Thumbnail.dragover .thumbnail-image {
  filter: brightness(0.5);
}
.theme-dark .SpeedDial--Thumbnail.dragover {
  color: var(--colorFgIntense);
  background-color: var(--colorBgInverser);
}
.theme-dark .SpeedDial--Thumbnail.dragover .thumbnail-image {
  filter: contrast(0.5);
}
.SpeedDial--Thumbnail:focus-visible {
  outline: 2px solid color-mix(in srgb, var(--colorImageCenterFg, var(--colorFg)), var(--colorHighlightBg) 80%);
  outline-offset: 2px;
}
.SpeedDial--Thumbnail .thumbnail-image {
  display: grid;
  border-width: 0;
  overflow: hidden;
  height: var(--thumbnailHeight);
  width: var(--thumbnailWidth);
  border-radius: 0;
}
.SpeedDial--Thumbnail .thumbnail-image img {
  max-height: var(--thumbnailHeight);
}
.SpeedDial--Thumbnail .thumbnail-image span {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 4;
  -webkit-box-orient: vertical;
  width: 100%;
  max-width: 100%;
  place-self: center;
  text-align: center;
  line-height: normal;
  word-break: break-word;
}
.SpeedDial--Thumbnail .thumbnail-image .thumbnail-folder-image {
  display: grid;
  height: 100%;
}
.SpeedDial--Thumbnail .thumbnail-image-preview {
  display: flex;
}
.SpeedDial--Thumbnail > .thumbnail-title.hidden {
  position: absolute;
  width: 100%;
  bottom: 0;
  background: var(--colorBgAlpha);
  box-shadow: inset 0 1px 1px 0 rgba(0, 0, 0, 0.1);
  transform: translateY(33px);
  transition: transform 100ms linear;
}
.SpeedDial--Thumbnail:focus-within > .thumbnail-title.hidden,
.SpeedDial--Thumbnail:focus-visible > .thumbnail-title.hidden,
.SpeedDial--Thumbnail:hover > .thumbnail-title.hidden {
  transform: translateY(0);
}
.SpeedDial--Thumbnail .thumbnail-title:has(img, .favicon) {
  justify-content: left;
}
.SpeedDial--Icon .thumbnail-favicon,
.SpeedDial--Icon .thumbnail-favicon-folder {
  display: grid;
  place-content: center;
  border-width: 0;
  overflow: hidden;
  height: var(--thumbnailHeight);
  width: var(--thumbnailWidth);
  transition: scale 200ms linear;
}
.SpeedDial--Icon:hover .thumbnail-favicon,
.SpeedDial--Icon:hover .thumbnail-favicon-folder {
  scale: 1.2;
  transition-duration: 50ms;
}
.SpeedDial--Icon .favicon,
.SpeedDial--Icon .thumbnail-image {
  box-sizing: content-box;
  height: 16px;
  width: 16px;
  margin: 0;
  padding: 6px;
}
.SpeedDial--Icon .favicon.SpeedDialAddButton-Favicon,
.SpeedDial--Icon .thumbnail-image.SpeedDialAddButton-Favicon {
  height: fit-content;
  width: 12px;
}
.SpeedDial--Icon .thumbnail-favicon .favicon,
.SpeedDial--Icon .thumbnail-favicon .bookmarklet,
.SpeedDial--Icon .thumbnail-image {
  height: 32px;
  width: 32px;
}
.SpeedDial--Icon .thumbnail-favicon .favicon svg,
.SpeedDial--Icon .thumbnail-favicon .bookmarklet svg,
.SpeedDial--Icon .thumbnail-image svg {
  width: 100% !important;
  height: auto;
}
.SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-favicon-children {
  display: grid;
  grid-template-columns: repeat(2, 16px);
  grid-template-rows: repeat(2, 16px);
  gap: 2px;
  padding: 5px;
  align-items: center;
  justify-items: center;
  width: min-content;
  margin-left: auto;
  margin-right: auto;
}
.SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-favicon-children .favicon {
  padding: 0;
}
.SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-image,
.SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-favicon-children,
.SpeedDial--Icon .thumbnail-favicon .favicon,
.SpeedDial--Icon .thumbnail-title {
  border-radius: var(--radius);
  box-shadow: none;
}
.SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-image,
.SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-favicon-children,
.SpeedDial--Icon .thumbnail-favicon .favicon {
  border-radius: var(--radius);
  background-color: var(--colorBgAlphaBlur);
  backdrop-filter: var(--backgroundBlur);
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 2px 4px 0 rgba(0, 0, 0, 0.2);
}
.SpeedDials-Wrapper:not(.dragging-disabled) .SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-image:hover,
.SpeedDials-Wrapper:not(.dragging-disabled) .SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-favicon-children:hover,
.SpeedDials-Wrapper:not(.dragging-disabled) .SpeedDial--Icon .thumbnail-favicon .favicon:hover {
  transition-duration: 0ms;
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 3px 7px 0 rgba(0, 0, 0, 0.2);
}
.dragging .SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-image,
.dragging .SpeedDial--Icon .thumbnail-favicon-folder .thumbnail-favicon-children,
.dragging .SpeedDial--Icon .thumbnail-favicon .favicon {
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 6px 10px 0 rgba(0, 0, 0, 0.15);
}
.theme-light .SpeedDial--Icon.dragover .thumbnail-favicon-folder .thumbnail-favicon-children,
.theme-light .SpeedDial--Icon.dragover .thumbnail-favicon-folder .thumbnail-image,
.theme-light .SpeedDial--Icon.dragover .thumbnail-favicon .favicon,
.theme-light .SpeedDial--Icon.dragover .thumbnail-title {
  color: var(--colorBg);
  background-color: var(--colorFgFaded);
}
.theme-light .SpeedDial--Icon.dragover .thumbnail-favicon-folder .thumbnail-favicon-children .thumbnail-image,
.theme-light .SpeedDial--Icon.dragover .thumbnail-favicon-folder .thumbnail-image .thumbnail-image,
.theme-light .SpeedDial--Icon.dragover .thumbnail-favicon .favicon .thumbnail-image,
.theme-light .SpeedDial--Icon.dragover .thumbnail-title .thumbnail-image {
  filter: brightness(0.5);
}
.theme-dark .SpeedDial--Icon.dragover .thumbnail-favicon-folder .thumbnail-favicon-children,
.theme-dark .SpeedDial--Icon.dragover .thumbnail-favicon-folder .thumbnail-image,
.theme-dark .SpeedDial--Icon.dragover .thumbnail-favicon .favicon,
.theme-dark .SpeedDial--Icon.dragover .thumbnail-title {
  color: var(--colorFgIntense);
  background-color: var(--colorBgInverser);
}
.theme-dark .SpeedDial--Icon.dragover .thumbnail-favicon-folder .thumbnail-favicon-children .thumbnail-image,
.theme-dark .SpeedDial--Icon.dragover .thumbnail-favicon-folder .thumbnail-image .thumbnail-image,
.theme-dark .SpeedDial--Icon.dragover .thumbnail-favicon .favicon .thumbnail-image,
.theme-dark .SpeedDial--Icon.dragover .thumbnail-title .thumbnail-image {
  filter: contrast(0.5);
}
.SpeedDial--Icon .thumbnail-title.hidden {
  opacity: 0;
  transition: opacity 100ms linear;
}
.SpeedDial--Icon:focus-within .thumbnail-title.hidden,
.SpeedDial--Icon:focus-visible .thumbnail-title.hidden,
.SpeedDial--Icon:hover .thumbnail-title.hidden {
  opacity: 1;
}
.SpeedDial--Icon.SpeedDial--HasTitle:focus-visible .thumbnail-title {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: 0;
}
.SpeedDial--Icon.SpeedDial--NoTitle:focus-visible .thumbnail-favicon-folder,
.SpeedDial--Icon.SpeedDial--NoTitle:focus-visible .thumbnail-favicon .favicon {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: 0;
}
.SpeedDial--Icon .thumbnail-title {
  font-size: 11.5px;
  gap: 3px;
  height: 21px;
  color: var(--colorImageCenterFg, var(--colorWindowFg));
}
.SpeedDial--Tiny .thumbnail-title {
  font-size: 11.5px;
  gap: 3px;
  height: 26px;
}
.SpeedDial--Tiny .thumbnail-image span {
  padding: 0 6%;
  font-weight: 500;
}
.SpeedDial--Small .thumbnail-image {
  font-size: 14px;
}
.SpeedDial--Medium .thumbnail-image {
  font-size: 18px;
}
.SpeedDial--Large .thumbnail-image {
  font-size: 22px;
}
.SpeedDial--Huge .thumbnail-image {
  font-size: 26px;
}
.thumb-controls {
  position: absolute;
  top: 9px;
  left: 9px;
  height: 20px;
  display: flex;
  justify-content: flex-end;
  gap: 3px;
}
.SpeedDials-Wrapper {
  margin: 0;
  transform-origin: 50% 400px;
  max-width: 100%;
}
.sdwrapper.has-SpeedDial .SpeedDialView {
  position: relative;
  display: grid;
  gap: 42px;
  grid-template-rows: 1fr auto;
  min-height: 100%;
  padding: 60px 0;
  overflow: hidden;
}
.sdwrapper.has-SpeedDial .SpeedDialView:focus-visible {
  outline: unset;
}
.sdwrapper.has-SpeedDial .SpeedDialView.SpeedDialView--HasSearch {
  grid-template-rows: auto 1fr auto;
}
.SpeedDial-Add-Buttons {
  height: 28px;
  align-self: flex-end;
  margin: 0 auto;
  gap: 1px;
  display: flex;
  justify-content: center;
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 2px 4px 0 rgba(0, 0, 0, 0.2);
  border-radius: var(--radius);
}
.SpeedDial-Add-Button {
  display: flex;
  align-items: center;
  gap: 6px;
  padding: 0 15px 0 9px;
  border-radius: unset;
  border-left: none;
  background-color: var(--colorBgIntense);
  border-width: 0;
}
.SpeedDial-Add-Button:first-child {
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
}
.SpeedDial-Add-Button:last-child {
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.SpeedDial-Add-Button.pressed {
  background-color: var(--colorBgDark);
}
.SpeedDial-Add-Button span {
  display: inline-flex;
  align-self: center;
  justify-self: center;
}
.SpeedDial-Add-Button span svg {
  height: 16px;
  width: 16px;
}
.SpeedDials .SpeedDial .edit > .button-title {
  padding: 0;
  border-radius: 0;
}
.SpeedDials .SpeedDial .edit > input {
  padding: 0;
  width: 100%;
  height: 100%;
  border: 0;
  border-radius: 0;
  box-shadow: none;
  background-color: transparent;
  font-size: inherit;
}
.SpeedDials .SpeedDial .edit > input:focus {
  outline: none;
}
.startpage-navigation .SpeedDials .SpeedDial .edit > input {
  border-width: 0;
  box-shadow: none;
}
.SpeedDials .SpeedDial .edit.edit button {
  color: transparent;
  text-shadow: none;
}
.sdwrapper .button-startpage,
.sdwrapper .SearchField {
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 2px 4px 0 rgba(0, 0, 0, 0.2);
}
.sdwrapper .left-enter,
.sdwrapper .left-leave,
.sdwrapper .right-enter,
.sdwrapper .right-leave,
.sdwrapper .up-enter,
.sdwrapper .up-leave,
.sdwrapper .down-enter,
.sdwrapper .down-leave {
  pointer-events: none;
  transition: transform 300ms cubic-bezier(0.2, 0.9, 0.6, 1), opacity 300ms cubic-bezier(0.2, 0.9, 0.6, 1);
}
nav:hover + .startpage-content .sdwrapper .SpeedDials-Wrapper > span,
nav:focus-within + .startpage-content .sdwrapper .SpeedDials-Wrapper > span {
  will-change: transform, opacity;
}
.sdwrapper .SpeedDials-Wrapper.left-height > span:first-child .SpeedDials,
.sdwrapper .SpeedDials-Wrapper.right-height > span:first-child .SpeedDials,
.sdwrapper .SpeedDials-Wrapper.up-height > span:first-child .SpeedDials,
.sdwrapper .SpeedDials-Wrapper.down-height > span:first-child .SpeedDials {
  opacity: 0;
}
.sdwrapper .SpeedDials-Wrapper.left-height > span:only-child .SpeedDials,
.sdwrapper .SpeedDials-Wrapper.right-height > span:only-child .SpeedDials,
.sdwrapper .SpeedDials-Wrapper.up-height > span:only-child .SpeedDials,
.sdwrapper .SpeedDials-Wrapper.down-height > span:only-child .SpeedDials {
  opacity: 1;
}
.sdwrapper .left-enter {
  left: 100vw;
  transform: translate3d(100vw, 0, 0);
  opacity: 0;
}
.sdwrapper .left-enter.left-enter-active {
  transform: translate3d(0, 0, 0);
  opacity: 1;
}
.sdwrapper .left-leave {
  left: 0;
  transform: translate3d(0, 0, 0);
  opacity: 1;
}
.sdwrapper .left-leave.left-leave-active {
  transform: translate3d(-100vw, 0, 0);
  opacity: 0;
}
.sdwrapper .right-enter {
  right: 100vw;
  transform: translate3d(-100vw, 0, 0);
  opacity: 0;
}
.sdwrapper .right-enter.right-enter-active {
  transform: translate3d(0, 0, 0);
  opacity: 1;
}
.sdwrapper .right-leave {
  right: 0;
  transform: translate3d(0, 0, 0);
  opacity: 1;
}
.sdwrapper .right-leave.right-leave-active {
  transform: translate3d(100vw, 0, 0);
  opacity: 0;
}
.sdwrapper .up-enter {
  transform: perspective(500px) translate3d(0, 0, 75px);
  opacity: 0;
}
.sdwrapper .up-enter.up-enter-active {
  transform: perspective(500px) translate3d(0, 0, 0);
  opacity: 1;
}
.sdwrapper .up-leave {
  transform: perspective(500px) translate3d(0, 0, 0);
  opacity: 1;
}
.sdwrapper .up-leave.up-leave-active {
  transform: perspective(500px) translate3d(0, 0, -75px);
  opacity: 0;
}
.sdwrapper .down-enter {
  transform: perspective(500px) translate3d(0, 0, -75px);
  opacity: 0;
}
.sdwrapper .down-enter.down-enter-active {
  transform: perspective(500px) translate3d(0, 0, 0);
  opacity: 1;
}
.sdwrapper .down-leave {
  transform: perspective(500px) translate3d(0, 0, 0);
  opacity: 1;
}
.sdwrapper .down-leave.down-leave-active {
  transform: perspective(500px) translate3d(0, 0, 75px);
  opacity: 0;
}
.SpeedDialView-Settings-Button {
  position: fixed;
  top: 12px;
  right: var(--scrollbarWidth);
  background-color: transparent;
  background-repeat: no-repeat;
  border: none;
  overflow: hidden;
  white-space: nowrap;
  padding: 6px 6px 3px;
  z-index: 2;
}
.startpage-navigation ~ .startpage-content .SpeedDialView-Settings-Button {
  top: 55px;
}
.SpeedDialView-Settings-Button svg {
  fill: var(--colorImageTopRightFg, var(--colorFgFaded));
}
.SpeedDialView-Settings {
  display: flex;
  flex-direction: column;
  position: fixed;
  top: 0;
  right: var(--scrollbarWidth);
  bottom: 0;
  width: 370px;
  background-color: var(--colorBg);
  z-index: 3;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  transition-property: width;
  transition-duration: 50ms;
  margin-right: calc(var(--scrollbarWidth) * -1);
  overflow: auto;
  animation: rightfade 100ms linear;
}
.SpeedDialView-Settings.navigation-title {
  top: 43px;
}
.SpeedDialView-Settings .row {
  display: flex;
  width: 100%;
  justify-content: space-between;
  align-items: center;
  grid-column-start: span 2;
}
.SpeedDialView-Settings .row label {
  flex: 1;
  padding: 6px 6px 9px 0;
}
.SpeedDialView-Settings .row.disabled {
  pointer-events: none;
  font-weight: 400;
  opacity: 0.5;
}
.SpeedDialView-Settings h2 {
  margin-bottom: 6px;
  grid-column-start: span 2;
}
.SpeedDialView-Settings h2:has(+ p.info) {
  margin-bottom: 0;
}
.SpeedDialView-Settings hr {
  border: var(--colorBorder) solid;
  border-width: 2px 0 0;
  margin: 12px 0;
  grid-column-start: span 2;
}
.SpeedDialView-Settings .info {
  margin-top: 3px;
  grid-column-start: span 2;
}
.SpeedDialView-Settings .SpeedDialView-Settings-Head {
  display: flex;
  justify-content: space-between;
  align-items: center;
  padding: 12px;
}
.SpeedDialView-Settings .SpeedDialView-Settings-BackgroundImages .actions {
  display: flex;
  justify-content: space-between;
  align-items: center;
}
.SpeedDialView-Settings .SpeedDialView-Settings-BackgroundImages .images {
  width: 100%;
  display: flex;
  align-items: center;
  gap: 12px;
  padding-bottom: 6px;
  overflow-x: auto;
  scroll-snap-type: x mandatory;
  scroll-behavior: smooth;
}
.SpeedDialView-Settings .SpeedDialView-Settings-BackgroundImages .images .selectbox {
  position: relative;
  width: 95px;
  scroll-snap-align: start;
}
.SpeedDialView-Settings .SpeedDialView-Settings-BackgroundImages .images .selectbox-image {
  width: 95px;
  height: 70.3px;
  background-size: cover;
  box-shadow: inset 0 0 0 1px var(--colorFgAlpha);
  margin: 0;
}
.SpeedDialView-Settings .SpeedDialView-Settings-BackgroundImages .images .selectbox-label {
  position: absolute;
  inset: 0;
  align-content: center;
  padding: 0 6px;
  color: var(--colorFgFaded);
  font-size: 11.5px;
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
}
.SpeedDialView-Settings .SpeedDialView-Settings-BackgroundImages .images .selectbox-label-highlighted span {
  color: #fff;
  background-color: rgba(50, 50, 50, 0.8);
  border-radius: var(--radius);
  padding: 3px 6px;
}
.SpeedDialView-Settings-StartPage,
.SpeedDialView-Settings-Appearance,
.SpeedDialView-Settings-Dashboard {
  padding: 0 12px;
}
.SpeedDialView-Settings-BackgroundImages,
.SpeedDial-Show-Settings {
  padding: 0 12px;
}
.SpeedDialView-Settings-BackgroundImages .select-wrapper,
.SpeedDial-Show-Settings .select-wrapper {
  max-width: 50%;
}
.SpeedDial-Show-Settings {
  margin-top: auto;
  margin-bottom: 12px;
  width: fit-content;
}
.SpeedDialView-Settings-Group {
  display: grid;
  grid-template-columns: 1fr max-content;
  padding: 0 12px;
}
.SpeedDialView-Settings-Group .grid-row {
  display: grid;
  grid-template-columns: subgrid;
}
.SpeedDialView-Settings-Group .grid-row .select-wrapper {
  max-width: 10em;
}
.SpeedDialView-Head {
  display: flex;
  flex-wrap: wrap;
  flex-direction: row;
  justify-content: center;
  gap: 12px 24px;
  width: 100%;
  margin: 0 auto;
}
.SpeedDialView-Head:empty,
.SpeedDialView-Head:has(.tracker-warning:first-child) {
  margin-top: 30px;
}
.tracker-warning {
  color: var(--colorFg);
  padding: 12px;
  margin-top: 12px;
  z-index: 3;
  flex-basis: 100%;
}
.tracker-warning .tony-illustration {
  box-sizing: content-box;
  height: 100px;
  margin-right: 6px;
  padding: 0 12px;
  width: 100px;
}
.tracker-warning button.close {
  position: absolute;
  top: 6px;
  right: 6px;
}
.tracker-warning h1 {
  margin-bottom: 6px;
  font-weight: 600;
}
.tracker-warning p {
  max-width: 100ch;
  padding-right: 18px;
  text-wrap: pretty;
}
.tracker-warning .engine-suggestion-container {
  display: flex;
  margin-top: 12px;
  gap: 6px;
  flex-wrap: wrap;
}
.tracker-warning .support-vivaldi {
  align-self: center;
  margin-left: 6px;
}
.tracker-warning .menu {
  width: auto;
}
.tracker-warning .menu > ul {
  background-color: var(--colorBgLightIntense);
}
.tracker-warning .menu > ul li > .menu-item-description-container {
  row-gap: 2px;
}
.tracker-warning,
.SpeedDialView-SearchField,
.SpeedDial-Blocked-Counter {
  background-color: var(--colorBgLightIntense);
  backdrop-filter: var(--backgroundBlur);
  border-radius: calc(var(--radius) * 2);
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 2px 4px 0 rgba(0, 0, 0, 0.2);
  position: relative;
}
.on-speeddial,
.SpeedDial-Blocked-Counter {
  z-index: 2;
  flex: 1 0;
  min-width: 320px;
}
.vivaldi-settings .tracker-warning {
  min-width: min-content;
  max-width: 696px;
}
.SpeedDial-Blocked-Counter {
  margin-bottom: auto;
  cursor: pointer;
}
.SpeedDial-Blocked-Counter-Container {
  display: flex;
  align-items: center;
  padding: calc(10px + var(--densityGap)) 12px;
  gap: 6px;
  box-sizing: content-box;
  height: 22px;
}
.SpeedDial-Blocked-Counter:hover {
  background-color: var(--colorBgIntense);
}
.SpeedDial-Blocked-Counter .Blocked-Info {
  font-size: 13px;
  line-height: 1.1;
  color: var(--colorFg);
}
.SpeedDial-Blocked-Counter .Info-Icon {
  margin-left: auto;
  display: flex;
}
.Blocker-Shield-Ads {
  --trackers: 0;
  --blocking: 0;
  --no-blocking: 0;
}
.Blocker-Shield-Blocking {
  --ads: 0;
  --trackers: 0;
  --no-blocking: 0;
}
.Blocker-Shield-Blocking .blocking-fill {
  display: none;
}
.Blocker-Shield-No-Blocking {
  --no-blocking: 1;
  --base: 0;
  --blocking: 0;
  --ads: 0;
  --trackers: 0;
}
#browser .button-startpage {
  display: flex;
  justify-content: flex-start;
  align-items: center;
  min-height: 43px;
  max-width: 16em;
  position: relative;
  white-space: nowrap;
  overflow: hidden;
  padding: 0 9px;
  background-color: transparent;
  border: 0 solid transparent;
  border-bottom-width: 2px;
  user-select: none;
}
#browser .button-startpage:not(:hover) {
  mask-image: linear-gradient(to left, transparent 0, #000 12px);
}
#browser .button-startpage:focus-visible {
  outline-width: 1px;
  outline-offset: -1px;
}
.linux #browser .button-startpage {
  mask-image: unset;
}
.linux #browser .button-startpage,
.linux #browser .button-startpage .button-title {
  display: block;
}
.linux #browser .button-startpage:not(.active),
.linux #browser .button-startpage .button-title:not(.active) {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
#browser .button-startpage.button-toolbar {
  padding: 0 6px;
}
#browser .button-startpage.button-toolbar button:hover {
  color: inherit;
  background-color: transparent;
}
#browser .button-startpage button {
  height: 100%;
  max-width: 100%;
  padding: 0;
  border: 0;
  border-radius: 0;
  gap: 3px;
}
#browser .button-startpage button .button-title {
  text-overflow: clip;
  overflow: visible;
  margin: 0;
}
#browser .button-startpage.hover-left,
#browser .button-startpage.hover-right {
  mask-image: unset;
}
@keyframes fadedragged {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0.5;
  }
}
#browser .button-startpage.collapsed {
  animation: fadedragged 50ms linear;
  opacity: 0.5;
}
#browser .button-startpage .button-icon,
#browser .button-startpage .button-icon svg {
  width: 28px;
  height: 28px;
  padding: 0;
}
#browser .button-startpage.add-set svg {
  margin-right: 0;
}
#browser .button-startpage.add-set svg path {
  fill: var(--colorFgFaded);
}
span + #browser .button-startpage.add-set {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
#browser .button-startpage:focus-visible,
#browser .button-startpage.active {
  color: var(--colorFg);
  border-color: var(--colorHighlightBg);
  mask-image: unset;
}
#browser .button-startpage:focus-visible {
  background-color: var(--colorHighlightBgAlpha);
}
#browser .button-startpage.up-level {
  position: relative;
  min-height: 34px;
  padding: 6px 12px 6px 34px;
  margin: 0 auto;
  border-radius: var(--radius);
  border-width: 0;
  mask-image: none;
  background-color: var(--colorBg);
}
#browser .button-startpage.up-level:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
#browser .button-startpage.up-level > span {
  display: contents;
}
#browser .button-startpage.up-level svg {
  position: absolute;
  width: 16px;
  height: 16px;
  left: 7px;
  transform: scaleX(-1);
}
.editable-title-container:first-of-type button:not(.collapsed).hover-left:before,
.editable-title-container:last-of-type button.hover-right:before,
.editable-title-container:not(:has(button.collapsed)) + .editable-title-container button.hover-left:before,
.editable-title-container:has(button.hover-right) + .editable-title-container button:not(.collapsed):before {
  content: '';
  border-left: 2px solid var(--colorHighlightBg);
  position: absolute;
  left: 0;
  top: 0;
  bottom: 0;
  opacity: 1;
}
.editable-title-container:last-of-type button.hover-right:before {
  left: unset;
  right: 0;
}
.startpage-navigation-group .button-toolbar {
  display: contents;
}
.startpage-navigation-group .editable-title-container {
  display: flex;
  flex: 0 1 auto;
  margin-right: 0;
  overflow: hidden;
}
.startpage-navigation-group .editable-title-container .button-startpage {
  border-radius: 0;
  margin-right: 0;
  width: auto;
}
.startpage-navigation-group .editable-title-container.edit .button-startpage {
  color: transparent;
  text-shadow: none;
  background-color: #fff;
}
.startpage-navigation-group .editable-title-container.edit .sd-title-editor {
  width: 120px;
  height: 42px;
  padding: 0 6px 2px;
  text-align: center;
  color: var(--colorHighlightBg);
  border: unset;
  border-radius: unset;
  box-shadow: unset;
  background-color: var(--colorBgDark);
}
.startpage-navigation-group .editable-title-container.edit .sd-title-editor:focus {
  z-index: 1;
  outline: unset;
}
.startpage {
  display: flex;
  flex-flow: column nowrap;
  flex: 1;
  color: var(--colorFg);
  user-select: none;
  overflow: hidden;
  position: absolute;
  inset: 0;
  contain: strict;
}
.startpage .startpage-content {
  display: flex;
  flex: 1;
  overflow: hidden;
  position: relative;
  z-index: 0;
}
.startpage .startpage-content .sdwrapper {
  flex: 1;
  overflow-y: overlay;
}
.startpage .startpage-content .sdwrapper.has-SpeedDial {
  scrollbar-gutter: stable;
  margin-left: var(--scrollbarWidth);
}
.startpage .startpage-content .sdwrapper:focus-visible {
  outline: none;
}
.startpage .startpage-content .sdwrapper .history webview {
  top: 0;
  overflow-y: hidden;
}
.startpage .startpage-content .sdwrapper .history webview::shadow object {
  overflow-y: auto;
}
.startpage #modal-bg.startpage-drawer {
  position: absolute;
  width: 510px;
  display: flex;
  flex-direction: column;
  flex: 1;
  background-color: var(--colorBgAlphaBlur);
  backdrop-filter: var(--backgroundBlur, blur(10px));
  border-radius: var(--radius);
  animation: pullfade 200ms linear;
  max-height: stretch;
  max-width: 80dvw;
  place-self: anchor-center;
  margin-bottom: 12px;
}
.startpage #modal-bg.startpage-drawer .modal-wrapper {
  display: flex;
  flex-direction: column;
  padding-bottom: 12px;
  overflow: auto;
  scrollbar-gutter: stable;
  background-color: unset;
}
.startpage #modal-bg.startpage-drawer section {
  display: flex;
  flex-direction: column;
  flex: 1 0 auto;
  padding-left: 18px;
  padding-right: calc(6px * 3 - var(--scrollbarWidth));
  padding-bottom: 6px;
}
.startpage #modal-bg.startpage-drawer section.drawer-adddial .drawer-addform {
  padding-left: 0;
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 6px;
  align-items: baseline;
}
.startpage #modal-bg.startpage-drawer section.drawer-adddial .drawer-addform input.address {
  flex: 1 1 100%;
}
.startpage #modal-bg.startpage-drawer section.drawer-adddial .drawer-addform .controls {
  grid-column: 2;
  display: flex;
  gap: 6px;
}
.startpage #modal-bg.startpage-drawer section.drawer-adddial .drawer-addform .add-dial-submit {
  flex: 0 0 auto;
}
.startpage #modal-bg.startpage-drawer section.drawer-adddial .drawer-addform .FormButton {
  display: flex;
  align-items: center;
  gap: 6px;
  padding: 0 12px;
}
.startpage #modal-bg.startpage-drawer section h2 {
  margin: 12px 0;
}
.startpage #modal-bg.startpage-drawer section.drawer-suggestions .back {
  max-width: fit-content;
  margin-top: 12px;
  margin-bottom: 0;
}
.startpage #modal-bg.startpage-drawer section.drawer-suggestions .SpeedDials {
  display: grid;
  grid-template-columns: repeat(auto-fit, 90px);
  align-items: unset;
  gap: 6px;
}
.startpage #modal-bg.startpage-drawer section .SpeedDial {
  position: relative;
  background-color: transparent;
  padding: 6px 6px 0;
  border: none;
  box-shadow: none;
  text-align: center;
  background-color: var(--colorBgIntenser);
  border-radius: var(--radiusHalf);
}
.startpage #modal-bg.startpage-drawer section .SpeedDial:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
}
.startpage #modal-bg.startpage-drawer section .SpeedDial.disabled div {
  opacity: 0.65;
  filter: grayscale(1);
}
.startpage #modal-bg.startpage-drawer section .SpeedDial.disabled:after {
  content: '';
  position: absolute;
  top: 3px;
  right: 3px;
  bottom: unset;
  left: unset;
  width: 16px;
  height: 16px;
  border-radius: 50%;
  background-color: var(--colorSuccessBg);
  mask-image: url('/resources/mask-check.svg');
}
.startpage #modal-bg.startpage-drawer section .SpeedDial .dial-image {
  background: transparent;
  height: 36px;
}
.startpage #modal-bg.startpage-drawer section .SpeedDial .dial-image svg,
.startpage #modal-bg.startpage-drawer section .SpeedDial .dial-image img {
  width: 36px;
  height: 36px;
  padding: 6px;
}
.startpage #modal-bg.startpage-drawer section .SpeedDial .dial-title {
  display: inline-block;
  max-width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  font-size: 11.5px;
  margin: 0 auto;
  opacity: 0.85;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDials {
  display: flex;
  flex-direction: row;
  flex-wrap: nowrap;
  gap: 6px;
  overflow: auto;
  padding: 0 0 6px;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  gap: 6px;
  flex: 0 0 100px;
  width: 100px;
  height: 100px;
  min-width: unset;
  color: #fff;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
  border: 3px var(--colorBgIntenser) solid;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.travel {
  background-color: #009b77;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.shopping {
  background-color: #378cf5;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.gaming {
  background-color: #45b8ac;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.social {
  background-color: #5b5ea6;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.finance {
  background-color: #886ad5;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.news {
  background-color: #88b04b;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.education {
  background-color: #92a8d1;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.sport {
  background-color: #955251;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.streaming {
  background-color: #afc8f0;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.food {
  background-color: #b565a7;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.health {
  background-color: #be8191;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.parenting {
  background-color: #dd4124;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.books {
  background-color: #efc050;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.photography {
  background-color: #f2ad00;
}
.startpage #modal-bg.startpage-drawer .drawer-categories .SpeedDial.tools {
  background-color: #ff6f61;
}
.startpage #modal-bg.startpage-drawer .close {
  position: absolute;
  top: 11px;
  right: 11px;
  background-color: unset;
}
.startpage .startpage-navigation {
  flex: 0 0 auto;
  text-align: center;
  position: relative;
  padding-top: 0;
  padding-bottom: 0;
  padding-right: 12px;
  padding-left: 12px;
  display: flex;
  justify-content: center;
  min-height: 43px;
  background-color: var(--colorBgLightIntense);
  box-shadow: inset 0 -2px 0 var(--colorBgDark);
  z-index: 4;
}
.startpage .startpage-navigation .startpage-navigation-group {
  display: flex;
  align-items: center;
  flex: 0 1 auto;
  overflow: hidden;
}
.startpage .startpage-navigation .startpage-navigation-group:first-of-type {
  margin-right: 18px;
}
.startpage .startpage-navigation .startpage-navigation-group .button-startpage {
  border-radius: 0;
}
.startpage .startpage-navigation .startpage-navigation-group .button-startpage:hover {
  background-color: var(--colorFgAlpha);
}
.startpage .startpage-folder-navigation {
  width: 100%;
  height: 30px;
  margin: 0 0 20px;
  text-align: center;
  position: sticky;
  top: 0;
  z-index: 1000;
}
.startpage .startpage-folder-navigation button {
  background-color: var(--colorBgDark);
  border-width: 1px;
}
.startpage .startpage-folder-navigation button:hover {
  background-color: var(--colorBg);
}
.startpage .startpage-folder-navigation button:after {
  content: unset;
}
.startpage .startpage-folder-navigation button.highlight {
  border: var(--colorHighlightBg) 5px dashed;
}
.window-preview-box {
  display: flex;
  width: 144px;
  height: 108px;
  padding: 0;
  margin-top: 6px;
  border: 1px solid var(--colorBorder);
  position: relative;
}
.window-preview-box::-webkit-file-upload-button {
  display: none;
}
.window-preview-box:after {
  content: attr(title);
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  display: flex;
  flex: 1;
  justify-content: center;
  align-items: center;
  text-shadow: 0 1px 0 var(--colorBgLight);
  background-image: linear-gradient(var(--colorBgAlphaHeavy), var(--colorBg));
  transition: opacity 100ms linear;
  opacity: 0;
}
.window-preview-box:hover:after {
  opacity: 1;
}
.settings-text-bubble-highlight-wrapper {
  position: relative;
  display: flex;
  flex-direction: column;
  align-items: baseline;
}
.settings-text-bubble-highlight {
  margin-top: 10px;
  border: 1px solid var(--colorHighlightBg);
  padding: 0 3px;
  min-width: 12px;
  text-align: center;
}
.settings-text-bubble-highlight:before {
  content: '';
  left: 0;
  position: absolute;
  margin-top: -8px;
  border-width: 0px 6px 7px 6px;
  border-style: solid;
  border-color: var(--colorHighlightBg) transparent;
  display: block;
  width: 0;
}
.internal-page {
  display: flex;
  flex: 1;
  overflow: hidden;
}
.info {
  font-size: 11.5px;
  margin: 6px 0;
  color: var(--colorFgFadedMore);
  max-width: 34em;
}
.info.full-width {
  flex-basis: 100%;
}
.info.no-max-width {
  max-width: 100%;
}
.vivaldi-settings label + .info.pad-zero {
  margin-left: 0;
}
.info .shortcuts {
  display: grid;
  grid-template-columns: auto 1fr;
  grid-gap: 3px 9px;
  margin: 12px 0 0;
  align-items: baseline;
}
.info .shortcut {
  display: inline-flex;
  grid-gap: 3px;
}
.info kbd {
  font-family: inherit;
  background-color: var(--colorFgAlpha);
  border: 1px solid var(--colorBorder);
  border-radius: var(--radiusHalf);
  padding: 2px;
  line-height: 11.5px;
  text-transform: capitalize;
}
.is-settingspage #header {
  box-shadow: inset 0 -1px var(--colorBorder);
}
.is-settingspage #titlebar #pagetitle {
  display: none;
}
.settings-container {
  display: flex;
  width: 100%;
}
.settings-header {
  display: none;
  pointer-events: none;
}
.is-settingspage.fullscreen.mac-menubar-permanent .settings-header,
.is-settingspage:not(.fullscreen, .native) .settings-header {
  display: flex;
  position: fixed;
  top: calc(6px / var(--uiZoomLevel));
  left: calc(100px / var(--uiZoomLevel));
  right: calc(100px / var(--uiZoomLevel));
  text-align: center;
  align-items: center;
  justify-content: center;
  scale: calc(1 / var(--uiZoomLevel));
  transform-origin: top center;
}
.settings-header h1 {
  font: inherit;
  display: inline;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
#browser.mac .settings-header h1 {
  font-weight: 600;
}
#browser.win .settings-header {
  top: 0;
  left: 0;
  right: calc(140px / var(--uiZoomLevel));
  font-size: 12px;
  height: 30px;
  justify-content: flex-start;
  transform-origin: top left;
}
#browser.win .settings-header img {
  margin: 0 6px 0 8px;
  overflow: hidden;
  max-width: 100%;
  object-fit: cover;
  flex: 0 0.1 16px;
}
.vivaldi-settings {
  display: grid;
  grid-template-columns: 190px 1fr;
  grid-template-rows: 1fr;
  flex: 1;
  background-color: var(--colorBg);
  color: var(--colorFg);
  position: relative;
  box-shadow: 0 -1px var(--colorBorder);
  max-width: 100%;
}
.vivaldi-settings:focus-visible {
  outline: unset;
}
.vivaldi-settings .hidden {
  display: none !important;
}
.vivaldi-settings h2 + .info {
  margin-bottom: 18px;
}
.vivaldi-settings h3 + .info {
  margin-bottom: 12px;
}
.vivaldi-settings .info + .info {
  margin-bottom: 12px;
}
.vivaldi-settings p.info.disabled {
  opacity: 0.5;
}
.vivaldi-settings label {
  display: inline-flex;
  vertical-align: top;
  gap: 9px;
}
.vivaldi-settings label + p.info,
.vivaldi-settings a.info {
  margin-top: 0;
  margin-right: 0;
  margin-bottom: 6px;
  margin-left: 26px;
  display: flex;
}
.vivaldi-settings label + p.info .InlineText,
.vivaldi-settings a.info .InlineText {
  display: contents;
}
.vivaldi-settings .settings-sidebar {
  box-shadow: -1px 0 var(--colorBorderSubtle) inset;
  background-color: var(--colorBg);
  display: flex;
  flex-direction: column;
  flex: 0;
  overflow: hidden;
}
.vivaldi-settings .settings-sidebar .tree-row {
  height: 100%;
}
.vivaldi-settings .settings-sidebar .tree-row:has(.button-category.spacer) {
  padding-top: 12px;
}
.vivaldi-settings .settings-sidebar .button-category {
  display: flex;
  flex: 0 0 auto;
  gap: 6px;
  height: 100%;
  padding-left: 6px;
  background: transparent;
  align-items: center;
  margin: 0 6px;
  border-radius: var(--radius);
}
.vivaldi-settings .settings-sidebar .button-category svg {
  display: block;
  pointer-events: none;
}
.vivaldi-settings .settings-sidebar .button-category.group_1 {
  fill: #ffad2e;
  stroke: #ffad2e;
}
.vivaldi-settings .settings-sidebar .button-category.group_2 {
  fill: #ff5c00;
  stroke: #ff5c00;
}
.vivaldi-settings .settings-sidebar .button-category.group_3 {
  fill: #19b899;
  stroke: #19b899;
}
.vivaldi-settings .settings-sidebar .button-category.group_4 {
  fill: #a585ff;
  stroke: #a585ff;
}
.vivaldi-settings .settings-sidebar .button-category.group_5 {
  fill: #1894ff;
  stroke: #1894ff;
}
.vivaldi-settings .settings-sidebar .button-category.group_6 {
  fill: #ff64a9;
  stroke: #ff64a9;
}
.vivaldi-settings .settings-sidebar .button-category.group_7 {
  fill: var(--colorFg);
  stroke: var(--colorFg);
}
.mono-icons.vivaldi-settings .settings-sidebar .button-category {
  fill: var(--colorFgFaded);
  stroke: var(--colorFgFaded);
}
.settings-navigation:focus-within .mono-icons.vivaldi-settings .settings-sidebar .button-category.category-selected {
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFgAlpha);
  stroke: var(--colorHighlightFgAlpha);
}
.vivaldi-settings .settings-sidebar .button-category.category-selected {
  background-color: var(--colorFgAlpha);
  color: var(--colorFg);
  fill: var(--colorFg);
  stroke: var(--colorFg);
}
.vivaldi-settings .settings-sidebar .settings-navigation:focus-within .tree-row[data-selected] .button-category:not(:active, .category-selected) {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
}
.vivaldi-settings .settings-sidebar .settings-navigation:focus-within .tree-row .button-category.category-selected {
  background-color: var(--colorHighlightBg);
  outline-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
  stroke: var(--colorHighlightFg);
}
.vivaldi-settings .settings-sidebar .settings-navigation-header {
  padding: 12px 6px;
  flex: 0 0 auto;
}
.vivaldi-settings .settings-sidebar .settings-navigation-header .settings-search {
  width: 100%;
}
.vivaldi-settings .settings-sidebar .settings-navigation {
  flex: 1;
  overflow: hidden;
  margin-right: 0;
  padding: 0;
}
.vivaldi-settings .settings-sidebar .settings-navigation .VivaldiList {
  scrollbar-gutter: unset;
  padding-bottom: 6px;
}
.vivaldi-settings .settings-donation-suggestion {
  position: absolute;
  top: 1rem;
  right: 3rem;
  background-color: var(--colorBg);
  border-radius: var(--radiusRound);
  padding: 6px 12px;
  display: flex;
  gap: 6px;
}
.vivaldi-settings .settings-donation-suggestion > div {
  display: flex;
  gap: 6px;
}
.vivaldi-settings .settings-content {
  overflow-x: hidden;
  overflow-y: auto;
  scrollbar-gutter: stable;
  position: relative;
  flex: 1 1 auto;
  background-color: var(--colorBgLightIntense);
  padding-top: 24px;
  padding-left: 36px;
  padding-bottom: 60px;
  padding-right: 36px;
}
.vivaldi-settings .settings-content mark {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
}
.vivaldi-settings .setting-section .setting-group {
  width: 100%;
  max-width: 220px;
}
.vivaldi-settings .setting-section .setting-group-double {
  width: 100%;
  max-width: 458px;
}
.vivaldi-settings .setting-section .setting-group-double .setting-group.setting-single + .setting-group.setting-single {
  margin-right: 0;
}
.vivaldi-settings .setting-section .setting-group-block {
  display: inline-block;
}
.vivaldi-settings .setting-section .setting-group.pad-top,
.vivaldi-settings .setting-section .setting-group-double.pad-top,
.vivaldi-settings .setting-section .setting-group-unlimited.pad-top {
  padding-top: 1em;
}
.vivaldi-settings .setting-section .setting-group:empty,
.vivaldi-settings .setting-section .setting-group-double:empty,
.vivaldi-settings .setting-section .setting-group-unlimited:empty {
  margin: 0;
}
.vivaldi-settings .setting-section .setting-group {
  margin: 0 18px 18px 0;
  display: inline-block;
  vertical-align: top;
}
.vivaldi-settings .setting-section .setting-group .pad-left {
  padding-left: 26px;
}
.vivaldi-settings .setting-section .setting-group .thumbnail-wrapper {
  margin-left: -6px;
}
.vivaldi-settings .setting-section .setting-group.unlimited {
  display: block;
  width: auto;
  margin-right: 0;
  max-width: 100%;
}
.vivaldi-settings .setting-section .setting-group.unlimited .setting-subgroup {
  display: inline-block;
  width: 380px;
  margin-right: 18px;
}
.vivaldi-settings .setting-section .setting-group.unlimited .setting-subgroup.marg-top {
  margin-top: 12px;
}
.vivaldi-settings .setting-section .proton-promo {
  padding: 12px;
  border-radius: var(--radius);
  background-color: var(--colorBg);
  display: flex;
  flex-flow: column;
  margin-bottom: 18px;
  max-width: 880px;
}
.vivaldi-settings .setting-section .proton-promo .container {
  display: flex;
  flex-wrap: wrap;
  gap: 18px;
}
.vivaldi-settings .setting-section .proton-promo .container p {
  flex: 1 1 0;
  min-width: 220px;
  padding: 6px 0 12px 0;
  font-size: 11.5px;
}
.vivaldi-settings .setting-section .proton-promo .container a {
  padding-top: 6px;
  display: flex;
}
.vivaldi-settings .setting-section .proton-promo .vpn-illustration {
  flex: 0 0 auto;
  min-width: 180px;
}
.vivaldi-settings .setting-section .site-icon {
  display: flex;
  width: 16px;
  height: 16px;
}
.vivaldi-settings h2 {
  padding-top: 24px;
  padding-bottom: 12px;
  margin-bottom: 12px;
  text-transform: uppercase;
  letter-spacing: 0.4pt;
  border-bottom: 1px solid var(--colorBorderSubtle);
  color: inherit;
}
.vivaldi-settings h3,
.vivaldi-settings p:not(.info) {
  margin-top: 0;
  margin-bottom: 6px;
}
.vivaldi-settings h3.pad-top,
.vivaldi-settings p:not(.info).pad-top {
  padding-top: 12px;
}
.vivaldi-settings .setting-single-flex {
  display: flex;
  flex: 1 1 auto;
  align-items: flex-end;
  gap: 6px;
}
.vivaldi-settings .setting-single-noflex {
  display: flex;
  flex: 0 0 auto;
}
.vivaldi-settings .setting-flexgroup {
  padding-bottom: 6px;
  display: flex;
}
.vivaldi-settings .setting-flexgroup .setting-single-noflex + .setting-single-noflex,
.vivaldi-settings .setting-flexgroup .setting-single-noflex + .setting-single-flex,
.vivaldi-settings .setting-flexgroup .setting-single-flex + .setting-single-noflex,
.vivaldi-settings .setting-flexgroup .setting-single-flex + .setting-single-flex {
  margin-left: 6px;
}
.vivaldi-settings .setting-single {
  margin: 0 0 6px;
}
.vivaldi-settings .setting-single.pad-top {
  padding-top: 12px;
}
.vivaldi-settings .setting-single.align-right {
  display: flex;
  justify-content: flex-end;
}
.vivaldi-settings .setting-single input[type='text']:first-child:last-child {
  width: 100%;
}
.vivaldi-settings .setting-single > label:not(.floating-label) {
  width: fit-content;
  max-width: 100%;
}
.vivaldi-settings .setting-single > label span:not(.select-wrapper) {
  margin-bottom: auto;
  margin-top: auto;
  flex: 1;
}
.vivaldi-settings .setting-single > label span:not(.select-wrapper) + select {
  margin: 3px 0;
}
.vivaldi-settings .setting-single > label > span:first-child:not(.select-wrapper) {
  margin-left: 26px;
  flex: unset;
}
.vivaldi-settings .setting-single--LeadingText > label > span:first-child {
  margin: 0;
  display: flex;
  align-items: center;
}
.vivaldi-settings .setting-single.full-width > label {
  display: flex;
  flex: 1;
}
.vivaldi-settings .setting-single.full-width > label > span:first-child {
  margin-right: auto;
}
.vivaldi-settings .setting-single h2 + .setting-single.pad-top {
  padding-top: 1em;
}
.vivaldi-settings .setting-single section + .setting-section h2 {
  padding-top: 18px;
}
.vivaldi-settings .setting-single dl {
  display: flex;
  padding-top: 6px;
  word-break: break-word;
}
.vivaldi-settings .setting-single dl dt {
  font-weight: 700;
  margin-right: 6px;
  flex: 1 1 160px;
}
.vivaldi-settings .setting-single dl dd {
  flex: 1 1 100%;
}
.vivaldi-settings .setting-single input.kbd {
  text-transform: capitalize;
  font-weight: 700;
}
.vivaldi-settings .setting-single .folder-selection {
  display: flex;
  flex-wrap: wrap;
  margin-top: -6px;
}
.vivaldi-settings .setting-single .folder-selection input[type=text] {
  flex-grow: 1;
  margin-top: 6px;
  margin-right: 6px;
}
.vivaldi-settings .setting-single .img-setting {
  display: flex;
  margin: 6px 0 4px 24px;
}
.vivaldi-settings .setting-single .img-setting .image {
  display: inline-flex;
  min-width: 32px;
}
.vivaldi-settings .setting-single .img-setting .image.mail-settings-image {
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
}
.vivaldi-settings .setting-single .img-setting .image svg {
  fill: var(--colorBorder);
}
.theme-dark .vivaldi-settings .setting-single .img-setting .image svg {
  fill: var(--colorFgFadedMost);
}
.vivaldi-settings .setting-single .img-setting .image svg .border {
  stroke: var(--colorBorder);
  fill: transparent;
}
.theme-dark .vivaldi-settings .setting-single .img-setting .image svg .border {
  stroke: var(--colorFgFadedMost);
}
.vivaldi-settings .setting-single .img-setting .image svg .background-intenser {
  fill: var(--colorBgIntenser);
}
.vivaldi-settings .setting-single .img-setting .image svg .highlight {
  fill: var(--colorHighlightBg);
}
.vivaldi-settings .setting-single .img-setting .image svg .dotted-style {
  display: none;
}
.vivaldi-settings .setting-single .img-setting .image.alternate svg .default-style {
  display: none;
}
.vivaldi-settings .setting-single .img-setting .image.alternate svg .dotted-style {
  display: initial;
}
.vivaldi-settings .setting-single .img-setting.disabled {
  opacity: 0.5;
  filter: grayscale(1);
}
.vivaldi-settings label.setting-single {
  width: 100%;
}
.vivaldi-settings .setting-single > input[type=button] + input[type=button],
.vivaldi-settings .setting-group-double > input[type=button] + input[type=button] {
  margin-left: 6px;
}
.vivaldi-settings .setting-single.fill > input[type='text'],
.vivaldi-settings .setting-single.fill > select {
  width: 100%;
}
.vivaldi-settings .setting-single input[type='range'] {
  align-self: center;
}
.vivaldi-settings .setting-single > input[type='button'],
.vivaldi-settings .setting-single > input[type='search'],
.vivaldi-settings .setting-single > input[type='submit'] {
  margin-top: 6px;
}
.vivaldi-settings .setting-section .setting-mailing-lists {
  position: relative;
}
.vivaldi-settings .setting-section .setting-mailing-lists.master-detail .master {
  max-width: min(35%, 219px);
}
.vivaldi-settings .setting-section .setting-mailing-lists.master-detail label {
  align-items: center;
  flex-wrap: wrap;
}
.vivaldi-settings .setting-section .setting-mailing-lists.master-detail .sortable-list .item {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.vivaldi-settings .setting-section .setting-mailing-lists .detail {
  overflow-y: auto;
}
.vivaldi-settings .setting-section .setting-mailing-lists .detail-toolbar {
  background-color: var(--colorBg);
}
.vivaldi-settings .setting-section .setting-mailing-lists .detail-toolbar input {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  max-width: 85%;
}
.vivaldi-settings .setting-mail-account.master-detail {
  min-height: 446px;
}
.vivaldi-settings .setting-mail-account .pop-how-many-days .pop-how-many-days-input {
  width: 3em;
  height: auto;
  margin-left: 9px;
  padding: 1px 6px;
}
.vivaldi-settings .setting-mail-account .pop-how-many-days .pop-how-many-days-input[disabled] + span {
  opacity: 0.5;
}
.vivaldi-settings .setting-mail-account .detail-content {
  display: flex;
  position: relative;
  flex-direction: column;
}
.vivaldi-settings .setting-mail-account .detail-content .toolbar {
  margin-bottom: 18px;
}
.vivaldi-settings .setting-mail-account .detail-content .unlimited {
  margin-top: auto;
}
.vivaldi-settings .setting-mail-account .detail-content .setting-group-block .setting-group {
  margin-bottom: 18px;
}
.vivaldi-settings .setting-mail-account .detail-content .mail-identity {
  grid-row: span 4;
}
.vivaldi-settings .setting-mail-account .detail-content .mail-identity .mail-signature {
  margin-top: 12px;
}
.vivaldi-settings .setting-mail-account .detail-content .mail-identity .mail-signature .editor-html {
  border-radius: var(--radius);
  border: 1px solid var(--colorBorder);
}
.vivaldi-settings .setting-mail-account .detail-content .mail-identity .mail-signature .editor-html-toolbar {
  padding: 6px 12px;
}
.vivaldi-settings .setting-mail-account .detail-content h2 {
  text-transform: initial;
  font-size: 16px;
  border-bottom: none;
  padding-bottom: 0;
}
.vivaldi-settings .setting-mail-account .detail-content .mail-setup-description {
  line-height: calc(1.2 * 1.3);
  font-size: 13px;
}
.vivaldi-settings .setting-mail-account-form .incoming-server-label {
  width: calc(75% - 6px);
  flex: 1;
}
.vivaldi-settings .setting-mail-account-form .outgoing-server-label {
  width: calc(50% - 6px);
  flex: 1;
}
.vivaldi-settings .setting-mail-account-form .port-label {
  width: 25%;
}
.vivaldi-settings .setting-mail-filters .setting-group-unlimited {
  padding-bottom: 12px;
}
.vivaldi-settings .setting-mail-filters .detail-toolbar {
  background-color: var(--colorBg);
  border-bottom-right-radius: var(--radius);
}
.vivaldi-settings .setting-mail-filters .setting-single {
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  gap: 6px;
}
.vivaldi-settings .setting-mail-filters .mail-query-filters .category {
  background-color: var(--colorBg);
  border: 1px solid var(--colorBg);
  border-radius: var(--radius);
  margin-top: 6px;
  padding: 6px 12px;
  line-height: 2em;
}
.theme-dark .vivaldi-settings .setting-mail-filters .mail-query-filters .category {
  background-color: var(--colorBgDark);
  border-color: var(--colorBgDark);
}
.vivaldi-settings .setting-mail-filters .mail-query-filters .category .content-all-or-any {
  display: block;
  margin-bottom: 12px;
}
.vivaldi-settings .setting-mail-filters .mail-query-filters .category .content-all-or-any span {
  margin-right: 6px;
}
.vivaldi-settings .setting-mail-filters .mail-query-filters .category .conditions {
  display: grid;
  gap: 6px;
}
.vivaldi-settings .setting-mail-filters .mail-query-filters .category .conditions .condition {
  background-color: var(--colorBgDark);
  border: 1px solid var(--colorBorderSubtle);
  border-radius: var(--radius);
  display: flex;
  gap: 6px;
  padding: 6px;
  flex-wrap: wrap;
}
.vivaldi-settings .setting-mail-filters .mail-query-filters .category .conditions .condition > input[type=text] {
  flex-grow: 1;
}
.vivaldi-settings .setting-mail-filters .mail-query-filters .category .conditions .condition .error svg {
  margin-top: 6px;
  width: 16px;
  height: 16px;
  fill: var(--colorErrorBg);
}
.vivaldi-settings.dialog-mailing-lists {
  grid-template-columns: 1fr;
  background-color: var(--colorBgLight);
}
.vivaldi-settings.dialog-mailing-lists .detail {
  border-radius: initial;
}
.vivaldi-settings.dialog-mail-filters {
  grid-template-columns: 1fr;
  height: 100%;
  background-color: var(--colorBgLight);
}
.vivaldi-settings.dialog-mail-filters .setting-section {
  overflow: auto;
}
.vivaldi-settings.dialog-mail-filters .detail,
.vivaldi-settings.dialog-mail-filters .detail-toolbar {
  border-radius: initial;
}
.vivaldi-settings .menu-lists {
  display: flex;
  flex-wrap: wrap;
  max-width: 660px;
}
.vivaldi-settings .menu-lists .menu-items,
.vivaldi-settings .menu-lists .menu-commands {
  flex: 0 0 50%;
  max-width: 50%;
  margin-bottom: 0;
}
.vivaldi-settings .menu-lists .menu-items .vivaldi-tree,
.vivaldi-settings .menu-lists .menu-commands .vivaldi-tree {
  min-height: 300px;
  max-height: 300px;
  border: 1px solid var(--colorBorder);
}
.vivaldi-settings .menu-lists .menu-items .vivaldi-tree .title,
.vivaldi-settings .menu-lists .menu-commands .vivaldi-tree .title {
  padding: 0;
}
.vivaldi-settings .menu-lists .info {
  max-width: 660px;
}
.vivaldi-settings .menu-lists .menu-items > .vivaldi-tree {
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
}
.vivaldi-settings .menu-lists .menu-commands > .vivaldi-tree {
  border-left-width: 0;
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.vivaldi-settings .setting-single + .menu-lists {
  margin-top: 12px;
}
.vivaldi-settings .Setting--GeoLocation {
  margin-top: 12px;
  min-height: 340px;
}
.vivaldi-settings .Setting--GeoLocation label {
  width: 100%;
}
.vivaldi-settings .Setting--GeoLocation .VivaldiSelector {
  width: 458px;
  max-width: 100%;
}
.vivaldi-settings .Setting--GeoLocation .detail-content {
  overflow: visible;
}
.vivaldi-settings .setting-search-engine.master-detail {
  position: relative;
  min-height: 316px;
  height: auto;
  max-height: 504px;
  margin-bottom: 6px;
}
.vivaldi-settings .setting-search-engine.master-detail .setting-group {
  margin-bottom: 6px;
}
.vivaldi-settings .master-detail.setting-mail-filters {
  height: 600px;
}
.vivaldi-settings .master-detail.setting-mailing-lists {
  height: 400px;
}
.vivaldi-settings .master-detail.setting-rss-accounts {
  height: 300px;
}
.vivaldi-settings .Setting--ChainedCommand {
  min-height: 400px;
  max-width: 1320px;
  height: unset;
}
.vivaldi-settings .Setting--ChainedCommand .detail-content {
  overflow: unset;
}
.vivaldi-settings .setting-group.setting-cookies .cookie-list {
  max-width: 660px;
  height: 620px;
  border: 1px solid var(--colorBorder);
}
.vivaldi-settings .setting-group.setting-cookies .cookie-list .cookie-items {
  height: 100%;
  margin-bottom: 0;
}
.vivaldi-settings .setting-group.setting-cookies .cookie-list .empty-cookie-items {
  margin: 6px;
}
.vivaldi-settings .setting-group.setting-cookies .count {
  opacity: 0.35;
  color: var(--colorBgDarker);
  background-color: var(--colorFg);
  height: auto;
  line-height: 1.2;
  padding: 0 4px;
  border-radius: 4px;
  font-size: 11.5px;
  font-weight: 700;
}
.vivaldi-settings .setting-group.setting-cookies button {
  display: flex;
  justify-content: flex-start;
  flex-direction: column;
  min-height: 28px;
  width: 100%;
  border-width: 0;
  border-radius: 0;
  background-color: var(--colorBgLight);
}
.vivaldi-settings .setting-group.setting-cookies button.even {
  background-color: var(--colorBg);
}
.vivaldi-settings .setting-group.setting-cookies button:hover .controls input.circular {
  transform: scale(1);
}
.vivaldi-settings .setting-group.setting-cookies button:hover .controls input.circular:hover {
  transform: scale(1.21);
}
.vivaldi-settings .setting-group.setting-cookies button:focus-visible {
  outline-offset: -2px;
}
.vivaldi-settings .setting-group.setting-cookies button .overview {
  display: grid;
  grid-template-columns: auto auto auto 1fr;
  align-items: center;
  text-align: left;
  width: stretch;
  min-height: 26px;
  position: relative;
  gap: 6px;
  padding-right: 24px;
}
.vivaldi-settings .setting-group.setting-cookies button .overview .controls {
  position: absolute;
  right: 0;
  top: 5px;
  margin: 0;
}
.vivaldi-settings .setting-group.setting-cookies button.secure .overview {
  background-image: url(/resources/pref-lock.svg);
}
.vivaldi-settings .setting-group.setting-cookies button .detail,
.vivaldi-settings .setting-group.setting-cookies button .info {
  animation: dropfade 100ms cubic-bezier(0, 0, 0.25, 1);
  transform-origin: top;
  max-width: unset;
  text-wrap: wrap;
  margin: 0;
  width: 100%;
}
.vivaldi-settings .setting-group.setting-cookies button .detail {
  display: flex;
  flex-wrap: wrap;
  gap: 3px;
  height: 28px;
  padding-right: 22px;
  text-align: left;
}
.vivaldi-settings .setting-group.setting-cookies button .detail a {
  display: inline-flex;
  align-items: center;
  width: var(--cookieWidth);
  height: 22px;
  border-radius: var(--radiusRounded);
  padding: 3px 3px 3px 6px;
  background-color: var(--colorHighlightBgAlpha);
  box-shadow: inset 0 0 0 1px var(--colorHighlightBgAlpha);
}
.vivaldi-settings .setting-group.setting-cookies button .detail a span {
  flex: 1;
  pointer-events: none;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.vivaldi-settings .setting-group.setting-cookies button .detail a .circular {
  border-radius: inherit;
  background-color: var(--colorFgFadedMost);
}
.vivaldi-settings .setting-group.setting-cookies button .detail a:active,
.vivaldi-settings .setting-group.setting-cookies button .detail a:focus {
  position: relative;
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  outline: none;
}
.vivaldi-settings .setting-group.setting-cookies button .detail a:active .circular,
.vivaldi-settings .setting-group.setting-cookies button .detail a:focus .circular {
  background-color: var(--colorHighlightFg);
}
.vivaldi-settings .setting-group.setting-cookies dl,
.vivaldi-settings .setting-group.setting-cookies dt {
  display: block;
}
.vivaldi-settings .setting-group.setting-cookies dt {
  float: left;
}
.vivaldi-settings .rocker-gesture-settings {
  display: flex;
  align-items: center;
}
.vivaldi-settings .rocker-gesture-settings-title {
  margin-right: 12px;
  margin-left: 6px;
}
.vivaldi-settings .rocker-gesture-settings-title {
  display: flex;
  gap: 6px;
}
@keyframes click {
  0% {
    opacity: 0.5;
  }
  60% {
    opacity: 0;
  }
}
#browser:not(.animation-off) .vivaldi-settings .rocker-gesture-settings-title:hover svg .lmb {
  opacity: 0;
  animation: click 1600ms linear 300ms infinite;
}
#browser:not(.animation-off) .vivaldi-settings .rocker-gesture-settings-title:hover svg .rmb {
  opacity: 0;
  animation: click 1600ms linear 500ms infinite;
}
#browser .keystrokes .controls {
  display: block;
  flex: 0 0 60%;
  min-width: 260px;
}
.settings-content .keystrokes {
  margin-bottom: 1em;
}
.keystrokes .keycombo {
  display: flex;
  justify-content: flex-end;
  align-items: baseline;
  margin: 0 0 3px;
}
.keystrokes .keycombo .multiinput:focus-within {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.keystrokes .keycombo .multiinput-group {
  flex-wrap: wrap;
}
.keystrokes .keycombo .multiinput-item.single {
  animation: pop 200ms ease-in;
}
.singlekeydisabled .keystrokes .keycombo .multiinput-item.single {
  display: none;
}
.keystrokes .keycombo .multiinput-item.singlefeatures {
  animation: pop 200ms ease-in;
}
.singlekeydisabledfeatures .keystrokes .keycombo .multiinput-item.singlefeatures {
  display: none;
}
.keystrokes .keycombo .multiinput-item[disabled] {
  opacity: 1;
  color: var(--colorFgFadedMore);
  background-color: var(--colorBgDark);
  box-shadow: inset 0 0 0 1px var(--colorBgDarker);
}
.keystrokes .keycombo p.info {
  animation: dropfade 200ms ease-in;
  margin: 6px 0;
}
.keystrokes .keycombo label {
  padding: 0 12px 0 0;
  text-align: right;
  line-height: 1.1;
}
.keystrokes .keycombo input[type='button'] {
  text-transform: capitalize;
  padding: 0 6px;
}
.keystrokes .keycombo input[type='button']:disabled {
  opacity: 1;
}
.keystrokes.singlekeydisabled .keycombo .item.single {
  opacity: 0.5;
}
.keystrokes.shortcutsdisabled .keycombo .item.regular {
  opacity: 0.5;
}
.keystrokes.shortcutsdisabled .keycombo .item.single {
  opacity: 0.5;
}
.browser-priority-list .controls {
  margin-bottom: 6px;
}
.browser-priority-list .multiinput-group {
  flex-wrap: wrap;
}
input.circular {
  border: none;
  background-image: none;
  mask-size: cover;
}
.controls input.circular {
  transform: scale(0);
}
.controls:hover input.circular,
.controls.focused input.circular,
.controls.active input.circular {
  transform: scale(1);
  box-shadow: none;
}
.controls input.circular:hover {
  transform: scale(1.2);
  transition-duration: 50ms;
}
input.circular:hover {
  background-image: none;
}
input.circular:focus-visible {
  transform: scale(1);
}
input.circular:active {
  transform: scale(1);
  background-color: var(--colorHighlightBg);
}
input.circular.add {
  mask-image: url('/resources/mask-add.svg');
}
input.circular.remove {
  mask-image: url('/resources/mask-remove.svg');
}
input.circular.clearkey {
  mask-image: url('/resources/mask-close.svg');
}
input.circular.showkey {
  mask-image: url('/resources/mask-eye.svg');
}
input.circular.restorekey {
  mask-image: url('/resources/mask-reload.svg');
}
input.circular.editkey {
  mask-image: url('/resources/mask-edit.svg');
}
input.circular.defaultkey {
  mask-image: url('/resources/mask-check.svg');
}
input.circular.morekey {
  mask-image: url('/resources/mask-more.svg');
}
input.circular.openkey {
  mask-image: url('/resources/mask-open.svg');
}
.controls {
  display: flex;
  gap: 6px;
}
.controls.focused .multiinput {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.controls.focused .multiinput .input[type='text']:focus {
  background-color: transparent;
  box-shadow: none;
}
.settings-startpage .master-detail .detail-content {
  padding-right: 0;
  padding-bottom: 0;
  padding-top: 30px;
  padding-left: 30px;
}
.settings-startpage .selectbox {
  width: 129px;
}
.settings-startpage .selectbox-image {
  width: 129px;
  height: 95.46px;
  background-size: cover;
}
.settings-startpage-custom {
  display: inline-block;
  vertical-align: top;
  margin-bottom: 24px;
  max-width: 153px;
}
.settings-startpage-custom > h3 {
  overflow-wrap: break-word;
  margin-right: 18px;
}
.settings-startpage-custom > .selectbox {
  display: block;
  margin-bottom: 6px;
}
.setting-single.left {
  float: left;
}
.max-columns {
  padding: 0 36px 0 12px;
}
.new-tab-page input.pad-top {
  margin-top: 5px;
}
.tab-min-width label {
  align-items: center;
}
.tab-min-width input[type='range'] {
  width: 130px;
  position: relative;
}
.tab-min-width input[type='range']:before {
  content: '';
  position: absolute;
  left: 7px;
  height: 6px;
  width: 123px;
  margin-top: 8px;
  opacity: 0.3;
  overflow: hidden;
  background-image: repeating-linear-gradient(90deg, var(--colorFg), var(--colorFg) 1px, transparent 1px, transparent 23.2px);
}
.vivaldi-settings .tab-stacking label {
  flex-wrap: wrap;
}
.vivaldi-settings .tab-stacking .img-setting {
  margin-top: 0;
}
.stacking-delay input[type='range'] {
  margin: 9px 0;
  width: 150px;
  position: relative;
}
.stacking-delay input[type='range']:before {
  content: '';
  position: absolute;
  left: 7px;
  height: 6px;
  width: 143px;
  margin-top: 8px;
  opacity: 0.3;
  overflow: hidden;
  background-image: repeating-linear-gradient(90deg, var(--colorFg), var(--colorFg) 1px, transparent 1px, transparent 34px);
}
.stacking-delay .stack-speed {
  width: 150px;
  display: flex;
  justify-content: space-between;
}
.gestures .gesture-map {
  display: flex;
  flex-wrap: wrap;
  max-width: 600px;
}
.gestures .gesture-map .gesture-list,
.gestures .gesture-map .gesture {
  margin: 0 12px 6px 0;
  background-color: var(--colorBgLightIntense);
  border-radius: var(--radius);
  overflow: hidden;
}
.gestures .gesture-map .gesture-list.active,
.gestures .gesture-map .gesture.active {
  outline: 2px solid #df4b2b;
  outline-offset: -1px;
}
.gestures .gesture-map .gesture-list {
  flex: 1;
  min-width: 222px;
  height: 202px;
  overflow-y: auto;
}
.gestures .gesture-map .gesture {
  width: 202px;
  height: 202px;
  border: 1px solid var(--colorBorder);
  background-color: var(--colorBg);
}
.gestures .record-gesture {
  --ToolbarItemGap: 6px;
}
.gestures .record-gesture select {
  margin: 0 6px 0 0;
}
.gestures .record-gesture .info {
  padding-right: 6px;
}
.gestures .add-gesture {
  display: flex;
  max-width: 600px;
}
.gestures .add-gesture div.save {
  flex: 0 0 202px;
  margin-right: 12px;
}
.gestures .add-gesture div.save input {
  margin: 3px 0;
}
.gestures .add-gesture div.save input[type='submit'] {
  margin-right: 6px;
}
.gestures .add-gesture .alert {
  margin: 6px 0;
}
#browser .tolerance .gesture-preview {
  max-width: 130px;
  margin: 12px 0 6px;
  text-align: center;
  font-size: 11.5px;
}
#browser .tolerance .gesture-preview .meter,
#browser .tolerance .gesture-preview .meter-bg {
  display: block;
  position: relative;
  height: 3px;
  background-color: var(--colorFgFadedMore);
  margin: 0 auto 3px;
}
#browser .tolerance .gesture-preview .meter:after,
#browser .tolerance .gesture-preview .meter-bg:after,
#browser .tolerance .gesture-preview .meter:before,
#browser .tolerance .gesture-preview .meter-bg:before {
  content: '';
  position: absolute;
  width: 1px;
  height: 7px;
  background-color: var(--colorFgFadedMore);
  top: -2px;
}
#browser .tolerance .gesture-preview .meter:after,
#browser .tolerance .gesture-preview .meter-bg:after {
  right: 0;
}
#browser .tolerance .gesture-preview .meter:before,
#browser .tolerance .gesture-preview .meter-bg:before {
  left: 0;
}
#browser .tolerance .gesture-preview .meter-bg {
  width: 100px;
  margin-bottom: -3px;
  opacity: 0.4;
}
#browser .tolerance label {
  align-items: center;
}
#browser input.button-wrap {
  text-wrap: auto;
  height: auto;
  padding-top: 5px;
  padding-bottom: 5px;
}
#browser .setting-startup-specific-pages {
  animation: dropfade 300ms cubic-bezier(0, 0, 0.25, 1);
}
#browser .setting-startup-specific-pages .setting-single {
  display: flex;
}
#browser .setting-startup-specific-pages .setting-single .edit {
  flex: 1;
}
#browser .setting-startup-specific-pages .setting-single .circular {
  margin-top: 3px;
  transform: scale(1);
}
#browser .setting-startup-specific-pages .setting-single .circular:hover {
  transform: scale(1.21);
}
#browser .setting-startup-specific-pages .setting-flexgroup {
  flex-wrap: wrap;
  padding-bottom: 0;
}
#browser .setting-startup-specific-pages .setting-flexgroup .setting-single-noflex,
#browser .setting-startup-specific-pages .setting-flexgroup .setting-single-flex {
  margin: 0 6px 6px 0;
}
.saved-passwords {
  margin: 12px 0;
}
.saved-passwords .saved-passwords-tree {
  border: 1px solid var(--colorBorder);
  margin: 12px 0 6px;
  overflow: hidden;
  max-width: 1392px;
  max-height: 340px;
}
.saved-passwords .saved-passwords-tree .vivaldi-tree .VivaldiList {
  height: 100% !important;
  max-height: 317px;
}
.saved-passwords .saved-passwords-tree .tree-row > div {
  display: flex;
  align-items: center;
}
.saved-passwords .saved-passwords-tree .tree-row label,
.saved-passwords .saved-passwords-tree .tree-row > div:last-of-type {
  padding: 0;
  margin: 0;
  flex: 1;
}
.saved-passwords .saved-passwords-tree .site-icon {
  flex: 0 0 16px;
  margin: auto 0 auto 6px;
}
.saved-passwords .saved-passwords-tree span {
  margin-left: 6px;
}
.saved-passwords .saved-passwords-tree .listcontrol {
  width: 16px;
  height: 16px;
  margin: auto 18px auto auto;
  padding: 0;
  background-color: transparent;
  border: unset;
}
.saved-passwords .saved-passwords-tree .listcontrol svg {
  width: 16px;
  height: 16px;
  fill: currentColor;
  stroke-width: 0;
}
#browser.hasfocus .saved-passwords .saved-passwords-tree .listcontrol svg {
  fill: currentColor;
}
.saved-passwords li:hover input[type='button'] {
  transform: scale(1);
}
.saved-passwords .controls {
  padding-right: 3px;
}
.doh-providers .select-wrapper.select-wrapper,
.doh-providers .FormFeedback {
  margin-top: 6px;
}
.doh-providers .server-input {
  display: flex;
  flex-direction: column;
  gap: 0;
}
.doh-providers .FormFeedback,
.doh-providers .server-input input {
  width: 75%;
  max-width: 75%;
  margin: 6px auto 6px 0;
}
.doh-providers .FormFeedback.valid,
.doh-providers .server-input input.valid {
  background-image: url(/resources/check-selected.png);
  background-size: 16px;
  background-repeat: no-repeat;
  background-position: right 3px center;
}
.font-slider {
  display: flex;
  flex-direction: column;
  gap: 6px;
}
.font-slider label {
  display: grid;
  grid-template-columns: 1.2fr 2.8fr;
  align-items: center;
}
.font-slider label span:first-of-type {
  text-align: right;
}
.font-slider .fake-dataset {
  position: relative;
  width: 55px;
}
.font-slider .fake-dataset input[type='number'] {
  width: 30px;
  position: relative;
  z-index: 1;
  border-radius: 0;
  border-color: transparent;
  background-color: transparent;
  box-shadow: none;
  padding: 0 0 0 9px;
  margin-top: -1px;
  opacity: 0;
  cursor: text;
}
.font-slider .fake-dataset input[type='number']:focus {
  opacity: 1;
  outline: unset;
}
.font-slider .fake-dataset input[type='number']:focus + .select-wrapper select {
  color: transparent;
}
.font-slider .fake-dataset .select-wrapper {
  position: absolute;
  width: 55px;
  left: 0;
}
.font-slider .fake-dataset .select-wrapper select:disabled {
  color: transparent;
}
.font-slider .fake-dataset:focus-within select {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.font-face-list {
  display: flex;
  flex-direction: column;
}
.font-face-list label {
  display: grid;
  grid-template-columns: 1.2fr 2.8fr;
  align-items: baseline;
}
.font-face-list label span {
  text-align: right;
}
#browser .accept-language-list {
  max-width: 350px;
}
#browser .accept-language-list .master-detail {
  height: 140px;
}
.capture-name-template input[type='text'] {
  width: 100%;
}
.capture-name-template .info span[draggable] {
  display: inline-block;
  background-color: var(--colorFgFaded);
  color: var(--colorBg);
  padding: 3px 6px;
  margin: 0 3px 3px 0;
  border-radius: 3px;
  margin-bottom: 3px;
}
.capture-name-template .info + .info {
  margin-bottom: 0;
}
#browser .max-bookmarks {
  display: inline-grid;
  grid-template-columns: repeat(3, auto);
  align-items: center;
  gap: 6px;
  margin: -3px 0 3px;
}
#browser .max-bookmarks label {
  align-items: center;
}
#browser .max-bookmarks input[type='checkbox'] {
  margin-bottom: auto;
}
#browser .max-bookmarks input[type='number'] {
  margin-top: auto;
  width: 3em;
  padding: 2px 1px 2px 4px;
  height: auto;
}
.edit.active {
  fill: var(--colorHighlightBg);
}
.theme-schedule-timeline {
  position: relative;
  margin-top: 34px;
  margin-bottom: 12px;
  margin-left: 24px;
  margin-right: 24px;
  height: 28px;
  max-width: 1100px;
  font-size: 11.5px;
}
.theme-schedule-timeline + .toolbar {
  margin-left: 24px;
}
.theme-schedule-timeline .theme-schedule-timeslice {
  position: absolute;
  height: 100%;
  width: 100%;
}
.theme-schedule-timeline .theme-schedule-timeslice:first-of-type select {
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
}
.theme-schedule-timeline .theme-schedule-timeslice:last-of-type select {
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.theme-schedule-timeline .theme-schedule-timeslice select {
  position: absolute;
  width: 100%;
  border-radius: 0;
  text-indent: 3px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  border-color: var(--colorBorderIntense);
  background-color: var(--colorBg);
  background-image: unset !important;
  box-shadow: 0 -3px var(--colorAccentBg) inset;
  padding-right: 16px;
}
.theme-schedule-timeline .theme-schedule-timeslice select:hover {
  background-color: var(--colorBgDark);
}
.theme-schedule-timeline .theme-schedule-timeslice select:focus {
  outline-offset: 0;
}
.theme-schedule-timeline .theme-schedule-timeslice .timeslice-bubble {
  position: absolute;
  cursor: col-resize;
  width: 50px;
  background-color: var(--colorBgLightIntense);
  text-align: center;
  font-weight: 500;
  margin-left: -25px;
  left: 0;
  padding: 3px 0;
  bottom: 40px;
  border-radius: var(--radiusRounded);
  box-shadow: 0 0 0 1px var(--colorBorder), 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.schedule-disabled.theme-schedule-timeline .theme-schedule-timeslice .timeslice-bubble {
  pointer-events: none;
  box-shadow: 0 0 0 1px var(--colorBorder);
}
.theme-schedule-timeline .theme-schedule-timeslice .timeslice-bubble:before,
.theme-schedule-timeline .theme-schedule-timeslice .timeslice-bubble:after {
  content: '';
  position: absolute;
  bottom: -12px;
  left: 50%;
  margin-left: -6px;
  border: 6px solid transparent;
}
.theme-schedule-timeline .theme-schedule-timeslice .timeslice-bubble:before {
  border-top-color: var(--colorBorderIntense);
  margin-bottom: -1px;
}
.theme-schedule-timeline .theme-schedule-timeslice .timeslice-bubble:after {
  border-top-color: var(--colorBgLightIntense);
}
.theme-schedule-timeline .theme-schedule-timeslice .theme-schedule-timeslice-indicator {
  position: absolute;
  bottom: 0;
  z-index: 1;
}
.theme-schedule-timeline .theme-schedule-timeslice .theme-schedule-timeslice-indicator .theme-schedule-timeslice-draghandle {
  cursor: col-resize;
  position: absolute;
  left: -5px;
  width: 10px;
  bottom: -3px;
  padding: 0;
  height: 36px;
  border-color: var(--colorBorderIntense);
}
.schedule-disabled.theme-schedule-timeline .theme-schedule-timeslice .theme-schedule-timeslice-indicator .theme-schedule-timeslice-draghandle {
  opacity: 1;
}
.theme-schedule-timeline .theme-schedule-timeslice.timeslice-selected {
  border-radius: var(--radius);
  box-shadow: 0 0 0 4px var(--colorBgDarker);
  background-color: var(--colorBgDarker);
}
.theme-schedule-timeline .theme-schedule-timeslice.timeslice-selected .timeslice-bubble {
  z-index: 1;
}
.theme-schedule-timeline .theme-schedule-timeslice.timeslice-selected .theme-schedule-timeslice-container {
  border-color: var(--colorHighlightBg);
}
.theme-schedule-timeline .theme-schedule-now-indicator {
  position: absolute;
  bottom: 0;
  padding-bottom: 37px;
  width: 50px;
  margin-left: -25px;
  text-align: center;
  color: var(--colorFgFadedMost);
  font-weight: 500;
  pointer-events: none;
}
.theme-schedule-timeline .theme-schedule-now-indicator:after {
  content: '';
  position: absolute;
  left: 50%;
  width: 1px;
  z-index: 1;
  background-color: var(--colorFgAlpha);
  bottom: -6px;
  height: 40px;
}
.theme-schedule-timeline.schedule-disabled {
  opacity: 0.6;
  filter: grayscale(0.75);
}
.master-detail .TabbedView {
  border: 0;
  max-width: unset;
}
.master-detail .TabbedView-List {
  padding: 6px 18px;
}
.master-detail .TabbedView-Content {
  padding: 18px 6px 6px 18px;
  scrollbar-gutter: stable;
}
.list-priority .master-detail {
  height: auto;
}
.list-priority .master-detail .master-items {
  overflow: visible;
}
.list-priority .master-detail .master-items button:first-of-type {
  border-top-left-radius: inherit;
  border-top-right-radius: inherit;
}
.list-priority .master-detail .master-items:only-child button:last-of-type {
  border-bottom-left-radius: inherit;
  border-bottom-right-radius: inherit;
}
.list-priority .master-detail .hint-position {
  flex: 1;
  top: -6px;
}
.list-priority .master-detail .HintTooltip__content {
  position-area: top span-left;
}
.list-priority .master-detail .HintTooltip__content:after {
  right: 1px;
}
.list-priority .master-detail .item-dragged .HintTooltip--Visible:after,
.list-priority .master-detail .item-dragged .HintTooltip__content {
  display: none;
  content: unset;
}
.ChainedCommand {
  display: flex;
  flex-direction: column;
  gap: 6px;
  margin: 12px 0;
}
.ChainedCommand-Item {
  position: relative;
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  gap: 6px;
  align-items: baseline;
  background-color: var(--colorBgDark);
  border-radius: var(--radius);
  padding: 12px;
}
.ChainedCommand-Item--Over {
  background-color: var(--colorBgInverser);
}
.ChainedCommand-Item--Over > * {
  pointer-events: none;
}
.ChainedCommand-Item[draggable='true']:after {
  content: '';
  position: absolute;
  top: 0;
  width: 60px;
  height: 6px;
  background-color: var(--colorBorder);
  left: calc(50% - 30px);
  border-bottom-left-radius: 6px;
  border-bottom-right-radius: 6px;
  cursor: ns-resize;
}
.ChainedCommand-Item .VivaldiSelector {
  width: unset;
  margin: 0;
}
.ChainedCommand-Item .floating-label {
  min-width: 180px;
  flex: 1;
  cursor: inherit;
}
.ChainedCommand-Item .floating-label > span {
  font-size: 11.5px;
  color: var(--colorFgFadedMore);
}
.ChainedCommand-Item--Title,
.ChainedCommand-Item--Parameter {
  display: flex;
  flex: 1;
}
#app .ChainedCommand-Item .floating-input {
  padding-right: 6px;
  width: 100%;
}
.ChainedCommand-Item--Delete {
  position: absolute;
  right: 6px;
}
.ChainedCommand-Item--Controls {
  display: flex;
  position: absolute;
  right: 6px;
  top: 6px;
  transform: scale(0.8);
  transform-origin: center right;
}
.ChainedCommand-Item .FormButton {
  padding: 6px;
}
.ChainedCommand-Item .FormButton svg {
  width: 16px;
  height: 16px;
}
.actionlog {
  z-index: 0;
  display: flex;
  flex-direction: column;
  flex: 1;
  padding: 12px 24px;
  color: var(--colorFg);
  background-color: var(--colorBg);
}
.actionlog h2 {
  padding: 12px 0;
}
.actionlog .actionlogs {
  height: 100%;
  width: 100%;
  resize: none;
}
.privacy-link {
  margin-bottom: 12px;
}
.privacy-link a:focus-visible {
  outline: 2px solid var(--colorHighlightBgAlpha);
}
#browser .day-setting-grid span {
  margin-left: auto;
}
#browser .day-setting-grid label {
  display: inline-grid;
  grid-template-columns: auto 1fr;
  grid-gap: 6px;
  width: auto;
  margin: 0 0 6px;
}
#browser .day-setting-grid select {
  margin: 0;
}
.brand-masking .stack-column {
  flex-direction: column;
}
.brand-masking .pad-top {
  padding-bottom: 12px;
}
.brand-masking input {
  max-width: 50%;
}
.brand-masking .selectable {
  padding: 3px;
  background-color: var(--colorBgInverse);
  border: 1px solid var(--colorBgInverser);
  line-height: calc(1rlh + 6px);
}
.vivaldi-settings .tracker-warning {
  margin-bottom: 24px;
}
.WorkspaceLinkRouting.disabled {
  pointer-events: none;
  opacity: 0.65;
}
.WorkspaceLinkRouting-Description {
  position: sticky;
  top: 0;
  z-index: 1;
  background-color: var(--colorBgLightIntense);
  padding-bottom: 2px;
}
.WorkspaceLinkRouting-Item {
  background-color: var(--colorBgDark);
  border-radius: var(--radius);
  padding: 12px;
  margin-bottom: 6px;
  width: 100%;
  max-width: 475px;
  position: absolute;
  height: 110px;
}
.WorkspaceLinkRouting-Item .header {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  cursor: ns-resize;
}
.WorkspaceLinkRouting-Item .name {
  color: var(--colorFgFadedMore);
}
.WorkspaceLinkRouting-Item form {
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 6px;
  align-items: baseline;
}
.WorkspaceLinkRouting-Item form .inputs {
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  gap: 6px;
}
.WorkspaceLinkRouting-Item form .expression {
  flex: 1;
}
.WorkspaceLinkRouting-Item:after {
  content: '';
  position: absolute;
  top: 0;
  width: 60px;
  height: 6px;
  background-color: var(--colorBorder);
  left: calc(50% - 30px);
  border-bottom-left-radius: 6px;
  border-bottom-right-radius: 6px;
  cursor: ns-resize;
}
.WorkspaceLinkRouting-DragArea {
  max-width: calc(475px + var(--scrollbarWidth));
  padding: 4px 0;
  overflow: auto;
}
.CardDisplay {
  display: inline-flex;
  width: 220px;
  background-color: var(--colorBgDark);
  border-radius: var(--radius);
  padding: 12px;
  margin: 0 18px 6px 0;
  gap: 12px;
  position: relative;
}
.CardDisplay-Details {
  display: flex;
  flex-direction: column;
}
.CardDisplay-Label {
  font-weight: 600;
  text-transform: uppercase;
}
.CardDisplay-Number,
.CardDisplay-Expiration {
  font-family: monospace;
}
.CardDisplay-Date {
  display: flex;
  gap: 6px;
}
#app .CardDisplay-Edit {
  height: auto;
  padding: 0 6px;
  margin: 0;
  border: none;
  background: transparent;
  position: absolute;
  right: -6px;
  top: 50%;
  transform: translateY(-50%) rotate(90deg);
  transform-origin: center;
  font-size: large;
  font-weight: 900;
  line-height: 1;
  opacity: 0.4;
  border-radius: var(--radiusRounded);
}
#app .CardDisplay-Edit:hover {
  opacity: 1;
}
.CardDisplay .VivaldiSvgIcon svg {
  height: auto;
  margin-bottom: auto;
}
.Address.CardDisplay {
  flex-direction: column;
  gap: 0;
  white-space-collapse: preserve-breaks;
}
#modal-bg.float.card {
  width: 300px;
  min-width: unset;
}
#modal-bg.float.card,
#modal-bg.float.address {
  top: 50%;
  transform: translate(0, -50%);
  max-height: 65dvh;
}
#modal-bg.float.card .dialog-content,
#modal-bg.float.address .dialog-content {
  gap: 9px;
  overflow: auto;
}
#modal-bg.float.card form,
#modal-bg.float.address form {
  display: flex;
  flex-direction: column;
  overflow: hidden;
  max-height: 100%;
}
#modal-bg.float.card label,
#modal-bg.float.address label {
  flex-direction: column;
}
#modal-bg.float.card label p,
#modal-bg.float.address label p {
  margin: 0;
}
#modal-bg.float.card textarea,
#modal-bg.float.address textarea {
  resize: none;
}
.setting-site-permissions {
  height: auto;
  min-height: 565px;
  max-height: 680px;
  max-width: 1172px;
  margin-top: 12px;
}
.setting-site-permissions .setting-single-noflex {
  gap: 12px;
}
.setting-site-permissions .master-detail .master-items .item {
  display: flex;
}
.setting-site-permissions .master-detail .master-items .item span {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.setting-site-permissions .master-detail .master-items .item.item-selected {
  font-weight: bold;
}
.setting-site-permissions .master-detail .master-items .item .item-count {
  margin-left: auto;
}
.setting-site-permissions #modal-bg {
  max-width: 450px;
}
.setting-site-permissions .detail {
  container-type: inline-size;
  container-name: permissionlist;
  overflow: auto;
}
.setting-site-permissions .detail .detail-content {
  display: grid;
  flex: 0 0 auto;
  grid-template-columns: 1fr 1fr;
  gap: 6px 36px;
}
.setting-site-permissions .detail .detail-content h3 {
  grid-column: 1/-1;
  padding: 0;
  margin-top: -6px;
}
.setting-site-permissions .detail .detail-content.create {
  display: flex;
  flex-direction: column;
}
.setting-site-permissions .detail .detail-content.create label input {
  flex: 0 1 220px;
}
.setting-site-permissions .detail .detail-content .toolbar {
  display: flex;
  align-items: flex-start;
  margin-top: 6px;
  gap: 6px;
}
.setting-site-permissions .detail > .setting-single {
  padding: 0;
  margin: 0 18px 12px;
}
.setting-site-permissions .detail > .setting-single input[type='button'] {
  margin-top: 0;
}
.setting-site-permissions label {
  align-items: center;
  line-height: 1;
  /* Colorize icons by permission value */
}
.setting-site-permissions label .icon {
  width: 16px;
  height: 16px;
}
.setting-site-permissions label .icon .permission-denied {
  display: none;
}
.setting-site-permissions label .icon svg {
  pointer-events: none;
}
.setting-site-permissions label.changed .icon {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  box-shadow: 0 0 0 3px var(--colorHighlightBg);
  border-radius: 50%;
}
.setting-site-permissions label.changed .icon {
  background-color: var(--colorWarningBg);
  color: var(--colorWarningFg);
  box-shadow: 0 0 0 3px var(--colorWarningBg);
  border-radius: 50%;
}
.setting-site-permissions label.changed.allow .icon {
  background-color: var(--colorSuccessBg);
  color: var(--colorSuccessFg);
  box-shadow: 0 0 0 3px var(--colorSuccessBg);
  border-radius: 50%;
}
.setting-site-permissions label.changed.block .icon {
  background-color: var(--colorErrorBg);
  box-shadow: 0 0 0 3px var(--colorErrorBg);
  color: var(--colorErrorFg);
}
#app .setting-site-permissions label .select-wrapper {
  margin-left: auto;
}
#app .setting-site-permissions label .select-wrapper select {
  max-height: 25px;
}
.setting-site-permissions + .setting-single {
  display: flex;
  gap: 6px;
  margin-top: 12px;
  align-items: center;
}
.setting-site-permissions + .setting-single input[type] {
  margin-top: 0;
}
.setting-site-permissions .FormFeedback {
  margin-top: auto;
  margin-right: auto;
}
@container permissionlist (max-width: 570px) {
  .setting-site-permissions .detail .detail-content {
    grid-template-columns: 1fr;
  }
}
.selectbox-layout .selectbox-image {
  padding: 18px 12px;
  background: linear-gradient(180deg, #dadbf1 0%, #f5e7e7 100%);
}
.layouts-undo-banner {
  display: flex;
  flex-direction: row;
  align-items: center;
  border-radius: var(--radius);
  padding: 9px;
  gap: 12px;
  background-color: var(--colorHighlightBgAlpha);
}
button,
input,
select,
textarea,
input[type=text],
input[type=search],
input[type=password],
input[type=email],
input[type=url],
input[type=number],
input[type=radio],
input[type=date],
input[type=time],
input[type=checkbox],
input[type=button],
input[type=submit] {
  appearance: none;
  border-width: 1px;
  border-style: solid;
  border-color: var(--colorBorder);
  border-radius: var(--radius);
}
button:disabled,
input:disabled,
select:disabled,
textarea:disabled,
input[type=text]:disabled,
input[type=search]:disabled,
input[type=password]:disabled,
input[type=email]:disabled,
input[type=url]:disabled,
input[type=number]:disabled,
input[type=radio]:disabled,
input[type=date]:disabled,
input[type=time]:disabled,
input[type=checkbox]:disabled,
input[type=button]:disabled,
input[type=submit]:disabled {
  opacity: 0.65;
  pointer-events: none;
}
button:disabled + span,
input:disabled + span,
select:disabled + span,
textarea:disabled + span,
input[type=text]:disabled + span,
input[type=search]:disabled + span,
input[type=password]:disabled + span,
input[type=email]:disabled + span,
input[type=url]:disabled + span,
input[type=number]:disabled + span,
input[type=radio]:disabled + span,
input[type=date]:disabled + span,
input[type=time]:disabled + span,
input[type=checkbox]:disabled + span,
input[type=button]:disabled + span,
input[type=submit]:disabled + span {
  opacity: 0.65;
}
input,
select,
textarea,
.dateInput input[type=date],
.dateInput input[type=time] {
  background-color: var(--colorBgIntense);
  color: var(--colorFg);
}
input::-webkit-input-placeholder,
select::-webkit-input-placeholder,
textarea::-webkit-input-placeholder,
.dateInput input[type=date]::-webkit-input-placeholder,
.dateInput input[type=time]::-webkit-input-placeholder {
  color: inherit;
  opacity: 0.66;
  padding: 0;
  margin: 0;
  line-height: 1.3;
}
#browser.mac.theme-light input:focus::selection,
#browser.mac.theme-light textarea:focus::selection,
#browser.mac.theme-light [contenteditable]:focus::selection {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 25%, transparent);
}
#browser.mac.theme-dark input:focus::selection,
#browser.mac.theme-dark textarea:focus::selection,
#browser.mac.theme-dark [contenteditable]:focus::selection {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 50%, transparent);
}
#browser.win input:focus::selection,
#browser.win textarea:focus::selection,
#browser.win [contenteditable]:focus::selection,
#browser.linux input:focus::selection,
#browser.linux textarea:focus::selection,
#browser.linux [contenteditable]:focus::selection {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
input[type=tel],
input[type=text],
input[type=search],
input[type=email],
input[type=url],
input[type=date],
input[type=time],
input[type=password],
input[type=number] {
  height: 28px;
  padding: 0 max(6px, var(--radiusCap));
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 0 0 3px transparent;
}
input[type=tel]:disabled,
input[type=text]:disabled,
input[type=search]:disabled,
input[type=email]:disabled,
input[type=url]:disabled,
input[type=date]:disabled,
input[type=time]:disabled,
input[type=password]:disabled,
input[type=number]:disabled {
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.08) inset, 0 0 0 3px transparent;
}
.cardview input[type=tel]:disabled,
.cardview input[type=text]:disabled,
.cardview input[type=search]:disabled,
.cardview input[type=email]:disabled,
.cardview input[type=url]:disabled,
.cardview input[type=date]:disabled,
.cardview input[type=time]:disabled,
.cardview input[type=password]:disabled,
.cardview input[type=number]:disabled {
  box-shadow: unset;
}
input[type=search] {
  padding-right: 3px;
}
input[type=search]::-webkit-search-decoration {
  flex: 0;
}
input[type=search]::-webkit-search-cancel-button {
  appearance: none;
  content: '';
  display: block;
  width: 14px;
  height: 14px;
  border: 1px solid transparent;
  background-clip: content-box;
  background-color: var(--colorFgFadedMost);
  border-radius: 50%;
  mask-image: url(/resources/mask-close.svg);
  mask-origin: border;
}
input[type=search]::-webkit-search-cancel-button:hover {
  background-color: var(--colorFgFaded);
}
input[type=date]::-webkit-inner-spin-button {
  display: none;
}
input[type=number]::-webkit-inner-spin-button {
  appearance: none;
}
input[type=time] {
  position: relative;
}
input[type=time]::-webkit-calendar-picker-indicator {
  display: none;
}
input[type=time]::-webkit-inner-spin-button {
  appearance: none;
}
input[type=date]::-webkit-clear-button,
input[type=time]::-webkit-clear-button {
  display: none;
}
input[type=date]::-webkit-calendar-picker-indicator:hover,
input[type=time]::-webkit-calendar-picker-indicator:hover {
  background-color: inherit;
}
input[type=radio],
input[type=checkbox] {
  position: relative;
  width: 16px;
  height: 16px;
  min-width: 16px;
  min-height: 16px;
  background-color: var(--colorBg);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset;
  margin: unset;
}
input[type=radio]:active:not(:disabled),
input[type=checkbox]:active:not(:disabled) {
  filter: saturate(0.7) brightness(0.95);
}
.theme-dark input[type=radio],
.theme-dark input[type=checkbox] {
  background-image: linear-gradient(180deg, transparent -100%, var(--colorFgFadedMost) 200%);
}
.theme-dark input[type=radio]:active:not(:disabled),
.theme-dark input[type=checkbox]:active:not(:disabled) {
  filter: saturate(0.7) brightness(0.9);
}
.theme-dark input[type=radio]:focus,
.theme-dark input[type=checkbox]:focus {
  outline-offset: 0;
}
input[type=radio]:checked,
input[type=checkbox]:checked {
  border-color: var(--colorHighlightBg);
  background-image: none;
  box-shadow: none;
}
input[type=radio]:checked:focus,
input[type=checkbox]:checked:focus {
  outline-offset: 1px;
}
input[type=radio] {
  border-radius: var(--radiusRound);
}
input[type=radio]:active {
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, inset 0 0 0 0 var(--colorHighlightBg);
}
input[type=radio]:checked {
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, inset 0 0 0 5px var(--colorHighlightBg);
  border-width: 0;
  transition: box-shadow 200ms ease-out;
}
input[type=checkbox] {
  border-radius: var(--radiusRounded);
}
input[type=checkbox]:before,
input[type=checkbox]:after {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  transform-origin: 0 0;
  transition: transform 0ms linear 0ms;
  background-color: var(--colorBg);
}
input[type=checkbox]:before {
  transform: rotate(-45deg) translateY(45%) translateX(-30%) scaleX(0.2) scaleY(0);
}
input[type=checkbox]:after {
  transform: rotate(225deg) translateY(-25%) translateX(-85%) scaleX(0.2) scaleY(0);
  transition-delay: 0ms;
}
input[type=checkbox]:indeterminate:before {
  transform: rotate(0) translateY(37.5%) translateX(10%) scaleX(0.8) scaleY(0.2);
  transition-duration: 33.33333333ms;
}
input[type=checkbox]:checked {
  background-color: var(--colorHighlightBg);
}
input[type=checkbox]:checked:before {
  transform: rotate(-45deg) translateY(45%) translateX(-30%) scaleX(0.2) scaleY(0.4);
  transition-duration: 33.33333333ms;
}
input[type=checkbox]:checked:after {
  transform: rotate(225deg) translateY(-25%) translateX(-85%) scaleX(0.2) scaleY(0.7);
  transition-duration: 100ms;
  transition-delay: 33.33333333ms;
}
input.circular,
button.circular {
  border-radius: var(--radiusRound);
  width: 20px;
  height: 20px;
  padding: 1px 0px;
  background-color: var(--colorBgLightIntense);
}
input.circular:hover,
button.circular:hover {
  background-color: var(--colorBg);
}
input.circular svg,
button.circular svg {
  width: 16px;
  height: auto;
}
input[type=button]:not(.circular),
input[type=submit],
input[type=color],
.FormButton {
  height: 28px;
  padding: 0 18px;
  user-select: none;
  color: var(--colorFg);
  fill: currentColor;
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgDark));
}
input[type=button]:not(.circular):hover:not(:disabled),
input[type=submit]:hover:not(:disabled),
input[type=color]:hover:not(:disabled),
.FormButton:hover:not(:disabled) {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
input[type=button]:not(.circular):active:not(:disabled),
input[type=submit]:active:not(:disabled),
input[type=color]:active:not(:disabled),
.FormButton:active:not(:disabled) {
  background-image: linear-gradient(var(--colorBgDark), var(--colorBgDark));
}
input[type=button]:not(.circular)[type=submit],
input[type=submit][type=submit],
input[type=color][type=submit],
.FormButton[type=submit],
input[type=button]:not(.circular).primary,
input[type=submit].primary,
input[type=color].primary,
.FormButton.primary {
  color: var(--colorHighlightBg);
  border-color: var(--colorHighlightBg);
}
input[type=button]:not(.circular)[type=submit]:hover,
input[type=submit][type=submit]:hover,
input[type=color][type=submit]:hover,
.FormButton[type=submit]:hover,
input[type=button]:not(.circular).primary:hover,
input[type=submit].primary:hover,
input[type=color].primary:hover,
.FormButton.primary:hover,
input[type=button]:not(.circular)[type=submit]:active,
input[type=submit][type=submit]:active,
input[type=color][type=submit]:active,
.FormButton[type=submit]:active,
input[type=button]:not(.circular).primary:active,
input[type=submit].primary:active,
input[type=color].primary:active,
.FormButton.primary:active {
  color: var(--colorHighlightFg);
  background: var(--colorHighlightBg);
  border-color: var(--colorHighlightBg);
}
input[type=button]:not(.circular).danger,
input[type=submit].danger,
input[type=color].danger,
.FormButton.danger {
  color: var(--colorErrorBg);
  border-color: var(--colorErrorBg);
}
.theme-dark input[type=button]:not(.circular).danger,
.theme-dark input[type=submit].danger,
.theme-dark input[type=color].danger,
.theme-dark .FormButton.danger {
  color: color-mix(in srgb, var(--colorErrorBg), var(--colorFg));
}
input[type=button]:not(.circular).danger.danger:focus-visible,
input[type=submit].danger.danger:focus-visible,
input[type=color].danger.danger:focus-visible,
.FormButton.danger.danger:focus-visible {
  outline-color: var(--colorErrorBg);
}
input[type=button]:not(.circular).danger.danger:hover,
input[type=submit].danger.danger:hover,
input[type=color].danger.danger:hover,
.FormButton.danger.danger:hover,
input[type=button]:not(.circular).danger.danger:active,
input[type=submit].danger.danger:active,
input[type=color].danger.danger:active,
.FormButton.danger.danger:active {
  color: var(--colorErrorFg);
  background: var(--colorErrorBg);
  border-color: var(--colorErrorBg);
}
.FormButton.FormButton--WithIcon {
  gap: 6px;
  padding: 6px;
  display: flex;
  align-items: center;
  white-space: nowrap;
}
.FormButton.FormButton--WithIcon svg {
  width: 16px;
  height: 16px;
}
input[type=button].circular {
  width: 16px;
  height: 16px;
  flex: 0 0 16px;
  padding: 0;
  border: 0;
  margin: auto 0 auto 6px;
  background-repeat: no-repeat;
  background-position: 50% 50%;
  transition: transform 100ms linear;
  background-color: var(--colorFgFadedMost);
}
input[type=button].circular:hover {
  background-color: var(--colorFgFaded);
}
input[type=button].circular:focus-visible {
  outline: none;
  background-color: var(--colorHighlightBg);
}
.transparent {
  background-color: transparent;
  border: none;
}
span.InlineText {
  color: var(--colorHighlightBg);
  text-underline-position: from-font;
  cursor: pointer;
  text-decoration: underline;
}
span.InlineText:focus-visible {
  outline-offset: 1px;
  outline-style: dotted;
  border-radius: var(--radius);
}
input[type=color] {
  width: 22px;
  padding: 0;
  border-radius: var(--radius);
}
input[type=color]::-webkit-color-swatch-wrapper {
  width: 20px;
  padding: 2px;
}
input[type=color]::-webkit-color-swatch {
  border-radius: var(--radiusHalf);
}
input[type=range] {
  appearance: none;
  height: 4px;
  border: 0 solid;
  border-radius: var(--radiusRounded);
  vertical-align: 2px;
  background-color: var(--colorFgFadedMore);
}
input[type=range]::-webkit-slider-thumb {
  appearance: none;
  position: relative;
  width: 16px;
  height: 16px;
  padding: 0;
  border: 1px solid var(--colorFgFaded);
  border-radius: var(--radiusRound);
  background-color: var(--colorBgLight);
  box-shadow: 0 1px 1px rgba(0, 0, 0, 0.3);
}
.color-behind-tabs-off .toolbar-mainbar input[type=range]::-webkit-slider-thumb {
  background-color: var(--colorAccentBg);
  border-color: var(--colorAccentFg);
}
input[type=range]::-webkit-slider-thumb:hover {
  border-color: var(--colorFg);
  border-width: 2px;
}
input[type=range]::-webkit-slider-thumb:active {
  filter: brightness(1.1);
}
.color-behind-tabs-off .toolbar-mainbar input[type=range]::-webkit-slider-container {
  background-color: var(--colorAccentFgFaded);
  border-radius: 2px;
}
input[type=range].isblurred::-webkit-slider-thumb,
input[type=range]:disabled::-webkit-slider-thumb {
  opacity: 0.5;
}
input[type=range]:focus-visible {
  outline: unset;
}
input[type=range]:focus-visible::-webkit-slider-thumb {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
  border-color: var(--colorHighlightBg);
}
textarea {
  padding: 6px;
  border-radius: var(--radius);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 0 0 3px rgba(0, 0, 0, 0);
}
select {
  height: 28px;
  color: var(--colorFg);
  padding: 0 24px 0 max(6px, var(--radiusCap));
  position: relative;
  max-width: 100%;
}
select option {
  -webkit-text-fill-color: var(--colorFg);
  background-color: var(--colorBgIntenser);
}
select[multiple],
select[size] {
  padding: 0;
}
select[multiple] option,
select[size] option {
  padding: 3px 6px;
}
select[multiple] option:checked,
select[size] option:checked {
  background: var(--colorFgAlpha);
}
select[multiple]:focus option:checked,
select[size]:focus option:checked {
  -webkit-text-fill-color: var(--colorHighlightFg);
  background: linear-gradient(var(--colorHighlightBg), var(--colorHighlightBg));
}
select:not([multiple], [size]) {
  width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
select::-webkit-calendar-picker-indicator,
input[type=date]::-webkit-calendar-picker-indicator {
  opacity: 0;
}
select:enabled:not([multiple], [size]),
.VivaldiSelector:not(:focus-within, .VivaldiSelector--is-disabled) .VivaldiSelector__control {
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgDark));
}
select:enabled:not([multiple], [size]):hover:not(:disabled),
.VivaldiSelector:not(:focus-within, .VivaldiSelector--is-disabled) .VivaldiSelector__control:hover:not(:disabled) {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
select:enabled:not([multiple], [size]):active:not(:disabled),
.VivaldiSelector:not(:focus-within, .VivaldiSelector--is-disabled) .VivaldiSelector__control:active:not(:disabled) {
  background-image: linear-gradient(var(--colorBgDark), var(--colorBgDark));
}
.VivaldiSelector.VivaldiSelector--is-disabled .VivaldiSelector__control {
  background: var(--colorBg);
  opacity: 0.65;
}
.select-wrapper.select-wrapper {
  display: inline-flex;
  align-items: center;
  width: auto;
  min-width: 60px;
  max-width: 100%;
  position: relative;
  margin: 0;
}
.select-wrapper.select-wrapper:after {
  content: '';
  position: absolute;
  width: 16px;
  height: 16px;
  right: 6px;
  background-color: currentColor;
  mask-image: var(--svgArrow);
  mask-repeat: no-repeat;
  mask-position: 0 0;
  mask-size: 16px 16px;
  pointer-events: none;
}
.select-wrapper.select-wrapper:has(select:disabled):after {
  opacity: 0.65;
}
.inline-gap {
  padding: 0 6px;
}
.bookmark-folder-picker {
  position: relative;
}
.bookmark-folder-picker input[type=text] {
  pointer-events: none;
  position: absolute;
  z-index: 1;
  border: 1px solid transparent;
  background-clip: padding-box;
  box-shadow: none;
  width: 100%;
  max-width: calc(100% - 16px);
  background: transparent;
}
.bookmark-folder-picker select {
  color: transparent;
}
.bookmark-folder-picker option {
  color: var(--colorFg);
}
.multiinput {
  display: inline-flex;
  flex-wrap: wrap;
  flex: 1;
  width: 200px;
  min-height: 28px;
  padding-bottom: 2px;
  vertical-align: middle;
  border-width: 1px;
  border-style: solid;
  border-color: var(--colorBorder);
  border-radius: var(--radius);
  background-color: var(--colorBgIntense);
}
.multiinput-disabled {
  background-color: var(--colorBgAlpha);
  border-color: var(--colorBorderDisabled);
}
.multiinput .multiinput-item {
  flex: 0 1 auto;
  display: flex;
  max-width: calc(100% - (6px * 2 / 3));
  align-items: center;
  background-image: none;
  background-color: var(--colorHighlightBgAlpha);
  border-width: 0;
  box-shadow: inset 0 0 0 1px var(--colorHighlightBgAlpha);
  border-radius: calc(var(--radius) - 2.5px);
  min-height: 22px;
  margin-top: 2px;
  margin-left: 2px;
  padding-left: 6px;
}
.multiinput .multiinput-item > * {
  pointer-events: none;
}
.multiinput .multiinput-item .multiinput-item-primary {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.multiinput .multiinput-item .multiinput-item-primary + .multiinput-item-secondary {
  margin-left: 6px;
  opacity: 0.7;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.multiinput .multiinput-item:focus {
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  outline: unset;
}
.multiinput .multiinput-item:focus .multiinput-item-primary + .multiinput-item-secondary {
  opacity: 1;
}
.multiinput .multiinput-item .close {
  margin: 0 3px;
  pointer-events: auto;
}
.multiinput .multiinput-group {
  position: relative;
  flex: 1 1 0;
  display: flex;
}
.multiinput .multiinput-group > input[type=text] {
  min-height: 22px;
  margin-top: 2px;
  margin-right: 2px;
  margin-left: 2px;
  border-radius: 0;
}
.multiinput input[type=text],
.multiinput input[type=text]:focus {
  color: var(--colorFg);
  background-color: transparent;
  outline: 0;
  border: 0;
  padding: 0 2px;
  height: auto;
  box-shadow: none;
  min-width: 0;
  flex: 1;
}
.multiinput .multiinput-select {
  position: absolute;
  left: -8px;
  top: 28px;
  padding-top: 3px;
  padding-bottom: 6px;
  background-color: var(--colorBgIntense);
  border-radius: var(--radiusRounded);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  max-height: 300px;
  overflow: auto;
  z-index: 2;
}
.multiinput .multiinput-select:has(.multiinput-leading-only) {
  padding-bottom: 3px;
}
.multiinput .multiinput-select .multiinput-leading {
  border-bottom: var(--colorBgLighter) solid 1px;
  border-bottom: var(--colorBorder) solid 1px;
  margin-bottom: 6px;
  padding-bottom: 3px;
  display: flex;
  justify-items: center;
}
.multiinput .multiinput-select .multiinput-leading.multiinput-leading-only {
  margin-bottom: 0;
  padding-bottom: 0;
  border: initial;
}
.multiinput .multiinput-select .multiinput-option {
  display: flex;
  flex: 1;
  white-space: nowrap;
  cursor: default;
  user-select: none;
  padding: 2px 12px;
}
.multiinput .multiinput-select .multiinput-option.multiinput-option-disabled {
  opacity: 0.5;
}
.multiinput .multiinput-select .multiinput-option .multiinput-option-primary + .multiinput-option-secondary {
  padding-left: 36px;
  margin-left: auto;
}
.multiinput .multiinput-select .multiinput-option .multiinput-option-primary {
  max-width: 250px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.multiinput .multiinput-select .multiinput-option > div {
  display: flex;
  flex: 1;
}
.multiinput .multiinput-select .multiinput-option span {
  width: 16px;
  height: 16px;
  margin-right: 4px;
  color: var(--colorFg);
}
.multiinput .multiinput-select .multiinput-option:hover {
  background-color: var(--colorBgDarker);
}
.multiinput .multiinput-select .multiinput-option[data-selected] {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.multiinput .multiinput-select .multiinput-option[data-selected] span {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
#browser .Switch {
  display: inline-flex;
  vertical-align: baseline;
  position: relative;
}
@keyframes animate-progress {
  100% {
    background-position: 28px 0;
  }
}
#browser .Switch-Input {
  appearance: none;
  background-color: var(--colorBorderIntense);
  width: 28px;
  height: 16px;
  border: 0;
  border-radius: 14px;
  padding: 0;
  box-shadow: inset 0 2px 3px 0 #0003;
  transition: background-color 200ms ease-out;
}
.theme-dark#browser .Switch-Input {
  background-color: var(--colorFgFadedMost);
}
#browser .Switch-Input:before,
#browser .Switch-Input:after {
  content: unset;
}
#browser .Switch-Input:checked {
  background-color: var(--colorHighlightBg);
  transition-duration: 500ms;
}
#browser .Switch-Input:focus {
  outline-offset: 1px;
}
#browser .Switch-Button {
  appearance: none;
  padding: 0;
  margin: 0;
  transition: transform 200ms ease-out;
  width: 12px;
  height: 12px;
  border: 0;
  border-radius: 100%;
  background-color: var(--colorBg);
  background-clip: padding-box;
  box-shadow: 0 2px 1px 0 #0003;
  position: absolute;
  left: 2px;
  top: 2px;
  outline: none;
}
#browser .Switch-Button.dragging {
  transition: unset;
}
#browser .Switch--Disabled {
  pointer-events: none;
  opacity: 0.5;
}
#browser .Switch--Disabled .Switch-Input,
#browser .Switch--Disabled .Switch-Button {
  box-shadow: unset;
}
#browser .Switch .Switch-Input {
  box-shadow: inset 0 2px 3px 0 #0003, 0 0 0 1px var(--colorBg);
}
#browser .Switch--Progress-Done:after {
  content: '';
  position: absolute;
  inset: 0;
  z-index: -1;
  border-radius: 14px;
  background-size: 28px 28px;
  background-position: 0 0;
  background-image: repeating-linear-gradient(-45deg, var(--colorHighlightBgFaded) 0, var(--colorHighlightBgFaded) 5px, var(--colorHighlightBg) 5px, var(--colorHighlightBg) 10px);
  animation: animate-progress 1.5s linear;
  animation-iteration-count: 3;
}
#browser .Switch--Progress:after {
  content: '';
  position: absolute;
  inset: 0;
  z-index: -1;
  border-radius: 14px;
  background-size: 28px 28px;
  background-position: 0 0;
  background-image: repeating-linear-gradient(-45deg, var(--colorHighlightBgFaded) 0, var(--colorHighlightBgFaded) 5px, var(--colorHighlightBg) 5px, var(--colorHighlightBg) 10px);
  animation: animate-progress 1.5s linear;
  animation-iteration-count: infinite;
}
#browser .Switch--Progress .Switch-Input {
  background-color: transparent;
}
.PasswordInputWrapper {
  display: flex;
  position: relative;
}
.PasswordInputWrapper .PasswordInput {
  width: 100%;
  padding-right: 28px;
}
.PasswordInputWrapper .PasswordToggle {
  position: absolute;
  top: 6px;
  right: 6px;
  width: 16px;
  height: 16px;
  padding: 0;
  background: none;
  border: none;
  color: var(--colorFgFadedMost);
}
.PasswordInputWrapper .PasswordToggle:hover,
.PasswordInputWrapper input[type=text] + .PasswordToggle {
  color: inherit;
}
.floating-label.verified .PasswordInputWrapper .PasswordToggle {
  right: 24px;
}
.FormFeedback {
  position: relative;
  display: flex;
  flex-direction: column;
  margin: 12px 0;
  padding: 6px 6px 6px 30px;
  border-radius: var(--radius);
  animation: dropfade 200ms linear;
  background-color: var(--colorHighlightBgAlpha);
  border: 1px solid var(--colorHighlightBg);
  fill: var(--colorHighlightBg);
}
.FormFeedback:first-child {
  margin-top: 0;
}
.FormFeedback--error {
  background-color: var(--colorErrorBgAlpha);
  border-color: var(--colorErrorBg);
  fill: var(--colorErrorBg);
}
.FormFeedback--warning {
  background-color: var(--colorWarningBgAlpha);
  border-color: var(--colorWarningBg);
  fill: var(--colorWarningBg);
}
.FormFeedback--success {
  background-color: var(--colorSuccessBgAlpha);
  border-color: var(--colorSuccessBg);
  fill: var(--colorSuccessBg);
}
.FormFeedback-Icon {
  position: absolute;
  left: 6px;
}
.FormFeedback-Icon svg {
  width: 16px;
  height: 16px;
}
.FormFeedback .InlineText {
  display: contents;
}
.FormFeedback p:not(.info):last-of-type {
  margin: 0;
}
.RangeButtonInput {
  display: flex;
  align-items: center;
  gap: 12px;
  min-height: 28px;
}
.RangeButtonInput button {
  padding: 6px;
}
.RangeButtonInput svg {
  width: 16px;
  height: 16px;
}
.VivaldiSelector {
  position: relative;
  width: 262px;
  margin-right: 6px;
  height: 28px;
}
.VivaldiSelector__control {
  cursor: default;
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  align-items: center;
  position: relative;
  min-height: auto;
  border-radius: var(--radius);
  background-color: var(--colorBgIntense);
  border: 1px solid var(--colorBorder);
  transition: all 100ms;
}
.VivaldiSelector__control:hover {
  border: 1px solid var(--colorBorder);
}
.VivaldiSelector__control:focus-within {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.VivaldiSelector__control--is-focused {
  min-height: auto;
}
.VivaldiSelector__value-container {
  align-self: stretch;
  display: flex;
  flex: 1;
  flex-wrap: wrap;
  align-items: center;
  position: relative;
  overflow: hidden;
  padding: 0 6px 0 12px;
}
.VivaldiSelector__menu {
  top: 100%;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  padding: 4px;
  margin-bottom: 8px;
  margin-top: 4px;
  position: absolute;
  width: 100%;
  z-index: 1;
  background: var(--colorBgIntense);
  border-radius: var(--radiusCap);
}
.VivaldiSelector__menu-list {
  max-height: 170px;
  overflow-x: hidden;
  overflow-y: auto;
  position: relative;
  border-radius: var(--radiusHalf);
}
.VivaldiSelector__menu-notice {
  color: var(--colorFgFadedMore);
  padding: 6px 12px;
  text-align: center;
  box-sizing: border-box;
}
.VivaldiSelector__option {
  cursor: default;
  user-select: none;
  display: flex;
  align-items: center;
  height: 24px;
  line-height: 0.9;
  font-size: inherit;
  color: var(--colorFg);
  background-color: transparent;
  padding: 0 12px;
  border-radius: var(--radiusHalf);
}
.VivaldiSelector__option--is-focused,
.VivaldiSelector__option:active {
  background-color: var(--colorBgDark);
}
.mac .VivaldiSelector__option--is-focused,
.mac .VivaldiSelector__option:active,
.linux .VivaldiSelector__option--is-focused,
.linux .VivaldiSelector__option:active {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
}
.VivaldiSelector__placeholder {
  position: absolute;
  color: var(--colorFgFadedMore);
}
.VivaldiSelector__input-container {
  padding: 0 0 0 12px;
}
.VivaldiSelector__value-container .VivaldiSelector__input {
  flex: 1;
  color: var(--colorFg);
  box-shadow: none !important;
  max-height: 26px;
  border-radius: 0;
  background: transparent;
  border: none;
  padding: 0;
}
.VivaldiSelector__value-container .VivaldiSelector__input:focus-visible {
  box-shadow: none !important;
  outline: 0;
}
.VivaldiSelector__value-container .VivaldiSelector__clear-indicator {
  display: flex;
  width: 16px;
  height: 16px;
  background-color: var(--colorFgFadedMost);
  border-radius: 50%;
  mask-image: url(/resources/mask-close.svg);
}
.VivaldiSelector__value-container .VivaldiSelector__clear-indicator:hover {
  background-color: var(--colorFgFaded);
}
.VivaldiSelector__value-container .VivaldiSelector__dropdown-indicator {
  display: flex;
  max-width: 16px;
  padding: 8px;
  transition: color 150ms;
  mask-image: var(--svgArrow);
  background-color: currentColor;
}
#modal-bg.qc-modal {
  top: 25vh;
  min-width: auto;
}
#modal-bg.qc-modal > div {
  animation: dropfade 100ms cubic-bezier(0.2, 0.9, 0.6, 1);
  contain: content;
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.15), 0 28px 50px rgba(0, 0, 0, 0.18);
}
.quick-command-container {
  position: relative;
  width: 40em;
}
.quick-command-container input:focus {
  outline: 0;
  box-shadow: none;
  border-radius: 0;
}
.quick-command-container .quick-command-search,
.quick-command-container .quick-command-search-hint {
  height: auto;
  margin: 0;
  padding: 15px 12px 12px 36px;
  border: none;
  border-bottom: 1px solid var(--colorBgDark);
  box-shadow: none;
  font-size: 2em;
  width: 100%;
  font-weight: 300;
  border-top-right-radius: inherit;
  border-top-left-radius: inherit;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.quick-command-container .quick-command-search-hint {
  position: absolute;
  top: 0;
  left: 0;
  opacity: 0.45;
  padding-right: 40px;
}
.quick-command-container .quick-command-search {
  position: relative;
  background-color: transparent;
}
.quick-command-container .quick-command-tip {
  padding-top: 9px;
  padding-left: 9px;
  padding-right: 9px;
}
.quick-command-container .quick-command-tip-content {
  display: flex;
}
.quick-command-container .quick-command-tip-content .close-tip {
  height: 16px;
}
.quick-command-container .quick-command-tip-content .VivaldiSvgIcon svg {
  width: 16px;
}
.quick-command-container .quick-commands {
  position: relative;
  height: auto;
  overflow-x: hidden;
  overflow-y: auto;
  transition: max-height 100ms cubic-bezier(0.2, 0.9, 0.6, 1);
  background-color: var(--colorBg);
}
.quick-command-container .quick-commands .quick-command-sectionheader {
  padding: 0 6px 0 12px;
  opacity: 0.8;
  display: flex;
  align-items: center;
  font-weight: 600;
}
.quick-command-container .quick-commands .quick-command-sectionheader .QuickCommand-Title--Subtitle {
  margin: auto auto 0 6px;
  font-size: 10px;
  /* opacity: 0.45; */
}
.quick-command-container .quick-commands > ul {
  list-style: none;
}
.quick-command-container .quick-commands .quick-command {
  display: flex;
  align-items: center;
  padding: 0 6px 0 36px;
  white-space: nowrap;
}
.hasfocus .quick-command-container .quick-commands .quick-command[data-selected] {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.isblurred .quick-command-container .quick-commands .quick-command[data-selected] {
  background-color: var(--colorBgDark);
}
.quick-command-container .quick-commands .quick-command-favicon {
  flex: 0 0 16px;
  width: 16px;
  height: 16px;
  margin: auto 8px auto 0px;
}
.quick-command-container .quick-commands .quick-command-workspace-icon {
  flex: 0 0 16px;
  width: 16px;
  height: 16px;
  margin: auto 8px auto 0px;
}
.quick-command-container .quick-commands .quick-command-workspace-icon > svg {
  fill: var(--colorFgAlpha);
  stroke: var(--colorFgFaded);
}
.quick-command-container .quick-commands .quick-command-title,
.quick-command-container .quick-commands .quick-command-url {
  margin: auto 6px auto 0;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.quick-command-container .quick-commands .quick-command-title {
  flex: 1 0 50%;
}
.quick-command-container .quick-commands .quick-command-url {
  flex: 1 1 50%;
  opacity: 0.45;
}
.quick-command-container .quick-commands .quick-command-timestamp {
  color: var(--colorBg);
  background-color: var(--colorFgFadedMore);
  border-radius: 3px;
  font-size: 10px;
  line-height: 16px;
  margin: auto 6px;
  padding: 0 4px;
}
.hasfocus .quick-command-container .quick-commands .quick-command[data-selected] .quick-command-timestamp,
.hasfocus .quick-command-container .quick-commands .quick-command[data-selected] .item-count {
  background-color: var(--colorHighlightBgDark);
  font-weight: 400;
}
.isblurred .quick-command-container .quick-commands .quick-command[data-selected] .quick-command-timestamp,
.isblurred .quick-command-container .quick-commands .quick-command[data-selected] .item-count {
  color: var(--colorFg);
  background-color: var(--colorBgInverser);
}
.quick-command-container .quick-commands .quick-command-attachment {
  min-width: 16px;
  stroke-width: 0;
  fill: var(--colorFgFaded);
}
.hasfocus .quick-command-container .quick-commands .quick-command[data-selected] .quick-command-attachment {
  fill: var(--colorHighlightFg);
}
.quick-command-container .quick-commands input {
  display: none;
}
.quick-command-container .quick-commands.editing {
  border-bottom: none;
  padding: 0;
}
.quick-command-container .quick-commands.editing .edit {
  display: block;
  width: 200px;
  padding: 13px 17px 12px 17px;
  margin: 0 0 0 43px;
}
.quick-command-container .quick-commands.editing .view {
  display: none;
}
.quick-command-container .quick-commands-actions .quick-command-meta {
  margin: auto 0 auto auto;
}
.setting-group input#new-url {
  margin-left: 0;
  margin-top: 4px;
  margin-right: 10px;
  width: 180px;
}
.webview-settings .settings-content .settings-container .setting-group input + label {
  margin-right: 10px;
}
#searchSuggest {
  width: auto;
}
#searchSuggest .setting-single > .setting-single {
  margin-top: 4px;
  padding-left: 24px;
}
.setting-starterpack-engines {
  max-width: fit-content;
}
.setting-starterpack-engines .starter_pack_grid {
  display: grid;
  grid-template-columns: 22px auto 130px 1fr;
  gap: 6px 12px;
  align-items: center;
}
.setting-starterpack-engines .starter_pack_grid .header {
  font-weight: 600;
  padding-bottom: 6px;
}
.setting-starterpack-engines .starter_pack_grid input[type=checkbox] {
  margin-left: 6px;
}
.ThemeEditor {
  padding: 6px 6px 0 6px;
}
.ThemeEditor-Header {
  display: flex;
  flex-wrap: wrap;
  padding-bottom: 18px;
  gap: 6px;
}
.ThemeEditor-HeaderBasics {
  display: flex;
  flex-direction: column;
  flex: 0 1 300px;
  margin-right: auto;
  max-width: 460px;
  gap: 12px;
}
.ThemeEditor-HeaderBasics select {
  min-width: 100px;
}
.ThemeEditor-HeaderBasics .ThemeEditor-Name {
  display: flex;
  justify-content: center;
  gap: 12px;
  align-items: baseline;
}
.ThemeEditor-HeaderBasics .ThemeEditor-Name > input {
  flex: 1;
  width: 100%;
}
.ThemeEditor .selectbox {
  width: 125px;
}
.ThemeEditor .selectbox-image {
  width: 125px;
  height: 92.5px;
  background-size: cover;
  box-shadow: inset 0 0 0 1px var(--colorFgAlpha);
}
.ThemeEditor option[disabled] {
  font-weight: 600;
  font-variant: all-small-caps;
  filter: contrast(0.9);
}
.theme-dark .ThemeEditor option[disabled] {
  filter: contrast(0.85);
}
.ThemeEditor-Tabs-Library {
  max-width: 840px;
  overflow: auto;
}
.ThemeEditor-BackgroundList {
  display: flex;
  flex-wrap: wrap;
  align-items: flex-start;
  gap: 24px 18px;
  max-height: 380px;
  overflow: auto;
  scrollbar-gutter: stable;
  padding: 18px 0 12px 18px;
}
.ThemeEditor-BackgroundMeta {
  padding: 6px 12px;
  background-color: var(--colorBg);
  border-bottom: 1px solid var(--colorBorderSubtle);
}
.ThemeEditor-BackgroundMetaBasic,
.ThemeEditor-BackgroundMetaInfoBar {
  display: flex;
  width: 100%;
  gap: 6px;
  align-items: center;
}
.ThemeEditor-BackgroundMetaInfoBar {
  margin-top: 6px;
}
.ThemeEditor-BackgroundMeta select + span {
  margin-left: 12px;
}
.ThemeEditor-BackgroundCustomButton {
  margin-left: auto;
}
.ThemeEditorColors {
  margin-bottom: 12px;
  padding: 12px;
  background-color: var(--colorBg);
  display: flex;
  width: 100%;
  gap: 6px;
  border-bottom: 1px solid var(--colorBorderSubtle);
}
.ThemeEditorColors-Base {
  margin-right: 18px;
  border-right: 1px solid var(--colorBgDarker);
  padding-right: 24px;
}
.ThemeEditorColors-Accent > .setting-single {
  margin-top: 6px;
}
.Button-Set-Picker.unlimited .setting-single {
  display: inline-flex;
  align-items: center;
  gap: 0.5ch;
}
.Button-Set-Picker.unlimited .setting-single > label > span:first-child {
  margin-left: 0;
}
.Button-Manager {
  display: grid;
  grid-template-columns: 250px auto;
}
.Button-Selector select {
  width: 100%;
  height: 100%;
}
.Button-Selector optgroup {
  line-height: 28px;
}
.Button-Editor {
  overflow: hidden;
  padding: 0 0 0 18px;
  align-items: center;
}
.Button-Editor .button-textonly,
.Button-Editor .Button-Area > *:not(.Button-Area-Preview) .button-toolbar {
  pointer-events: none;
  margin: 0 auto 12px;
  background-color: var(--colorBgLight);
}
#app #browser .Button-Editor .Button-Area .button-toolbar {
  box-shadow: inset 0 0 0 1px var(--colorBorder);
}
#app #browser .Button-Editor .Button-Area .button-toolbar .button-title,
#app #browser .Button-Editor .Button-Area .button-toolbar .button-toolbar-menu-indicator {
  display: none;
}
#app #browser .Button-Editor .Button-Area .button-toolbar > button {
  border: unset;
  pointer-events: none;
  z-index: 1;
  padding: 0;
}
#app #browser .Button-Editor .Button-Area .button-toolbar > button svg,
#app #browser .Button-Editor .Button-Area .button-toolbar > button img {
  opacity: 1 !important;
}
#app #browser .Button-Editor .Button-Area .button-toolbar > button:disabled svg {
  opacity: 1;
}
.Button-Editor .info {
  margin: 0 0 12px;
}
.Button-Editor .droparea {
  padding: 12px 0;
  border-radius: var(--radius);
}
.Button-Editor .droparea:hover {
  background-color: var(--colorBgDarker);
}
.Button-Editor .droparea > * {
  pointer-events: none;
}
.Button-Editor .dragover {
  background-color: var(--colorBgDarker);
  box-shadow: inset 0 0 0 2px var(--colorHighlightBg);
}
.Button-Editor .dragover .button-toolbar {
  animation: wiggle 200ms linear infinite;
}
.Button-Editor .Button-Area {
  display: grid;
  grid-template-columns: 1fr 1fr;
  margin: 24px 0;
  text-align: center;
  justify-content: center;
  align-items: baseline;
}
.Button-Editor .Button-Area[inert=true] {
  opacity: 0.65;
}
.Button-Editor .Button-Area .workspace-popup .button-icon:not(.override) svg {
  width: 16px;
  height: 16px;
}
.Button-Editor .Button-Area-Preview .droparea.droparea {
  padding: 0;
}
.Button-Editor .Button-Area-Preview .button-toolbar {
  margin: 0 auto 12px;
  width: 112px;
  height: 112px;
}
.Button-Editor .Button-Area-Preview .button-toolbar:before {
  content: '';
  position: absolute;
  top: 24px;
  right: 24px;
  bottom: 24px;
  left: 24px;
  border: 1px dashed var(--colorFgFadedMost);
  opacity: 50%;
}
.Button-Editor .Button-Area-Preview svg,
.Button-Editor .Button-Area-Preview img {
  scale: 4;
  width: 28px;
  height: 28px;
}
.Button-Editor .Button-Area-Large .button-toolbar {
  margin: 0 auto;
  width: 28px;
  height: 28px;
}
.Button-Editor .Button-Area-Large .button-toolbar:before {
  content: '';
  position: absolute;
  top: 6px;
  right: 6px;
  bottom: 6px;
  left: 6px;
  border: 1px dashed var(--colorFgFadedMost);
  opacity: 50%;
}
.Button-Editor .Button-Area-Controls {
  display: flex;
  gap: 6px;
}
.Button-Editor .Button-Area .button-toolbar + .label {
  background: var(--colorFgFadedMost);
  color: var(--colorBg);
  margin: 0 auto 18px;
  padding: 0 6px;
  border-radius: 20px;
}
.Button-Editor .Button-Area div:empty,
.Button-Editor .Button-Area .button-badge {
  display: none;
}
.Button-Editor .Button-Area .toolbar-extensions {
  display: contents;
}
.Button-Editor .Button-Area .ClockButton .ClockIcon-AlarmBell {
  transform: none;
}
.ThemeEditorColorPicker {
  display: inline-block;
  margin-right: 6px;
  position: relative;
}
.ThemeEditorColorPicker-Label {
  width: 100%;
  padding-bottom: 3px;
  padding-top: 3px;
}
.ThemeEditorColorPicker-ColorInput.ThemeEditorColorPicker-ColorInput {
  appearance: none;
  width: 28px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  position: relative;
}
.ThemeEditorColorPicker-ColorInput.ThemeEditorColorPicker-ColorInput:focus {
  z-index: 1;
}
.ThemeEditorColorPicker-ColorInput.ThemeEditorColorPicker-ColorInput::-webkit-color-swatch-wrapper {
  padding: 0;
  width: 26px;
}
.ThemeEditorColorPicker-ColorInput.ThemeEditorColorPicker-ColorInput::-webkit-color-swatch {
  border-top-left-radius: calc(var(--radius) - 1px);
  border-bottom-left-radius: calc(var(--radius) - 1px);
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  border: none;
}
.ThemeEditorColorPicker-HexSymbol {
  position: absolute;
  height: 28px;
  left: 34px;
  bottom: 0;
  display: flex;
  align-items: center;
  color: var(--colorFgFadedMore);
  z-index: 2;
}
#browser .ThemeEditorColorPicker-HexSymbol {
  font-family: monospace;
}
.ThemeEditorColorPicker-HexInput.ThemeEditorColorPicker-HexInput {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  border-left: 0;
  max-width: 10ch;
  padding-left: 2ch;
  position: relative;
}
.ThemeEditorColorPicker-HexInput.ThemeEditorColorPicker-HexInput:focus {
  z-index: 1;
}
#browser .ThemeEditorColorPicker-HexInput.ThemeEditorColorPicker-HexInput {
  font-family: monospace;
}
#history-panel select {
  flex: 1;
}
#history-panel .title {
  flex: 1;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
#history-panel .title.link {
  cursor: pointer;
}
#history-panel .time {
  display: inline-block;
  min-width: 5ex;
  vertical-align: bottom;
  margin-right: 6px;
  text-align: right;
  font-variant-numeric: tabular-nums;
}
#history-panel .date-range {
  animation: dropfade 100ms cubic-bezier(0, 0, 0.25, 1);
  display: flex;
  flex: 2 0;
  flex-wrap: wrap;
  gap: 6px;
  margin-right: 0;
  min-width: 60%;
}
#history-panel .date-range label {
  display: flex;
  flex: 1;
  align-items: center;
  margin: 0 6px 6px 0;
}
#history-panel .date-range .dateInput {
  min-width: 100px;
  flex: 1;
  height: 28px;
  border-radius: var(--radius);
}
#history-panel section p {
  margin: 0 12px;
}
#history-panel .vivaldi-tree .tree-row {
  height: 100%;
  padding-inline: 3px;
  background-color: var(--colorBgLighter);
  border-radius: unset;
}
.theme-dark #history-panel .vivaldi-tree .tree-row {
  background-color: var(--colorBgDark);
}
#history-panel .vivaldi-tree .tree-row.folder {
  border-radius: var(--radius);
  grid-template-columns: 1fr;
}
#history-panel .vivaldi-tree .VivaldiList-Offset {
  padding: 3px;
  border-radius: var(--radius);
}
#history-panel .vivaldi-tree .tree-item:not(:first-child) .tree-row.folder {
  margin-top: 7px;
}
#history-panel .vivaldi-tree .tree-item .tree-row.folder {
  margin-top: 1px;
  padding-block: 3px;
  height: calc(var(--treeViewRowHeight) + 6px);
  border-radius: var(--radius);
}
#history-panel .vivaldi-tree .tree-item[data-expanded] .tree-row {
  border-bottom-left-radius: 0 !important;
  border-bottom-right-radius: 0 !important;
}
#history-panel .vivaldi-tree .tree-item:last-of-type {
  min-height: 31px;
  margin-bottom: 12px;
}
#history-panel .vivaldi-tree .tree-item:last-of-type label {
  margin-bottom: 3px;
}
#history-panel .vivaldi-tree .tree-row:has(.last-in-group) {
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
  padding-bottom: 3px;
}
.hasfocus #history-panel .vivaldi-tree .VivaldiList:focus-within .tree-row[data-selected] label {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
#history-panel .vivaldi-tree .tree-row[data-selected] {
  box-shadow: unset;
}
#history-panel .vivaldi-tree .tree-row[data-selected] label {
  border-inline: 3px solid transparent;
  border-radius: inherit;
  padding-inline: 3px;
}
#history-panel .vivaldi-tree .tree-row[data-selected].tree-row-selected--first label {
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
}
#history-panel .vivaldi-tree .tree-row[data-selected].tree-row-selected--last label {
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.startpage .history {
  flex-direction: column;
  overflow: hidden;
}
.startpage .history .navigation select {
  display: none;
}
.startpage .history .manager-content,
.startpage .history .manager-editor {
  display: flex;
  flex-direction: column;
  align-items: stretch;
  overflow: hidden;
}
.startpage .history .manager-editor {
  border: solid var(--colorBorder);
  border-width: 1px 1px 0 0;
}
.startpage .history .manager-editor span.heat {
  position: absolute;
  inset: 0;
  display: grid;
  align-items: center;
  justify-content: center;
}
.startpage .history .calendar.manager .rbc-row,
.startpage .history .history-calendar-container ~ .manager-editor {
  border-width: 1px 0 0 1px;
}
.startpage .history .history-view {
  overflow: hidden;
  display: flex;
  flex: 1;
}
.startpage .history .search-options {
  background-color: var(--colorBg);
  border-top: solid 1px var(--colorBorder);
}
.startpage .history .search-options > label > input[type=checkbox] {
  margin-left: 6px;
  margin-right: 6px;
}
.startpage .history .search-options > .filtered-entries {
  margin-left: auto;
}
.startpage .history .manager-content {
  border: 0;
  flex: 1;
  flex-direction: row;
}
.startpage .history .manager-content p {
  margin: 12px;
}
.startpage .history .manager-content header {
  display: block;
  padding: 3px 6px;
  height: 22px;
  background-color: var(--colorBg);
  border-top: 1px solid var(--colorBorder);
  border-bottom: 1px solid var(--colorBorder);
  font-size: 11.5px;
  font-weight: 700;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.startpage .history .manager-content header:hover {
  background-color: var(--colorBgDark);
}
.startpage .history .manager-content header.disabled {
  pointer-events: none;
  font-weight: 400;
  opacity: 0.5;
}
.startpage .history .manager-content .view {
  display: flex;
  flex-direction: column;
  flex: 1;
  overflow: hidden;
}
.startpage .history .manager-content .month {
  display: flex;
  flex-direction: row;
  flex: 1;
  overflow: hidden;
}
.startpage .history .manager-content .month .month-calendar {
  flex: 1;
  position: relative;
}
.startpage .history .manager-content .month .month-calendar .CalendarMonth {
  grid-gap: 0;
}
.startpage .history .manager-content .month .month-links {
  display: flex;
  flex-direction: column;
  flex: 0 0 270px;
  border: solid var(--colorBorder);
  border-width: 1px 0 0 1px;
}
.startpage .history .manager-content .month .month-links .vivaldi-tree {
  flex: 1;
}
.startpage .history .manager-content .month .month-links .vivaldi-tree .tree-row label {
  flex: 1;
}
.startpage .history .manager-content .week .week-container {
  display: flex;
  flex: 1;
  overflow: hidden;
}
.startpage .history .manager-content .week .week-day {
  display: flex;
  flex: 1;
  flex-direction: column;
  overflow: hidden;
}
.startpage .history .manager-content .week .week-day:not(:last-child) > header {
  border-right: 1px solid var(--colorBorder);
}
.startpage .history .manager-content .week .week-day:not(:last-child) > .tree {
  border-right: 1px solid var(--colorFgAlpha);
}
.startpage .history .manager-content .week .week-day .tree {
  display: flex;
  flex: 1;
  overflow: hidden;
}
.startpage .history .manager-content .week .week-day .vivaldi-tree .tree-row label {
  flex: 1;
  padding: 0 6px !important;
}
.startpage .history .manager-content .week .week-day .vivaldi-tree .tree-row label span.time {
  display: none;
}
.startpage .history .manager-content .week .week-day .vivaldi-tree .ReactVirtualized__List {
  scrollbar-gutter: auto;
}
.startpage .history .manager-content .week .graph {
  flex: 0 0 auto;
}
.startpage .history .manager-content .history-tree {
  display: flex;
  flex: 1;
  overflow: hidden;
}
.startpage .history .more-info {
  display: flex;
  flex: 0 0 270px;
  flex-direction: column;
  overflow: hidden;
  max-width: 100%;
}
.startpage .history .more-info .header {
  flex: 0 0 auto;
  padding: 12px 12px 6px;
}
.startpage .history .more-info .moreinfo-stats {
  display: flex;
  flex: 1;
  flex-direction: column;
  padding: 0 12px 6px;
  overflow-x: hidden;
  overflow-y: auto;
}
.startpage .history .more-info h2 {
  position: relative;
  margin: 12px 0 6px;
  padding-top: 12px;
}
.startpage .history .more-info h2:before {
  content: '';
  position: absolute;
  top: 0;
  left: -12px;
  right: -12px;
  height: 1px;
  background-color: var(--colorBorder);
}
.startpage .history .more-info h2:first-of-type {
  margin: 6px 0;
}
.startpage .history .more-info ul {
  margin: 6px 0 0;
}
.startpage .history .more-info li {
  position: relative;
}
.startpage .history .more-info svg text,
.startpage .history .more-info svg tspan {
  fill: inherit !important;
}
.startpage .history .more-info .moreinfo-activity {
  flex: 0 0 204px;
}
.startpage .history .more-info .moreinfo-activity svg {
  overflow: visible;
}
.startpage .history .more-info .moreinfo-top-domains li {
  display: flex;
  height: 22px;
  align-items: center;
}
.startpage .history .more-info .moreinfo-top-domains li img {
  margin-right: 6px;
}
.startpage .history .more-info .moreinfo-link-types {
  display: flex;
  flex: 0 0 164px;
  align-items: center;
  justify-content: space-between;
}
.startpage .history .more-info .moreinfo-link-types + h2 {
  margin-top: 6px;
}
.startpage .history .more-info .moreinfo-link-types svg {
  width: auto !important;
  max-height: 160px;
  overflow: visible;
}
.startpage .history .more-info .moreinfo-link-labels {
  display: flex;
  flex-direction: column;
  min-width: 80px;
}
.startpage .history .more-info .moreinfo-activity-labels,
.startpage .history .more-info .moreinfo-link-labels {
  font-size: 11.5px;
}
.startpage .history .more-info .moreinfo-activity-labels li,
.startpage .history .more-info .moreinfo-link-labels li {
  display: flex;
  line-height: 1.1;
  padding-bottom: 3px;
}
.startpage .history .more-info .moreinfo-activity-labels li.disabled,
.startpage .history .more-info .moreinfo-link-labels li.disabled {
  display: none;
}
.startpage .history .more-info .moreinfo-activity-labels li span,
.startpage .history .more-info .moreinfo-link-labels li span {
  min-width: 12px;
  height: 12px;
  margin-right: 6px;
  pointer-events: none;
}
.startpage .history .more-info .moreinfo-links {
  display: flex;
  flex: 1;
}
.startpage .history .more-info .moreinfo-links .vivaldi-tree .folder label,
.startpage .history .more-info .moreinfo-links .vivaldi-tree label {
  padding-right: 12px;
}
.startpage .history .tree-row.folder {
  grid-template-columns: 1fr;
  background-color: var(--colorBg);
}
.isblurred .startpage .history .tree-row.folder[data-selected] {
  background-color: var(--colorBgDarker);
}
.startpage .history .manager-content .vivaldi-tree .tree-row label,
.startpage .history .sortselector.sortselector-tableheader label {
  flex: unset;
}
.startpage .history .manager-content .vivaldi-tree .tree-row.folder label,
.startpage .history .sortselector.sortselector-tableheader.folder label {
  flex: 1;
  padding-right: 12px;
}
.startpage .history .timeline-grid,
.startpage .history .month-view-grid {
  position: absolute;
  inset: 0;
}
.startpage .history .month-view-grid {
  top: 22px;
}
.startpage .history .CalendarMonth-Day--Current ~ .CalendarMonth-Day,
.startpage .history .CalendarMonth:last-child .CalendarMonth-Day--Current ~ .CalendarMonth-Day--OtherMonth {
  color: var(--colorFgFadedMost);
}
.startpage .history .timeline {
  margin: 0;
  display: flex;
  flex: 1;
  flex-direction: column;
  justify-content: space-between;
  position: relative;
  min-height: 270px;
  background-color: var(--colorBgLightIntense);
}
.startpage .history .timeline .CalendarMonth {
  grid-gap: 0;
  grid-template-columns: repeat(7, auto);
  background: linear-gradient(to bottom, transparent 20%, var(--colorBgLightIntense) 40%, var(--colorBg) 80%);
  pointer-events: none;
}
.startpage .history .timeline .CalendarMonth > *:nth-child(-n+7) {
  background-color: var(--colorBgLightIntense);
}
.startpage .history .timeline .CalendarMonth-Day {
  width: 100%;
  height: 50px;
  box-shadow: inset 0 0 1px 0 var(--colorBorder);
  outline: unset;
}
.startpage .history .timeline .CalendarMonth-Day--OtherMonth {
  color: inherit;
  background-color: var(--colorBg) !important;
}
.startpage .history .timeline .CalendarMonth-Day--Weekend {
  background-color: transparent;
}
.startpage .history .timeline .CalendarMonth-Day--Current {
  color: var(--colorFg);
  background: unset;
}
.startpage .history .sorting {
  display: flex;
  flex: 0 0 auto;
}
.startpage .history .sorting .toolbar {
  margin-bottom: 0;
}
.startpage .history .toolbar > span {
  margin: 6px 6px 0 0;
  align-self: baseline;
  min-height: 28px;
}
.startpage .history .toolbar select {
  flex: 0 0 auto;
  min-width: 0;
}
.startpage .history .toolbar.grouping {
  flex: 0 0 auto;
}
.startpage .history .toolbar.grouping select {
  flex: 1;
  margin-left: 6px;
}
.startpage .history .toolbar .button-toolbar.toggle-info svg {
  width: 16px;
}
.startpage .history .vivaldi-tree .tree-row > div {
  display: flex;
  flex: 1;
  overflow: hidden;
}
.startpage .history .vivaldi-tree .tree-row.folder label {
  padding: 0 12px 0 6px;
  flex: 1;
  font-weight: 700;
}
.startpage .history .vivaldi-tree .tree-row label.date {
  padding-right: 12px;
  justify-content: flex-end;
  font-variant-numeric: tabular-nums;
}
.startpage .history .vivaldi-tree .tree-row label.url svg {
  vertical-align: -3px;
  margin: 0 -3px 0 -3px;
  min-width: 16px;
}
.startpage .history .vivaldi-tree .tree-row label.visits {
  text-align: right;
  padding: 0 12px;
}
.startpage .history .history-calendar-container {
  display: flex;
  flex: 1;
  overflow: hidden;
}
.startpage .history .moreinfo-chart {
  display: flex;
}
.startpage .history .overview-chart {
  position: absolute !important;
  z-index: -1;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  display: flex;
  align-items: flex-end;
  opacity: 0.5;
}
.startpage .history .manager-content {
  position: relative;
}
.startpage .history .manager-content .CalendarMonth {
  background-color: var(--colorBg);
}
.startpage .history .manager-content .CalendarMonth-Day {
  box-shadow: inset 0 0 1px 0 var(--colorBorder);
  background-color: var(--colorBgLightIntense);
  font-size: 11.5px;
  width: 100%;
  height: 100%;
  outline: none;
  align-items: flex-start;
  justify-content: unset;
}
.startpage .history .manager-content .CalendarMonth-Day > div {
  display: flex;
  flex-direction: column;
  flex: 1;
  padding: 6px;
  overflow: hidden;
}
.startpage .history .manager-content .CalendarMonth-Day--Current {
  color: inherit;
  font-weight: inherit;
}
.startpage .history .manager-content .CalendarMonth-Day--Current .Cal__Day__day {
  background-color: var(--colorBgDarker);
  opacity: 1;
}
.startpage .history .manager-content .CalendarMonth-Day--Weekend {
  background-color: var(--colorBgLightIntense);
}
.startpage .history .manager-content .Cal__Day__day {
  display: flex;
  flex: 0 0 auto;
  justify-content: center;
  align-items: center;
  width: 26px;
  height: 26px;
  margin: -3px -3px 0 auto;
  border-radius: 100%;
  font-size: 16px;
  opacity: 0.6;
}
.startpage .history .manager-content button.toggle-month-entries {
  position: absolute;
  z-index: 10;
  top: 2px;
  right: 1px;
  padding: 1px 6px;
  border: 0;
  background-color: transparent;
}
.startpage .history .history-view.selecting .selected .Cal__Day__day {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  opacity: 1;
}
.startpage .history .history-view.selecting header.selected {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.startpage .history .history-view.selecting header.disabled {
  pointer-events: none;
  font-weight: 400;
}
.startpage .history .manager-editor span.heat:hover:active,
.startpage .history .manager-editor span.heat.selected {
  box-shadow: inset 0 0 0 20px var(--colorHighlightBgAlpha);
}
.startpage .history .timeline .CalendarMonth-Day span {
  pointer-events: none;
  font-size: 11.5px;
  margin: 0 auto;
}
.startpage .history .timeline .CalendarMonth-Day span.heat {
  pointer-events: all;
}
.startpage .history .timeline .CalendarMonth-Day span.heat span:only-child {
  margin: auto;
}
.startpage .history .timeline .CalendarMonth-Day span.heat span:first-child {
  margin-top: auto;
}
.startpage .history .timeline .CalendarMonth-Day span.heat span:last-child {
  margin-bottom: auto;
}
.startpage .history .timeline .CalendarMonth-Day span.heat span.Cal__Day__year {
  font-size: 10px;
  font-weight: 400;
}
.startpage .history .timeline .CalendarMonth-Day span.heat span.Cal__Day__month {
  font-size: 13px;
  font-weight: 600;
  line-height: 1;
}
.startpage .history .CalendarMonth-Weekdays {
  background-color: var(--colorBg);
  color: var(--colorFgFaded);
  border-bottom: 1px solid var(--colorBorder);
  display: flex;
  padding-right: var(--scrollbarWidth);
  z-index: 2;
}
.startpage .history .month-calendar .CalendarMonth-Weekdays {
  border-top: 1px solid var(--colorBorder);
}
.startpage .history .month-calendar .ReactVirtualized__Grid.ReactVirtualized__List {
  overflow: hidden !important;
}
.startpage .history .CalendarMonth-DayOfWeek {
  padding: 0 0 0 6px;
  line-height: 20px;
  font-size: 11.5px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  justify-content: flex-start;
}
.startpage .history .timeline:focus-within .CalendarMonth-Day--Highlighted,
.startpage .history .month-calendar:focus-within .CalendarMonth-Day--Highlighted {
  outline: 2px var(--colorHighlightBg) solid;
  outline-offset: -2px;
}
.startpage .history .timeline > div:focus-within,
.startpage .history .month-calendar > div:focus-within {
  outline: unset;
}
.startpage .history h4 {
  flex: 0 0 auto;
  margin-top: 3px;
  font-weight: 400;
  text-align: initial;
  padding: 3px;
  border: 1px solid;
  overflow: hidden;
}
.startpage .history h4 .visits,
.startpage .history h4 .pages {
  display: flex;
  white-space: nowrap;
  margin-right: 0.5ex;
}
.startpage .history h4 .visits strong,
.startpage .history h4 .pages strong {
  margin-right: 0.5ex;
}
.startpage .history ul.top-links {
  flex-direction: column;
  align-items: flex-start;
  margin-top: 3px;
  text-align: left;
}
.startpage .history ul.top-links li {
  height: 15px;
  background-color: transparent;
  display: block;
  flex: 0 0 auto;
  max-width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.startpage .history .CalendarMonth-Day:hover ul.top-links {
  opacity: 1;
  transition: none;
}
.startpage .history .heat.low {
  background-color: rgba(187, 255, 0, 0.1);
  border-color: rgba(187, 255, 0, 0.7);
}
.startpage .history .heat.mid {
  background-color: rgba(255, 238, 0, 0.2);
  border-color: rgba(255, 238, 0, 0.7);
}
.startpage .history .heat.high {
  background-color: rgba(255, 204, 0, 0.3);
  border-color: rgba(255, 204, 0, 0.7);
}
.startpage .history .heat.max {
  background-color: rgba(255, 153, 0, 0.4);
  border-color: rgba(255, 153, 0, 0.7);
}
#history-panel select {
  min-width: 60%;
}
#history-panel .toolbar-default {
  width: 100%;
}
.dialog-clear-data {
  max-height: 70vh;
  display: flex;
  flex-direction: column;
  overflow: hidden;
}
.event-container {
  min-width: 100px;
  display: flex;
  flex-direction: column;
  gap: 1px;
  pointer-events: none;
}
.event-container > * {
  pointer-events: initial;
}
.event-container.selected {
  z-index: 1;
}
.calendar-event .dateInput .faux input {
  height: inherit;
  box-shadow: unset;
  border: none;
}
.calendar-event input[type=button].circular {
  transform: none;
  border: 1px solid var(--colorBorder);
  background-color: var(--colorBg);
  margin: 0;
}
.calendar-event input[type='checkbox'] {
  margin: 0 6px 0 0;
  border-color: var(--colorCalendarBg);
  border-radius: var(--radiusHalf);
  background-color: var(--colorCalendarBgAlpha);
}
.editing.calendar-event input[type='checkbox'] {
  margin: 0;
}
.calendar-grid:focus-within .selected:not(.editing).calendar-event input[type='checkbox'],
.calendar-grid:focus-within .selected:not(.editing).calendar-event input[type='checkbox']:focus {
  border-color: var(--colorCalendarFg);
  background-color: var(--colorCalendarFgAlpha);
}
.calendar-event .edit-group input[type='checkbox'] {
  margin: 0;
}
.calendar-event input[type=number] {
  max-width: 5ex;
}
.calendar-event input[type=time]:focus-visible:after,
.calendar-event input[type=number]:focus-visible:after,
.calendar-event input[type=time]:focus-visible:before,
.calendar-event input[type=number]:focus-visible:before,
.calendar-event input[type=time]:hover:after,
.calendar-event input[type=number]:hover:after,
.calendar-event input[type=time]:hover:before,
.calendar-event input[type=number]:hover:before {
  background-color: transparent;
}
.calendar-event input[type=time]::-webkit-inner-spin-button,
.calendar-event input[type=number]::-webkit-inner-spin-button {
  visibility: hidden;
  width: initial;
  margin-inline-start: 0;
}
.calendar-event .calendar-input-disabled {
  opacity: 0.5;
}
p.editable[contenteditable=true],
p.editable[contenteditable=plaintext-only] {
  padding-left: 6px;
  padding-right: 6px;
  text-wrap: unset;
}
p.editable[contenteditable=true]:empty:before,
p.editable[contenteditable=plaintext-only]:empty:before {
  content: attr(data-placeholder);
  opacity: 0.5;
}
.calendar-event {
  display: grid;
  grid-template-rows: auto 1fr;
  position: relative;
  border-radius: var(--radiusHalf);
  color: var(--colorFgIntense);
  margin: 0 1px;
}
.day .calendar-event,
.week .calendar-event {
  box-shadow: inset 3px 0 0 var(--colorCalendarBg);
}
.calendar-event.solid,
.calendar-event.all-day {
  background-color: var(--colorCalendarBgAlpha);
}
#tasks_panel .calendar-event.solid:not(.selected),
#tasks_panel .calendar-event.all-day:not(.selected) {
  background-color: transparent;
}
.calendar-event.filtered-out {
  opacity: 0.2;
}
.calendar-event.event-passed {
  opacity: 0.6;
}
.calendar-event.multiday-continuing {
  padding-left: 6px;
}
.calendar-event.all-day.multiday-continues,
.calendar-event.solid.multiday-continues,
.calendar-event.selected.multiday-continues {
  clip-path: polygon(0% 0%, calc(100% - 6px) 0%, calc(100% - 6px) calc(50% - 6px), 100% 50%, calc(100% - 6px) calc(50% + 6px), calc(100% - 6px) 100%, 0% 100%);
}
.calendar-event.all-day.multiday-continuing,
.calendar-event.solid.multiday-continuing,
.calendar-event.selected.multiday-continuing {
  clip-path: polygon(0% 0%, 100% 0%, 100% 100%, 0% 100%, 0% calc(50% + 6px), 4px 50%, 0% calc(50% - 6px));
}
.calendar-event.all-day.multiday-continues.multiday-continuing,
.calendar-event.solid.multiday-continues.multiday-continuing,
.calendar-event.selected.multiday-continues.multiday-continuing {
  clip-path: polygon(0% 0%, calc(100% - 6px) 0%, calc(100% - 6px) calc(50% - 6px), 100% 50%, calc(100% - 6px) calc(50% + 6px), calc(100% - 6px) 100%, 0% 100%, 0% calc(50% + 6px), 4px 50%, 0% calc(50% - 6px));
}
.calendar-grid:focus-within .calendar-event.selected:not(.editing),
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) {
  background-color: var(--colorCalendarBg);
  color: var(--colorCalendarFg);
  fill: var(--colorCalendarFg);
  opacity: 1;
}
.calendar-grid:focus-within .calendar-event.selected:not(.editing) a,
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) a,
.calendar-grid:focus-within .calendar-event.selected:not(.editing) a:link,
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) a:link,
.calendar-grid:focus-within .calendar-event.selected:not(.editing) a:visited,
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) a:visited,
.calendar-grid:focus-within .calendar-event.selected:not(.editing) a:focus-visible,
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) a:focus-visible,
.calendar-grid:focus-within .calendar-event.selected:not(.editing) a:hover,
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) a:hover,
.calendar-grid:focus-within .calendar-event.selected:not(.editing) a:active,
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) a:active {
  color: var(--colorCalendarFg);
}
.calendar-grid:focus-within .calendar-event.selected:not(.editing) input[type=checkbox]:checked,
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) input[type=checkbox]:checked {
  border-color: var(--colorCalendarFg);
  background-color: var(--colorCalendarFg);
}
.calendar-grid:focus-within .calendar-event.selected:not(.editing) input[type=checkbox]:checked:before,
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) input[type=checkbox]:checked:before,
.calendar-grid:focus-within .calendar-event.selected:not(.editing) input[type=checkbox]:checked:after,
.calendar-grid-agenda:focus-within .calendar-event.selected:not(.editing) input[type=checkbox]:checked:after {
  background-color: var(--colorCalendarBg);
}
.calendar-event.editing {
  background-color: var(--colorBgLightIntense);
  outline: 2px solid var(--colorCalendarBg);
  color: var(--colorFg);
  box-shadow: none;
  margin: 2px;
}
.calendar-grid-week .calendar-event.editing,
.calendar-grid-multiweek .calendar-event.editing,
.calendar-grid-month .calendar-event.editing {
  max-width: 220px;
}
.calendar-grid-agenda .event-container:last-child .calendar-event.editing {
  border-bottom: none;
}
.calendar-event .cal-event-body {
  position: relative;
  display: grid;
  grid-template-rows: auto 1fr;
  padding: 3px 6px;
  overflow-wrap: break-word;
}
.panel .calendar-event .cal-event-body {
  overflow-wrap: anywhere;
}
:is(#tasks_panel, #tasks-widget) .calendar-event:not(.editing) .cal-event-body .cal-event-header {
  padding-left: 22px;
  text-indent: -22px;
}
:is(#tasks_panel, #tasks-widget) .calendar-event:not(.editing) .cal-event-body .cal-event-header * {
  text-indent: initial;
  vertical-align: middle;
}
.calendar-event .cal-event-dot {
  display: inline-block;
  margin-right: 4px;
  color: var(--colorCalendarBg);
}
.calendar-grid:focus-within .selected.calendar-event .cal-event-dot,
.calendar-grid-agenda:focus-within .selected.calendar-event .cal-event-dot {
  opacity: 0.5;
}
.calendar-event .cal-event-dot > svg {
  height: 8px;
  width: 8px;
}
.calendar-event .cal-event-header {
  min-height: 1em;
}
.calendar-event .cal-event-header .cal-event-time {
  white-space: nowrap;
  margin-right: 3px;
  display: inline-block;
}
.calendar-event .cal-event-header .cal-event-title {
  font-weight: 600;
  padding-right: 6px;
  word-break: break-word;
}
.task-completed.calendar-event .cal-event-header .cal-event-title {
  text-decoration: line-through;
}
.calendar-event .cal-event-header .cal-event-progression {
  padding-right: 6px;
}
.calendar-event .cal-event-header .cal-event-icons {
  display: inline-block;
  vertical-align: middle;
  line-height: 1;
  stroke: var(--colorCalendarBg, var(--colorFg));
  fill: var(--colorCalendarBg, var(--colorFg));
}
.selected.calendar-event .cal-event-header .cal-event-icons {
  stroke: currentColor;
  fill: currentColor;
}
.calendar-event .cal-event-header .cal-event-icons svg {
  height: 16px;
  width: 16px;
}
.calendar-event .cal-event-header .cal-event-icon-link {
  cursor: pointer;
}
.calendar-event.minimal:not(.editing) .cal-event-header {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 1;
  -webkit-box-orient: vertical;
}
.calendar-event.compact:not(.editing) .cal-event-header {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
}
.calendar-event:not(.solid):not(.selected) .cal-event-body input[type=checkbox] {
  background-color: var(--colorCalendarBgAlpha);
  box-shadow: 0 1px 1px var(--colorCalendarBgAlpha) inset;
  border-color: var(--colorCalendarBg);
}
.calendar-event:not(.solid):not(.selected) .cal-event-body input[type=checkbox]:before,
.calendar-event:not(.solid):not(.selected) .cal-event-body input[type=checkbox]:after {
  background-color: var(--colorCalendarBg);
}
.calendar-event:not(.solid):not(.selected) .cal-event-body input[type=checkbox]:checked {
  background-color: var(--colorCalendarBg);
}
.calendar-event:not(.solid):not(.selected) .cal-event-body input[type=checkbox]:checked:before,
.calendar-event:not(.solid):not(.selected) .cal-event-body input[type=checkbox]:checked:after {
  background-color: var(--colorCalendarFg);
}
.calendar-event .cal-event-body-content {
  grid-area: 2 / 1 / 3 / 2;
  min-width: 0;
  display: flex;
  flex-direction: column;
  align-items: flex-start;
}
.calendar-event .cal-event-body-content p {
  display: inline-block;
  padding-bottom: 3px;
}
.calendar-event .cal-event-body-content span {
  word-break: break-word;
}
.calendar-event .cal-event-description {
  overflow: hidden;
  max-width: 100%;
}
.calendar-event .cal-event-description p {
  display: initial;
}
.calendar-event .cal-event-description p.delimiter {
  max-width: 100%;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: clip;
}
.calendar-event.compact:not(.editing) .cal-event-description {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 4;
  -webkit-box-orient: vertical;
}
.calendar-event.compact .cal-event-location,
.calendar-event.compact .cal-event-url {
  max-width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.calendar-event .cal-event-body-edit {
  display: flex;
  flex-direction: column;
  grid-area: 2 / 1 / 3 / 2;
  visibility: hidden;
  margin-top: 6px;
  width: 208px;
  height: var(--editorHeight);
}
.calendar-event .cal-event-body-edit:not(.selected) {
  pointer-events: none;
}
.calendar-event .cal-event-body-edit.selected {
  visibility: visible;
}
.calendar-event .cal-event-body-edit.description {
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: auto auto 1fr;
}
.calendar-event .cal-event-body-edit.description .edit-group {
  overflow: hidden;
}
.calendar-event .cal-event-body-edit p {
  flex: 1 1 auto;
  max-height: 4em;
  overflow-y: auto;
}
.calendar-event .cal-event-body-edit p:focus-visible {
  text-overflow: unset;
}
.calendar-event .cal-event-body-edit p.info {
  overflow: visible;
  white-space: break-spaces;
}
.calendar-event .cal-event-body-edit p.cal-event-url,
.calendar-event .cal-event-body-edit p.cal-event-description {
  max-height: stretch;
}
.calendar-event .cal-event-body-edit label {
  display: flex;
  max-width: stretch;
  align-items: center;
  gap: 6px;
}
.calendar-event .cal-event-body-edit label > span:not(.select-wrapper),
.calendar-event .cal-event-body-edit label > button,
.calendar-event .cal-event-body-edit label > input[type=button],
.calendar-event .cal-event-body-edit label > div {
  flex: 0 0 auto;
}
.calendar-event .cal-event-body-edit label > input[type=text],
.calendar-event .cal-event-body-edit label > input[type=number],
.calendar-event .cal-event-body-edit label > input[type=date],
.calendar-event .cal-event-body-edit label > input[type=time],
.calendar-event .cal-event-body-edit label > select {
  min-width: 0;
  flex: 1 1 auto;
}
.calendar-event .cal-event-body-edit .inline label {
  width: auto;
}
.calendar-event .cal-event-body-edit .cal-event-body-buttons {
  display: flex;
  margin: auto 0 3px 0;
  gap: 6px;
  justify-content: flex-start;
}
.mac .calendar-event .cal-event-body-edit .cal-event-body-buttons {
  justify-content: flex-end;
}
.calendar-event .cal-event-body-edit .cal-event-body-filtered-warning {
  color: var(--colorWarning);
  fill: var(--colorWarning);
}
.calendar-event .cal-event-body-edit .cal-event-body-edit-label {
  flex: 0 0 auto;
  height: auto;
  margin: 0 1em 0 0;
  padding: 0;
  font-size: 11.5px;
  opacity: 0.5;
}
.calendar-event .cal-event-alarms {
  margin: -3px -3px 3px -3px;
}
.calendar-event .cal-event-alarm {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  margin: 3px;
}
.calendar-event .cal-edit-tabs {
  display: flex;
  color: var(--colorFg);
  margin-bottom: 2px;
  padding: 2px;
}
.calendar-event .cal-edit-tabs > .cal-edit-tab {
  display: flex;
  flex: 0 1 36px;
  height: 24px;
  background-color: transparent;
  border: 1px solid transparent;
  border-radius: var(--radiusHalf);
  padding: 3px 6px;
  justify-content: center;
  align-items: center;
}
.panel .calendar-event .cal-edit-tabs > .cal-edit-tab {
  padding: 2px 3px;
}
.calendar-event .cal-edit-tabs > .cal-edit-tab > svg {
  align-self: center;
  width: 16px;
  height: 16px;
  stroke: currentColor;
  fill: currentColor;
}
.calendar-event .cal-edit-tabs > .cal-edit-tab:hover {
  background-color: var(--colorBg);
}
.calendar-event .cal-edit-tabs > .cal-edit-tab:active {
  background-color: var(--colorBgDark);
}
.calendar-event .cal-edit-tabs > .cal-edit-tab.selected {
  background-color: var(--colorCalendarBg);
  color: var(--colorCalendarFg);
  fill: var(--colorCalendarFg);
}
.calendar-event .cal-event-attachment {
  display: inline-flex;
  flex-direction: row;
  margin: 3px 0 6px 0;
  color: var(--colorFg);
  background-color: var(--colorBgIntense);
  box-shadow: 0 0 0 1px var(--colorBorder);
  border-radius: var(--radiusHalf);
  padding: 2px 6px;
  cursor: pointer;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.calendar-event .cal-event-attachment svg {
  width: 16px;
  height: 16px;
  margin-right: 6px;
}
.calendar-event .edit-group {
  display: flex;
  flex-wrap: wrap;
  margin: -3px -3px 3px -3px;
}
.calendar-event .edit-group.large-gap {
  margin-bottom: 9px;
}
#app .calendar-event .edit-group > * {
  margin: 3px;
  background-position-y: unset;
}
.calendar-event .edit-group > h2 {
  flex: 1 1 auto;
}
.calendar-grid-day .calendar-event .edit-group.capped-width > * {
  flex: 1 0 auto;
  max-width: 200px;
}
.calendar-event .edit-group > input[type=text]:only-child,
.calendar-event .edit-group > select:only-child,
.calendar-event .edit-group .CalendarSelector:only-child {
  max-width: 208px;
}
.calendar-event .edit-group .VivaldiSelector {
  width: 208px;
}
.calendar-event .edit-group .VivaldiSelector__input-container {
  padding-left: 6px;
}
.calendar-event .edit-group .VivaldiSelector__control:focus-within {
  outline-color: var(--colorCalendarBg);
}
.calendar-event button,
.calendar-event select:not([multiple]):not([size]),
.calendar-event input[type=text],
.calendar-event input[type=button],
.calendar-event input[type=submit],
.calendar-event input[type=time],
.calendar-event input[type=number],
.calendar-event input[type=date],
.calendar-event .VivaldiSelector {
  height: 20px;
}
.calendar-event input[type=text],
.calendar-event p[contenteditable=true],
.calendar-event p[contenteditable=plaintext-only],
.calendar-event input[type=time],
.calendar-event input[type=number],
.calendar-event input[type=date],
.calendar-event .dateInput .dateInputHidden {
  box-shadow: unset;
  border: none;
  border-bottom: 2px solid var(--colorBgDarker);
  border-radius: 0;
  background-color: transparent;
}
.calendar-event input[type=text]:focus-visible,
.calendar-event p[contenteditable=true]:focus-visible,
.calendar-event p[contenteditable=plaintext-only]:focus-visible,
.calendar-event input[type=time]:focus-visible,
.calendar-event input[type=number]:focus-visible,
.calendar-event input[type=date]:focus-visible,
.calendar-event .dateInput .dateInputHidden:focus-visible {
  outline: unset;
}
.calendar-event input[type=text]:focus-within,
.calendar-event p[contenteditable=true]:focus-within,
.calendar-event p[contenteditable=plaintext-only]:focus-within,
.calendar-event input[type=time]:focus-within,
.calendar-event input[type=number]:focus-within,
.calendar-event input[type=date]:focus-within,
.calendar-event .dateInput .dateInputHidden:focus-within {
  border-color: var(--colorCalendarBg);
}
.calendar-event .dateInput:focus-within .dateInputHidden {
  border-color: var(--colorCalendarBg);
  outline: unset;
}
.calendar-event button:focus-visible,
.calendar-event select:focus-visible,
.calendar-event input[type=button]:focus-visible,
.calendar-event input[type=submit]:focus-visible,
.calendar-event input[type=checkbox]:focus-visible,
.calendar-event .button-toolbar:focus-within > button:not([tabindex='-1']):focus-visible {
  border-color: var(--colorCalendarBg);
  box-shadow: 0 0 0 1px var(--colorCalendarBg);
  outline-color: var(--colorCalendarBg);
}
.calendar-event .cal-edit-tab:focus-visible {
  outline-offset: -2px;
  border: var(--colorBg) 3px solid;
  box-shadow: unset;
}
.calendar-event input[type=checkbox]:checked {
  border-color: var(--colorCalendarBg);
  background-color: var(--colorCalendarBg);
}
.task-completed.calendar-event input[type=checkbox]:checked {
  background-color: var(--colorCalendarBg);
}
.task-completed.calendar-event input[type=checkbox]:checked:before,
.task-completed.calendar-event input[type=checkbox]:checked:after {
  background-color: var(--colorCalendarFg);
}
.calendar-event input[type=button].narrow {
  padding-left: 6px;
  padding-right: 6px;
}
.calendar-event input[type=radio]:before,
.calendar-event input[type=checkbox]:before,
.calendar-event input[type=radio]:after,
.calendar-event input[type=checkbox]:after,
.calendar-event input[type=radio]:focus-visible:before,
.calendar-event input[type=checkbox]:focus-visible:before,
.calendar-event input[type=radio]:focus-visible:after,
.calendar-event input[type=checkbox]:focus-visible:after,
.calendar-event input[type=radio]:active:focus-visible:before,
.calendar-event input[type=checkbox]:active:focus-visible:before,
.calendar-event input[type=radio]:active:focus-visible:after,
.calendar-event input[type=checkbox]:active:focus-visible:after {
  background-color: var(--colorCalendarFg);
}
.calendar-event .toolbar {
  width: 100%;
  display: flex;
  padding: 0;
}
.calendar-event .toolbar > .toolbar-group {
  display: flex;
  margin: 0;
}
.calendar-event .toolbar > .toolbar-group > hr {
  margin-bottom: 0;
}
.calendar-event .toolbar > .toolbar-group > .button-toolbar {
  flex-grow: 1;
  margin: 0;
  max-width: 16px;
}
.calendar-event .toolbar > .toolbar-group > .button-toolbar:last-child {
  margin-right: 0;
}
#app .dom-picker .button-pressed,
#app .calendar-week-picker .button-pressed {
  border-color: var(--colorFgFadedMore);
  background-image: linear-gradient(var(--colorFgFadedMore), var(--colorFgFadedMost));
  color: var(--colorBg);
}
.calendar-week-picker .button-toolbar:not(:last-of-type) {
  border-right: 1px solid var(--colorBorder);
}
.dom-picker {
  padding: 6px;
}
.dom-picker .toolbar {
  display: grid;
  gap: 3px;
  --totalGap: 6px * 3;
  grid-template-columns: repeat(auto-fit, calc((100% - var(--totalGap)) / 7));
}
.calendar-event-resizer {
  position: absolute;
  z-index: 2;
}
.calendar-event-resizer.vertical {
  height: 6px;
  width: 100%;
  cursor: ns-resize;
}
.calendar-event-resizer.vertical.pre {
  top: 0;
}
.calendar-event-resizer.vertical.post {
  bottom: 0;
}
.calendar-event-resizer.horizontal {
  width: 6px;
  height: 100%;
  cursor: ew-resize;
}
.calendar-event-resizer.horizontal.pre {
  left: 0;
}
.calendar-event-resizer.horizontal.post {
  right: 0;
}
.CalendarSelector.CalendarSelector.CalendarSelector.button-toolbar {
  flex: 0 0 auto;
  width: min-content;
}
.CalendarSelector .ToolbarButton-Button {
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgDark));
  padding-right: 24px;
}
.CalendarSelector .ToolbarButton-Button:hover:not(:disabled) {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
.CalendarSelector .ToolbarButton-Button:active:not(:disabled) {
  background-image: linear-gradient(var(--colorBgDark), var(--colorBgDark));
}
.CalendarSelector .ToolbarButton-Button:after {
  content: '';
  position: absolute;
  width: 16px;
  height: 16px;
  right: 6px;
  background-color: currentColor;
  mask-image: var(--svgArrow);
  mask-repeat: no-repeat;
  mask-position: 0 0;
  mask-size: 16px 16px;
  pointer-events: none;
}
.CalendarSelector.button-toolbar > button > span.button-toolbar-menu-indicator {
  margin: 0 0 0 6px;
}
.calendar-dot {
  display: inline;
  margin-right: 4px;
  vertical-align: middle;
}
.calendar-dot > svg {
  height: 16px;
  width: 16px;
}
#panels #calendar_panel .cal-tasks-row,
#panels #tasks_panel .cal-tasks-row {
  background-color: var(--colorBgLighter);
  border-radius: var(--radius);
}
#panels #calendar_panel .cal-tasks-row-events,
#panels #tasks_panel .cal-tasks-row-events {
  min-width: 100%;
}
#panels #calendar_panel .search-results-list .cal-tasks-row,
#panels #tasks_panel .search-results-list .cal-tasks-row {
  flex-wrap: wrap;
}
#panels #calendar_panel .panel-empty-state,
#panels #tasks_panel .panel-empty-state {
  height: 100%;
}
.calendar-viewport {
  display: flex;
  flex: 1;
  flex-direction: column;
  justify-content: stretch;
  background-clip: content-box;
  background-color: var(--colorBorderSubtle);
  overflow-x: auto;
  outline: unset;
}
.manager-detail .calendar-viewport,
.manager-view.year .calendar-viewport {
  background-clip: border-box;
  background-color: var(--colorBgLightIntense);
}
#calendar_panel .calendar-viewport,
#tasks_panel .calendar-viewport {
  background-color: transparent;
}
.calendar.manager .manager-detail {
  display: flex;
  flex: 1 1;
  flex-direction: column;
  height: 100%;
  border-left: 1px solid var(--colorBorder);
  border-top: 1px solid var(--colorBorder);
}
.calendar.manager .manager-detail > .header,
.calendar.manager .manager-detail > .footer {
  background-color: var(--colorBg);
  padding: 12px;
}
.calendar.manager .manager-detail > .header {
  border-bottom: 1px solid var(--colorBorder);
}
.calendar.manager .manager-detail > .footer {
  border-top: 1px solid var(--colorBorder);
}
.calendar.manager .manager-detail .cal-tasks label {
  display: flex;
  flex-shrink: 0;
}
.calendar.manager .manager-detail .cal-tasks label input {
  margin-right: 6px;
}
.calendar.manager .manager-detail .cal-tasks label span {
  margin-left: 3px;
}
.calendar.manager > .toolbar h1 {
  font-weight: 600;
}
.calendar.manager > .toolbar .density-label {
  margin-right: 6px;
}
.calendar.manager > .toolbar .weeks {
  color: var(--colorFgFaded);
  padding: 3px 6px;
  background-color: var(--colorBg);
  border-radius: var(--radiusRounded);
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.calendar.manager > .toolbar .button-toolbar.button-menu button .button-title {
  padding-left: 6px;
}
.calendar.manager .search-results-list {
  display: block;
  flex: 1;
}
.calendar.manager .no-search-results {
  padding: 0 6px;
  background-color: var(--colorBgLightIntense);
}
.panel .manager-content,
.calendar.manager .manager-content {
  flex: 4 4;
  border-top: 1px solid var(--colorBorder);
  position: relative;
}
.panel .manager-content.search-result,
.calendar.manager .manager-content.search-result {
  display: flex;
}
.panel .manager-content.search-result .calendar-viewport,
.calendar.manager .manager-content.search-result .calendar-viewport {
  flex: 1;
}
.panel .manager-content.search-result .calendar-viewport .search-results-list,
.calendar.manager .manager-content.search-result .calendar-viewport .search-results-list {
  display: block;
  min-height: auto;
  flex: 1;
  overflow: hidden;
}
.panel .search-results,
.calendar.manager .search-results {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: center;
  padding: 6px 12px;
  background-color: var(--colorBg);
  border-top: 1px solid var(--colorBgDarker);
  font-weight: 600;
}
.panel .search-results button,
.calendar.manager .search-results button {
  background: none;
  border: none;
  line-height: normal;
}
.panel .search-results button svg,
.calendar.manager .search-results button svg {
  width: 16px;
  height: 16px;
}
.panel .manager-content.search-result {
  flex: 1;
}
.CalendarPanel-MiniCalendar {
  position: relative;
  display: flex;
  flex-direction: column;
  justify-content: space-around;
  padding-top: 9px;
}
.calendar-grid {
  display: grid;
  width: 100%;
  height: 100%;
  gap: 1px;
  overflow-y: auto;
  outline: unset;
}
.panel .calendar-grid {
  scrollbar-gutter: stable;
}
.calendar-grid > * {
  min-width: min-content;
}
.calendar-grid .calendar-header-date {
  position: sticky;
  top: 0px;
  text-align: center;
  padding: 3px 12px;
  z-index: 2;
  font-weight: 500;
  background-color: var(--colorBg);
  outline: 1px solid var(--colorBorderSubtle);
}
.calendar-grid .calendar-header-date.current {
  font-weight: bold;
}
.calendar-grid .calendar-background-day {
  pointer-events: none;
  border-left: 1px solid var(--colorBorderSubtle);
  margin-left: -1px;
}
.manager .calendar-grid .calendar-background-day {
  background-color: var(--colorBgLightIntense);
}
.calendar-grid .calendar-background-day.weekend {
  background-color: var(--colorBgLight);
}
.calendar-grid .week-number {
  font-weight: 500;
}
.calendar-grid .hour,
.calendar-grid .week-number {
  position: sticky;
  left: 0;
  grid-column-start: 1;
  z-index: 2;
}
.calendar-grid .calendar-drop-target {
  display: flex;
  align-items: center;
  border: 1px solid transparent;
  outline: 1px solid transparent;
  background-color: var(--colorBgLightIntense);
}
.calendar-grid .calendar-drop-target.weekend {
  background-color: var(--colorBgLight);
}
.calendar-grid .calendar-drop-target.out-of-view {
  background-color: var(--colorBg);
  color: var(--colorFgFadedMore);
}
.calendar-grid .calendar-drop-target.dragged-over,
.calendar-grid .calendar-drop-target:active,
.calendar-grid .calendar-drop-target:hover {
  background-color: var(--colorBg);
}
.calendar-add-event-button {
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBg));
  border: 1px solid var(--colorBorderSubtle);
  border-radius: var(--radiusHalf);
  margin: 0;
  min-height: 16px;
}
.calendar-add-event-button svg {
  height: 100%;
  width: 100%;
  max-height: 12px;
  max-width: 12px;
}
.calendar-grid-hours .calendar-add-event-button {
  position: relative;
  top: 1px;
}
.calendar-add-event-button:hover {
  background-image: none;
  background-color: var(--colorBg);
}
.calendar-grid-agenda .calendar-add-event-button {
  height: 20px;
  width: 100%;
  background: none;
  border: none;
  font-weight: 400;
  font-size: 13px;
  flex-direction: row;
  justify-content: start;
  margin: 2px 0;
  padding: 6px 1px;
  color: var(--colorFgFaded);
  height: inherit;
  border-radius: var(--radiusHalf);
}
.calendar-grid-agenda .calendar-add-event-button:hover {
  color: var(--colorFg);
  background: var(--colorBgDark);
}
.calendar-grid-agenda .calendar-add-event-button:hover:before {
  border-color: var(--colorFg);
}
.Dashboard-Widgets .transparent .calendar-grid-agenda .calendar-add-event-button:hover {
  color: var(--colorImageCenterFg, var(--colorWindowFg));
  background: var(--colorBgAlphaHeavier);
}
.calendar-grid-agenda:focus-visible .calendar-grid-agenda .calendar-add-event-button:not(.is-dragging).active,
.calendar-grid-agenda:focus-within .calendar-grid-agenda .calendar-add-event-button:not(.is-dragging).active {
  background: var(--colorBgDark);
}
.calendar-grid-agenda .calendar-add-event-button:before {
  content: '';
  mask: url(/resources/mask-add-outline.svg) no-repeat 50% 50%;
  mask-size: cover;
  display: block;
  margin: 0 2px;
  box-sizing: border-box;
  width: 16px;
  height: 16px;
  background-color: currentColor;
}
.calendar-grid-agenda .calendar-add-event-button.task-list:before {
  content: ' ';
  mask: none;
  background: none;
  margin: 0 6px;
  box-sizing: border-box;
  border: 1px dashed currentColor;
  border-radius: var(--radiusHalf);
}
.is-dragging.calendar-add-event-button {
  pointer-events: none;
}
.calendar-add-event-button.disabled {
  opacity: 0.5;
  pointer-events: none;
}
.calendar-grid:focus-visible .calendar-add-event-button:not(.is-dragging).active,
.calendar-grid:focus-within .calendar-add-event-button:not(.is-dragging).active,
.calendar-grid:focus-visible .calendar-add-event-button:not(.is-dragging):focus,
.calendar-grid:focus-within .calendar-add-event-button:not(.is-dragging):focus,
.calendar-grid:focus-visible .calendar-add-event-button:not(.is-dragging):hover,
.calendar-grid:focus-within .calendar-add-event-button:not(.is-dragging):hover {
  color: var(--colorFg);
  background-color: var(--colorBgDark);
  border-color: var(--colorCalendarBg);
}
.calendar-grid-hours {
  --calendar-hour-column-width: 50px;
}
.calendar-grid-hours .calendar-day-allday {
  display: grid;
  grid-template-columns: repeat(auto-fit, minmax(100px, 1fr));
  grid-column-start: 2;
  grid-gap: 6px;
  border-bottom: 1px solid var(--colorBgDarker);
  padding: 3px 0;
}
.manager-detail .calendar-grid-hours {
  min-width: 270px;
}
.calendar-grid-hours .calendar-grid-hover {
  display: none;
}
.calendar-grid-hours:hover .calendar-grid-hover {
  display: block;
  pointer-events: none;
  background-color: var(--colorBg);
}
.calendar-grid-hours .hour-track {
  grid-row-start: 1;
  grid-column-start: 1;
  position: sticky;
  left: 0;
  z-index: 2;
}
.manager .calendar-grid-hours .hour-track {
  background-color: var(--colorBgLight);
}
.calendar-grid-hours .hour {
  font-size: 11.5px;
  color: var(--colorFgFaded);
  grid-row-end: span 4;
  min-height: 16px;
  white-space: nowrap;
}
.calendar-grid-hours .hour.hour-last {
  grid-row-end: span 1;
}
.calendar-grid-hours .hour .hour-value {
  position: relative;
  margin-top: -0.65em;
  text-align: right;
  font-variant-numeric: tabular-nums lining-nums;
  width: 100%;
  height: 100%;
  padding: 0 9px;
}
.calendar-grid-hours .quarter {
  min-height: 5px;
  grid-column-start: 1;
}
.calendar-grid-hours .quarter.collapsed {
  min-height: 0;
}
.calendar-grid-hours .quarter-line {
  height: 1px;
  border-top: 1px dotted var(--colorBorder);
  grid-column-start: 2;
  grid-column-end: grid-right;
}
.calendar-grid-hours .hour-line {
  height: 1px;
  border-top: 1px solid var(--colorBorderSubtle);
  grid-column-start: 2;
  grid-column-end: grid-right;
}
.calendar-grid-hours .current-time {
  position: relative;
}
.calendar-grid-hours .current-time .marker {
  position: absolute;
  left: 0;
  right: 0;
  display: block;
  height: 1px;
  background-color: var(--colorHighlightBg);
}
.calendar-grid-hours .current-time .marker:before {
  z-index: 2;
  display: block;
  content: '';
  background-color: var(--colorHighlightBg);
  width: 8.66666667px;
  height: 8.66666667px;
  border-radius: 50%;
  position: absolute;
  top: -4.33333333px;
  left: -8.66666667px;
}
.calendar-grid-multiweek,
.calendar-grid-month {
  grid-template-columns: repeat(7, minmax(min-content, 14.28571429%));
}
.calendar-grid-multiweek.show-weeknumber,
.calendar-grid-month.show-weeknumber {
  grid-template-columns: 2em repeat(7, minmax(min-content, 14.28571429%));
}
.calendar-day-picker {
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: var(--colorBgLightIntense);
}
.calendar-grid-days .week-number {
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: var(--colorBgLight);
}
.calendar-grid-days .week-number .week-number-value {
  font-variant-numeric: tabular-nums lining-nums;
}
.calendar-grid-days .calendar-drop-target {
  align-items: start;
  justify-content: center;
  line-height: 1.65em;
}
.calendar-grid-days .calendar-drop-target .day {
  width: 100%;
  text-align: center;
  color: var(--colorFgFadedMore);
}
.calendar-grid-days .calendar-drop-target .day.current {
  background-color: var(--colorHighlightBg);
  color: var(--colorBg);
  font-weight: bold;
  border-radius: var(--radiusHalf);
  width: calc(100% + 12px);
}
.calendar-grid-days.calendar-grid-week {
  grid-template-columns: 1fr 1fr;
}
.calendar-grid-days .calendar-add-event-button {
  pointer-events: none;
}
.panel .calendar-grid-days .calendar-add-event-button {
  margin-top: 4px;
}
.calendar-grid-days .calendar-add-event-button.active {
  pointer-events: initial;
}
.calendar-grid-days .calendar-add-event-button.selected,
.calendar-grid-days .calendar-add-event-button:hover {
  opacity: 1;
}
.calendar-grid-days:focus-visible .calendar-add-event-button:not(.is-dragging).active,
.calendar-grid-days:focus-within .calendar-add-event-button:not(.is-dragging).active {
  background-color: var(--colorBg);
  border: 1px solid var(--colorCalendarBg);
  outline: unset;
}
.calendar-grid-year {
  --padding: 6px * 2;
  grid-template-columns: repeat(auto-fill, minmax(22em, 1fr));
  grid-gap: var(--padding);
  padding: var(--padding) max(var(--padding), (100% - 100em) / 2);
  justify-items: center;
}
.calendar-grid-year .month-name {
  font-weight: bold;
  text-align: center;
  padding: 6px;
  text-transform: capitalize;
}
.calendar-grid-agenda {
  min-height: 100%;
  display: flex;
  flex-direction: column;
  align-items: center;
  overflow-y: auto;
  background-color: var(--colorBgLightIntense);
  outline: unset;
  gap: 6px;
}
.panel .calendar-grid-agenda {
  background-color: transparent;
}
.calendar-grid-agenda .cal-tasks-row {
  display: flex;
  flex-direction: column;
  width: 100%;
  border-bottom: 1px solid var(--colorBgDark);
  justify-content: left;
}
.calendar-grid-agenda .cal-tasks-row:last-child {
  border: none;
}
.Dashboard-Widgets .transparent .calendar-grid-agenda .cal-tasks-row {
  border-color: var(--colorBgAlphaHeavier);
}
.calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date {
  flex: 0 0 auto;
  font-size: 11.5px;
  color: var(--colorFgFaded);
  text-align: left;
  padding: 6px 0 0 6px;
}
.calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date.current {
  font-weight: bold;
}
.calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date .cal-tasks-row-dow {
  margin: 3px 0 0 0;
  padding: 3px 0 0 6px;
  margin-right: 3px;
  border-top-left-radius: var(--radiusHalf);
  border-top-right-radius: var(--radiusHalf);
}
.calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date .cal-tasks-row-dow:after {
  content: ',';
}
.calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date .cal-tasks-row-doy {
  padding: 0 0 3px 6px;
  border-bottom-left-radius: var(--radiusHalf);
  border-bottom-right-radius: var(--radiusHalf);
}
.calendar-grid-agenda .cal-tasks-row .cal-tasks-row-events {
  padding: 6px 6px 3px 6px;
  flex: 1 1;
  display: flex;
  flex-direction: column;
  gap: 2px;
  align-items: center;
  min-width: 150px;
}
.calendar-grid-agenda .cal-tasks-row .cal-tasks-row-events .event-container {
  width: 100%;
  position: relative;
}
.calendar-grid-agenda .cal-tasks-row .cal-tasks-row-events .event-container.exiting {
  opacity: 0;
  transition: opacity 500ms ease-in;
  transition-delay: 1000ms;
}
.manager-content .calendar-grid-agenda .cal-tasks-row {
  flex-direction: row;
  justify-content: center;
}
.manager-content .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date {
  flex-basis: 10em;
  font-size: 13px;
  padding: 0 6px;
}
.panel .manager-content .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date {
  flex-basis: 100%;
}
.manager-content .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date.current {
  background: none;
}
.manager-content .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date.current .cal-tasks-row-doy,
.manager-content .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date.current .cal-tasks-row-dow {
  width: 100%;
  margin-top: 6px;
  font-weight: bold;
}
.manager .manager-content .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date span {
  display: block;
}
.manager .manager-content .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date span:after {
  content: unset;
}
#modal-bg .calendar-dialog .modal-wrapper {
  background-color: var(--colorBgIntense);
}
.calendar-dialog .Invitation-Preview {
  margin: 12px 0;
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
  min-height: 8em;
}
.calendar-dialog .Invitation-Preview-Title {
  padding: 3px 12px;
  background-color: var(--colorBorder);
  font-weight: 600;
}
.calendar-dialog .Invitation-Preview-Body {
  background-color: var(--colorBg);
  padding: 12px;
}
.calendar-dialog footer {
  flex-wrap: nowrap;
  border-top: 1px solid var(--colorBgDark);
}
#modal-bg.calendar-dialog {
  top: 0;
}
.dialog-add-event,
.dialog-add-template {
  display: flex;
  flex-direction: column;
  height: 100%;
  border-radius: var(--radius);
}
#modal-bg.calendar-new .dialog-add-event .dialog-content,
#modal-bg.calendar-new .dialog-add-template .dialog-content {
  overflow-y: auto;
  flex: 1 1 auto;
  padding: 6px;
}
#modal-bg.calendar-new .dialog-add-event .dialog-content p.info,
#modal-bg.calendar-new .dialog-add-template .dialog-content p.info {
  max-width: 36em;
}
#modal-bg.calendar-new .dialog-add-template .dialog-content {
  overflow-y: auto;
  flex: 1 1 auto;
  padding: 0 calc(6px * 2 - var(--scrollbarWidth)) 12px 12px;
}
.sentry {
  position: absolute;
}
#app .dialog-content .import-webcal > p {
  margin: 6px 0 12px;
}
#app .dialog-content .import-webcal .floating-label {
  flex-direction: row;
  align-items: center;
}
#app .dialog-content .import-calendar-files padding-right .dialog-content {
  scrollbar-gutter: unset;
}
#app .dialog-content .import-calendar-targets {
  padding: 0;
}
#app .dialog-content .import-calendar-target {
  width: 400px;
  flex-wrap: wrap;
  padding: 6px;
  gap: 6px;
}
#app .dialog-content .import-calendar-target > * {
  flex: 1 1 auto;
}
#app .dialog-content .import-calendar-target select,
#app .dialog-content .import-calendar-target label {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
#app .dialog-content .import-calendar-target .import-calendar-name {
  font-weight: bold;
  flex-basis: 100%;
}
.CalendarManagerAddDialog {
  position: fixed;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  z-index: 2;
  display: flex;
  align-items: center;
  justify-content: center;
}
.CalendarManagerAddDialog .dialog-add-event {
  height: fit-content;
  color: var(--colorFg);
  background-color: var(--colorBgLight);
  border-radius: inherit;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.calendar-drag-image {
  position: absolute;
  left: -10000px;
  width: 1px;
  height: 1px;
}
.calendar-drag-overlay {
  height: 100%;
  min-height: 17px;
  display: grid;
  grid-auto-flow: column;
  border: 2px solid transparent;
  color: var(--colorFgIntense);
  justify-content: space-between;
  background-color: var(--colorCalendarBgAlpha);
  padding-left: 6px;
  padding-right: 6px;
}
.calendar-drag-overlay.start {
  border-top-left-radius: var(--radiusHalf);
  border-top-right-radius: var(--radiusHalf);
}
.calendar-drag-overlay.end {
  border-bottom-left-radius: var(--radiusHalf);
  border-bottom-right-radius: var(--radiusHalf);
}
.calendar-drag-overlay .start-time {
  position: relative;
  align-self: start;
}
.calendar-drag-overlay .end-time {
  position: relative;
  align-self: end;
}
.CalendarAccountSheet {
  display: flex;
  flex: 1;
  flex-direction: column;
  gap: 6px;
  padding: 24px 0 0 0;
  color: var(--colorFg);
  background-color: var(--colorBgLight);
}
.CalendarAccountSheet a {
  color: var(--colorHighlightBg);
  text-decoration: underline;
  cursor: pointer;
}
.CalendarAccountSheet h1 {
  font-weight: 600;
  font-size: 23px;
  margin: 18px 0;
}
.CalendarAccountSheet h2 {
  font-weight: 600;
  font-size: 23px;
  margin: 0 auto 12px;
  text-transform: initial;
  border-bottom: initial;
  letter-spacing: initial;
}
.CalendarAccountSheet .detail {
  overflow-y: hidden;
  display: flex;
  flex-direction: column;
}
.CalendarAccountSheet .detail-content {
  display: flex;
  flex-direction: column;
  align-items: center;
  margin: 18px auto;
  padding: 0 18px;
  flex: 0 1 auto;
}
.CalendarAccountSheet .detail-content p {
  margin-bottom: 18px;
  text-align: center;
}
.CalendarAccountSheet .detail-content .toolbar.toolbar-pills {
  gap: 6px;
}
.CalendarAccountSheet .detail-content .setting-group.unlimited {
  width: 100%;
  display: flex;
  flex-direction: row;
  justify-content: space-between;
}
.CalendarAccountSheet .detail-content .setting-group {
  display: inline-block;
  margin: 3px 6px;
  width: 100%;
}
.CalendarAccountSheet .detail-toolbar {
  padding: 12px 24px;
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  justify-content: center;
  gap: 6px;
  background-color: var(--colorBg);
  border-top: 1px solid var(--colorBorder);
}
.account-settings.master-detail-wrapper > h3 {
  font-size: 11.5px;
  font-weight: 400;
  margin: 6px 0 18px;
  color: var(--colorFgFadedMore);
  max-width: 34em;
}
.account-settings.master-detail {
  height: 320px;
}
.CalendarAccountSheet .detail-done .detail-content,
.account-settings .detail-done .detail-content {
  display: flex;
  flex-direction: column;
  align-items: center;
}
.CalendarAccountSheet .detail-done .detail-content h1,
.account-settings .detail-done .detail-content h1 {
  font-weight: 600;
  margin: 18px 0 6px 0;
}
.CalendarAccountSheet .detail-done .detail-content p,
.account-settings .detail-done .detail-content p {
  text-align: center;
}
.CalendarAccountSheet .detail-content table,
.account-settings .detail-content table {
  width: 100%;
  margin-bottom: 24px;
  border: 1px solid var(--colorBorder);
  color: var(--colorFg);
  background-color: var(--colorBgLight);
}
.CalendarAccountSheet .detail-content thead,
.account-settings .detail-content thead {
  font-weight: 600;
  background-color: var(--colorBgDarker);
}
.CalendarAccountSheet .detail-content tr,
.account-settings .detail-content tr {
  border-bottom: 1px solid var(--colorBorder);
}
.CalendarAccountSheet .detail-content td,
.account-settings .detail-content td {
  width: 60px;
  padding: 6px 3px;
  text-align: center;
  border-left: 1px solid var(--colorBorder);
}
.CalendarAccountSheet .detail-content td:first-child,
.account-settings .detail-content td:first-child {
  width: auto;
  padding: 6px;
  text-align: left;
  border: none;
}
.CalendarAccountSheet-Exit {
  position: fixed;
  right: 5px;
  top: 5px;
  height: 30px;
  width: 30px;
  font-weight: 400;
  background-color: initial;
  border: none;
}
.CalendarAccountSheet-Exit:hover {
  transform: scale(1.2);
  transition: 100ms;
  cursor: pointer;
  border-color: var(--colorImageCenterFg);
}
.CalendarMonth {
  display: grid;
  grid-template-columns: repeat(7, 1fr);
  grid-gap: 6px;
  justify-items: center;
  border-radius: var(--radiusHalf);
}
.CalendarMonth--ShowWeeknumber {
  grid-template-columns: 2fr repeat(7, 3fr);
}
.CalendarMonth svg {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  stroke-width: 20;
}
.CalendarMonth-Day {
  height: 26px;
  width: 32px;
  position: relative;
  display: flex;
  align-items: center;
  justify-content: center;
  overflow: hidden;
  outline: 1px solid var(--colorBorderSubtle);
}
.CalendarMonth-Day:active {
  outline-color: var(--colorBorder);
}
.CalendarMonth-Day--Weekend {
  background-color: var(--colorBg);
}
.CalendarMonth-Day--OtherMonth {
  color: var(--colorFgFadedMost);
}
.CalendarMonth-Day--Current {
  background: var(--colorFgFadedMore);
  color: var(--colorBg);
  font-weight: bold;
}
.CalendarMonth-Day--Selected {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.CalendarMonth-Day--Selected:focus-visible {
  outline-color: var(--colorCalendarBg, var(--colorHighlightBg));
}
.CalendarMonth-Week,
.CalendarMonth-DayOfWeek {
  width: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 10px;
  color: var(--colorFgFaded);
  padding: 0 3px;
}
.CalendarMonth-Week {
  justify-content: flex-end;
}
@keyframes CalendarNotificationFadeUp {
  0% {
    opacity: 0;
    transform: translateY(100%);
  }
  100% {
    opacity: 1;
    transform: translateY(0);
  }
}
@keyframes CalendarNotificationFadeDown {
  0% {
    opacity: 0;
    transform: translateY(-100%);
  }
  100% {
    opacity: 1;
    transform: translateY(0);
  }
}
.CalendarNotifications {
  display: flex;
  flex-direction: column;
  background-color: var(--colorBgIntense);
  border-radius: var(--radius);
  max-height: 50vh;
  min-width: 400px;
  max-width: 600px;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.CalendarNotifications--FadeUp {
  animation: CalendarNotificationFadeUp 400ms cubic-bezier(0, 0.85, 0.2, 1);
}
.CalendarNotifications--FadeDown {
  animation: CalendarNotificationFadeDown 400ms cubic-bezier(0, 0.85, 0.2, 1);
}
.CalendarNotifications-Header {
  display: flex;
  flex-direction: row;
  gap: 6px;
}
.CalendarNotifications-List {
  overflow-y: auto;
  overflow-x: hidden;
  padding: 2px 0;
}
.CalendarNotifications-Footer {
  gap: 6px;
  align-items: center;
  margin-top: 12px;
  padding-top: 12px;
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.CalendarNotification-Content {
  width: 400px;
  display: flex;
  position: relative;
  flex-direction: row;
  align-items: flex-start;
  gap: 6px;
  padding: 12px 18px;
  cursor: pointer;
  margin: 0 12px 0 6px;
  padding: 6px 6px 6px 12px;
  align-items: center;
  border-radius: var(--radius);
}
.CalendarNotification-Content:hover,
.CalendarNotification-Content:focus-within {
  background-color: var(--colorBg);
}
.CalendarNotification-Time {
  flex: 0 0 auto;
  z-index: 1;
}
.CalendarNotification-Text {
  flex: 1 1 auto;
  font-weight: 600;
  z-index: 1;
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
}
.CalendarNotifications-List .CalendarNotification-Text {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.CalendarNotification-Actions {
  flex: 0 0 auto;
  display: flex;
  flex-direction: row-reverse;
  justify-content: flex-end;
  align-items: center;
}
.CalendarNotification-Actions .button-toolbar button {
  height: 28px;
  margin: 0;
  padding: 0 6px;
  width: 0;
  opacity: 0;
  z-index: 1;
}
.CalendarNotification-Content:hover .CalendarNotification-Actions button,
.CalendarNotification-Content:focus-within .CalendarNotification-Actions button,
.CalendarNotification-Actions .button-highlight-color button,
.CalendarNotification-Actions .button-highlight-color ~ div button {
  width: auto;
  opacity: 1;
}
.CalendarNotification-Actions .CalendarNotifcation-HoverBackground {
  position: absolute;
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  border-radius: var(--radius);
  z-index: 0;
}
.CalendarNotification-Actions .button-highlight-color ~ .CalendarNotifcation-HoverBackground {
  background-color: var(--colorBg);
}
.CalendarNotification-Actions > * {
  margin-right: 6px;
}
.CalendarNotification-Button.CalendarNotification-Button.CalendarNotification-Button {
  margin: 0;
}
.CalendarNotification-Input {
  width: 3em;
}
.calendar-alarm .modal-wrapper div:focus-visible {
  outline: none;
}
.CalendarPicker {
  width: max-content;
  min-width: 200px;
  max-width: 320px;
  background-color: var(--colorBgLight);
  padding: 4px;
  border-radius: var(--radius);
}
.CalendarPicker:focus-visible {
  outline: unset;
}
.CalendarPicker-Account {
  padding: 6px;
  font-size: 11.5px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.CalendarPicker-Account:not(:first-child) {
  margin-top: 6px;
}
.CalendarPicker-Item {
  display: flex;
  align-items: center;
  padding: 0 6px;
  height: 24px;
  background: none;
  border: none;
  border-radius: var(--radiusHalf);
  width: 100%;
}
.CalendarPicker-Item:hover {
  background-color: var(--colorBgDark);
}
.mac .CalendarPicker-Item:hover,
.linux .CalendarPicker-Item:hover {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
}
.CalendarPicker-Item:focus-visible {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  outline: unset;
}
.CalendarPicker-Item--Submenu {
  position: relative;
  padding-right: 22px;
  border-radius: var(--radiusHalf);
}
.CalendarPicker-Item--Submenu:hover {
  background-color: var(--colorBgDark);
}
.mac .CalendarPicker-Item--Submenu:hover,
.linux .CalendarPicker-Item--Submenu:hover {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
}
.CalendarPicker-SubmenuIcon {
  position: absolute;
  right: 6px;
}
.CalendarPicker-Separator {
  margin: 3px 0;
  border-top: 1px solid var(--colorFgAlpha);
}
.CalendarPicker-Icon {
  margin-right: 6px;
  height: 16px;
  width: 16px;
}
.CalendarPicker-Title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.CalendarPicker-Title:first-child {
  margin-left: 22px;
}
.CalendarPicker-Title--Default {
  font-weight: 600;
}
.CalendarPicker-Submenu {
  width: max-content;
  position: absolute;
  left: 100%;
  top: -3px;
  padding: 3px;
  overflow: hidden;
  color: var(--colorFg);
  background-color: var(--colorBgLight);
  border-radius: var(--radiusHalf);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.DatePickerPopup {
  display: flex;
  flex-direction: column;
  align-items: center;
  width: 100%;
  background-color: var(--colorBgIntense);
  border-radius: inherit;
  overflow: hidden;
  outline: unset;
}
.DatePickerPopup .toolbar {
  width: 100%;
  padding: 6px;
  margin-bottom: 6px;
  background-color: var(--colorBg);
}
.DatePickerPopup .CalendarMonth {
  gap: 6px;
}
.DatePickerPopup .CalendarMonth-Day {
  width: stretch;
}
.DatePickerPopup .CalendarMonth-Day--Current {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  outline: 2px solid var(--colorHighlightBg);
}
.DatePickerPopup h1 {
  border-radius: var(--radius);
  padding: 3px 6px;
  font-weight: 600;
  border: 1px solid transparent;
}
.DatePickerPopup h1.button:hover {
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgLight));
  border-color: var(--colorBorder);
}
.DatePickerPopup-Contents {
  width: 100%;
  padding: 0 6px 6px;
}
.DatePickerPopup-Contents--Decrease {
  animation: dropfade 100ms;
}
.DatePickerPopup-Contents--Increase {
  animation: pullfade 100ms;
}
.DatePickerPopup-YearMonths {
  display: grid;
  width: 100%;
  margin-top: 12px;
  padding: 6px;
  gap: 6px;
  grid-template-columns: repeat(3, 1fr);
}
.DatePickerPopup-YearMonth {
  height: 26px;
  line-height: 26px;
  position: relative;
  padding: 0 6px;
  outline: 1px solid var(--colorBorderSubtle);
  text-align: center;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.DatePickerPopup-YearMonth--Highlighted {
  color: var(--colorAccentFg);
  background-color: var(--colorAccentBg);
}
.DatePickerPopup-YearMonth--Selected {
  outline: 2px solid var(--colorBorder);
  outline-offset: -1px;
}
:focus-visible .DatePickerPopup-YearMonth--Selected {
  outline-color: var(--colorCalendarBg, var(--colorHighlightBg));
}
.PeriodPicker {
  display: flex;
  align-items: center;
  border-radius: var(--radius);
  padding: 2px 2px 2px 12px;
  border: 1px solid transparent;
  gap: 6px;
  width: fit-content;
}
.PeriodPicker:hover {
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgLight));
  border: 1px solid var(--colorBorder);
}
.PeriodPicker:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -2px;
}
.PeriodPicker.PeriodPicker .button-toolbar > button,
.PeriodPicker.PeriodPicker .button-toolbar > button:hover,
.PeriodPicker.PeriodPicker .button-toolbar > button.button-pressed {
  height: 26px;
  border: none;
  box-shadow: none;
  background: none;
}
#calendar_panel .PeriodPicker.PeriodPicker {
  border-color: var(--colorBorder);
  padding: 0 0 0 12px;
  gap: 0;
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgDark));
}
#calendar_panel .PeriodPicker.PeriodPicker:hover:not(:disabled) {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
#calendar_panel .PeriodPicker.PeriodPicker:active:not(:disabled) {
  background-image: linear-gradient(var(--colorBgDark), var(--colorBgDark));
}
#calendar_panel .PeriodPicker.PeriodPicker .button-toolbar {
  min-width: 16px;
}
#calendar_panel .PeriodPicker.PeriodPicker .button-toolbar > button {
  background-color: transparent;
}
#calendar_panel .PeriodPicker h1 {
  display: block;
  font-size: 13px;
  margin: 0;
}
.CalendarEventBubble {
  position: absolute;
  max-height: 100%;
  padding: 6px 12px;
  left: -10000px;
  z-index: 6;
  display: flex;
}
.CalendarEventBubble-Arrow {
  position: absolute;
  width: 15px;
  height: 15px;
  transform: rotateZ(45deg) translate(-33%, -33%);
  background-color: var(--colorBgIntense);
  content: '';
}
.CalendarEventBubble--LeftArrow .CalendarEventBubble-Arrow {
  left: 5px;
  box-shadow: -2px 2px 2px 0 rgba(0, 0, 0, 0.05);
}
.CalendarEventBubble--RightArrow .CalendarEventBubble-Arrow {
  right: 5px;
  box-shadow: 2px -2px 2px 0 rgba(0, 0, 0, 0.05);
}
.CalendarEventBubble-Inner {
  height: 100%;
  padding: 6px;
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.15), 0 28px 50px rgba(0, 0, 0, 0.18);
  color: var(--colorFg);
  fill: var(--colorFg);
  background: var(--colorBgIntense);
  border-radius: var(--radius);
}
.CalendarEventBubble-Inner form {
  display: flex;
  flex-direction: column;
  height: 100%;
}
.CalendarEventBubble-Inner .CalendarEventFull {
  overflow-y: auto;
}
.CalendarEventBubble-Buttons {
  margin-top: 6px;
  padding: 6px;
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
  gap: 6px;
}
.CalendarEventFull {
  width: 440px;
}
.dialog-content .CalendarEventFull {
  padding: 18px 12px 24px 12px;
}
.settings-content .dialog-content .CalendarEventFull {
  padding: 0;
}
.CalendarEventFull-Row {
  display: flex;
  flex-direction: row;
  align-items: center;
  margin-top: 6px;
  gap: 12px;
}
.CalendarEventFull-Row .button-toolbar {
  margin: 0 0 0 6px;
}
.CalendarEventFull-Row .button-toolbar:first-child,
.CalendarEventFull-Row .button-toolbar.CalendarSelector {
  margin: 0;
}
.CalendarEventFull-Row > input,
.CalendarEventFull-Row > p.field {
  width: 100%;
  margin: 0;
  cursor: text;
  padding: 2px 0;
  border-bottom: 2px solid transparent;
  word-break: break-word;
}
.CalendarEventFull-Row > input:focus-visible,
.CalendarEventFull-Row > p.field:focus-visible {
  border-color: var(--colorHighlightBg);
  outline: none;
}
.CalendarEventFull-Row > input[type=button] {
  width: auto;
  padding-left: 6px;
  padding-right: 6px;
}
.CalendarEventFull-Row > p.cal-event-title {
  font-size: 16px;
  font-weight: 600;
}
.settings-content .CalendarEventFull-Row > p.cal-event-title {
  font-size: inherit;
  font-weight: 400;
}
.CalendarEventFull-Row > p.cal-event-title,
.CalendarEventFull-Row > p.cal-event-description {
  max-height: 16vh;
  overflow-y: auto;
  overflow-x: hidden;
}
.CalendarEventFull-Row--NoIcon {
  padding-left: 40px;
}
.CalendarEventFull-Row input.circular,
.CalendarEventFull-Row button.circular {
  border-radius: var(--radiusRound);
  width: 20px;
  padding: 1px 0px;
  background-color: var(--colorBgLightIntense);
}
.CalendarEventFull-Row input.circular:hover,
.CalendarEventFull-Row button.circular:hover {
  background-color: var(--colorBg);
}
.CalendarEventFull-Row input.circular svg,
.CalendarEventFull-Row button.circular svg {
  width: 16px;
  height: auto;
}
.CalendarEventFull-Row .Participants {
  display: inline-block;
}
.CalendarEventFull-Row .Participants input[type=button] {
  margin-left: auto;
}
.CalendarEventFull-Row .Participants-List {
  max-height: 102px;
  overflow-y: auto;
}
.CalendarEventFull-TaskTime {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: 6px;
}
.CalendarEventFull-Icon {
  align-self: flex-start;
  height: 28px;
  width: 28px;
  flex: 0 0 28px;
  display: flex;
}
.CalendarEventFull-Icon > svg {
  margin: 5px auto;
  width: 16px;
  height: 16px;
  stroke: var(--colorFgFadedMore);
  fill: var(--colorFgFadedMore);
}
.CalendarEventFull-RowContent {
  display: flex;
  flex: 1;
  flex-direction: column;
}
.CalendarEventFull-Attachment {
  display: inline;
  margin: 3px 0 6px 0;
  color: var(--colorFg);
  background-color: var(--colorBgIntense);
  box-shadow: 0 0 0 1px var(--colorBorder);
  border-radius: var(--radiusHalf);
  padding: 2px 6px;
  cursor: pointer;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.CalendarEventFull .edit-group {
  display: flex;
  flex-direction: row;
  align-items: center;
  flex: 1;
}
.CalendarEventFull .edit-group + .edit-group {
  margin-top: 6px;
}
.CalendarEventFull .edit-group .toolbar {
  padding-top: 0;
}
.CalendarEventFull .edit-group .dom-picker .toolbar {
  display: flex;
  flex-wrap: wrap;
  margin: 0;
  padding: 2px;
}
.CalendarEventFull .edit-group .button-toolbar {
  min-width: unset;
  margin: 0;
}
.CalendarEventFull .edit-group .button-toolbar button {
  max-width: 20px;
  padding: 3px 1em;
  text-align: center;
}
.CalendarEventFull .edit-group .button-toolbar button:focus-visible {
  border-color: transparent;
  box-shadow: 0 0 0 2px var(--colorHighlightBg);
  z-index: 1;
}
.CalendarEventFull .edit-group label {
  display: flex;
  flex: 0 1 auto;
  flex-direction: row;
  justify-items: flex-start;
  align-items: center;
}
.CalendarEventFull .edit-group label:not(:last-child) {
  margin-right: 12px;
}
.CalendarEventFull .edit-group label > *:not(:last-child) {
  margin-right: 6px;
}
.CalendarEventFull .edit-group label > input[type=text],
.CalendarEventFull .edit-group label > input[type=number] {
  background-color: transparent;
  box-shadow: none;
  border: none;
  padding: 0;
  border-radius: 0;
}
.CalendarEventFull .edit-group label > input[type=text]:focus-visible,
.CalendarEventFull .edit-group label > input[type=number]:focus-visible {
  box-shadow: 0 2px 0 0 var(--colorHighlightBg);
  outline: none;
}
.CalendarEventFull .edit-group label > input[type=number] {
  width: 4ex;
  text-align: center;
}
.CalendarEventFull .edit-group label > input[type=text] {
  width: auto;
}
.CalendarEventFull .cal-event-participant {
  display: flex;
  flex-direction: row;
  align-items: center;
  margin-top: 6px;
}
.CalendarEventFull .cal-event-participant .cal-event-participant-address {
  margin-right: 6px;
}
.CalendarEventFull .cal-event-participant .cal-event-participant-status {
  margin-right: 6px;
  line-height: 1;
}
.CalendarEventFull .cal-event-participant svg {
  width: 16px;
  height: 16px;
}
.CalendarEventFull .dateInput,
.CalendarEventFull .dateInputHidden {
  background-color: transparent;
  padding: 0;
  border: unset;
  box-shadow: unset;
  outline: none;
  border-bottom: 1px solid var(--colorBgDarker);
}
.CalendarEventFull .dateInput input,
.CalendarEventFull .dateInputHidden input {
  background-color: transparent;
  border: 0;
}
.CalendarEventFull .dateInput:focus-visible,
.CalendarEventFull .dateInputHidden:focus-visible,
.CalendarEventFull .dateInput:focus-within,
.CalendarEventFull .dateInputHidden:focus-within {
  outline: none;
  box-shadow: inset 0 -2px var(--colorHighlightBg);
}
.CalendarEventFull .dateInput:first-child .faux,
.CalendarEventFull .dateInputHidden:first-child .faux {
  margin-left: 0;
}
.CalendarEventFull .dateInput .faux input.dateInputAmPm,
.CalendarEventFull .dateInputHidden .faux input.dateInputAmPm {
  width: 3ex;
}
.CalendarEventFull select[name='endsRepeating'] {
  flex: unset;
}
.CalendarEventFull input[type=button],
.CalendarEventFull button {
  margin: 0;
}
.CalendarEventFull input[type=button].circular,
.CalendarEventFull button.circular {
  border: 1px solid var(--colorBorder);
}
.CalendarEventFull input[type=button].circular:focus-visible,
.CalendarEventFull button.circular:focus-visible {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.CalendarEventFull input[type=button].TaskTime,
.CalendarEventFull button.TaskTime {
  margin-left: 6px;
}
.CalendarEventFull input[type=button].TaskTime:first-child,
.CalendarEventFull button.TaskTime:first-child {
  margin-left: 0;
}
.CalendarEventFull .FormFeedback {
  margin-left: 6px;
  margin-right: 6px;
}
.settings-content .dialog-content .CalendarEventFull,
.dialog-add-template .dialog-content .CalendarEventFull {
  padding: initial;
}
.settings-content .dialog-content .CalendarEventFull label,
.dialog-add-template .dialog-content .CalendarEventFull label {
  gap: 0;
}
.settings-content .dialog-content .CalendarEventFull .Switch,
.dialog-add-template .dialog-content .CalendarEventFull .Switch {
  margin-left: 12px;
}
.settings-content .dialog-content .CalendarEventFull .CalendarSelector,
.dialog-add-template .dialog-content .CalendarEventFull .CalendarSelector {
  flex: 1 1 auto;
  margin: 0;
}
.settings-content .dialog-content .CalendarEventFull .CalendarSelector button,
.dialog-add-template .dialog-content .CalendarEventFull .CalendarSelector button {
  justify-content: start;
  flex: 0 1 auto;
}
.settings-content .dialog-content .CalendarEventFull .CalendarSelector button .button-icon,
.dialog-add-template .dialog-content .CalendarEventFull .CalendarSelector button .button-icon {
  flex: 0;
}
.Participants-Input {
  position: relative;
}
.Participants-Input input {
  flex: 1 1 auto;
}
.Participants-List {
  max-height: 136px;
  overflow-y: auto;
}
.Participants-Dropdown {
  position: absolute;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  top: 20px;
  padding: 3px 0;
  background-color: var(--colorBgLightIntense);
  max-height: 300px;
  overflow-x: hidden;
  overflow-y: auto;
  z-index: 6;
}
.Participants-Dropdown-Item {
  display: flex;
  white-space: nowrap;
  padding: 2px 12px;
}
.Participants-Dropdown-Item:hover,
.Participants-Dropdown-Item--Selected {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
}
.Participants-Dropdown-Item-Secondary {
  padding-left: 12px;
}
.Participant {
  display: flex;
  flex-direction: row;
  align-items: center;
  margin: 3px 0 0 0;
  overflow: hidden;
}
.Participant > * {
  flex: 0 0 auto;
}
.Participant .select-wrapper {
  flex: 1;
}
.Participant-Status {
  height: 1em;
  width: 1em;
  margin-right: 6px;
}
.Participant-Address {
  flex: 1 1 auto;
  margin-right: 6px;
  margin-left: 9px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.MonthDayPicker {
  display: grid;
  flex: 0 1 100%;
  grid-template-columns: repeat(7, 1fr);
  grid-template-rows: min-content repeat(7, 1fr);
  grid-gap: 2px 1px;
  text-align: center;
  padding: 3px 6px 6px 6px;
  margin-bottom: 6px;
  background-color: var(--colorBgLightIntense);
  border-radius: var(--radius);
  overflow-y: hidden;
}
.MonthDayPicker-Header {
  grid-area: 1 / 1 / 2 / 8;
  display: flex;
  justify-content: space-between;
  align-items: center;
}
.MonthDayPicker-Month {
  text-transform: capitalize;
  margin-left: 6px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.MonthDayPicker-Day {
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 10px;
  padding: 3px 4px;
  line-height: 1;
  border-radius: var(--radiusHalf);
}
.MonthDayPicker-Day--OtherMonth {
  color: var(--colorFgFadedMore);
}
.MonthDayPicker-Day:active:not(--Current):not(--Selected) {
  background-color: var(--colorBgDark);
}
.MonthDayPicker-Day--Current {
  font-weight: 600;
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.MonthDayPicker-Day--Current:not(--Selected):active {
  background-color: var(--colorAccentBgDark);
}
.MonthDayPicker-Day--Selected {
  color: var(--colorCalendarFg, var(--colorHighlightFg));
  background-color: var(--colorCalendarBg, var(--colorHighlightBg));
}
.MonthDayPicker-Day--SelectedWeek {
  background-color: var(--colorBg);
  border-radius: 0;
}
.MonthDayPicker-DayOfWeek {
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 10px;
  font-weight: 600;
  padding: 3px 4px;
  line-height: 1;
}
.FilterAndSearch {
  position: relative;
}
.panel .FilterAndSearch {
  flex: 1;
}
.FilterAndSearch-Input.FilterAndSearch-Input {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  margin-right: -1px;
  flex: 0 1 150px;
  min-width: 40px;
}
.FilterAndSearch-Input.FilterAndSearch-Input:focus {
  position: relative;
}
.FilterAndSearch-Button.FilterAndSearch-Button {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  padding-left: 12px;
  padding-right: 12px;
}
.SearchDropdown {
  z-index: 101;
  position: absolute;
  top: 29px;
  right: 0;
  background-color: var(--colorBgIntense);
  border-radius: var(--radius);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  width: 380px;
  overflow: hidden;
}
.panel .SearchDropdown {
  width: stretch;
}
.SearchDropdown.SearchDropdown.SearchDropdown {
  margin: unset;
}
.SearchDropdown-Button {
  margin: 12px;
}
.SearchDropdown-Item {
  display: flex;
  flex-direction: column;
  padding: 6px 12px;
  background: none;
  border: none;
}
.SearchDropdown-Item--Selected {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.SearchDropdown-Item--Selected.SearchDropdown-Item--Selected mark {
  color: var(--colorHighlightFg);
}
.SearchDropdown-Item--Selected:active {
  background-color: var(--colorHighlightBgDark);
}
.SearchDropdown-ItemMetaData {
  display: flex;
}
.SearchDropdown-ItemIcon {
  flex: 0 0 auto;
  display: flex;
  align-items: flex-start;
  margin-right: 10px;
  height: 15px;
}
.SearchDropdown-ItemEvent {
  flex: 1 1 auto;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.SearchDropdown-ItemEventTitle {
  margin-bottom: 3px;
}
.SearchDropdown-ItemEventTitle mark {
  background-color: transparent;
  color: var(--colorFgIntense);
  font-weight: 600;
}
.SearchDropdown-ItemEventCalendar {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  margin-right: 6px;
  font-size: 11.5px;
}
.SearchDropdown-ItemDate {
  flex: 0 0 auto;
  text-align: right;
  margin-left: auto;
  font-size: 11.5px;
}
.SearchDropdown-MoreItems {
  margin: 6px 12px 0 12px;
  padding: 6px 0 0 12px;
  border-top: 1px solid var(--colorBorder);
}
.SearchDropdown-NoItems {
  padding: 12px;
}
.ShowCalendarTipsAndTricks {
  flex: 1 1 auto;
}
.ShowCalendarTipsAndTricks.ShowCalendarTipsAndTricks h1 {
  color: var(--colorHighlightBg);
  margin-top: 6px;
}
.ShowCalendarTipsAndTricks.ShowCalendarTipsAndTricks h3 {
  color: var(--colorFg);
  font-weight: 400;
  font-size: 16px;
}
.ShowCalendarTipsAndTricks .detail {
  height: 100%;
}
.ShowCalendarTipsAndTricks-Selectbox {
  display: flex;
  flex-direction: row;
  gap: 24px;
}
.ShowCalendarTipsAndTricks-Selectbox .selectbox {
  width: 180px;
  margin: 0;
}
.ShowCalendarTipsAndTricks-Selectbox .selectbox-image img {
  width: 100%;
  height: auto;
}
.ShowCalendarTipsAndTricks-WithImage {
  max-width: 500px;
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: 24px;
}
.ShowCalendarTipsAndTricks-TextBlock.ShowCalendarTipsAndTricks-TextBlock.ShowCalendarTipsAndTricks-TextBlock p {
  text-align: left;
}
svg.onboarding-illustration .bg-fill {
  fill: var(--colorBgLightIntense);
}
svg.onboarding-illustration .highlight-stroke {
  stroke: var(--colorHighlightBg);
}
svg.onboarding-illustration .highlight-fill {
  fill: var(--colorHighlightBg);
}
.panel.downloads .vivaldi-tree .tree-item {
  --treeViewRowHeight: 52px;
}
.DownloadItem {
  --iconOpacity: 1;
  --itemHeight: var(--treeViewRowHeight);
  --progressBarRowHeight: 12px;
  --metadataLineHeight: calc(calc(var(--itemHeight) - var(--progressBarRowHeight)) / 2);
  padding: 0 12px 0 6px;
  height: var(--itemHeight);
  width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  display: grid;
  grid-template-columns: 38px auto 24px;
  grid-template-rows: minmax(auto, var(--metadataLineHeight)) fit-content(var(--progressBarRowHeight)) minmax(auto, var(--metadataLineHeight));
  column-gap: 3px;
  row-gap: 2px;
  align-items: center;
  align-content: center;
  grid-template-areas: 'FileIcon FileName ActionButton' 'FileIcon ProgressBar ActionButton' 'FileIcon FileSize ActionButton';
}
.DownloadItem--Unavailable {
  --iconOpacity: 0.4;
}
.vivaldi-tree .tree-row .DownloadItem-Icon {
  grid-area: FileIcon;
  width: 32px;
  height: 32px;
  pointer-events: none;
  justify-self: flex-start;
  opacity: var(--iconOpacity);
}
.DownloadItem-FileName {
  translate: 0 3px;
  grid-area: FileName;
  align-self: end;
  display: grid;
  grid-template-columns: auto 1fr;
}
.DownloadItem-FileName-Name {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.DownloadItem-FileSize {
  grid-area: FileSize;
  align-self: start;
  opacity: 0.65;
  font-size: 11.5px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.DownloadItem .ActionButton {
  grid-area: ActionButton;
}
.DownloadItem-KeepDiscard {
  background-color: var(--colorHighlightBg);
  position: absolute;
  width: 100%;
  height: 100%;
  border-radius: var(--radius);
  display: flex;
  align-items: center;
  flex-wrap: wrap;
  gap: 3px 12px;
  padding: 6px 12px;
}
.DownloadItem-KeepDiscard-KeepDiscardButton {
  background-image: none;
  background-color: var(--colorBg);
}
.tree-row-selected .DownloadItem-KeepDiscard {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
  outline-offset: -2px;
}
.DownloadItem-ProgressBar {
  appearance: none;
  grid-area: ProgressBar;
  position: relative;
  height: 0;
  margin: 0;
  width: 100%;
  background-color: var(--colorFgAlpha);
  border-radius: var(--radiusHalf);
  transition: height 200ms linear 500ms, margin 200ms linear 500ms;
}
.DownloadItem-ProgressBar::-webkit-progress-bar,
.DownloadItem-ProgressBar::-webkit-progress-value {
  display: none;
}
.DownloadItem-ProgressBar:after {
  content: '';
  border-radius: var(--radiusHalf);
  background-color: var(--colorHighlightBg);
  position: absolute;
  inset: 0;
  will-change: scale;
  scale: 1 1;
  left: 0;
  top: 0;
  bottom: 0;
  right: 0;
  transition: scale var(--duration) linear;
  transform-origin: left;
}
.download-editor .DownloadItem-ProgressBar:after {
  transition: unset;
}
.DownloadItem-ProgressBar:focus {
  outline: none;
}
.DownloadItem-ProgressBar.visible {
  height: 6px;
  margin: 3px 0;
}
.DownloadItem-ProgressBar.visible:after {
  scale: var(--progress) 1;
}
.DownloadItem-ProgressBar.visible:not(.loading):after {
  background-color: color-mix(in srgb, var(--colorFg) 60%, transparent);
}
.DownloadItem-ProgressBar.visible.unknown-filesize {
  background-position: 0 0;
  background-image: linear-gradient(-45deg, transparent 5px, var(--colorHighlightBg) 6px, var(--colorHighlightBg) 14px, transparent 15px);
  background-size: 24px 6px;
  animation: animated-stripes 5s linear infinite;
}
.DownloadItem-ProgressBar.visible.unknown-filesize:after {
  scale: 0 1;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .DownloadItem-ProgressBar.visible {
  background-color: color-mix(in srgb, var(--colorHighlightFg) 20%, var(--colorHighlightBg));
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .DownloadItem-ProgressBar.visible:after {
  background-color: var(--colorHighlightFg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .DownloadItem-ProgressBar.visible:not(.loading):after {
  background-color: var(--colorHighlightFgAlpha);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .DownloadItem-ProgressBar.visible.unknown-filesize {
  background-image: linear-gradient(-45deg, var(--colorFgAlpha) 5px, var(--colorBgDarker) 6px, var(--colorBgDarker) 14px, var(--colorFgAlpha) 15px);
}
.download-editor.download-editor {
  display: flex;
  flex: 0 0 auto;
  padding: 0;
  min-height: 5px;
  scrollbar-gutter: stable;
}
.download-editor.download-editor .data {
  display: flex;
  flex-direction: column;
  flex: 1;
  max-width: 100%;
}
.download-editor.download-editor .data.disabled .panel-pathfield,
.download-editor.download-editor .data.disabled .panel-timefield {
  opacity: 0.5;
}
.download-editor.download-editor input.title {
  flex: 0 0 auto;
  margin: 12px 0 0;
}
@media screen and (max-height: 600px) {
  .download-editor {
    display: none;
  }
}
.panel-timefield,
.panel-urlfield,
.panel-pathfield {
  display: flex;
  flex: 0 0 30px;
  align-items: center;
  margin-left: 8px;
}
.panel-timefield.downloads,
.panel-urlfield.downloads,
.panel-pathfield.downloads {
  flex-wrap: wrap;
}
.panel-timefield {
  margin-top: 6px;
}
.panel-timefield.bookmark {
  margin-left: 6px;
}
.panel-timefield .container {
  max-width: 220px;
  display: grid;
  grid-template-columns: auto 1fr;
  grid-template-rows: 1fr 1fr;
  gap: 6px;
  align-items: center;
  grid-template-areas: 'started   started-time' 'completed progress';
}
.panel-timefield .started-time {
  grid-area: started-time;
}
.panel-timefield .progress {
  grid-area: progress;
  font-weight: 600;
  font-variant-numeric: tabular-nums;
  display: flex;
  align-items: center;
  gap: 6px;
}
.panel-timefield .started {
  color: var(--colorFgFaded);
  grid-area: started;
}
.panel-timefield .completed {
  color: var(--colorFgFaded);
  grid-area: completed;
}
.panel-urlfield > div {
  display: flex;
  flex: 1;
}
.panel-pathfield {
  margin-top: 6px;
}
.panel-pathfield .container {
  display: grid;
  height: 80px;
  width: 100%;
  grid-template-columns: 100px 1fr;
  grid-template-rows: 1fr 1fr minmax(32px, auto);
  gap: 6px;
  grid-auto-flow: row;
  grid-template-areas: 'completed     chart' 'speed         chart' 'actionbuttons actionbuttons';
}
.panel-pathfield .container .VictoryContainer {
  z-index: 1;
  border-radius: var(--radius);
}
.panel-pathfield .container .VictoryContainer svg {
  border: 1px solid var(--colorFgAlpha);
  border-radius: var(--radius);
}
.panel-pathfield .completed {
  grid-area: completed;
  display: flex;
  align-items: flex-end;
  font-weight: 600;
}
.panel-pathfield .speed {
  grid-area: speed;
  display: flex;
  align-items: flex-start;
  font-size: 11.5px;
}
.panel-pathfield .speed span {
  margin-right: 6px;
}
.panel-pathfield .speed span svg {
  fill: var(--colorFgFaded);
}
.panel-pathfield .chart {
  contain: strict;
  grid-area: chart;
  display: flex;
  align-items: center;
}
.panel-pathfield .actionbuttons {
  grid-area: actionbuttons;
  display: flex;
  gap: 6px;
  align-items: flex-end;
}
.panel-pathfield .action-button {
  padding: 0 12px;
}
.panel-pathfield #show-in-folder-button {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.panel-pathfield .download-speed-icon {
  flex: 0 0 16px;
  width: 16px;
  height: 16px;
}
.download-placeholder {
  width: 100%;
  height: 100%;
  display: grid;
}
.download-placeholder .download-empty-state {
  margin: 18px 12px;
  text-align: center;
}
.download-placeholder .download-empty-state h1 {
  font-weight: 600;
  margin-top: 18px;
  padding-bottom: 12px;
}
#contacts .vivaldi-tree .tree-row-image {
  border-radius: var(--radiusRound);
  line-height: 0;
  width: 18px;
  height: 18px;
}
#contacts .vivaldi-tree .tree-row-image img {
  width: 18px;
  height: 18px;
  image-rendering: -webkit-optimize-contrast;
}
#contacts.panel .panel-empty-state {
  flex: 1;
}
#contacts.panel .panel-empty-state ~ div,
#contacts.panel .panel-empty-state ~ section {
  visibility: collapse;
}
.panel-group .panel-contacts-edit {
  position: relative;
  overflow: visible;
  min-height: 2px;
  max-height: 600px;
  margin-top: 0;
  flex: 0;
  padding-top: 6px;
}
.panel-group .panel-contacts-edit .SlideBar {
  right: 9px;
  min-width: 0;
}
.contact-view {
  overflow-y: auto;
  display: grid;
  width: 100%;
  padding: 12px;
  grid-gap: 2px 6px;
  grid-template-columns: [photo-field] 60px [input-fields] 1fr;
}
.contact-view > * {
  grid-column: input-fields;
}
.contact-view .contact-field {
  display: flex;
}
.contact-view .contact-type-picker {
  grid-column: photo-field;
  font-size: 11.5px;
  height: 1.7em;
  padding: 0 6px;
  margin: auto 0;
}
.contact-view .contact-type-picker:after {
  scale: 0.8;
  right: 2px;
}
.contact-view .contact-header {
  display: contents;
}
.contact-view .contact-header .contact-name {
  display: flex;
  flex: 1;
  overflow: hidden;
  grid-column: input-fields;
  margin: auto 0;
  padding: 1px;
  font-weight: 700;
  font-size: 16px;
}
.contact-view .contact-field-type,
.contact-view .contact-photo-picker {
  grid-column: photo-field;
  display: flex;
  align-items: center;
  margin: auto 0 auto auto;
}
.contact-view .info {
  margin: 0 6px 0 0;
}
.contact-view .contact-action-button {
  width: 16px;
  height: 16px;
}
.contact-view .contact-action-button:hover {
  transform: scale(1.3);
}
.contact-view .contact-trusted {
  display: contents;
}
.contact-view .contact-trusted input {
  justify-self: flex-end;
  align-self: flex-start;
}
.contact-view .spacer {
  grid-column: span 2;
  height: 0;
  margin: 3px 0;
}
.contact-view .spacer + .spacer {
  margin: 0;
}
.contact-view .disabled {
  opacity: 0.5;
}
.contact-view form {
  display: contents;
  grid-column: input-fields;
}
.contact-view .add {
  grid-column: input-fields;
  margin-right: auto;
  padding: 3px 6px;
  min-height: 22px;
  font-size: 11.5px;
}
.contact-view .remove {
  width: 16px;
  height: 16px;
  border-radius: 100%;
  display: flex;
  line-height: 10px;
  color: #fff;
  background-color: var(--colorBorder);
  margin: auto 0 auto 6px;
  justify-content: center;
  font-weight: bold;
}
.contact-view .remove:hover {
  border-color: var(--colorError);
  background-color: var(--colorError);
}
.contact-view .dateInput {
  flex: 1;
}
.contact-view .contact-edit-note {
  margin-bottom: 12px;
  min-height: 56px;
}
.contact-view .contact-trusted input {
  margin: 6px 0 6px 6px;
}
.contact-view .contact-trusted span {
  margin-top: 6px;
  margin-bottom: 6px;
}
.contact-view .contact-trusted[disabled] {
  opacity: 0.5;
  pointer-events: none;
}
.contact-photo-picker .contact-photo {
  --photo-size: 50px;
  height: var(--photo-size);
  width: var(--photo-size);
  background-color: transparent;
  border-radius: var(--radiusRound);
  background-size: cover;
  background-position: 50%;
  position: relative;
}
.contact-photo-picker .contact-photo:active:after {
  border-radius: var(--radiusRound);
  position: absolute;
  content: '';
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-color: rgba(0, 0, 0, 0.2);
}
.contact-photo-picker .contact-photo > svg {
  width: 100%;
  height: 100%;
  pointer-events: none;
}
.contact-photo-picker .contact-photo.contact-photo-is-droptarget {
  filter: brightness(0.5);
}
.contact-photo-picker .contact-photo-picker-overlay {
  background: var(--colorBgLight);
  border-radius: var(--radius);
  position: absolute;
  padding: 12px;
  padding-right: 6px;
  left: 5px;
  top: -153px;
  width: 200px;
  height: 148px;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  display: flex;
  flex-direction: column;
  z-index: 3;
}
.contact-photo-picker .contact-photo-picker-overlay:before,
.contact-photo-picker .contact-photo-picker-overlay:after {
  content: '';
  position: absolute;
  bottom: -20px;
  left: 10px;
  border: 10px solid transparent;
  border-top-color: var(--colorBgLight);
  pointer-events: none;
}
.contact-photo-picker .contact-photo-picker-overlay:before {
  bottom: -21px;
  border-top-color: var(--colorBorder);
}
.contact-photo-picker .contact-photo-picker-overlay input[type=button] {
  margin-top: 6px;
  margin-bottom: 0;
  margin-left: 0;
  margin-right: 6px;
}
.contact-photo-picker .contact-photo-picker-overlay .photo-picker-suggestions {
  display: flex-wrap;
  margin-bottom: auto;
}
.contact-photo-picker .contact-photo-picker-overlay .photo-picker-suggestions .photo-picker-suggestion {
  margin-right: 3px;
  margin-bottom: 3px;
  height: 57px;
  width: 57px;
  background: var(--colorBg);
  background-size: cover;
  background-position: 50%;
}
.contact-photo-picker .contact-photo-picker-overlay .photo-picker-suggestions .photo-picker-suggestion > svg {
  pointer-events: none;
}
.contact-photo-picker .contact-photo-picker-overlay small {
  margin: 3px auto;
  text-align: center;
}
#browser.fullscreen.inner #mail_search {
  display: none !important;
}
#browser.fullscreen.inner .mail-detail-header {
  display: none !important;
}
.webpageview #contact_view {
  flex: 1;
  display: flex;
}
.webpageview #mail_view {
  display: flex;
  flex-direction: column;
  background-color: var(--colorBg);
  color: var(--colorFg);
  overflow: hidden;
}
.webpageview #mail_view #mail_search {
  display: flex;
  flex-direction: column;
  position: relative;
  z-index: 3;
  overflow: visible;
}
.webpageview #mail_view #mail_search > .toolbar {
  padding-left: 6px;
}
.webpageview #mail_view #mail_search > .toolbar.mail-search {
  padding: 6px;
  margin-bottom: 1px;
  border-bottom: 1px solid var(--colorBorder);
}
.webpageview #mail_view #mail_search > .toolbar .multiinput .multiinput-select {
  max-height: 120px;
  min-width: 100%;
}
.webpageview #mail_view #mail_search > .toolbar .multiinput:focus-within {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.webpageview #mail_view #mail_search .sortselector-dropdown {
  padding: 0 0 0 6px;
}
.webpageview #mail_view #mail_search .SlideBar--FullHeight {
  right: -4px;
}
.webpageview #mail_view #mail_search .sortselector .SlideBar {
  right: 0;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row label,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row label {
  flex: unset;
}
.webpageview #mail_view .search-wrapper {
  flex: 0 0 auto;
  padding: 12px 6px 6px 12px;
  border-bottom: 1px solid var(--colorBorder);
  display: flex;
}
.webpageview #mail_view .search-wrapper span {
  display: flex;
  flex-wrap: wrap;
  flex: 1;
}
.webpageview #mail_view .search-wrapper input[type=search] {
  min-width: 0;
  flex: 1 1 auto;
}
.webpageview #mail_view .search-wrapper input {
  margin-right: 6px;
  margin-bottom: 6px;
}
.webpageview #mail_view .mail-view-filters {
  display: flex;
  flex-wrap: wrap;
  align-items: center;
}
.webpageview #mail_view .mail-view-filters span {
  flex: 1 0 auto;
  margin-right: 12px;
}
.webpageview #mail_view .list-wrapper {
  display: flex;
  flex: 1;
  overflow: hidden;
  background-color: var(--colorBgIntense);
  position: relative;
}
.webpageview #mail_view .list-wrapper .jump-to-latest-container {
  position: absolute;
  top: 12px;
  right: 0;
  left: 0;
  width: 100%;
  display: flex;
  z-index: 2;
  pointer-events: none;
}
.webpageview #mail_view .list-wrapper .jump-to-latest-container-ascending {
  top: initial;
  bottom: 12px;
}
.webpageview #mail_view .list-wrapper .jump-to-latest-container-ascending .VivaldiSvgIcon {
  rotate: 180deg;
}
.webpageview #mail_view .list-wrapper .closeContainer {
  display: flex;
  color: var(--colorBgAlphaHeavy);
}
.theme-dark .webpageview #mail_view .list-wrapper .closeContainer {
  color: var(--colorFg);
}
.webpageview #mail_view .list-wrapper .jump-to-latest {
  pointer-events: initial;
  border-radius: var(--radiusRound);
  display: flex;
  gap: 9px;
  align-items: center;
  margin-left: auto;
  margin-right: auto;
  padding: 4px 9px;
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.15), 0 24px 20px rgba(0, 0, 0, 0.18);
  border: none;
  background-color: var(--colorFg);
  color: var(--colorBg);
}
.webpageview #mail_view .list-wrapper .jump-to-latest:hover,
.webpageview #mail_view .list-wrapper .jump-to-latest:focus-within {
  background-color: var(--colorFgFaded);
}
.theme-dark .webpageview #mail_view .list-wrapper .jump-to-latest {
  background-color: var(--colorBgLighter);
  color: var(--colorFg);
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.5), 0 24px 20px rgba(0, 0, 0, 0.5);
}
.theme-dark .webpageview #mail_view .list-wrapper .jump-to-latest:hover,
.theme-dark .webpageview #mail_view .list-wrapper .jump-to-latest:focus-within {
  background-color: var(--colorBg);
}
.webpageview #mail_view .list-wrapper .trash svg {
  height: 15px;
  width: 15px;
}
.webpageview #mail_view .mailContentWrapper {
  padding-top: 12px;
}
.webpageview #mail_view .flag-color {
  height: 16px;
}
.webpageview #mail_view .flag-color svg {
  width: 16px;
  stroke: none;
}
.webpageview #mail_view.horizontal #mail_search {
  flex-grow: 0;
  flex-shrink: 0;
  max-height: max(50%, 100% - 470px);
}
.webpageview #mail_view.horizontal #mail_search .MailFilterSelector .multiinput .multiinput-select {
  left: unset;
  right: 0;
  max-width: 50vw;
}
.webpageview #mail_view.horizontal,
.webpageview #mail_view.vertical_wide {
  grid-template-columns: 1fr;
}
.webpageview #mail_view.horizontal .mail_entry,
.webpageview #mail_view.vertical_wide .mail_entry {
  display: grid;
  grid-template-columns: var(--gridColumns);
  align-items: flex-start;
}
.webpageview #mail_view.horizontal .mail-preview,
.webpageview #mail_view.vertical_wide .mail-preview {
  font-size: 11.5px;
}
.webpageview #mail_view.horizontal #mail_search,
.webpageview #mail_view.vertical_wide #mail_search {
  min-height: 120px;
  min-width: 100%;
  max-width: 100%;
}
.webpageview #mail_view.horizontal #mail_search .search-wrapper,
.webpageview #mail_view.vertical_wide #mail_search .search-wrapper {
  flex-direction: row;
  flex-wrap: wrap;
}
.webpageview #mail_view.horizontal .mail-attachment-indicator,
.webpageview #mail_view.vertical_wide .mail-attachment-indicator {
  margin-left: 3px;
  vertical-align: -4px;
}
.webpageview #mail_view.horizontal .mail-attachment-indicator svg,
.webpageview #mail_view.vertical_wide .mail-attachment-indicator svg {
  height: 16px;
  max-width: 16px;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry {
  max-height: var(--mailEntryRowHeight);
  min-height: var(--mailEntryRowHeight);
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .subject,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .subject {
  flex-direction: column;
  align-items: flex-start;
  gap: 0;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .subject .subject-title-container,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .subject .subject-title-container {
  display: flex;
  align-items: center;
  gap: 6px;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .subject .subject-title-container .mail-queued,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .subject .subject-title-container .mail-queued {
  display: flex;
  gap: 0;
  margin-right: 0;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .labels,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .labels {
  display: flex;
  justify-content: center;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .mailattachment,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .mailattachment,
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .mailsize,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .mailsize,
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .maildate,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .maildate {
  font-variant-numeric: lining-nums tabular-nums;
  font-size: 13px;
  flex-direction: row;
  gap: 6px;
  justify-content: space-between;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .maildate,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .maildate {
  color: inherit;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry svg,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry svg {
  stroke: unset;
  width: 16px;
  height: 16px;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .expand-icon svg,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .expand-icon svg {
  width: 10px;
  height: 10px;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .mail-status-indicator,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .mail-status-indicator {
  display: flex;
  align-items: baseline;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .mail-status-indicator span,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .mail-status-indicator span {
  word-break: keep-all;
  white-space: break-spaces;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .mail-queued,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .mail-queued {
  margin-right: 6px;
  height: 12px;
  width: 12px;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry .mail-queued svg,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry .mail-queued svg {
  margin-bottom: -1px;
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry.mail-parent,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry.mail-parent {
  background-color: rgba(0, 0, 0, 0.03);
}
.theme-dark .webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry.mail-parent,
.theme-dark .webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry.mail-parent {
  background-color: rgba(0, 0, 0, 0.1);
}
.webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry.mail-child,
.webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry.mail-child {
  background-color: rgba(0, 0, 0, 0.03);
}
.theme-dark .webpageview #mail_view.horizontal .vivaldi-tree .tree-row .mail_entry.mail-child,
.theme-dark .webpageview #mail_view.vertical_wide .vivaldi-tree .tree-row .mail_entry.mail-child {
  background-color: rgba(0, 0, 0, 0.1);
}
.webpageview #mail_view.vertical_wide {
  flex-direction: row;
}
.webpageview #mail_view.vertical_wide #mail_search {
  min-width: 200px;
}
.webpageview #mail_view.vertical {
  flex-direction: row;
}
.webpageview #mail_view.vertical .list-wrapper .jump-to-latest-container {
  top: 18px;
}
.webpageview #mail_view.vertical .list-wrapper .jump-to-latest-container-ascending {
  top: initial;
  bottom: 18px;
}
.webpageview #mail_view.vertical .search-wrapper {
  flex-direction: column;
}
.webpageview #mail_view.vertical .mail-data-wrapper {
  flex-direction: column;
  display: flex;
  flex: 1;
}
.webpageview #mail_view.vertical .trash svg {
  height: 14px;
  width: 14px;
}
.webpageview #mail_view.vertical #mail_search {
  min-width: 200px;
  min-height: 100%;
  max-height: 100%;
}
.webpageview #mail_view.vertical .mail-attachment-indicator {
  margin-left: 3px;
  vertical-align: -4px;
}
.webpageview #mail_view.vertical .mail-attachment-indicator svg {
  height: 16px;
  max-width: 16px;
}
.webpageview #mail_view.vertical .tree-item.group + .tree-item .mail_entry:not(.mail-child),
.webpageview #mail_view.vertical .tree-item:nth-child(1) .mail_entry {
  border-top-width: 0px;
}
.webpageview #mail_view.vertical .tree-item:has(.last-mail-child) + .tree-item:not(.group) .tree-row {
  margin-top: 4px;
}
.webpageview #mail_view.vertical .tree-item:has(.last-mail-child) + .tree-item:not(.group) .mail_entry {
  border-top-width: 0px;
  max-height: calc(var(--mailEntryRowHeight) - 4px);
  min-height: calc(var(--mailEntryRowHeight) - 4px);
}
.webpageview #mail_view.vertical .tree-item.group:nth-last-child(1) .mail_entry {
  border-bottom: 1px solid var(--colorBorderSubtle);
}
.webpageview #mail_view.vertical .tree-item:not([data-expanded]) .mail-parent:not(.mail-child) {
  max-height: calc(var(--mailEntryRowHeight) - 4px);
  min-height: calc(var(--mailEntryRowHeight) - 4px);
  margin-bottom: 4px;
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
  border-bottom: 2px hidden var(--colorBg);
}
.webpageview #mail_view.vertical .tree-item:not([data-expanded]) .mail-parent:not(.mail-child) .subject_row {
  padding-bottom: 0;
}
.theme-dark .webpageview #mail_view.vertical .tree-item:not([data-expanded]) .mail-parent:not(.mail-child) {
  border-bottom: 2px hidden var(--colorBgDark);
}
.webpageview #mail_view.vertical .mail_entry {
  display: flex;
  flex-direction: column;
  grid-row-gap: 2px;
  justify-content: flex-start;
  max-height: var(--mailEntryRowHeight);
  min-height: var(--mailEntryRowHeight);
  padding: calc(6px + var(--densityGap) / 2) 6px;
  border-top: 1px solid var(--colorBorderSubtle);
}
.webpageview #mail_view.vertical .mail_entry .body_preview {
  padding-left: 24px;
}
.theme-dark .webpageview #mail_view.vertical .mail_entry {
  border-color: var(--colorBgAlphaHeavy);
}
.webpageview #mail_view.vertical .mail_entry .mail_entry_row {
  display: grid;
  grid-template-rows: 1fr;
  grid-auto-flow: column;
  grid-gap: 6px;
}
.webpageview #mail_view.vertical .mail_entry .mail_entry_row.body_preview_1 {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 1;
  -webkit-box-orient: vertical;
}
.webpageview #mail_view.vertical .mail_entry .mail_entry_row.body_preview_2 {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
}
.webpageview #mail_view.vertical .mail_entry .mail_entry_row.body_preview_3 {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
}
.webpageview #mail_view.vertical .mail_entry .mail_entry_row.subject_row {
  grid-template-columns: 16px 1fr auto;
}
.webpageview #mail_view.vertical .mail_entry .mail_entry_row.data_row {
  grid-template-columns: 16px 1fr 16px auto;
}
.webpageview #mail_view.vertical .mail_entry.mail-child .body_preview {
  -webkit-line-clamp: 1;
}
.webpageview #mail_view.vertical .mail_entry .mail-queued {
  height: 12px;
  width: 12px;
  margin-right: 6px;
}
.webpageview #mail_view.vertical .mail_entry.mail-parent {
  margin-inline: 3px;
  background-color: var(--colorBg);
}
.theme-dark .webpageview #mail_view.vertical .mail_entry.mail-parent {
  background-color: var(--colorBgDark);
}
.webpageview #mail_view.vertical .mail_entry.mail-parent:not(.mail-child) {
  margin-top: 4px;
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
  border-top: 2px hidden var(--colorBg);
}
.theme-dark .webpageview #mail_view.vertical .mail_entry.mail-parent:not(.mail-child) {
  border-top: 2px hidden var(--colorBgDark);
}
.webpageview #mail_view.vertical .mail_entry.mail-child {
  margin-inline: 3px;
  max-height: var(--mailEntryRowHeightChild);
  min-height: var(--mailEntryRowHeightChild);
  background-color: var(--colorBg);
  border-bottom-color: rgba(0, 0, 0, 0.08);
  justify-content: center;
}
.webpageview #mail_view.vertical .mail_entry.mail-child .mail_entry_row {
  grid-template-columns: 16px 1fr auto minmax(20px, auto);
}
.theme-dark .webpageview #mail_view.vertical .mail_entry.mail-child {
  background-color: var(--colorBgDark);
}
.webpageview #mail_view.vertical .mail_entry.last-mail-child {
  margin-bottom: 4px;
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
  border-bottom: 2px hidden var(--colorBg);
}
.theme-dark .webpageview #mail_view.vertical .mail_entry.last-mail-child {
  border-bottom: 2px hidden var(--colorBgDark);
}
.webpageview #mail_view.vertical .mail_entry .status-indicators {
  grid-column: 1;
  display: flex;
  margin: auto 0;
}
.webpageview #mail_view.vertical .mail_entry .status-indicators .expand-icon {
  margin-left: 3px;
  margin-right: 6px;
}
.webpageview #mail_view.vertical .mail_entry .status-indicators + .subject {
  margin-left: 0;
}
.webpageview #mail_view.vertical .mail_entry .subject {
  grid-column: 2;
  display: flex;
  align-items: center;
  height: 100%;
  min-width: 60px;
}
.webpageview #mail_view.vertical .mail_entry .subject .subject-title {
  font-weight: 600;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.webpageview #mail_view.vertical .mail_entry .expand-icon > svg {
  margin: auto;
}
.webpageview #mail_view.vertical .mail_entry .from {
  grid-column: 2;
  display: flex;
  align-items: flex-start;
  flex-shrink: 1;
  height: 100%;
}
.webpageview #mail_view.vertical .mail_entry .from .mail-contact-name {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.webpageview #mail_view.vertical .mail_entry .labels {
  grid-column: 3;
  flex-shrink: 4;
  border-radius: var(--radiusRounded);
  display: flex;
  align-items: flex-end;
  height: 100%;
  width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.webpageview #mail_view.vertical .mail_entry .mail-status-indicator {
  grid-column: 4;
}
.webpageview #mail_view.vertical .mail_entry .maildate {
  grid-column: 5;
  display: flex;
  justify-content: flex-end;
  align-items: flex-end;
}
.webpageview #mail_view.vertical .mail_entry .maildate .mailDateInfo {
  font-size: 11.5px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.webpageview #mail_view.vertical .mail_entry .mail-status-indicator {
  height: 16px;
  width: 16px;
  margin-bottom: auto;
}
.webpageview #mail_view.vertical .mail_entry .mail-status-indicator svg {
  max-width: 16px;
  height: 16px;
}
.webpageview #mail_view.vertical label {
  flex: 1;
  margin-right: 0;
  min-height: 12px;
  line-height: normal;
}
.webpageview #mail_view.vertical .VivaldiList .tree-row[data-selected] .mail-parent,
.webpageview #mail_view.vertical .VivaldiList .tree-row[data-selected] .mail-child {
  background-color: var(--colorFgAlpha);
}
.webpageview #mail_view.vertical .VivaldiList .tree-row[data-selected]:has(.mail-parent),
.webpageview #mail_view.vertical .VivaldiList .tree-row[data-selected]:has(.mail-child) {
  background-color: unset;
  box-shadow: unset;
}
.hasfocus .webpageview #mail_view.vertical .VivaldiList:focus-within .tree-row[data-selected] .mail-parent,
.hasfocus .webpageview #mail_view.vertical .VivaldiList:focus-within .tree-row[data-selected] .mail-child {
  background-color: var(--colorHighlightBg);
}
.webpageview #mail_view #mail_detail {
  display: flex;
  flex-direction: column;
  flex: 1;
  background-color: var(--colorBgDark);
  min-width: 140px;
  overflow: hidden;
  z-index: 2;
}
.webpageview #mail_view #mail_detail:has(#modal-bg) {
  z-index: 6;
}
.webpageview #mail_view #mail_detail .mail-detail-header {
  display: grid;
  grid-template-columns: minmax(50px, 1fr) auto;
  grid-template-rows: 32px 1fr;
  grid-template-areas: 'subject indicator' 'details details';
  grid-row-gap: 6px;
  padding: 12px;
  border-bottom: 1px solid var(--colorBorder);
  background-color: var(--colorBg);
}
@media (max-height: 640px) {
  .webpageview #mail_view #mail_detail .mail-detail-header {
    padding-bottom: 6px;
    padding-top: 6px;
  }
}
.webpageview #mail_view #mail_detail .mail-detail-header a {
  margin-right: 6px;
  margin-left: 6px;
  line-height: 20px;
  color: var(--colorHighlightBg);
  cursor: pointer;
}
.webpageview #mail_view #mail_detail .mail-detail-header a:active,
.webpageview #mail_view #mail_detail .mail-detail-header a:hover {
  outline: 2px solid var(--colorHighlightBgAlpha);
}
.webpageview #mail_view #mail_detail .mail-detail-header .attachment-button {
  border-radius: var(--radiusRounded);
  border-color: var(--colorBorder);
  background-color: var(--colorBg);
  margin-right: 6px;
  padding-bottom: 0;
  padding-top: 0;
  line-height: 17px /*border*/ /*margins*/;
  margin-top: 1px;
}
.theme-dark .webpageview #mail_view #mail_detail .mail-detail-header .attachment-button {
  background-color: var(--colorBgLight);
}
.webpageview #mail_view #mail_detail .mail-detail-header .attachment-button:hover,
.webpageview #mail_view #mail_detail .mail-detail-header .attachment-button:focus-visible {
  background-color: var(--colorHighlightBgAlpha);
  border-color: var(--colorHighlightBgAlpha);
}
.webpageview #mail_view #mail_detail .mail-detail-header .attachment-button:active {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
}
.webpageview #mail_view #mail_detail .mail-detail-header .button-toolbar button {
  margin-right: -6px;
  border-color: transparent;
}
.webpageview #mail_view #mail_detail .mail-detail-header .subject {
  grid-area: subject;
  color: var(--colorFgIntense);
  font-size: 21px;
}
.webpageview #mail_view #mail_detail .mail-detail-header .subject .button-with-dropdown-wrapper .status,
.webpageview #mail_view #mail_detail .mail-detail-header .subject .button-with-dropdown-container .dropdown-menu {
  top: 32px;
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details {
  grid-area: details;
  display: flex;
  flex-wrap: wrap;
  padding-right: 4px;
  padding-left: 6px;
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-main {
  max-width: fit-content;
  display: grid;
  grid-template-columns: minmax(40px, auto) minmax(40px, 1fr);
  grid-template-rows: repeat(9, auto) 1fr;
  grid-column-gap: 12px;
  line-height: 20px;
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-main .spacer {
  grid-row-start: 9;
  grid-row-end: 10;
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-main svg {
  width: 12px;
  height: 20px;
  vertical-align: bottom;
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-main .label {
  display: inline-flex;
  font-size: 13px;
  color: var(--colorFgFadedMore);
  margin-bottom: 2px;
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-main .detail {
  position: relative;
  color: var(--colorFgIntense);
  flex-wrap: wrap;
  display: flex;
  height: fit-content;
  margin-bottom: 2px;
  gap: 2px;
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-main .detail.from {
  font-weight: 600;
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-side {
  flex: 1 0 85px;
  display: grid;
  grid-auto-rows: minmax(20px, auto);
  margin-top: auto;
  margin-left: auto;
  color: var(--colorFgFadedMore);
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-side .mail-detail-item {
  display: flex;
  justify-content: flex-end;
  padding-left: 6px;
  text-align: end;
  gap: 2px;
  flex-wrap: wrap;
  line-height: 20px;
  margin-bottom: 2px;
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-side .mail-detail-item .mail-detail-item-accountId {
  margin-left: 3px;
  color: var(--colorFgFadedMost);
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-side .mail-detail-item .mail-detail-item-mailing-list {
  display: flex;
  align-items: center;
  gap: 6px;
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBg));
}
.webpageview #mail_view #mail_detail .mail-detail-header .mail-details .mail-detail-side .mail-detail-item .mail-detail-item-mailing-list:hover {
  background-image: none;
  background-color: var(--colorBg);
}
.webpageview #mail_view #mail_detail .mail-indicators {
  grid-area: indicator;
  display: flex;
  justify-content: center;
  align-items: center;
  padding: 0 2px 0 2px;
}
.webpageview #mail_view #mail_detail .mail-content-blocked {
  display: flex;
  flex-wrap: wrap;
  justify-content: flex-start;
  align-items: center;
  flex: 0 0 auto;
  padding: 6px 18px;
  border-bottom: 1px solid var(--colorBorder);
  background-color: var(--colorBg);
}
.webpageview #mail_view #mail_detail .mail-content-blocked .content-blocked-text {
  flex: 2;
  min-width: 104px;
  margin-top: auto;
  padding-right: 6px;
  padding-bottom: 6px;
  padding-top: 6px;
  margin-bottom: auto;
  margin-right: auto;
}
.webpageview #mail_view #mail_detail .mail-content-blocked .content-blocked-toggle-container {
  flex: 1;
  min-width: 104px;
  padding: 6px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.webpageview #mail_view #mail_detail .mail-content-blocked .content-blocked-toggle-container .content-blocked-toggle {
  margin-right: 6px;
  vertical-align: bottom;
}
.webpageview #mail_view #mail_detail .mail-content-blocked .content-blocked-action {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.webpageview #mail_view.horizontal #mail_detail {
  border-top: 1px solid var(--colorBorder);
}
.webpageview #mail_view.horizontal #mail_detail .maildetails-group-message-actions {
  display: block;
  padding-left: 18px;
  padding-right: 18px;
  fill: var(--colorFg);
}
.color-behind-tabs-off .webpageview #mail_view.horizontal #mail_detail .maildetails-group-message-actions {
  background: var(--colorBgIntense);
  color: var(--colorFg);
  fill: var(--colorFg);
}
.color-behind-tabs-off .webpageview #mail_view.horizontal #mail_detail .maildetails-group-message-actions button:hover,
.color-behind-tabs-off .webpageview #mail_view.horizontal #mail_detail .maildetails-group-message-actions button:active {
  background-color: var(--colorBgDarker);
}
#browser:not(.inner) .webpageview #mail_view.vertical #mail_detail,
#browser:not(.inner) .webpageview #mail_view.vertical_wide #mail_detail {
  border-left: 1px solid var(--colorBorder);
}
.theme-dark#browser:not(.inner) .webpageview #mail_view.vertical #mail_detail,
.theme-dark#browser:not(.inner) .webpageview #mail_view.vertical_wide #mail_detail {
  border-left: 1px solid var(--colorBgAlphaHeavy);
}
.webpageview #mail_view.vertical #mail_detail .maildetails-group-message-actions,
.webpageview #mail_view.vertical_wide #mail_detail .maildetails-group-message-actions {
  display: none;
}
.webpageview #mail_view .mail_body {
  display: flex;
  flex: 1;
  background-color: var(--colorBgIntense);
  color: var(--colorFgIntense);
  height: 100%;
}
.webpageview #mail_view .mail_body section {
  width: 100%;
  height: 100%;
}
.webpageview #mail_view .mail_body section:focus {
  outline: none;
}
.webpageview #mail_view .mail_body section webview {
  position: relative;
  width: 100%;
  height: 100%;
}
.mail_entry.mail_entry {
  display: flex;
  flex: 1;
  width: 100%;
}
.mail_entry.mail_entry .body_preview {
  display: -webkit-box;
  -webkit-box-orient: vertical;
  font-size: 11.5px;
  overflow: hidden;
  white-space: normal;
  line-height: 1.4;
}
.mail_entry.mail_entry .body_preview_1 {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 1;
  -webkit-box-orient: vertical;
}
.mail_entry.mail_entry .body_preview_2 {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
}
.mail_entry.mail_entry .body_preview_3 {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
}
.mail_entry.mail_entry .folder svg {
  margin-right: 6px;
  flex: 0 0 auto;
}
.mail_entry.mail_entry .maildate,
.mail_entry.mail_entry .body_preview {
  color: var(--colorFgFadedMore);
  justify-content: space-between;
}
.theme-dark .mail_entry.mail_entry .maildate,
.theme-dark .mail_entry.mail_entry .body_preview {
  color: var(--colorFgFadedMost);
}
.mail_entry.mail_entry .status-indicators {
  color: var(--colorFgFadedMost);
}
.mail_entry.mail_entry .maildate,
.mail_entry.mail_entry .status-indicators,
.mail_entry.mail_entry .body_preview,
.mail_entry.mail_entry svg {
  fill: currentColor;
  stroke-width: 0;
}
.hasfocus .vivaldi-tree:focus-within [data-selected] .mail_entry.mail_entry .maildate,
.hasfocus .vivaldi-tree:focus-within [data-selected] .mail_entry.mail_entry .status-indicators,
.hasfocus .vivaldi-tree:focus-within [data-selected] .mail_entry.mail_entry .body_preview,
.hasfocus .vivaldi-tree:focus-within [data-selected] .mail_entry.mail_entry svg {
  color: var(--colorHighlightFg);
}
.mail_entry.mail_entry.unread .from,
.mail_entry.mail_entry.unseen .from,
.mail_entry.mail_entry.unread .subject,
.mail_entry.mail_entry.unseen .subject {
  font-weight: 600;
}
.mail_entry.mail_entry.unseen svg,
.mail_entry.mail_entry.unread svg {
  fill: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail_entry.mail_entry.unseen svg,
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail_entry.mail_entry.unread svg {
  fill: var(--colorHighlightFg);
}
.tree-row:not([data-selected]) .mail_entry.mail_entry.unseen {
  color: var(--colorHighlightBg);
}
#mail_composer,
.mail-signature {
  display: flex;
  flex-flow: column nowrap;
  color: var(--colorFg);
  flex: 1 1 auto;
}
#mail_composer > header,
.mail-signature > header {
  display: grid;
  grid-template-columns: max-content minmax(0, 1fr);
  padding: 12px 24px;
}
#mail_composer > header > div,
.mail-signature > header > div {
  display: contents;
}
#mail_composer > header > div > label,
.mail-signature > header > div > label,
#mail_composer > header > div > .headerItemWrapper,
.mail-signature > header > div > .headerItemWrapper,
#mail_composer > header > div > input[type=text],
.mail-signature > header > div > input[type=text] {
  border-bottom: var(--colorBgDarker) solid 1px;
  width: 100%;
  height: 100%;
}
.theme-dark #mail_composer > header > div > label,
.theme-dark .mail-signature > header > div > label,
.theme-dark #mail_composer > header > div > .headerItemWrapper,
.theme-dark .mail-signature > header > div > .headerItemWrapper,
.theme-dark #mail_composer > header > div > input[type=text],
.theme-dark .mail-signature > header > div > input[type=text] {
  border-bottom-color: var(--colorBgLighter);
}
#mail_composer > header > div:focus-within > label,
.mail-signature > header > div:focus-within > label,
#mail_composer > header > div:focus-within > .headerItemWrapper,
.mail-signature > header > div:focus-within > .headerItemWrapper,
#mail_composer > header > div:focus-within > input[type=text],
.mail-signature > header > div:focus-within > input[type=text],
#mail_composer > header > div:focus-within > .composer-attachments,
.mail-signature > header > div:focus-within > .composer-attachments {
  border-bottom-color: var(--colorHighlightBg);
}
#mail_composer > header > div input[type=text],
.mail-signature > header > div input[type=text],
#mail_composer > header > div .attachment,
.mail-signature > header > div .attachment {
  margin-top: 2px;
  min-height: 24px;
  margin-left: 0;
  padding-left: 0;
  outline: unset;
}
#mail_composer > header > div .multiinput,
.mail-signature > header > div .multiinput {
  width: 100%;
  padding: 0;
  min-height: 24px;
}
#mail_composer > header > div .multiinput .multiinput-item,
.mail-signature > header > div .multiinput .multiinput-item {
  border-radius: var(--radiusRounded);
}
#mail_composer > header #subject,
.mail-signature > header #subject {
  width: 100%;
  height: 24px;
  padding: 0;
  border-radius: 0;
}
#mail_composer > header input[type=text],
.mail-signature > header input[type=text],
#mail_composer > header .headerItemWrapper,
.mail-signature > header .headerItemWrapper {
  grid-column-start: 2;
  grid-column-end: 3;
  flex: 1;
  background-color: transparent;
  border: initial;
  box-shadow: none;
  justify-content: center;
}
#mail_composer > header .headerItemWrapper,
.mail-signature > header .headerItemWrapper,
#mail_composer > header .composer-attachments,
.mail-signature > header .composer-attachments {
  padding-top: 6px;
  padding-bottom: 6px;
}
#mail_composer > header .select-wrapper select,
.mail-signature > header .select-wrapper select {
  height: 24px;
}
#mail_composer .composer_reply_field .headerItemWrapper,
.mail-signature .composer_reply_field .headerItemWrapper {
  display: flex;
  flex-wrap: wrap;
  justify-content: flex-start;
  gap: 2px;
}
#mail_composer .composer_reply_field .headerItemWrapper .multiinput,
.mail-signature .composer_reply_field .headerItemWrapper .multiinput {
  display: contents;
}
#mail_composer > footer,
.mail-signature > footer {
  padding: 6px;
  margin-bottom: 21px;
}
#mail_composer > footer > div,
.mail-signature > footer > div {
  display: flex;
}
#mail_composer > main,
.mail-signature > main {
  display: flex;
  flex: 1;
}
#mail_composer > main #modal-bg,
.mail-signature > main #modal-bg {
  top: 1px;
}
#mail_composer > main .editor-html,
.mail-signature > main .editor-html {
  display: flex;
  flex: 1;
  flex-direction: column;
  position: relative;
}
#mail_composer > main .editor-html-toolbar,
.mail-signature > main .editor-html-toolbar {
  display: flex;
  flex-wrap: wrap;
  gap: 3px;
  padding: 6px;
  margin-top: 6px;
}
#browser:not(.density-on) #mail_composer > main .editor-html-toolbar,
#browser:not(.density-on) .mail-signature > main .editor-html-toolbar {
  margin-top: unset;
}
#mail_composer > main .editor-html-toolbar .toolbar-group,
.mail-signature > main .editor-html-toolbar .toolbar-group {
  display: flex;
  flex-wrap: wrap;
  gap: inherit;
  align-items: center;
  padding-bottom: 6px;
}
#mail_composer > main .editor-html-toolbar input,
.mail-signature > main .editor-html-toolbar input,
#mail_composer > main .editor-html-toolbar select,
.mail-signature > main .editor-html-toolbar select {
  font-size: 11.5px;
  height: 22px;
  max-width: 120px;
}
#mail_composer > main .editor-html-toolbar button.button-toolbar,
.mail-signature > main .editor-html-toolbar button.button-toolbar {
  height: 22px;
  width: 22px;
  padding: 0;
  justify-content: center;
  align-items: center;
  background-color: transparent;
  border: none;
}
#mail_composer > main .editor-html-toolbar button.button-toolbar.active,
.mail-signature > main .editor-html-toolbar button.button-toolbar.active,
#mail_composer > main .editor-html-toolbar button.button-toolbar:active,
.mail-signature > main .editor-html-toolbar button.button-toolbar:active {
  background-color: var(--colorBgDarker);
}
.theme-dark #mail_composer > main .editor-html-toolbar button.button-toolbar.active,
.theme-dark .mail-signature > main .editor-html-toolbar button.button-toolbar.active,
.theme-dark #mail_composer > main .editor-html-toolbar button.button-toolbar:active,
.theme-dark .mail-signature > main .editor-html-toolbar button.button-toolbar:active {
  background-color: var(--colorBgLighter);
}
#mail_composer > main .editor-html-toolbar button.button-toolbar:focus-visible,
.mail-signature > main .editor-html-toolbar button.button-toolbar:focus-visible {
  position: relative;
  z-index: 1;
}
#mail_composer > main .editor-html-toolbar button.button-toolbar:hover,
.mail-signature > main .editor-html-toolbar button.button-toolbar:hover {
  background-color: var(--colorBgDark);
}
#mail_composer > main .editor-html-toolbar button.button-toolbar svg .hl,
.mail-signature > main .editor-html-toolbar button.button-toolbar svg .hl {
  fill: var(--colorHighlightBg);
}
#mail_composer > main .editor-html-toolbar input.text-bg-color,
.mail-signature > main .editor-html-toolbar input.text-bg-color {
  position: relative;
}
#mail_composer > main .editor-html-toolbar input.text-bg-color:after,
.mail-signature > main .editor-html-toolbar input.text-bg-color:after {
  content: 'a';
  position: absolute;
  top: 0px;
  left: 50%;
  transform: translateX(-50%);
  font-size: 14px;
  color: #fff;
  mix-blend-mode: exclusion;
}
#mail_composer .multiinput,
.mail-signature .multiinput {
  border: unset;
  border-radius: unset;
  background: transparent;
}
#mail_composer .multiinput:focus-within,
.mail-signature .multiinput:focus-within {
  box-shadow: initial;
}
#mail_composer label,
.mail-signature label {
  grid-column-start: 1;
  grid-column-end: 2;
  display: inline-flex;
  justify-content: flex-start;
  align-items: center;
  text-align: left;
  color: var(--colorFgFadedMore);
  word-break: break-word;
}
#mail_composer label:focus-within #mail_composer label,
#mail_composer label:focus-within .mail-signature label,
.mail-signature label:focus-within #mail_composer label,
.mail-signature label:focus-within .mail-signature label {
  color: var(--colorHighlightBg);
}
.editor-mode-toggle {
  display: inline-flex;
  border-radius: var(--radius);
  border: 1px solid var(--colorBorder);
  padding: 2px;
  margin-right: 6px;
  height: 22px;
  box-sizing: border-box;
  align-items: center;
}
.theme-dark .editor-mode-toggle {
  background-color: var(--colorBgLighter);
}
.editor-mode-toggle .editor-mode-toggle-option {
  padding: 0 12px;
  border: none;
  border-radius: var(--radius);
  background: none;
  cursor: pointer;
  font-size: 11.5px;
  color: var(--colorFgFadedMore);
  white-space: nowrap;
  line-height: 1;
  height: 100%;
  display: inline-flex;
  align-items: center;
}
.editor-mode-toggle .editor-mode-toggle-option.active {
  background-color: var(--colorBgDarker);
  color: var(--colorFg);
  cursor: default;
}
.editor-mode-toggle .editor-mode-toggle-option:hover {
  color: var(--colorFg);
}
#mail_composer textarea.editor-plaintext {
  flex: 1;
  resize: none;
  border: none;
  border-radius: 0;
  box-shadow: none;
  padding: 12px;
  font-family: monospace;
  font-size: inherit;
  color: var(--colorFg);
}
#mail_composer textarea.editor-plaintext:focus {
  outline: none;
  box-shadow: none;
}
#mail_composer {
  overflow: auto;
  background-color: var(--colorBgIntenser);
  overflow: hidden;
}
#mail_composer .editor-html-toolbar {
  padding: 6px 24px 3px;
  border-bottom: 1px solid var(--colorBorderIntense);
}
#mail_composer label {
  padding-right: 6px;
}
#mail_composer label:after {
  content: ':';
}
.mail-signature .floating-label {
  overflow: visible;
}
.mail-signature .editor-html {
  border: 1px solid var(--colorBorder);
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
}
.mail-signature .editor-html-toolbar {
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
}
.mail-signature .editor-webview {
  border-bottom-left-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
  max-height: 90px;
}
.mail-signature textarea {
  width: 100%;
  resize: none;
}
.mail-signature-footer {
  display: grid;
  grid-template-columns: repeat(2, 1fr);
  gap: 0 18px;
  margin-top: 12px;
}
.mail-signature-footer-sidebar {
  display: grid;
  gap: 6px;
  grid-row: span 2;
}
.mail-signature-footer-sidebar h3 {
  margin: 0;
}
#mail_composer webview,
.mail-signature webview {
  flex: 1;
  position: relative;
  max-width: 100%;
  max-height: 100%;
  white-space: pre-wrap;
  word-break: break-word;
  user-select: auto;
}
.composer-attachments {
  padding: 6px 0;
  display: flex;
  flex-wrap: wrap;
  border-bottom: var(--colorBgDarker) solid 1px;
}
.theme-dark .composer-attachments {
  border-bottom-color: var(--colorBgLighter);
}
.composer-attachments .attachment {
  display: flex;
  margin: 2px 4px 0 0;
  align-items: center;
  background-color: var(--colorHighlightBgAlpha);
  box-shadow: 0 0 0 1px var(--colorHighlightBgAlpha) inset;
  border-radius: var(--radiusRounded);
}
.composer-attachments .attachment .attachment-icon {
  margin: auto;
  width: 16px;
  height: 16px;
}
.composer-attachments .attachment .attachment-title {
  flex: 1;
  margin: 3px 3px 3px 6px;
}
.composer-attachments .attachment .attachment-remove {
  height: 100%;
  padding: 0;
  background-color: transparent;
  padding: 0 2px;
  border-color: transparent;
  border-radius: var(--radiusRounded);
}
.composer-attachments .attachment .attachment-remove svg {
  pointer-events: none;
  vertical-align: text-bottom;
}
.composer-attachments .attachment .attachment-remove:hover {
  background-color: var(--colorHighlightBgAlpha);
}
.composer-attachments .attachment .attachment-remove:active {
  fill: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.composer-attachments .attachment .attachment-remove:focus-visible {
  outline-offset: -3px;
}
#mail_view .VivaldiList .tree-row {
  display: flex;
}
#mail_view .VivaldiList .tree-row .unread .read-status {
  display: flex;
}
#app #browser .flag-color.flag-yellow svg {
  fill: #fd0;
}
#app #browser .flag-color.flag-red svg {
  fill: #f01;
}
#app #browser .flag-color.flag-blue svg {
  fill: #08f;
}
#app #browser .flag-color.flag-purple svg {
  fill: #a09;
}
#app #browser .flag-color.flag-orange svg {
  fill: #f80;
}
#app #browser .flag-color.flag-green svg {
  fill: #3c0;
}
#app #browser .flag-color.flag-gray svg {
  fill: #666;
}
#app #browser .flag-color.red {
  --flagColor: #f01;
  --flagOpacity: 1;
}
#app #browser .flag-color.orange {
  --flagColor: #f80;
  --flagOpacity: 1;
}
#app #browser .flag-color.yellow {
  --flagColor: #fd0;
  --flagOpacity: 1;
}
#app #browser .flag-color.green {
  --flagColor: #3c0;
  --flagOpacity: 1;
}
#app #browser .flag-color.blue {
  --flagColor: #08f;
  --flagOpacity: 1;
}
#app #browser .flag-color.purple {
  --flagColor: #a09;
  --flagOpacity: 1;
}
#app #browser .flag-color.gray {
  --flagColor: #666;
  --flagOpacity: 1;
}
.mail-loading {
  display: flex;
  flex: 1;
  justify-content: center;
  align-items: center;
  text-align: center;
  position: relative;
  font-size: 21px;
  padding: 12px;
  flex-direction: column;
  gap: 6px;
  z-index: 1;
}
.list-wrapper > .mail-loading {
  background-color: var(--colorBgLight);
}
.mail-folder-subscribe {
  flex: 1;
  padding: 24px;
  background-color: var(--colorBgLight);
  z-index: 1;
}
.mail-folder-subscribe > p {
  margin-top: 6px;
  margin-bottom: 12px;
}
.message-body-part {
  display: flex;
  flex-flow: column;
  flex: 1;
}
#quick_reply {
  display: flex;
  flex-flow: column;
  position: relative;
  background-color: var(--colorBg);
  border-top: 1px solid var(--colorBorderSubtle);
  min-height: 12px;
}
#quick_reply label {
  display: inline-flex;
  flex: none !important;
  flex-direction: row !important;
  gap: 6px !important;
  vertical-align: top;
  gap: 9px;
  margin-bottom: 6px;
}
#quick_reply .toolbar.toolbar-default {
  justify-content: space-between;
  align-content: center;
  flex-wrap: wrap;
  margin-top: 6px;
  margin-bottom: 6px;
}
#quick_reply .toolbar.toolbar-default > div {
  display: grid;
  grid-auto-flow: column;
  grid-gap: 18px;
  margin-right: 6px;
}
#quick_reply .toolbar.toolbar-default > div label {
  margin-bottom: 0;
}
#quick_reply .SlideBar {
  height: 12px;
}
#quick_reply .SlideBar:before {
  content: '';
  display: block;
  width: 150px;
  max-width: 30%;
  height: 6px;
  margin-left: auto;
  margin-right: auto;
  border-bottom: solid var(--colorBorderIntense) 2px;
}
#quick_reply .SlideBar:hover:before {
  border-color: var(--colorFgFadedMore);
}
#quick_reply section {
  display: flex;
  flex-direction: column;
  flex: 1;
  margin-bottom: 6px;
  margin-left: 12px;
  margin-right: 12px;
  margin-top: 12px;
}
#quick_reply section.minimize {
  margin: 0;
}
#quick_reply textarea {
  width: 100%;
  flex: 1;
  resize: none;
}
.no-message-selected {
  display: flex;
  flex: 1;
  flex-direction: column;
  justify-content: center;
  background-color: var(--colorBg);
  gap: 6px;
  align-items: center;
  font-weight: 400;
  font-size: 21px;
  color: var(--foregroundColor);
  text-align: center;
  padding: 6px;
}
.button-with-dropdown-wrapper {
  max-width: fit-content;
  height: 100%;
  position: relative;
  min-width: 0;
}
.button-with-dropdown-wrapper:not(:last-child) {
  margin-right: 6px;
}
.vpn-alert .FormFeedback,
#mail_composer > .FormFeedback {
  border: none;
  background-color: transparent;
  margin: 6px 0;
  padding-right: 32px;
  border-radius: 0;
}
.vpn-alert .FormFeedback .close,
#mail_composer > .FormFeedback .close {
  position: absolute;
  background: unset;
  border: none;
}
#mail_composer > .FormFeedback {
  padding: 0 0 6px 48px;
  border-bottom: 1px solid var(--colorBorder);
}
#mail_composer > .FormFeedback .FormFeedback-Icon {
  padding-left: 18px;
}
#mail_composer > .FormFeedback .close {
  top: 0;
  right: 9px;
}
.vpn-alert .FormFeedback .close {
  top: 6px;
  right: 0;
}
.mail-onboarding {
  grid-row-start: 2;
  grid-row-end: 4;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  margin: 2em;
  text-align: center;
}
.mail-onboarding h1 {
  font-weight: 600;
  margin-top: 18px;
  padding-bottom: 12px;
}
.mail-onboarding p {
  margin-bottom: 24px;
}
.mail-onboarding input {
  margin: auto;
  min-height: 28px;
}
.mail-onboarding svg {
  overflow: initial;
}
.mail-loading .critical-error-icon {
  fill: var(--colorErrorBg);
  left: -0.2em;
  position: relative;
  scale: 5;
  top: -2.5em;
}
.mail-single-window-error {
  display: flex;
  flex: 1;
  justify-content: center;
  align-items: center;
}
.mail-single-window-error > div {
  padding: 12px 24px;
  border-radius: var(--radius);
  background-color: var(--colorBgLight);
  text-align: center;
}
.mail-single-window-error > div h1 {
  font-weight: 600;
  padding-bottom: 6px;
}
.mail-single-window-error > div p {
  padding-bottom: 12px;
}
.buttom-mail-three-dot-menu {
  margin-left: auto;
}
.button-with-dropdown-container {
  border-radius: var(--radiusRounded);
  display: flex;
  overflow: hidden;
  white-space: nowrap;
  height: 100%;
}
.button-with-dropdown-container-address {
  padding-right: 2px;
  padding-left: 2px;
}
.button-with-dropdown-container:hover button:last-of-type,
.button-with-dropdown-container:focus-visible button:last-of-type,
.button-with-dropdown-container:focus-within button:last-of-type {
  background-color: var(--colorBg);
  opacity: 1;
}
.button-with-dropdown-container:hover button:last-of-type:after,
.button-with-dropdown-container:focus-visible button:last-of-type:after,
.button-with-dropdown-container:focus-within button:last-of-type:after,
.button-with-dropdown-container:hover button:last-of-type:before,
.button-with-dropdown-container:focus-visible button:last-of-type:before,
.button-with-dropdown-container:focus-within button:last-of-type:before {
  width: 16px;
  height: 100%;
  background: var(--colorHighlightBgAlpha);
  position: absolute;
  top: 0;
  right: 0;
}
.button-with-dropdown-container:hover button:last-of-type:before,
.button-with-dropdown-container:focus-visible button:last-of-type:before,
.button-with-dropdown-container:focus-within button:last-of-type:before {
  content: '';
}
.button-with-dropdown-container:hover button:last-of-type:hover:after,
.button-with-dropdown-container:focus-visible button:last-of-type:hover:after,
.button-with-dropdown-container:focus-within button:last-of-type:hover:after {
  content: '';
}
.button-with-dropdown-container:hover button * > svg,
.button-with-dropdown-container:focus-visible button * > svg,
.button-with-dropdown-container:focus-within button * > svg {
  fill: inherit;
}
.button-with-dropdown-container:last-child button:first-of-type:after {
  content: '';
}
.button-with-dropdown-container:hover,
.button-with-dropdown-container:focus-within {
  border-radius: var(--radiusRounded);
  background-color: var(--colorHighlightBgAlpha);
}
.button-with-dropdown-container:hover {
  border-color: var(--colorHighlightBgAlpha);
}
.button-with-dropdown-container:active {
  background-color: var(--colorHighlightBg);
}
.button-with-dropdown-container:active > button {
  color: var(--colorHighlightFg);
  border-color: var(--colorHighlightBg);
}
.button-with-dropdown-container:focus-within {
  border-color: var(--colorHighlightBg);
}
.button-with-dropdown-container > button {
  border-width: 0;
  padding: 0;
  display: inline-flex;
  background-color: transparent;
  border-radius: var(--radiusRounded);
  justify-content: center;
  align-items: center;
}
.button-with-dropdown-container > button > span {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.button-with-dropdown-container > button > img {
  width: 16px;
  height: 16px;
  border-radius: var(--radiusRound);
  margin: 0 6px 0 2px;
}
.button-with-dropdown-container > button > svg {
  z-index: 1;
  min-width: 16px;
}
.button-with-dropdown-container > button:hover,
.button-with-dropdown-container > button:focus-visible {
  background-color: var(--colorHighlightBgAlpha);
}
.button-with-dropdown-container > button:first-of-type {
  max-width: 100%;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  border-right: none;
  overflow: hidden;
}
.button-with-dropdown-container > button:last-of-type {
  opacity: 0.3;
  position: sticky;
  height: 100%;
  padding: 0;
  margin-right: 0;
  border-left: none;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  background-color: inherit;
}
.button-with-dropdown-container > button:last-of-type:active {
  fill: var(--colorHighlightFg);
  background-color: transparent;
}
.button-with-dropdown-container .status,
.button-with-dropdown-container .dropdown-menu {
  min-width: 50px;
  width: 100%;
  font-size: 13px;
  font-weight: 400;
  position: absolute;
  white-space: initial;
  z-index: 2;
  background-color: inherit;
  border: solid 1px var(--colorHighlightBgAlpha);
  top: 20px;
  right: 0;
}
.button-with-dropdown-container .status > li,
.button-with-dropdown-container .dropdown-menu > li {
  background-color: var(--colorBg);
  border-top: solid 1px var(--colorHighlightBgAlpha);
  padding: 4px 6px;
}
.button-with-dropdown-container .status > li:first-of-type,
.button-with-dropdown-container .dropdown-menu > li:first-of-type {
  border-top: none;
}
.button-with-dropdown-container .status > li:hover,
.button-with-dropdown-container .dropdown-menu > li:hover,
.button-with-dropdown-container .status > li.active,
.button-with-dropdown-container .dropdown-menu > li.active {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.button-with-dropdown-container .status {
  transition: backgroud-color 700ms;
  text-align: center;
  padding: 2px 6px;
  border-radius: var(--radiusRounded);
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.MailDisabled {
  grid-row-start: 2;
  grid-row-end: 4;
  flex: 1;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  margin: 12px;
  padding: 12px;
  text-align: center;
  color: var(--colorFg);
  background-color: var(--colorBgAlphaBlur);
  border-radius: var(--radius);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.MailDisabled > h1 {
  font-size: 16px;
  font-weight: 600;
  margin-top: 24px;
}
.MailDisabled > p {
  margin: 24px 0;
}
.MailDisabled > input {
  min-height: 28px;
}
.MailDisabled > svg {
  overflow: initial;
}
.AddedMailTrigger {
  display: flex;
  gap: 6px;
  align-items: center;
  margin-top: 6px;
}
.AddedMailTrigger-Icon {
  height: 25px;
  width: 25px;
}
.AddedMailTrigger-DeleteButton {
  padding: 0;
  height: 25px;
  width: 25px;
  justify-self: end;
  align-self: baseline;
}
.MailAccountSheet .email-providers,
.setting-mail-account .email-providers {
  display: grid;
  gap: 36px;
  grid-auto-flow: column;
  align-items: center;
  padding: 24px 0 30px 0;
}
.MailAccountSheet .email-providers.email-providers-welcome-page,
.setting-mail-account .email-providers.email-providers-welcome-page {
  display: block;
  padding: 0 0 6px 0;
  max-width: 300px;
  justify-self: flex-end;
}
.welcome-content .MailAccountSheet .email-providers.email-providers-welcome-page img,
.welcome-content .setting-mail-account .email-providers.email-providers-welcome-page img {
  width: auto;
  margin: 24px 0 24px 48px;
}
.MailAccountSheet .tips,
.setting-mail-account .tips {
  padding: 0 18px;
}
.MailAccountSheet .TabbedView,
.setting-mail-account .TabbedView {
  margin-bottom: 0;
}
.MailAccountSheet .TabbedView.hide-navigation .TabbedView-List,
.setting-mail-account .TabbedView.hide-navigation .TabbedView-List {
  display: none;
}
.MailAccountSheet .detail-content,
.setting-mail-account .detail-content {
  background-color: var(--colorBgLighter);
  padding: 18px;
}
.MailAccountSheet .detail-content .setting-group-double + .setting-group-double,
.setting-mail-account .detail-content .setting-group-double + .setting-group-double {
  margin-top: 12px;
  margin-bottom: 12px;
}
.MailAccountSheet .mail-address,
.setting-mail-account .mail-address {
  display: flex;
  padding: 0;
}
.MailAccountSheet .mail-address .floating-label,
.setting-mail-account .mail-address .floating-label {
  flex: 1;
}
.MailAccountSheet .CreateMailAccount-dropdown,
.setting-mail-account .CreateMailAccount-dropdown {
  margin-left: 6px;
}
.MailAccountSheet .mail-setup-description.no-margin,
.setting-mail-account .mail-setup-description.no-margin {
  margin-bottom: 0 !important;
}
.MailAccountSheet .mail-setup-email-link,
.setting-mail-account .mail-setup-email-link {
  text-decoration: none !important;
  margin-left: 0 !important;
  display: flex;
  gap: 6px;
  display: inline;
  white-space: nowrap;
  width: 100%;
  text-wrap-style: balance;
}
.MailAccountSheet .mail-setup-email-link span,
.setting-mail-account .mail-setup-email-link span {
  white-space: normal;
  display: inline;
  vertical-align: middle;
  padding-right: 6px;
}
.StatusButton--HasError .button-badge {
  color: var(--colorErrorFg);
  background-color: var(--colorErrorBg);
}
.StatusPopup {
  background-color: var(--colorBgLighter);
  display: grid;
  grid-template-rows: auto auto 1fr;
  grid-auto-flow: column;
  grid-template-columns: auto;
  width: min-content;
  min-width: var(--popupWidth);
}
.StatusPopup h3 {
  flex-shrink: 0;
  font-weight: normal;
  margin: 0 18px 6px;
}
.StatusPopup img,
.StatusPopup svg,
.StatusPopup .spinner {
  height: 16px;
  width: 16px;
  transform: scale(1);
}
.StatusPopup .toolbar {
  margin: 0;
}
.StatusPopup .ToolbarButton-Button {
  background: var(--colorBgIntense);
}
.StatusPopup .ToolbarButton-Button .button-badge {
  color: var(--colorErrorFg);
  background-color: var(--colorErrorBg);
}
.StatusPopup > .toolbar {
  padding: 12px;
}
.StatusPopup-Header {
  background-color: var(--colorBg);
  border-bottom: 1px solid var(--colorBorder);
  display: flex;
  align-items: center;
  padding: 6px 12px;
  border-top-left-radius: var(--radiusCap);
  border-top-right-radius: var(--radiusCap);
}
.StatusPopup-Header > h2 {
  border-bottom: unset;
  flex: 1;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.StatusPopup-Content {
  display: grid;
  height: 45vh;
}
.StatusPopup-ContentPane {
  display: flex;
  flex-direction: column;
  min-height: 0;
  height: 100%;
}
.StatusPopup-ContentPane.pad-top-bottom {
  margin-top: 6px;
  margin-bottom: 12px;
}
.StatusPopup-ContentPane--Empty {
  height: 100%;
  display: flex;
  justify-content: center;
  align-items: center;
}
.StatusPopup-ContentPane--Empty h1 {
  font-weight: 600;
  margin: 12px 0 6px 0;
}
.StatusPopup-ContentPane--Empty input[type=button] {
  margin: 24px 0;
}
.StatusPopup-ContentPane--Empty svg {
  width: initial;
  height: initial;
}
.StatusPopupViewFilterSelect {
  padding: 0 12px 6px;
}
.StatusPopupViewFilterSelect > span:first-of-type {
  margin-right: 6px;
}
.StatusPopup-List {
  display: flex;
  flex-direction: column;
  overflow: auto;
  flex: 1 1 100%;
  padding: 2px 12px 12px 12px;
  gap: 6px;
}
.StatusPopup-List .FormFeedback {
  margin: 0;
  user-select: text;
  word-break: break-word;
}
.StatusPopup-List:focus-visible {
  outline: unset;
}
.StatusPopup-List.pad-top {
  margin-top: 12px;
}
.StatusPopup-Footer {
  display: flex;
  justify-content: flex-end;
  gap: 6px;
  background-color: var(--colorBg);
  padding: 6px 12px;
  border-top: 1px solid var(--colorBorder);
  border-bottom-left-radius: var(--radiusCap);
  border-bottom-right-radius: var(--radiusCap);
  min-height: 40px;
}
.StatusPopup-Footer:empty {
  display: none;
}
.StatusPopup-Footer.PrefetchProgress {
  display: flex;
  justify-content: flex-start;
  align-items: center;
  flex-wrap: wrap;
  padding: 12px;
  background-color: var(--colorBgDark);
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
  margin: 12px 0;
}
.StatusPopup-Footer.PrefetchProgress .info {
  margin-top: 0;
}
.StatusPopup-Footer.PrefetchProgress .progress-wrapper {
  flex: 1;
  display: flex;
  flex-basis: 90%;
}
.StatusPopup-Footer.PrefetchProgress .progress-wrapper progress {
  width: 100%;
  margin-right: 12px;
}
.StatusPopup-Footer.PrefetchProgress .prefetch-details {
  font-size: 11.5px;
  font-weight: 600;
  width: 16ch;
}
.StatusPopup-Mail {
  display: grid;
  grid-template-columns: max-content 1fr max-content;
  grid-template-areas: 'icon to    to' 'icon title date';
  gap: 3px 6px;
  border-radius: var(--radius);
  padding: 3px 6px;
  background-color: var(--colorBg);
  text-align: initial;
}
.StatusPopup-Mail:hover {
  background-color: var(--colorBgDark);
}
.StatusPopup-MailIcon {
  grid-area: icon;
}
.StatusPopup-MailReceiver {
  grid-area: to;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  font-size: 11.5px;
  color: var(--colorFgFadedMore);
}
.StatusPopup-MailTitle {
  grid-area: title;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.StatusPopup-Mail--Unread .StatusPopup-MailTitle {
  font-weight: 600;
}
.StatusPopup-MailDate {
  grid-area: date;
  color: var(--colorFgFadedMore);
}
.StatusPopup-MailDetail,
.StatusPopup-EventDetail {
  border-radius: var(--radius);
  margin: 6px 12px 6px;
  padding: 6px;
  background-color: var(--colorBg);
  display: grid;
  grid-template-columns: max-content 1fr;
  column-gap: 12px;
  row-gap: 3px;
  user-select: text;
}
.StatusPopup-MailDetail > dt,
.StatusPopup-EventDetail > dt {
  text-align: right;
  padding-left: 6px;
}
.StatusPopup-MailDetail > dt:after,
.StatusPopup-EventDetail > dt:after {
  content: ':';
}
.StatusPopup-MailDetail > dd,
.StatusPopup-EventDetail > dd {
  font-variant: tabular-nums;
}
.StatusPopup-MailDetail > dd {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.StatusPopup-EventDetail > dd {
  word-break: break-all;
}
.StatusPopup-Event {
  display: grid;
  grid-template-columns: max-content 1fr;
  grid-template-areas: 'icon date' 'icon title';
  gap: 3px 6px;
  border-radius: var(--radius);
  padding: 3px 6px;
  background-color: var(--colorBg);
  text-align: initial;
}
.StatusPopup-EventIcon {
  grid-area: icon;
  fill: var(--colorCalendarBg);
}
.StatusPopup-EventIcon svg {
  height: 8px;
  width: 8px;
}
.StatusPopup-EventTitle {
  grid-area: title;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.StatusPopup-Event--AllDay .StatusPopup-EventTitle {
  font-weight: 600;
}
.StatusPopup-EventDate {
  grid-area: date;
  color: var(--colorFgFadedMore);
}
.StatusPopup-LogEntry {
  padding: 6px 6px 3px;
  display: flex;
  flex-direction: row;
  gap: 6px;
  user-select: text;
  border-radius: var(--radius);
  background-color: var(--colorHighlightBgAlpha);
  border: 1px solid var(--colorHighlightBg);
  fill: var(--colorHighlightBg);
}
.StatusPopup-LogEntry--error {
  background-color: var(--colorErrorBgAlpha);
  border-color: var(--colorErrorBg);
  fill: var(--colorErrorBg);
}
.StatusPopup-LogEntry--warn {
  background-color: var(--colorWarningBgAlpha);
  border-color: var(--colorWarningBg);
  fill: var(--colorWarningBg);
}
.StatusPopup-LogEntry--success {
  background-color: var(--colorSuccessBgAlpha);
  border-color: var(--colorSuccessBg);
  fill: var(--colorSuccessBg);
}
.StatusPopup-LogEntryTags {
  padding-right: 6px;
  color: var(--colorFgFaded);
  font-size: 11.5px;
}
.StatusPopup-LogEntryMessage {
  flex-grow: 1;
  color: var(--colorFgIntense);
}
.StatusPopup-LogEntryTimestamp {
  display: flex;
  float: right;
  color: var(--colorFgFaded);
  font-size: 11.5px;
  font-variant-numeric: tabular-nums;
  padding-top: 2px;
  padding-bottom: 3px;
}
.StatusPopup-LogEntryStacktrace {
  fill: var(--colorFg);
  height: 13px;
  margin-top: -2px;
}
.StatusPopup-Account {
  display: grid;
  grid-template-columns: max-content 1fr max-content;
  gap: 3px 6px;
  align-items: center;
  border-radius: var(--radius);
  padding: 6px;
  background-color: var(--colorBg);
  text-align: initial;
}
.StatusPopup-Account .button-toolbar .ToolbarButton-Button {
  font-size: 11.5px;
  height: 28px;
}
.StatusPopup-AccountIcon {
  height: 16px;
}
.StatusPopup-AccountName {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  margin-right: 6px;
  font-weight: 600;
}
.StatusPopup-AccountName--Local {
  grid-column-end: span 2;
}
.StatusPopup-AccountStatus {
  display: flex;
  align-items: center;
  gap: 6px;
  text-align: right;
  font-size: 11.5px;
  color: var(--colorFgFadedMore);
}
.StatusPopup-AccountStatus > span {
  line-height: 1;
}
.StatusPopup-AccountStatus button {
  color: var(--colorFg);
}
.StatusPopup-AccountStatus--Error {
  fill: var(--colorErrorBg);
}
.StatusPopup-AccountStatus--Warning {
  fill: var(--colorWarningBg);
}
.StatusPopup-AccountStatus--Success {
  fill: var(--colorSuccessBg);
}
.StatusPopup-DbInfo {
  display: grid;
  grid-template-columns: max-content 1fr max-content;
  gap: 3px 6px;
  align-items: center;
  border-radius: var(--radius);
  padding: 6px;
  margin: 0 12px;
  text-align: initial;
}
.StatusPopup-DbInfo:nth-child(2n) {
  background-color: var(--colorBg);
}
.StatusPopup-DbInfo > div {
  margin-left: auto;
  padding-right: 6px;
}
.StatusPopup-CalendarName {
  grid-column-end: span 2;
}
.StatusPopup-CalendarIcon {
  line-height: 1;
}
.StatusPopup-AccountPoll {
  grid-column-end: span 3;
  text-align: right;
  color: var(--colorFgFadedMore);
}
.StatusPopup-AccountStatus {
  margin-left: auto;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.MailLabels-Container {
  display: flex;
  align-items: center;
  overflow: hidden;
  padding-left: 3px;
}
.MailLabels-Label {
  display: inline-block;
  flex-shrink: 1;
  align-items: center;
  font-size: 11.5px;
  background-color: var(--colorFgFadedMore);
  color: var(--colorBg);
  border-radius: var(--radiusRounded);
  line-height: 16px;
  margin-right: 3px;
  padding: 0 3px;
  min-width: 2ch;
  text-align: center;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.MailLabels-Label:last-of-type {
  margin-right: 0;
}
.MailLabels-Observer {
  width: 100%;
  display: flex;
  justify-content: flex-end;
}
.MailLabels-Tooltip {
  min-width: 19px;
  text-overflow: clip;
}
.adjustment-mail-labels {
  width: 100%;
  align-self: center;
}
.adjustment-mail-labels .MailLabels-Observer {
  justify-content: flex-start;
}
.adjustment-mail-labels .MailLabels-Container {
  padding-left: unset;
}
.hasfocus .VivaldiList:focus-within [data-selected] .MailLabels-Label {
  background-color: var(--colorHighlightFgAlphaHeavy);
  color: var(--colorHighlightFg);
}
.MailLabels-Label[data-label='Important'] {
  background-color: #f01;
}
.MailLabels-Label[data-label='Work'] {
  background-color: #f80;
}
.MailLabels-Label[data-label='Personal'] {
  background-color: #3c0;
}
.MailLabels-Label[data-label='To Do'] {
  background-color: #08f;
}
.MailLabels-Label[data-label='Later'] {
  background-color: #a09;
}
.MailSearchOptions {
  container-type: inline-size;
  z-index: 2;
  display: flex;
  flex-wrap: wrap;
  width: 100%;
}
.MailSearchOptions .dateInput {
  flex: 1 0 auto;
}
.MailSearchOptions .dateInput .dateInputDay,
.MailSearchOptions .dateInput .dateInputMonth,
.MailSearchOptions .dateInput .dateInputYear {
  flex: 0;
}
.MailSearchOptions .dateInput .placeholder::-webkit-input-placeholder {
  opacity: 1;
}
.MailSearchOptions--search {
  align-items: baseline;
  gap: 6px;
}
.MailSearchOptions--search .multiinput {
  width: auto;
  min-width: 100px;
}
.MailSearchOptions-SaveButtonContainer,
.MailSearchOptions-DropdownContainer {
  display: flex;
  flex-direction: row;
  gap: 6px;
  flex: 1;
}
.MailSearchOptions-SaveButtonContainer {
  justify-content: flex-end;
  align-items: center;
}
.MailSearchOptions-Menu {
  align-self: center;
}
.vertical_wide .MailSearchOptions--contact {
  display: flex;
  justify-content: space-between;
  padding-right: 12px !important;
}
.MailSearchOptions-FoundItems {
  width: fit-content;
  white-space: nowrap;
  grid-column-end: -1;
  justify-self: end;
}
.MailSearchOptions-SearchContext {
  max-width: 100%;
}
.MailSearchOptions-Image {
  height: 20px;
  width: 20px;
  border-radius: var(--radiusRound);
  margin-right: 6px;
}
.MailSearchOptions-DropdownContainer .select-wrapper select {
  text-overflow: ellipsis;
}
.MailSearchOptionsSelectedFolder span {
  text-wrap: nowrap;
}
.MailSearchOptions-Dropdown {
  outline-offset: -2px;
}
.MailSearchOptions-Attachments {
  display: flex;
  gap: 6px;
  padding: 3px 6px;
  align-self: baseline;
  min-width: fit-content;
  flex-grow: 1;
  margin-top: auto;
  margin-bottom: auto;
}
.MailSearchOptions-FromToCc {
  display: flex;
  gap: 6px;
  align-items: center;
  flex-basis: 100%;
}
.MailSearchOptions-FromToCc--showLess {
  flex: 1;
  min-width: 200px;
}
.MailSearchOptions-Dash {
  display: flex;
  justify-content: center;
  align-items: center;
  padding: 3px;
}
.MailSearchOptions-ContactWrapper {
  display: flex;
  align-items: center;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.MailSearchOptions-Contact {
  display: inline-block;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.MailSearchOptions-Title {
  font-weight: 400;
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  gap: 6px;
}
.MailSearchOptions-TitleWrapper {
  display: flex;
  flex-wrap: wrap;
  gap: 6px;
  align-items: center;
}
.MailSearchOptions-RecipientTypes {
  display: flex;
  gap: 12px;
  width: fit-content;
  flex-wrap: wrap;
}
.MailSearchOptions-RecipientType {
  display: flex;
  gap: 6px;
}
.MailSearchOptions-Save,
.MailSearchOptions-Clear {
  grid-column-end: -1;
  width: fit-content;
  justify-self: end;
}
.MailSearchOptions-Clear {
  justify-self: flex-end;
}
.MailSearchOptions-Save--search {
  margin-left: auto;
}
.MailSearchOption-ShowMore {
  align-items: baseline;
  display: flex;
  color: var(--colorHighlightBg);
  margin-left: 6px;
  gap: 6px;
  text-wrap: nowrap;
  width: max-content;
}
.MailSearchOption-ShowMore span {
  display: flex;
  align-items: center;
  justify-content: center;
  height: auto;
  width: auto;
}
.MailSearchOption-ShowMore span.ascending {
  transform: rotate(0deg);
  align-self: center;
}
.MailSearchOption-ShowMore span.descending {
  transform: rotate(-180deg);
}
@container (max-width: 600px) {
  .MailSearchOptions--wideOnly {
    display: none !important;
  }
  .MailSearchOptions--search {
    display: grid;
    grid-template-columns: auto 1fr auto;
    width: 100%;
  }
  .MailSearchOptions--search > span {
    padding-left: 6px;
    min-width: 80px;
  }
  .MailSearchOptions--search > span.select-wrapper {
    padding-left: 0;
  }
  .MailSearchOptions--search > form {
    grid-column: 2 / 4;
  }
  .MailSearchOptionsSelectedFolder {
    flex-grow: 1;
  }
  .MailSearchOptionsSelectedFolder .select-wrapper {
    flex-grow: 1;
  }
  .MailSearchOptions-DropdownContainer {
    flex: 1;
    grid-column: 2 / 4;
    flex-wrap: wrap;
    min-width: 100%;
  }
  .MailSearchOptions-DropdownContainer .select-wrapper {
    flex-grow: 1;
  }
  .MailSearchOptions-SaveButtonContainer {
    flex-basis: fit-content;
    flex-wrap: wrap;
  }
}
@container (min-width: 600px) {
  .MailSearchOptions--narrowOnly {
    display: none !important;
  }
  .MailSearchOptions--search {
    display: flex;
    flex-wrap: wrap;
  }
  .MailSearchOptions-DropdownContainer {
    padding-right: 6px;
    max-width: fit-content;
    align-items: center;
    flex-basis: max-content;
  }
  .MailSearchOptions--search {
    justify-content: flex-start;
    padding-left: 6px;
  }
  .MailSearchOptions--contact {
    display: flex;
    justify-content: flex-start;
    gap: 18px;
  }
}
.SearchField.MailSearchField {
  border: none;
  outline: none;
  background: transparent;
  gap: 6px;
  background: var(--colorBgDark);
}
.color-behind-tabs-off .SearchField.MailSearchField {
  background: var(--colorAccentBgDark);
}
.SearchField.MailSearchField button.ToolbarButton-Button {
  border: none;
}
.dim-blurred:not(.hasfocus) .SearchField.MailSearchField {
  border: none;
}
.color-behind-tabs-on .SearchField.MailSearchField,
.color-behind-tabs-off .SearchField.MailSearchField {
  border: none;
}
.color-behind-tabs-on .SearchField.MailSearchField:focus-within,
.color-behind-tabs-off .SearchField.MailSearchField:focus-within {
  outline: none;
}
.MailSearchField-Inner {
  display: flex;
  flex-direction: row;
  flex-grow: 1;
}
.density-on .MailSearchField-Inner {
  height: 30px;
  padding: 0 var(--densityGap);
}
.MailSearchField-advancedSearchIcon {
  display: flex;
  background: initial;
  padding: 3px;
  margin: 1px 0;
  border: none;
}
.MailSearchField-advancedSearchIcon:hover {
  background: var(--colorBg);
}
.MailSearchField .button-menu .button-toolbar-menu-indicator {
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
  height: 28px;
}
.MailSearchField .button-icon svg {
  padding: 6px;
}
.MailSearchOptionsSelectedFolder {
  display: flex;
  gap: 6px;
  align-items: center;
}
.MailSearchOptionsSelectedFolder.horizontal {
  padding-right: 12px;
}
.horizontal .MailSearchOptionsSelectedFolder,
.vertical_wide .MailSearchOptionsSelectedFolder {
  padding-right: 6px;
}
.ShowMailTipsAndTricks {
  display: flex;
  align-items: center;
  border: 1px solid var(--colorBorder);
  flex: 1;
  flex-direction: column;
  gap: 12px;
  color: var(--colorFg);
  background-color: var(--colorBgLight);
  padding-top: 24px;
}
.ShowMailTipsAndTricks--inSettings {
  border: none;
  width: initial;
  overflow-y: auto;
  margin-left: -18px;
  margin-top: -18px;
  background-color: initial;
  max-width: 600px;
  margin-bottom: 48px;
}
.ShowMailTipsAndTricks-icon {
  flex: 1;
  display: flex;
  max-height: fit-content;
  justify-content: center;
  flex-basis: 45%;
  flex-grow: 1;
}
.ShowMailTipsAndTricks-icon svg {
  max-height: 200px;
}
.ShowMailTipsAndTricks-title {
  font-size: 16px;
  align-self: center;
}
.ShowMailTipsAndTricks-subtitle {
  font-size: 23px;
  align-self: center;
  color: var(--colorHighlightBg) !important;
  text-transform: initial !important;
  border-bottom: initial !important;
  letter-spacing: initial !important;
  margin: -6px 0 6px 0 !important;
  padding: 0 !important;
}
.ShowMailTipsAndTricks-allSetContainer {
  display: flex;
  flex-direction: column;
  flex: 1;
  justify-content: center;
  align-items: center;
  gap: 30px;
}
.ShowMailTipsAndTricks-allSetIcon {
  align-self: center;
}
.ShowMailTipsAndTricks-allSetIcon svg {
  width: 200px;
}
.ShowMailTipsAndTricks-allSetTitle {
  font-weight: 600;
  font-size: 23px;
  margin-bottom: -18px;
}
.ShowMailTipsAndTricks-description {
  margin-left: 18px;
  margin-right: 18px;
}
.ShowMailTipsAndTricks-descriptionContainer {
  display: flex;
  gap: 30px;
  padding: 0 24px;
  align-items: center;
  justify-content: center;
  margin: auto 0;
  flex-wrap: wrap-reverse;
}
.ShowMailTipsAndTricks-descriptionSide {
  min-width: 150px;
  flex-grow: 1;
  flex-basis: 40%;
  max-height: fit-content;
  display: flex;
  flex-direction: column;
  gap: 18px;
  align-items: baseline;
}
.ShowMailTipsAndTricks-descriptionSide--Unseen {
  padding-top: 18px;
  align-self: flex-end;
}
.ShowMailTipsAndTricks-radioGroup {
  display: flex;
  flex-direction: column;
  padding-left: 12px;
}
.ShowMailTipsAndTricks-button {
  justify-self: center;
  align-self: center;
  min-width: fit-content;
}
.ShowMailTipsAndTricks-buttonCenter {
  width: 100%;
  max-width: 600px;
  display: flex;
  justify-content: center;
  gap: 6px;
  flex-wrap: wrap;
}
.ShowMailTipsAndTricks-buttonContainer {
  display: flex;
  align-self: stretch;
  flex-direction: row;
  background-color: var(--colorBg);
  border-top: 1px solid var(--colorBorder);
  padding: 12px 6px;
  margin-top: 18px;
  justify-content: center;
}
.ShowMailTipsAndTricks-buttonContainer--inSettings {
  position: absolute;
  left: 0;
  right: 0;
  bottom: 0;
}
.ShowMailTipsAndTricks-fakeButton {
  display: flex;
  justify-content: center;
  align-items: center;
  border: solid 2px var(--colorBorder);
  min-width: 30px;
  min-height: 30px;
  border-radius: var(--radius);
}
.ShowMailTipsAndTricks-shortcutContainer {
  display: flex;
  align-items: center;
  width: 225px;
  flex-grow: 1;
  gap: 12px;
}
.ShowMailTipsAndTricks-shortcuts {
  display: flex;
  flex-wrap: wrap;
  padding: 18px;
  gap: 6px;
  flex: 1;
  align-content: baseline;
  justify-content: center;
  max-width: 500px;
}
.ShowMailTipsAndTricks-shortcutLink {
  flex-grow: 1;
}
svg.onboarding-illustration .color-fg {
  fill: var(--colorFg);
}
svg.onboarding-illustration .color-fg-stroke-faded {
  stroke: var(--colorFgFadedMost);
}
svg.onboarding-illustration .color-fg-faded {
  fill: var(--colorFgFadedMost);
}
svg.onboarding-illustration .bg-fill {
  fill: var(--colorBgLightIntense);
}
svg.onboarding-illustration .highlight-stroke {
  stroke: var(--colorHighlightBg);
}
svg.onboarding-illustration .highlight-fill {
  fill: var(--colorHighlightBg);
}
svg.onboarding-illustration .form-field {
  fill: var(--colorBgIntenser);
  stroke: var(--colorBorder);
}
svg.onboarding-illustration .success {
  fill: var(--colorSuccessBg);
}
.MailAccountSheet.welcome-content-inner .ShowMailTipsAndTricks {
  text-align: left;
  font-size: 13px;
  padding-top: initial;
}
.MailAccountSheet.welcome-content-inner .ShowMailTipsAndTricks-descriptionContainer {
  margin-top: 18px;
}
.MailAccountSheet.welcome-content-inner .ShowMailTipsAndTricks-shortcuts {
  flex-grow: 0;
  margin-bottom: auto;
}
.MailAccountSheet {
  display: flex;
  flex: 1;
  flex-direction: column;
  gap: 6px;
  height: auto;
  overflow-y: auto;
  color: var(--colorFg);
}
.onboarding .MailAccountSheet {
  background-color: var(--colorBgLight);
}
.MailAccountSheet > img {
  margin: 0 auto;
}
.MailAccountSheet h2 {
  font-weight: 600;
  font-size: 16px;
  padding: 0;
  text-transform: initial;
  border-bottom: initial;
  letter-spacing: initial;
}
.MailAccountSheet .detail {
  border: none;
  position: initial;
}
.MailAccountSheet .TabbedView {
  border: 0;
}
.MailAccountSheet .TabbedView-Content,
.MailAccountSheet .tips {
  padding: 18px 0 0 18px;
}
.MailAccountSheet .setting-mail-account-form {
  margin-bottom: 12px;
}
.MailAccountSheet-exit {
  position: absolute;
  right: 5px;
  top: 5px;
  height: 30px;
  width: 30px;
  font-weight: 400;
  background-color: initial;
  border: none;
  opacity: 0.7;
}
.MailAccountSheet-exit:hover {
  opacity: 1;
  cursor: pointer;
  border-color: var(--colorImageCenterFg);
}
.MailAccountSheet.welcome-content-inner {
  justify-content: center;
}
.MailAccountSheet.welcome-content-inner #modal-bg h1 {
  font-size: 16px;
}
.MailAccountSheet.welcome-content-inner .ShowMailTipsAndTricks-allSetTitle {
  margin-top: initial;
}
.MailAccountSheet.welcome-content-inner h2 {
  text-align: left;
  font-size: 33px;
  font-weight: 600;
}
.MailAccountSheet.welcome-content-inner .detail-content {
  background-color: initial;
}
.MailAccountSheet.welcome-content-inner .mail-setup-description {
  font-size: 16px;
  text-align: left;
}
.MailAccountSheet.welcome-content-inner .setting-section {
  text-align: left;
  font-size: 13px;
  padding-top: initial;
}
.MailFilterSelector {
  display: flex;
  gap: 6px;
}
.MailFilterSelector .select-wrapper {
  flex: 0 0 max-content;
}
.MailFilterSelector--mailList {
  flex-wrap: nowrap;
  flex-grow: 2;
  align-items: flex-start;
  max-width: 100%;
}
.MailFilterSelector--mailList.MailFilterSelector--multipleSelect {
  flex-wrap: wrap;
}
.MailFilterSelector--isSettings {
  flex-wrap: wrap;
  border: var(--colorBorderSubtle) 1px solid;
  border-radius: var(--radius);
  background-color: var(--colorBg);
  padding: 6px;
}
.MailFilterSelector-inputContainer {
  display: flex;
  gap: 6px;
  flex-wrap: wrap;
  flex-grow: 1;
  min-width: 0;
}
.MailFilterSelector-inputContainer .multiinput-group {
  width: 30px;
}
.MailFilterSelector-buttonContainer {
  display: flex;
  gap: 3px;
  margin-left: auto;
}
.MailFilterSelector-input {
  flex-grow: 1;
}
.MailAliasesForm-block {
  padding: 12px;
  padding-bottom: 0;
  background-color: var(--colorBg);
  margin-bottom: 12px;
  border-radius: var(--radius);
}
.MailListButtons {
  fill: var(--colorFgFaded);
  display: flex;
  align-items: center;
  justify-items: center;
  padding: 0 6px;
  border-bottom: 1px solid var(--colorBorder);
  flex-wrap: wrap;
  background: var(--colorBgDark);
  min-height: 24px;
}
.MailListButtons .toolbar-insideinput {
  gap: 3px;
}
.vertical_wide .MailListButtons .toolbar-insideinput,
.horizontal .MailListButtons .toolbar-insideinput,
.vivaldi-settings .MailListButtons .toolbar-insideinput {
  flex: 1;
  flex-wrap: wrap;
  font-size: 11.5px;
}
.vertical_wide .MailListButtons .toolbar-insideinput.toolbar-insideinput > .button-toolbar > button.button-textonly,
.horizontal .MailListButtons .toolbar-insideinput.toolbar-insideinput > .button-toolbar > button.button-textonly,
.vivaldi-settings .MailListButtons .toolbar-insideinput.toolbar-insideinput > .button-toolbar > button.button-textonly {
  padding: 0;
  height: initial;
  width: fit-content;
  border-color: var(--colorFgFadedMost) !important;
  border-radius: var(--radiusRound);
}
.vertical_wide .MailListButtons .toolbar-insideinput.toolbar-insideinput > .button-toolbar > button:hover,
.horizontal .MailListButtons .toolbar-insideinput.toolbar-insideinput > .button-toolbar > button:hover,
.vivaldi-settings .MailListButtons .toolbar-insideinput.toolbar-insideinput > .button-toolbar > button:hover {
  background-color: var(--colorBgLightIntense);
}
.vertical_wide .MailListButtons .toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > .button-on.button-textonly:not(:active):not(:focus):not(.button-pressed),
.horizontal .MailListButtons .toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > .button-on.button-textonly:not(:active):not(:focus):not(.button-pressed),
.vivaldi-settings .MailListButtons .toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > .button-on.button-textonly:not(:active):not(:focus):not(.button-pressed) {
  color: var(--colorBg);
  background-color: var(--colorFgFaded);
}
.vertical_wide .MailListButtons .toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > .button-on.button-textonly:not(:active):not(:focus):not(.button-pressed):hover,
.horizontal .MailListButtons .toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > .button-on.button-textonly:not(:active):not(:focus):not(.button-pressed):hover,
.vivaldi-settings .MailListButtons .toolbar-insideinput.toolbar-insideinput.toolbar-insideinput > .button-toolbar > .button-on.button-textonly:not(:active):not(:focus):not(.button-pressed):hover {
  background-color: var(--colorFg);
}
.MailListButtons-CheckboxWrapper {
  border: none;
  display: flex;
  justify-content: flex-start;
  align-items: center;
  gap: 6px;
  width: 100%;
  padding: 3px 12px;
  height: 30px;
}
.MailListButtons-CheckboxWrapper:hover,
.MailListButtons-CheckboxWrapper:focus-within {
  background-color: var(--colorBg);
}
.MailListButtons-CheckboxWrapper:first-of-type {
  margin-top: 3px;
}
.MailListButtons-CheckboxWrapper--active {
  color: var(--colorHighlightBg);
}
.MailListButtons-CheckboxIcon {
  height: 16px;
  width: 16px;
  flex-grow: 0;
}
.MailListButtons-CheckboxIcon--active {
  fill: var(--colorHighlightBg);
}
.MailListButtons-Checkbox[type=checkbox] {
  margin-left: auto;
}
.MailListButtons--popUp {
  display: flex;
  font-size: 11.5px;
  justify-content: space-between;
}
.MailListButtons--textMenu {
  padding: 6px;
}
.MailListButtons--textMenu .toolbar-insideinput {
  gap: 6px;
}
.MailListButtons--settings {
  background: initial;
  border: none;
  padding: 0;
  flex-direction: column;
  align-items: flex-start;
  gap: 6px;
}
.MailListButtons-TextMenuTitle {
  display: flex;
  align-items: center;
  gap: 6px;
  font-weight: 600;
  color: var(--colorFg);
  height: 24px;
}
.MailListButtons-MessageCount {
  font-size: 11.5px;
  color: var(--colorFgFaded);
}
.MailListButtons-MessageCount--hasQuery {
  width: 100%;
  min-height: 18px;
  align-items: center;
  display: flex;
}
.MailListButtons-FilterIcon {
  margin-left: auto;
}
.MailListButtons-FilterIcon button {
  height: 18px;
  width: 18px;
  border-color: var(--colorFgFaded);
  border-radius: 100%;
}
.MailListButtons-FilterIcon--active button {
  background-color: var(--colorHighlightBg);
  fill: var(--colorHighlightFg);
  border-color: var(--colorHighlightBg);
}
.MailListButtons-Popup:before {
  border-bottom-color: var(--colorBgDarker);
}
.MailListButtons-Label {
  font-size: 11.5px;
  font-weight: 700;
  padding: 4px 0;
  padding-right: 12px;
}
.MailListButtons-Popup .MailListButtons-Label {
  border-bottom: 1px solid var(--colorBorder);
  background: var(--colorBgDarker);
  padding-left: 12px;
}
.horizontal .MailListButtons-Label,
.vertical_wide .MailListButtons-Label {
  gap: 6px;
}
.MailListButtons-NonDefaultStateMessage {
  width: 100%;
  margin-bottom: 6px;
  color: var(--colorFgFaded);
}
.MailListButtons-PopupButtons {
  background-color: var(--colorBg);
  width: fit-content;
}
input[type=button]:not(.circular).MailListButtons-PopupButtons {
  padding: 3px 6px;
}
.MailListButtons-PopupButtonsWrapper {
  display: flex;
  padding: 12px;
  gap: 6px;
}
.MailListButtons-PopupButtonsWrapper input[type='button'] {
  height: unset;
  min-height: 28px;
  text-wrap: wrap;
}
.MailActionManagerEditor-mailTriggerSelectors {
  display: grid;
  gap: 6px;
}
.MailTriggerSelector {
  border: var(--colorBorderSubtle) 1px solid;
  border-radius: var(--radius);
  background-color: var(--colorBgDark);
  padding: 6px;
  display: flex;
  gap: 6px;
  flex-wrap: wrap;
}
.MailTriggerSelector-button {
  justify-self: flex-end;
  align-self: flex-end;
}
.MailTriggerSelector-buttonContainer {
  display: flex;
  gap: 3px;
  margin-left: auto;
}
.MailTriggerSelector-select {
  flex-grow: 1;
}
.MailWarningMessage {
  display: flex;
  flex-direction: row;
  position: relative;
  flex: 0 0 auto;
  padding: 6px 36px 6px 18px;
  font-size: 11.5px;
  border-bottom: 1px solid var(--colorBorder);
  background-color: var(--colorBg);
}
.MailWarningMessage ul {
  list-style: inside;
  margin-bottom: 3px;
}
.MailWarningMessage:before {
  content: '?';
  display: inline-flex;
  width: 1em;
  height: 1em;
  padding: 1px;
  border: 1px solid var(--colorFgFadedMore);
  border-radius: 50%;
  color: var(--colorFgFadedMore);
  align-items: center;
  justify-content: center;
  font-weight: bold;
  font-size: 11.5px;
  margin-right: 12px;
  flex-shrink: 0;
}
.warning.MailWarningMessage:before {
  content: '!';
  background: var(--colorWarningBg);
  color: var(--colorWarningFg);
  border-color: var(--colorWarningBgAlpha);
}
.danger.MailWarningMessage:before {
  content: '!';
  background: var(--colorErrorBg);
  color: var(--colorErrorFg);
  border-color: var(--colorErrorBgAlpha);
}
.MailWarningMessage-Exit {
  position: absolute;
  flex-shrink: 0;
  top: 0px;
  right: 0px;
  height: 30px;
  width: 30px;
  font-weight: 400;
  background-color: initial;
  border: none;
  opacity: 0.7;
}
.MailWarningMessage-Exit:hover {
  transition: 100ms;
  opacity: 1;
  cursor: pointer;
  border-color: var(--colorImageCenterFg);
}
.menubar {
  align-items: center;
  display: flex;
  font-size: 12px;
}
.menubar button {
  border-radius: 0;
  background-color: transparent;
  display: inline-flex;
  align-items: center;
  flex: 0 0 auto;
  max-width: 120px;
  border: 0;
  padding: 3px 10px;
}
.menubar button .underlined {
  text-decoration: underline;
}
.menubar button.highlighted {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
}
.StatusInfo {
  display: flex;
  align-items: center;
  overflow: hidden;
  opacity: 0;
  transition: opacity 200ms cubic-bezier(0.75, 0, 1, 1);
  min-height: 28px;
  position: relative;
}
.toolbar > .StatusInfo {
  flex: 1;
}
.StatusInfo--Visible {
  opacity: 1;
  transition: none;
}
.StatusInfo .ToolbarButton-Button span {
  justify-content: flex-start;
  padding-right: 6px;
  align-items: center;
}
.toolbar-edit-mode :not(.default-toolbar) > .toolbar .StatusInfo {
  opacity: 1;
}
.toolbar-edit-mode :not(.default-toolbar) > .toolbar .StatusInfo:before {
  content: '';
  z-index: 1;
  position: absolute;
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
  display: flex;
  align-items: center;
  border: 1px dashed var(--colorFg);
  margin: 1px;
  padding: 0 6px;
}
#webview-container ~ .StatusInfo {
  pointer-events: none;
  position: absolute;
  bottom: 6px;
  right: 6px;
  left: 6px;
}
.StatusInfo .UrlFragments,
.StatusInfo-Content {
  align-items: center;
  padding-right: 6px;
  padding-left: 6px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
#webview-container ~ .StatusInfo .StatusInfo .UrlFragments,
#webview-container ~ .StatusInfo .StatusInfo-Content {
  display: inline-block;
  padding-top: 3px;
  padding-bottom: 3px;
  color: var(--colorFg);
  background-color: var(--colorBg);
  border: 1px solid var(--colorBorder);
  border-radius: var(--radiusRounded);
}
.StatusInfo.button-dragover-left:not(.StatusInfo--Visible),
.StatusInfo.button-dragover-right:not(.StatusInfo--Visible),
.StatusInfo.button-dragover-top:not(.StatusInfo--Visible),
.StatusInfo.button-dragover-bottom:not(.StatusInfo--Visible) {
  opacity: 1;
}
.StatusInfo.button-dragover-left:not(.StatusInfo--Visible) > *,
.StatusInfo.button-dragover-right:not(.StatusInfo--Visible) > *,
.StatusInfo.button-dragover-top:not(.StatusInfo--Visible) > *,
.StatusInfo.button-dragover-bottom:not(.StatusInfo--Visible) > * {
  opacity: 0;
}
#browser:has(.toolbar.dragging) .StatusInfo {
  transition: unset;
}
.find-in-page {
  height: calc(34px + var(--densityGap));
  display: flex;
  justify-content: center;
  align-items: center;
}
.find-in-page-wrapper {
  color: var(--colorFg);
  background-color: var(--colorBgLightIntense);
  border-bottom: 1px solid var(--colorBorder);
}
.find-in-page-wrapper:empty {
  display: none;
}
#browser .find-in-page {
  padding: 0 calc(6px + var(--densityGap));
}
#browser .find-in-page input,
#browser .find-in-page .fip-input-label,
#browser .find-in-page .fip-checkbox-label,
#browser .find-in-page .toolbar,
#browser .find-in-page .button-toolbar {
  margin-bottom: 0;
}
#browser .find-in-page input,
#browser .find-in-page button {
  max-height: 24px;
}
#browser .find-in-page button {
  max-width: 24px;
}
#browser .find-in-page svg {
  min-width: 16px;
}
#browser .find-in-page .toolbar-group {
  flex: 0 1 auto;
}
#browser .find-in-page .button-toolbar {
  align-self: center;
}
.find-in-page .fip-input-label {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.find-in-page .fip-checkbox-label {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  padding-left: 6px;
}
.find-in-page .fip-input-container {
  position: relative;
  padding-top: unset;
  margin: unset;
  flex: 1;
  min-width: 125px;
  max-width: 250px;
}
.find-in-page .fip-input-container > input {
  flex: 1;
  min-width: 0;
}
.find-in-page .fip-input-container > input[type=search]::-webkit-search-cancel-button {
  margin-left: 48px;
}
.fip-nomatches.find-in-page .fip-input-container > input {
  background-color: var(--colorBgInverser);
}
.find-in-page .fip-input-container > .fip-results {
  pointer-events: none;
  position: absolute;
  top: 4px;
  right: 30px;
  opacity: 0.6;
}
.find-in-page.find-in-page-enter {
  opacity: 0.01;
  transform: translateY(-4px);
}
.find-in-page.find-in-page-enter-active {
  opacity: 1;
  transform: translateY(0);
  transition: transform 200ms ease-out, opacity 100ms ease-out;
}
.find-in-page.find-in-page-exit-active {
  opacity: 0.01;
  transform: translateY(-4px);
  transition: transform 100ms ease-in, opacity 100ms ease-in;
}
.fip-active-hit {
  outline: 2px solid var(--colorHighlightBg);
  border-radius: var(--radiusHalf);
  z-index: 1;
  image-rendering: -webkit-optimize-contrast;
  transition: transform 200ms ease-in;
  transform: scale(1);
  filter: brightness(95%);
}
.fip-active-hit.entering,
.fip-active-hit.entered {
  transition: none;
  transform: scale(1.2);
}
.menu {
  z-index: 101;
  position: absolute;
  text-align: left;
}
.topmenu .menu {
  background: inherit;
}
.menu.horizontal {
  margin-top: 1px;
  display: flex;
  flex-direction: row;
  -webkit-app-region: no-drag;
}
.menu.horizontal > ul {
  overflow: hidden;
  white-space: nowrap;
}
.menu.horizontal > ul > li {
  display: inline-block;
}
.menu.horizontal > ul > li > a {
  text-decoration: none;
  cursor: default;
  padding: 4px 12px;
}
.menu:not(.horizontal) > ul > li > a > img,
.menu ul ul li > a > img,
.menu:not(.horizontal) > ul > li > a input,
.menu ul ul li > a input {
  margin-right: -16px;
}
.menu > ul {
  overflow-x: hidden;
  overflow-y: auto;
  max-height: 100vh;
  max-width: 100vw;
}
.menu > ul > li {
  display: flex;
}
.menu > ul > li > a {
  position: relative;
  display: flex;
  flex: 1;
  height: 22px;
  max-width: 100%;
}
.menu > ul > li .menu-icon {
  margin: auto 0;
  flex: 0 0 16px;
}
.menu > ul > li .menu-icon img,
.menu > ul > li .menu-icon svg {
  width: 16px;
  height: 16px;
  display: block;
}
.menu > ul > li .menu-label {
  display: flex;
  overflow: hidden;
  gap: 6px;
}
.menu > ul > li .menu-label > span {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.menu > ul > li .menu-description {
  flex-basis: 100%;
  margin-left: 25px;
  color: var(--colorFgFaded);
  font-size: 11.5px;
}
.menu > ul > li .menu-item-description-container > .menu-label {
  font-weight: 600;
}
.menu > ul > li label {
  display: flex;
  align-items: center;
  flex: 1;
}
.menu > ul > li .underlined + span {
  overflow: hidden;
  text-overflow: ellipsis;
}
.menu > ul > li .menu-delete {
  display: none;
  margin: 0 0 0 auto;
  flex: 0 0 22px;
  border-radius: var(--radiusRounded);
}
.menu > ul > li .menu-delete:hover {
  background-color: rgba(0, 0, 0, 0.15);
}
.menu > ul > li .menu-delete:active {
  background-color: rgba(0, 0, 0, 0.25);
}
.menu > ul > li a:hover .menu-delete {
  display: flex;
}
.menu.horizontal.platform-popups input ~ ul > li > a .underlined {
  text-decoration: underline;
}
#browser:not(.mac) .menu:not(.horizontal):hover input ~ ul > li > a .underlined,
#browser:not(.mac) .menu.horizontal.open:hover input ~ ul > li > a .underlined,
#browser:not(.mac) .menu.horizontal:not(.open):hover input ~ ul > li > a .underlined,
#browser:not(.mac) .menu:not(.horizontal).opensubmenu input ~ ul > li > a .underlined,
#browser:not(.mac) .menu.horizontal.open.opensubmenu input ~ ul > li > a .underlined,
#browser:not(.mac) .menu.horizontal:not(.open).opensubmenu input ~ ul > li > a .underlined {
  text-decoration: underline;
}
.menu:not(.horizontal):hover .selectedItem > a,
.menu.horizontal.open:hover .selectedItem > a,
.menu.horizontal:not(.open):hover .selectedItem > a,
.menu:not(.horizontal).opensubmenu .selectedItem > a,
.menu.horizontal.open.opensubmenu .selectedItem > a,
.menu.horizontal:not(.open).opensubmenu .selectedItem > a {
  background-color: var(--colorBgDark);
}
.mac .menu:not(.horizontal):hover .selectedItem > a,
.mac .menu.horizontal.open:hover .selectedItem > a,
.mac .menu.horizontal:not(.open):hover .selectedItem > a,
.mac .menu:not(.horizontal).opensubmenu .selectedItem > a,
.mac .menu.horizontal.open.opensubmenu .selectedItem > a,
.mac .menu.horizontal:not(.open).opensubmenu .selectedItem > a,
.linux .menu:not(.horizontal):hover .selectedItem > a,
.linux .menu.horizontal.open:hover .selectedItem > a,
.linux .menu.horizontal:not(.open):hover .selectedItem > a,
.linux .menu:not(.horizontal).opensubmenu .selectedItem > a,
.linux .menu.horizontal.open.opensubmenu .selectedItem > a,
.linux .menu.horizontal:not(.open).opensubmenu .selectedItem > a {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
}
.menu .focusTrap {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  overflow: hidden;
  opacity: 0.01;
}
.menu .shortcut {
  text-align: right;
  flex: 1 0 auto;
}
.menu input[type=checkbox] {
  transform: scale(0.75);
}
.menu :not(.selectedItem) > a .shortcut {
  color: var(--colorFgFadedMost);
}
.menu .selectedItem .menu-description {
  color: inherit;
  opacity: 0.8;
}
.topmenu {
  display: flex;
  flex-direction: row;
  position: relative;
  -webkit-app-region: drag;
  min-height: 25px;
}
.topmenu button.vivaldi-horizontal-icon {
  display: flex;
  border: 0;
  background: none;
  margin-top: 3px;
}
.topmenu button.vivaldi-horizontal-icon svg {
  width: 16px;
  height: 16px;
}
.topmenu button.vivaldi-horizontal-icon:active {
  opacity: 0.5;
}
.native .topmenu button.vivaldi-horizontal-icon {
  display: none;
}
.color-behind-tabs-off .topmenu button.vivaldi-horizontal-icon span.application-icon {
  display: block;
}
.color-behind-tabs-off .topmenu button.vivaldi-horizontal-icon span.vivaldi-v {
  display: none;
}
.color-behind-tabs-on .topmenu button.vivaldi-horizontal-icon span.application-icon {
  display: none;
}
.color-behind-tabs-on .topmenu button.vivaldi-horizontal-icon span.vivaldi-v,
.color-behind-tabs-on .topmenu button.vivaldi-horizontal-icon span.burger-icon {
  display: block;
  opacity: 0.7;
}
.win .topmenu {
  padding-right: 140px;
  overflow: hidden;
}
.tabs-top.maximized.horizontal-menu.win .topmenu {
  margin-bottom: -3px;
}
.stacks-dotted.tabs-top.maximized.horizontal-menu.win .topmenu,
.substrip-tabs-on.tabs-top.maximized.horizontal-menu.win .topmenu {
  margin-bottom: 4px;
}
.stacks-off.tabs-top.maximized.horizontal-menu.win .topmenu {
  margin-bottom: 1px;
}
.maximized.win .topmenu {
  margin-top: -1px;
}
.mac .topmenu {
  padding-left: 70px;
}
.linux .topmenu {
  padding-right: 102px;
  padding-top: 5px;
  padding-left: 5px;
}
.maximized.linux .topmenu {
  margin-top: -1px;
}
.alt.linux .topmenu .horizontal-menu-pagetitle {
  padding-left: 0;
}
.linux.alt .topmenu {
  margin-left: 100px;
  margin-right: 6px;
}
.topmenu .horizontal-menu-pagetitle {
  display: block;
  margin-top: 5px;
  margin-right: auto;
  margin-left: auto;
  padding-left: 12px;
  font-size: 12px;
  line-height: 1.3;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  scale: calc(1 / var(--uiZoomLevel));
  transform-origin: top center;
}
.native .topmenu .horizontal-menu-pagetitle {
  display: none;
}
.topmenu + #tabs-tabbar-container.top {
  padding: 2px 0 0 6px;
}
.topmenu > .menu > ul > li > a > img {
  display: none;
}
#browser {
  --menuWidth: calc(34px + 1px);
}
#browser.menu-icon {
  --menuWidth: calc(34px + 16px);
}
.vivaldi {
  display: flex;
  align-items: center;
  justify-content: center;
  position: relative;
  z-index: 1;
  top: 0;
  left: 0;
  width: var(--menuWidth);
  height: 30px;
  margin: 0 var(--densityGap);
  border: none;
  border-radius: var(--radiusHalf);
  background-color: transparent;
  scale: calc(1 / var(--uiZoomLevel));
  transform-origin: top left;
}
#browser.menu-icon .vivaldi {
  display: grid;
  grid-template-columns: 22px 16px;
}
.density-on .vivaldi {
  border-radius: var(--radius);
}
.color-behind-tabs-on .vivaldi:hover,
.color-behind-tabs-on .vivaldi:focus-visible {
  background-color: var(--colorAccentBgAlpha);
}
.color-behind-tabs-off .vivaldi:hover,
.color-behind-tabs-off .vivaldi:focus-visible {
  background-color: var(--colorBgDarker);
}
.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .vivaldi:hover,
.transparent-tabbar:not(.acc-dark.bg-dark.color-accent-from-page.color-behind-tabs-on) .vivaldi:focus-visible {
  background-color: var(--colorImageBgAlpha, var(--colorBgAlpha));
}
.vivaldi span {
  justify-content: center;
  align-items: center;
  display: flex;
}
.vivaldi .expand-arrow {
  opacity: 0.65;
}
#browser:not(.tabs-top) #titlebar .vivaldi {
  scale: calc(0.75 / var(--uiZoomLevel));
  transform-origin: left center;
}
.alt#browser:not(.tabs-top) #titlebar .vivaldi {
  top: calc((6px / 2) / var(--uiZoomLevel));
}
#browser .toolbar-mainbar .vivaldi {
  width: var(--menuWidth);
  height: 34px;
  border-radius: var(--radius);
  transform-origin: center;
}
:not(.alt) #browser .toolbar-mainbar .vivaldi {
  position: relative;
}
#browser .toolbar-mainbar .vivaldi:hover,
#browser .toolbar-mainbar .vivaldi:focus-visible {
  background-color: var(--colorBgDark);
}
#browser.alt #header .vivaldi,
#browser.alt .toolbar-mainbar .vivaldi {
  position: absolute;
  right: 0;
  left: unset;
  transform-origin: top right;
}
#browser.alt #header .vivaldi {
  top: calc((var(--densityGap, 0) + 3px) / var(--uiZoomLevel));
}
.tabs-at-edge#browser.alt #header .vivaldi {
  top: 0;
}
#browser.alt .toolbar-mainbar .vivaldi {
  top: calc((var(--densityGap, 0) * 2) / var(--uiZoomLevel));
}
#browser.color-behind-tabs-off .toolbar-mainbar .vivaldi:hover {
  background-color: var(--colorAccentBgDark);
}
.mac .vivaldi,
#browser.is-settingspage .vivaldi {
  display: none;
}
.panel .TranslatePanel {
  display: grid;
  grid-auto-rows: 1fr auto auto;
  gap: 6px;
  flex: 1;
}
.panel .TranslatePanel-Content {
  display: flex;
  flex-direction: column;
  gap: 6px;
  max-width: 100%;
}
.panel .TranslatePanel-FromTo {
  display: grid;
  grid-template-columns: 1fr auto 1fr;
}
.panel .TranslatePanel-SrcText,
.panel .TranslatePanel-TranslatedText {
  display: flex;
  resize: none;
  width: 100%;
  height: 100%;
  outline-offset: -2px;
}
.panel .TranslatePanel-TranslatedText {
  background-color: var(--colorBgDark);
  padding-right: 20px;
}
.panel .TranslatePanel-CopyButton {
  position: absolute;
  border: none;
  display: block;
  width: 20px;
  height: 20px;
  bottom: 5px;
  right: 12px;
  padding: 0;
  cursor: pointer;
  fill: var(--colorFgFadedMore);
  border: 1px solid transparent;
  background-color: transparent;
}
.theme-dark .panel .TranslatePanel-CopyButton {
  fill: var(--colorFgFadedMost);
}
.panel .TranslatePanel-CopyButton:hover {
  fill: var(--colorFg);
  border: 1px solid var(--colorBorder);
  background-color: var(--colorBgDarker);
}
.panel .TranslatePanel-BottomToolbar {
  display: flex;
  flex-flow: row;
  gap: 6px;
  flex-wrap: wrap;
  justify-content: end;
}
.panel .TranslatePanel-BottomToolbar input[type='submit'] {
  margin-right: auto;
}
.panel .TranslatePanel-CheckboxArea {
  display: flex;
  flex-flow: column;
  align-items: flex-start;
}
.panel .TranslatePanel-CheckboxArea label input {
  margin-right: 6px;
}
.panel .TranslatePanel-CheckboxArea label {
  margin-top: 6px;
}
.panel .TranslatePanel-ShowTranslateHistory {
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  margin: 12px 0 12px 0;
}
.panel .TranslatePanel-ShowTranslateHistory .credits {
  margin-top: 6px;
  color: var(--colorFgFaded);
  font-size: 11.5px;
}
.panel .TranslatePanel-History {
  display: flex;
  flex-direction: column;
}
.panel .TranslatePanel-History .tree-item .tree-row {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  height: calc(100% - 6px);
  background-color: var(--colorBgAlphaHeavy);
}
.panel .TranslatePanel-Pages {
  display: flex;
  align-items: center;
  padding: 0 3px;
}
.panel .TranslatePanel-Pages button {
  background-image: linear-gradient(var(--colorBgLightIntense), var(--colorBgDark));
}
.panel .TranslatePanel-Pages button:hover:not(:disabled) {
  background-image: linear-gradient(var(--colorBg), var(--colorBg));
}
.panel .TranslatePanel-Pages button:active:not(:disabled) {
  background-image: linear-gradient(var(--colorBgDark), var(--colorBgDark));
}
.panel .TranslatePanel-Pages .Translate-Characters {
  display: flex;
  align-items: center;
  color: var(--colorFgFadedMore);
  font-size: 11.5px;
}
.panel .TranslatePanel-Pages .Translate-Characters span {
  fill: var(--colorFgFadedMore);
  margin-left: 6px;
  width: 16px;
  height: 16px;
}
.panel .TranslatePanel-Pages .Translate-Page-Index {
  margin-left: auto;
  margin-right: 12px;
}
.panel .TranslatePanel-Pages .Previous-Translate {
  margin-right: 6px;
}
.panel .TranslatePanel .TranslatePanel-Row {
  display: grid;
  grid-template-rows: 18px auto 1fr;
  gap: 3px;
  overflow: hidden;
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
}
.panel .TranslatePanel .TranslatePanel-Row label {
  line-height: initial;
  min-height: unset;
  white-space: normal;
  max-height: unset;
  padding: 0 6px;
}
.panel .TranslatePanel .TranslatePanel-Row .TranslatePanel-Row-Heading {
  font-size: 11.5px;
  background-color: var(--colorFgAlpha);
  padding: 3px 6px;
}
.panel .TranslatePanel .TranslatePanel-Row .TranslatePanel-Row-Source {
  font-weight: 300;
}
.panel .TranslatePanel .TranslatePanel-Row .TranslatePanel-Row-Result {
  line-height: 1.2em;
  max-height: 3.6em;
  align-items: flex-start;
  margin-bottom: 3px;
}
.panel .TranslatePanel .TranslatePanel-Row .TranslatePanel-Row-Result span {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 3;
  -webkit-box-orient: vertical;
  white-space: normal;
  font-weight: bold;
}
.panel .TranslatePanel .TranslatePanel-Row-Narrow .TranslatePanel-Row-Result span {
  -webkit-line-clamp: 1;
}
.panel .TranslatePanel .FormFeedback {
  margin: 0;
}
#translate-panel header {
  margin-bottom: 0;
}
#translate-panel .Translate-Main-Form {
  display: flex;
  flex-direction: column;
  flex: 1;
  gap: 6px;
}
#translate-panel .Translate-History-Form {
  margin-bottom: 12px;
}
.toolbar-large .SearchField {
  width: var(--SearchFieldWidth);
}
.SearchField-SlideBar {
  top: -2px;
  left: -6px;
  bottom: -2px;
  width: 6px;
}
.toolbar-medium .SearchField-SlideBar {
  display: none;
}
.SearchField .search-history {
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.SearchField .search-history > svg {
  margin-right: calc(var(--radius) * 0.2);
}
.SearchField .SearchEngineSelect-Icon {
  z-index: 3;
  margin-right: 3px;
}
.SearchField .SearchEngineSelect-Icon span {
  margin-left: 3px;
}
.on-speeddial .SearchField .SearchEngineSelect-Icon {
  margin-right: 6px;
}
.on-speeddial .SearchField .SearchEngineSelect-Icon button {
  width: 24px;
  height: 24px;
}
.SearchField .menu {
  display: flex;
  flex-direction: column;
  top: calc(30px + var(--densityGap));
  left: 0;
  right: 0;
  z-index: 2;
  max-height: 65vh;
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.35);
  background-color: var(--colorBgLightIntense);
  border-radius: var(--radiusCap);
}
.sdwrapper .SearchField .menu {
  top: 0;
}
.SearchField.below .menu {
  top: 0;
  padding-top: 33px;
}
.density-on .SearchField.below .menu {
  padding-top: 34px;
}
.SearchField.above .menu {
  top: auto;
  bottom: 0;
  padding-top: 0;
  padding-bottom: 33px;
}
.density-on .SearchField.above .menu {
  padding-bottom: 34px;
}
.SearchField .menu > ul {
  box-shadow: none;
  overflow-y: auto;
  background-color: transparent;
}
.SearchField .menu > ul:focus-visible {
  outline: none;
}
.SearchField .menu > ul > li > a .menu-delete {
  padding: 2px;
}
.SearchField .menu > ul > li > a .menu-delete:hover {
  background-color: rgba(0, 0, 0, 0.15);
}
.SearchField .menu > ul > li > a .menu-delete:active {
  background-color: rgba(0, 0, 0, 0.25);
}
.SearchField .menu > ul > li > a:hover .menu-delete {
  display: flex;
}
.SearchField .search-engines {
  margin-right: 3px;
  border-top-left-radius: var(--radius);
  border-bottom-left-radius: var(--radius);
  padding: 2px;
}
.SearchField .search-engines > svg {
  width: 16px;
  margin-left: calc(var(--radius) * 0.2);
}
#browser:not(.win) .SearchField .search-history + nav .menu-icon {
  display: none;
}
.SearchField .searchfield-input {
  z-index: 3;
  box-shadow: none;
  border: none;
  border-radius: 0;
  overflow: hidden;
  text-overflow: ellipsis;
  flex: 1 1 100%;
  color: inherit;
  background-color: transparent;
  min-width: 0;
  padding: 0 0 0 6px;
  height: 22px;
}
.SearchField .searchfield-input:focus-visible {
  outline: unset;
}
.SearchField .SearchEngineSelect-Icon ~ .searchfield-input {
  padding: 0;
}
.SearchField .toolbar-insideinput {
  z-index: 2;
}
.sdwrapper {
  position: relative;
}
.sdwrapper .SpeedDials-Wrapper {
  position: relative;
  z-index: 1;
}
.sdwrapper .SpeedDials-Wrapper.dragging {
  z-index: 2;
}
.sdwrapper .iconmenu-container.SearchField {
  position: relative;
  padding: calc(6px * 1.5 + var(--densityGap));
  height: auto;
  background-color: var(--colorBgLightIntense);
  border: none;
}
.sdwrapper .iconmenu-container.SearchField .SlideBar {
  display: none;
}
.sdwrapper .iconmenu-container.SearchField .urlSearch,
.sdwrapper .iconmenu-container.SearchField .menu.opensubmenu.open {
  top: 32px;
  left: -1px;
  right: -1px;
}
.sdwrapper .iconmenu-container.SearchField .OmniDropdown {
  top: 0px;
  padding-top: calc(34px + var(--densityGap) * 2);
}
.sdwrapper .iconmenu-container.SearchField .menu > ul > li > a,
.sdwrapper .iconmenu-container.SearchField .OmniLinkItem {
  --grid-gap: 9px;
  padding: 0 calc(6px * 1.5 + var(--densityGap));
}
.iconmenu-container {
  position: relative;
}
.iconmenu-container .iconmenu-header {
  border: 1px solid #dedede;
  background: linear-gradient(#dddddd, #dddddd) no-repeat, linear-gradient(rgba(195, 195, 195, 0.3), rgba(195, 195, 195, 0.3)) no-repeat, url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAA4AAAAHCAQAAACSTrSSAAAAH0lEQVR4AWNg+I8HMuCWhgBcUrikUQG6FC5p7ABdCgBV/zfJ882pQwAAAABJRU5ErkJggg==');
  background-size: 1px 100%, 28px 100%, 8px 4px;
  background-position: right 28px center, right center, 97% center;
  background-repeat: no-repeat;
  background-color: var(--colorBgLight);
}
.iconmenu-container .iconmenu-header:hover {
  background-color: #fbfbfb;
}
.iconmenu-container .iconmenu-header:active {
  border-color: #c4c4c4;
  background-color: #f8f8f8;
}
.iconmenu-container .iconmenu-header a {
  display: flex;
  padding: 5px;
  padding-right: 37px;
  text-decoration: none;
  color: inherit;
  cursor: default;
}
.iconmenu-container .iconmenu-header a img {
  flex: 0 0 auto;
  margin-right: 6px;
}
.iconmenu-container .iconmenu-header a span {
  display: flex;
  flex: 0 1 auto;
}
.iconmenu-container .iconmenu-header a span label {
  flex: 1;
}
.iconmenu-container .iconmenu-header a span kbd {
  margin-left: 0.5em;
  flex: 0 0 auto;
  font: inherit;
  opacity: 0.45;
}
.MailSearchField-Inner-ExecuteSearchButton > svg {
  transform: rotate(-90deg);
}
.MailSearchField-Inner:has(.MailSearchField-advancedSearchIcon:focus) {
  outline: 0;
}
.SearchField-Popup {
  padding: 3px;
  border-radius: var(--radiusCap);
}
.SearchField-Popup label.menu-label {
  margin: 0;
}
.SearchField-Popup .OmniDropdown {
  margin: 2px -4px;
}
.SearchField-Popup:has(.OmniDropdown) {
  box-shadow: none;
}
.SearchField-Popup .UrlBar-SearchField {
  max-height: 28px;
  margin: 0;
}
.tabswitcher {
  height: 220px;
  position: relative;
  background-color: var(--colorBg);
}
.tabswitcher .visual-tabs {
  padding: 12px;
  white-space: nowrap;
  font-size: 0;
  border: solid 0 var(--colorBgDark);
  border-bottom-width: 1px;
  background-color: var(--colorBgLight);
}
.tabswitcher .visual-tabs .visual-tab {
  display: inline-block;
  position: relative;
  margin: 6px;
  width: 200px;
  height: 140px;
  background-size: cover;
  background-color: var(--colorBgInverser);
  border-radius: var(--radiusHalf);
  box-shadow: 0 0 0 2px rgba(0, 0, 0, 0.2);
}
.tabswitcher .visual-tabs .visual-tab.active-page {
  background-blend-mode: soft-light;
}
.tabswitcher .visual-tabs .visual-tab.selected {
  box-shadow: 0 0 0 2px var(--colorHighlightBg);
}
.tabswitcher .visual-tabs .visual-tab.selected .visual-tab-favicon-container {
  background: linear-gradient(135deg, transparent 49%, var(--colorHighlightBg) 51%);
  color: var(--colorHighlightFg);
}
.tabswitcher .visual-tabs .visual-tab:active {
  box-shadow: 0 0 0 2px var(--colorHighlightBg), 0 0 0 4px var(--colorHighlightBgAlpha);
}
.tabswitcher .visual-tabs .visual-tab .visual-tab-favicon-container {
  position: absolute;
  height: 50px;
  width: 50px;
  right: 0;
  bottom: 0;
  border-bottom-right-radius: var(--radiusHalf);
  background: linear-gradient(135deg, transparent 49%, #fff 51%);
}
.tabswitcher .visual-tabs .visual-tab .visual-tab-favicon-container .visual-tab-favicon {
  height: 16px;
  width: 16px;
  margin-top: 28px;
  margin-left: 28px;
}
.tabswitcher .visual-tabs .visual-tab .visual-tab-favicon-container .visual-tab-favicon > svg {
  height: 16px;
  width: 16px;
  margin-top: 28px;
}
.tabswitcher .visual-tab-switcher-title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  color: var(--colorFg);
  font-size: 16px;
  justify-content: center;
  position: absolute;
  bottom: 12px;
  display: flex;
  left: 12px;
  right: 12px;
}
.tabswitcher .visual-tab-switcher-title > .tab-audio {
  flex-shrink: 0;
}
.tabswitcher.list {
  display: grid;
  grid-template-columns: 220px 1fr;
  grid-template-rows: 1fr;
  grid-gap: 12px;
  width: calc(36em + 220px);
  height: auto;
  max-width: 90vw;
  max-height: 90vh;
  min-height: 0;
  min-width: 0;
  padding: 12px 0 12px 12px;
}
.tabswitcher.list ul.listed-tabs {
  margin: -3px 0;
  overflow: overlay;
}
.tabswitcher.list li {
  display: flex;
  margin: 2px 12px 2px 0;
  padding: 3px;
  border-radius: var(--radiusRounded);
  color: var(--colorFg);
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.tabswitcher.list li > .tab-audio {
  flex-shrink: 0;
}
.tabswitcher.list li.active-page {
  color: var(--colorFg);
  background-color: var(--colorFgAlpha);
}
.tabswitcher.list li.selected {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.tabswitcher.list img.visual-list-preview {
  width: 220px;
  min-width: 220px;
  height: 180px;
  min-height: 180px;
  border: 1px solid var(--colorBorderDisabled);
  transition: opacity 50ms ease-in;
}
.tabswitcher.list img.visual-list-preview.active-page {
  opacity: 0.5;
}
.tabswitcher.list .visual-tab-list-favicon {
  flex: 0 0 auto;
  width: 16px;
  height: 16px;
  margin-right: 6px;
  vertical-align: bottom;
}
.biscuit-setting-version {
  display: flex;
  padding: 0 6px;
  max-width: 40%;
}
.biscuit-setting-version span.application-icon-biscuit {
  display: flex;
  margin: auto 0;
}
.biscuit-setting-version span.application-icon-biscuit svg {
  width: 16px;
  height: auto;
}
.biscuit-setting-version .biscuit-string {
  user-select: text;
  cursor: text;
  -webkit-app-region: no-drag;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  margin: auto 0 auto 3px;
}
.biscuit-area h3 {
  margin-top: 12px;
}
/* NOTE: This page makes use of hardcoded white colors */
.welcome-wrapper .welcome-content-inner:not(.intro) {
  background-color: var(--colorBgIntenser);
  border-radius: var(--radius);
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.05), 0 28px 50px rgba(0, 0, 0, 0.08);
}
.welcome-wrapper {
  position: relative;
  display: flex;
  width: 100%;
  contain: strict;
}
.welcome-navigation {
  position: absolute;
  right: 24px;
  top: 0;
  bottom: 0;
  display: flex;
  flex-direction: column;
  justify-content: center;
  gap: 9px;
}
.welcome-navigation > .nav-page {
  width: 12px;
  height: 12px;
  padding: 0;
  border-radius: var(--radiusRound);
  border: 2px solid var(--colorFgFadedMore);
  background: transparent;
  transition: transform 0.2s linear;
}
.welcome-navigation > .nav-page:hover {
  transition-duration: 0.1s;
  transform: scale(1.2);
  cursor: pointer;
  border-color: var(--colorFg);
}
.welcome-navigation > .nav-page-current {
  border-color: var(--colorFg);
  background-color: var(--colorFg);
  opacity: 1;
}
.welcome-navigation > .nav-page-completed {
  background-color: color-mix(in srgb, var(--colorFg) 30%, transparent);
}
.welcome-content {
  --trackers: 0;
  --ads: 0;
  --blocking: 0;
  --no-blocking: 0;
  --base: 1;
  display: flex;
  flex: 1;
  position: relative;
  overflow-y: auto;
  overflow-x: hidden;
  scrollbar-gutter: stable;
  padding-left: var(--scrollbarWidth);
  contain: strict;
}
.welcome-content .welcome-content-outer {
  will-change: transform, opacity;
  position: absolute;
  inset: 0;
  /* React-transition-group styling end. */
}
.welcome-content .welcome-content-outer .welcome-content-inner {
  font-size: 16px;
  line-height: 1.6;
  display: flex;
  flex-direction: column;
  margin: 80px;
  padding: 60px;
  min-height: calc(100% - 80px * 2);
  min-width: 250px;
  height: auto;
}
.welcome-content .welcome-content-outer .welcome-content-inner.welcome-center-horizontal.welcome-center-vertical {
  text-align: center;
}
.welcome-content .welcome-content-outer .welcome-content-inner.welcome-center-horizontal.welcome-center-vertical p:not(.info) {
  color: var(--colorFgFaded);
  margin-left: auto;
  margin-right: auto;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account,
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-control {
  display: flex;
  gap: 6px 36px;
  flex-direction: row;
  align-items: start;
  justify-content: center;
  flex-wrap: wrap;
  max-width: fit-content;
  margin: auto auto 0;
  text-align: left;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account-panel,
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-control-panel {
  max-width: 510px;
  display: inline-flex;
  flex-direction: column;
  flex: 1;
  align-items: flex-start;
  padding: 12px;
  gap: 18px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account-panel p,
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-control-panel p {
  text-align: left;
  min-width: 220px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account-media,
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-control-media {
  display: flex;
  align-self: center;
  background-repeat: no-repeat;
  background-size: 100%;
  width: 260px;
  height: 330px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account-wrapper,
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-control-wrapper {
  display: flex;
  flex-direction: column;
  gap: 9px;
  padding-top: 18px;
  padding-bottom: 32px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account-wrapper label,
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-control-wrapper label {
  display: inline-flex;
  align-items: flex-start;
  gap: 9px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account .welcome-button,
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-control .welcome-button {
  margin-bottom: 0;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account-media {
  background-image: url(/resources/welcome-account.webp);
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-control-media {
  background-image: url(/resources/welcome-control.webp);
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account p {
  text-align: left;
  color: inherit;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account ul {
  margin-bottom: 18px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account li {
  list-style: disc;
  margin-left: 30px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account input {
  padding: 18px;
  width: 18em;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account .HintTooltip {
  width: fit-content;
  height: 40px;
  padding-right: 0;
  margin-left: 12px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-account .HintTooltip:before {
  top: 12px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-icon {
  display: inline-flex;
  width: 84px;
  height: 84px;
  margin: 30px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button {
  align-self: center;
  height: 44px;
  line-height: 1;
  margin-top: auto;
  padding-top: 12px;
  padding-right: 36px;
  padding-bottom: 12px;
  padding-left: 36px;
  min-width: 174px;
  transition: all 0.2s ease-out;
  background-color: var(--colorBgLight);
  color: var(--colorFg);
  border-radius: var(--radius);
  box-shadow: 0 0 var(--colorHighlightBg), 0 0 0 1px rgba(0, 0, 0, 0.1), 0 0 6px rgba(0, 0, 0, 0.2);
  position: relative;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button:after {
  /* pseudo element alt text after slash delimiter. */
  content: '\279d' / '';
  color: inherit;
  position: absolute;
  opacity: 0;
  top: 14px;
  right: 0;
  transform: translate(-19px, 0);
  transition: transform 0.15s, opacity 0.15s;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button.primary {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
  font-weight: 500;
  border-color: var(--colorHighlightBgDark);
  outline-offset: 1px;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button.setup {
  margin-left: 24px;
  animation: rightfade 100ms linear;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button:hover,
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button:active {
  scale: 1.01;
  box-shadow: 0 0 var(--colorHighlightBg), 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button:hover:after,
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button:active:after {
  opacity: 1;
  transform: translate(-14px, 0);
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button:active {
  scale: 1;
  box-shadow: none;
}
.welcome-content .welcome-content-outer .welcome-content-inner .welcome-button:focus-visible {
  outline-offset: 3px;
  box-shadow: 0 0 0 2px var(--colorHighlightBg), 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.welcome-content .welcome-content-outer .welcome-content-inner.intro {
  align-items: center;
  padding: 60px 0;
}
.welcome-content .welcome-content-outer .welcome-content-inner.intro h1 {
  margin-top: 0;
}
.welcome-content .welcome-content-outer .welcome-content-inner.intro img {
  margin-top: auto;
}
.welcome-content .welcome-content-outer .welcome-content-inner.intro > p {
  margin-bottom: 32px;
}
.welcome-content .welcome-content-outer h1 {
  font-size: 33px;
  font-weight: 600;
  margin-bottom: 12px;
  line-height: 1.1;
  margin-top: auto;
}
.welcome-content .welcome-content-outer p {
  opacity: 0.8;
  margin-bottom: 0;
  max-width: 65ch;
  text-wrap-style: balance;
}
.welcome-content .welcome-content-outer p.link {
  text-decoration: underline;
  cursor: pointer;
}
.welcome-content .welcome-content-outer p.link:hover {
  opacity: 1;
}
.welcome-content .welcome-content-outer label {
  line-height: 1.1;
  text-align: left;
}
.welcome-content .welcome-content-outer label.mail-and-calendar {
  display: inline-flex;
  margin-top: 18px;
  padding: 12px;
  justify-content: center;
  background-color: var(--colorBgDark);
  border-radius: var(--radius);
}
.welcome-content .welcome-content-outer label.mail-and-calendar > .Switch {
  margin-right: 12px;
}
.welcome-content .welcome-content-outer.welcome-page-enter {
  opacity: 0;
  transform: translateX(15px);
  z-index: 1;
}
.welcome-content .welcome-content-outer.welcome-page-enter.welcome-page-enter-active {
  opacity: 1;
  transform: none;
  transition: opacity 0.4s 0.2s ease-out, transform 0.4s 0.2s ease-out;
}
.welcome-content .welcome-content-outer.welcome-page-exit {
  transform: translateX(-10px);
  opacity: 0;
  transition-duration: 0.15s;
}
.welcome-content .welcome-content-outer.welcome-page-exit.welcome-page-exit-active {
  opacity: 0;
  transition-duration: 0.4s;
}
.welcome-content .cards-container {
  display: flex;
  justify-content: center;
  flex-wrap: wrap;
  align-items: flex-start;
  align-content: flex-start;
  gap: 32px;
  background-color: transparent;
  margin-top: 32px;
  margin-bottom: 32px;
}
.welcome-content .cards-container .ThemePreview--Selected:after {
  content: unset;
}
.welcome-content .cards-container .welcome-card {
  display: flex;
  flex-direction: column;
  gap: 12px;
  align-items: center;
  width: 220px;
  height: 200px;
  flex: 0 0 auto;
  background-color: transparent;
  color: var(--colorFg);
  border-width: 0;
  padding: 0;
  position: relative;
}
.welcome-content .cards-container .welcome-card:not(.card-is-selected):focus-visible.card-has-image-zoom > .card-image,
.welcome-content .cards-container .welcome-card:not(.card-is-selected):hover.card-has-image-zoom > .card-image {
  transform: scale(1.1);
  transition-duration: 500ms;
}
.welcome-content .cards-container .welcome-card:disabled {
  opacity: 1;
}
.welcome-content .cards-container .welcome-card:focus-visible {
  outline: none;
}
.welcome-content .cards-container .welcome-card.card-is-done {
  font-weight: bold;
}
.welcome-content .cards-container .welcome-card.card-is-done .card-image {
  background-color: var(--colorBgDark);
}
.welcome-content .cards-container .welcome-card.card-is-done .card-image img {
  filter: grayscale(1);
  opacity: 0.65;
}
.welcome-content .cards-container .welcome-card.card-is-done:after {
  content: '';
  position: absolute;
  top: 18px;
  right: 18px;
  bottom: unset;
  left: unset;
  width: 16px;
  height: 16px;
  border-radius: 50%;
  background-color: var(--colorSuccessBg);
  mask-image: url('/resources/mask-check.svg');
}
.welcome-content .cards-container .welcome-card.card-is-selected button {
  box-shadow: 0 0 0 2px var(--colorHighlightBg);
}
.welcome-content .cards-container .welcome-card.card-is-selected button:focus-visible button {
  box-shadow: 0 0 0 2px var(--colorHighlightBg);
}
.welcome-content .cards-container .welcome-card .card-image {
  display: flex;
  flex: 0 0 auto;
  justify-content: center;
  align-items: center;
  transition: transform 600ms, box-shadow 200ms;
  box-shadow: unset;
  border-radius: var(--radius);
  overflow: hidden;
}
.welcome-content .cards-container .welcome-card .card-image .active-tab-preview {
  fill: var(--colorAccentBg);
}
.welcome-content .cards-container .welcome-card .ThemePreview-Image {
  border-radius: var(--radius);
  box-shadow: 0 0 0 1px var(--colorBorder);
  transition: box-shadow 200ms linear;
}
.welcome-content .cards-container .welcome-card .card-text {
  display: flex;
  flex: 1;
  justify-content: center;
  align-items: center;
  line-height: 1.3;
  text-wrap-style: balance;
}
.welcome-content .cards-container .welcome-card.ThemePreview {
  width: 100%;
  height: 100%;
  max-width: unset;
}
.welcome-content .cards-container .welcome-card.ThemePreview button {
  width: 100%;
  max-width: 220px;
  height: unset;
  aspect-ratio: 4 / 2.6;
}
.welcome-content .cards-container .welcome-card.ThemePreview button .ThemePreview-Browser {
  width: 100%;
  height: 100%;
}
.welcome-content .cards-container:not(:focus-visible) .card-is-selected svg {
  color: var(--colorHighlightBg);
}
.welcome-content .cards-container:not(:focus-visible) .card-is-selected .card-image {
  box-shadow: 0 0 0 2px var(--colorHighlightBg);
}
.welcome-content .pad-top {
  margin-top: 32px;
}
.welcome-content .pad-left {
  margin-left: 32px;
}
.welcome-content .welcome-pref {
  display: flex;
  flex-direction: column;
  align-items: flex-start;
}
.welcome-content .welcome-pref.pad-top {
  margin-top: auto;
  padding: 36px 0;
}
.welcome-content .welcome-pref.pad-top + .welcome-button {
  margin-top: 0;
}
.welcome-content .welcome-pref .info {
  font-size: 13px;
  text-align: left;
  padding-left: 38px;
  max-width: 56ch;
  margin-top: 0;
}
.welcome-content .welcome-pref-checkbox {
  display: flex;
  align-items: flex-start;
  align-self: center;
  gap: 9px;
  margin: 12px 0 6px;
}
.welcome-content .welcome-pref-checkbox.intro {
  width: 100%;
}
.welcome-content .welcome-pref-checkbox.intro .info {
  margin: 0;
}
.welcome-content .FormFeedback {
  max-width: 600px;
  text-align: left;
  margin: auto auto 6px auto;
  padding-right: 12px;
}
.cards-container.card-blocker .welcome-card {
  width: 130px;
  height: 180px;
}
.cards-container.card-blocker .card-image {
  width: 120px;
  height: 120px;
  box-shadow: none;
}
.cards-container.card-blocker svg {
  width: 84px;
  height: 84px;
  stroke-width: 0.5;
}
.cards-container.card-blocker svg path[fill-opacity='.5'] {
  transform: scale(1.4, 1.25);
  transform-origin: 50% 48%;
}
.cards-container.cards-container-import {
  gap: 24px 0;
}
.cards-container.cards-container-import .welcome-card {
  width: 130px;
  height: auto;
}
.cards-container.cards-container-import .welcome-card .card-image {
  box-shadow: unset;
  width: 100px;
  height: 100px;
}
.cards-container.cards-container-tabs,
.cards-container.cards-container-layouts,
.cards-container.cards-container-themes {
  display: grid;
  width: 100%;
  grid-template-columns: repeat(4, minmax(120px, 1fr));
  max-width: calc(220px * 4 + 32px * 3);
  margin-left: auto;
  margin-right: auto;
}
.cards-container.cards-container-tabs .welcome-card,
.cards-container.cards-container-layouts .welcome-card,
.cards-container.cards-container-themes .welcome-card {
  width: unset;
  height: unset;
}
.cards-container.cards-container-tabs .welcome-card .card-image,
.cards-container.cards-container-layouts .welcome-card .card-image,
.cards-container.cards-container-themes .welcome-card .card-image {
  height: unset;
  position: relative;
  box-shadow: 0 0 0 1px var(--colorBorder);
}
.cards-container.cards-container-tabs .welcome-card .card-image svg,
.cards-container.cards-container-layouts .welcome-card .card-image svg,
.cards-container.cards-container-themes .welcome-card .card-image svg {
  width: 100%;
  height: auto;
}
.cards-container.cards-container-tabs .welcome-card.card-is-selected .card-image,
.cards-container.cards-container-layouts .welcome-card.card-is-selected .card-image,
.cards-container.cards-container-themes .welcome-card.card-is-selected .card-image {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.cards-container.cards-container-layouts .card-image {
  padding: 18px 12px;
  background: linear-gradient(180deg, #dadbf1 0%, #f5e7e7 100%);
}
.cards-container.cards-container-choice {
  flex: 1;
  align-items: center;
  align-content: center;
  margin-top: auto;
  gap: 42px;
}
.cards-container.cards-container-choice .card-text {
  max-width: calc(50% - 50px);
  width: 500px;
  text-align: left;
}
.cards-container.cards-container-choice .card-image {
  max-width: 50%;
  box-shadow: unset;
  width: 500px;
}
.cards-container.cards-container-choice .card-image img {
  width: 100%;
  scale: 1.15;
}
.cards-container.cards-container-choice ~ .feature-choice-switch {
  display: flex;
  gap: 12px;
  align-items: flex-start;
  margin: auto 0 32px;
  justify-content: center;
}
.cards-container.cards-container-choice ~ .feature-choice-switch + .welcome-button.primary {
  margin-top: 0;
}
.cards-container.cards-container-a11y {
  margin-top: auto;
  min-height: 430px;
}
.cards-container.cards-container-a11y .vivaldi-settings {
  font-size: 13px;
  line-height: normal;
  text-align: left;
  background: transparent;
  box-shadow: none;
  display: flex;
  margin-top: 6vh;
}
.cards-container.cards-container-a11y .vivaldi-settings .setting-section {
  display: grid;
  justify-content: center;
  grid-template-columns: repeat(3, minmax(min-content, 300px));
  gap: 30px;
  padding: 18px;
}
.cards-container.cards-container-a11y .vivaldi-settings div:has(> .setting-single) {
  max-width: unset;
  min-width: 220px;
  margin: 0;
}
.cards-container.cards-container-a11y .vivaldi-settings div:has(> .setting-single).unlimited {
  width: 100%;
  margin-right: 0;
}
.cards-container.cards-container-a11y .vivaldi-settings .setting-single {
  display: flex;
  flex-direction: column;
}
#app .cards-container.cards-container-a11y .vivaldi-settings .pad-top {
  margin: 0 0 6px;
  padding-top: 0;
}
#app .cards-container.cards-container-a11y .vivaldi-settings h3.pad-top {
  padding-top: 18px;
}
#app .cards-container.cards-container-a11y .vivaldi-settings h3,
#app .cards-container.cards-container-a11y .vivaldi-settings p.info {
  margin: 0 0 9px;
}
#app .cards-container.cards-container-a11y .vivaldi-settings label + p.info {
  margin: 0 0 0 25px;
}
.cards-container .ThemePreview-Image:focus-visible,
.cards-container.card-blocker .welcome-card:focus-visible .card-image,
.cards-container.cards-container-tabs .welcome-card:focus-visible .card-image,
.cards-container.cards-container-layouts .welcome-card:focus-visible .card-image,
.cards-container.cards-container-import .welcome-card:focus-visible .card-image,
.cards-container.cards-container-choice .welcome-card:focus-visible .card-image {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
  outline-offset: 2px;
}
.welcome-wrapper .MailAccountSheet .detail .detail-content {
  padding-left: 1px;
  padding-right: 0;
}
.MailAccountSheet .email-provider-signup-welcome-page {
  line-height: 1.3;
  max-width: 100%;
  width: 1048px;
  padding: 6px;
  font-size: 13px;
  display: grid;
  gap: 6px;
  grid-template-columns: min-content 1fr;
  align-items: center;
  background-color: var(--colorHighlightBgAlpha);
  border: 1px solid var(--colorHighlightBgAlpha);
  border-radius: var(--radiusHalf);
}
.MailAccountSheet .email-provider-signup-welcome-page h2 {
  font-size: 13px;
  margin-bottom: 0;
}
.MailAccountSheet .email-provider-signup-welcome-page a,
.MailAccountSheet .email-provider-signup-welcome-page p {
  grid-column-start: 2;
  max-width: initial;
}
.MailAccountSheet .email-provider-signup-welcome-page a span,
.MailAccountSheet .email-provider-signup-welcome-page p span {
  vertical-align: initial;
}
.MailAccountSheet .email-provider-signup-welcome-page .mail-setup-email-link {
  padding-left: 0.5ex;
}
.effect-container {
  overflow: hidden;
  z-index: -1;
  position: fixed;
  left: 0;
  top: 0;
  width: calc(100% + var(--scrollbarWidth));
  height: 100%;
  transform: translateZ(0);
  background-color: var(--colorBg);
  background-size: cover;
  background-position: center;
}
.theme-dark .effect-container {
  opacity: 0.5;
}
#browser.first-start-animate #header,
#browser.first-start-animate .mainbar,
#browser.first-start-animate .tabbar-wrapper {
  animation: dropfade 400ms ease-out;
}
#browser.first-start-animate #panels-container {
  animation: leftfade 400ms ease-out;
}
#browser.first-start-animate .toolbar-statusbar {
  animation: pullfade 400ms ease-out;
}
#browser.first-start #panels-container,
#browser.first-start .mainbar,
#browser.first-start .vivaldi,
#browser.first-start .tabbar-wrapper,
#browser.first-start .toolbar-statusbar {
  display: none !important;
}
#browser.first-start #header {
  min-height: 0 !important;
}
#browser.first-start #titlebar {
  -webkit-app-region: drag;
  min-height: 34px;
  z-index: 1;
}
#browser.first-start #titlebar > * {
  max-height: 34px;
  color: var(--colorFg);
}
#browser.first-start .welcome-navigation {
  translate: 0 22px;
}
.welcome-wrapper .welcome-content-outer {
  container-type: inline-size;
  container-name: welcome_card_container;
}
@container welcome_card_container (max-width: 1400px) {
  .MailAccountSheet .cards-container.cards-container-choice .card-text {
    max-width: calc(67% - 50px);
  }
}
@container welcome_card_container (max-width: 1321px) {
  .MailAccountSheet .email-provider-signup-welcome-page {
    width: 788px;
  }
  .MailAccountSheet .cards-container.cards-container-choice .card-image {
    width: auto;
  }
  .MailAccountSheet .cards-container.card-blocker .welcome-card {
    max-width: 20%;
  }
  .MailAccountSheet .cards-container.card-blocker .welcome-card .card-image {
    scale: 0.75;
  }
  .MailAccountSheet .cards-container.cards-container-choice .card-text,
  .MailAccountSheet .cards-container.cards-container-choice .card-image {
    max-width: unset;
    text-align: center;
  }
  .MailAccountSheet .cards-container.cards-container-choice .card-text .feature-choice-switch,
  .MailAccountSheet .cards-container.cards-container-choice .card-image .feature-choice-switch {
    justify-content: center;
  }
  .MailAccountSheet .cards-container.cards-container-choice .card-text img,
  .MailAccountSheet .cards-container.cards-container-choice .card-image img {
    scale: 1;
  }
  .MailAccountSheet .cards-container.cards-container-tabs,
  .MailAccountSheet .cards-container.cards-container-layouts,
  .MailAccountSheet .cards-container.cards-container-themes {
    grid-template-columns: repeat(2, minmax(120px, 1fr));
    max-width: calc(220px * 2 + 32px);
  }
}
@container welcome_card_container (max-width: 1122px) {
  .MailAccountSheet .email-providers.email-providers-welcome-page {
    padding: 0;
    max-width: unset;
  }
  .MailAccountSheet .email-providers.email-providers-welcome-page img {
    margin: 0 36px 0 0;
  }
  .MailAccountSheet .email-providers.email-providers-welcome-page img:last-child {
    margin-right: 0;
  }
  .MailAccountSheet .cards-container.cards-container-choice {
    flex-direction: column;
    gap: 6px;
    align-items: flex-start;
    align-content: flex-start;
  }
  .MailAccountSheet .cards-container.cards-container-choice .card-image {
    order: -1;
  }
  #app .cards-container.cards-container-a11y .setting-section {
    grid-template-columns: repeat(2, minmax(min-content, 300px));
    gap: 24px;
  }
}
@container welcome_card_container (max-width: 840px) {
  .cards-container.card-blocker .welcome-card {
    max-width: 20%;
  }
  .cards-container.card-blocker .welcome-card .card-image {
    scale: 0.75;
  }
  .cards-container.cards-container-choice .card-text,
  .cards-container.cards-container-choice .card-image {
    max-width: unset;
    text-align: center;
  }
  .MailAccountSheet .cards-container.cards-container-choice .card-text,
  .MailAccountSheet .cards-container.cards-container-choice .card-image {
    width: auto;
  }
  .cards-container.cards-container-choice .card-text .feature-choice-switch,
  .cards-container.cards-container-choice .card-image .feature-choice-switch {
    justify-content: center;
  }
  .cards-container.cards-container-choice .card-text img,
  .cards-container.cards-container-choice .card-image img {
    scale: 1;
  }
  .MailAccountSheet .email-provider-signup-welcome-page {
    width: 500px;
    margin: 0;
  }
  .cards-container.cards-container-choice .card-image {
    display: none;
  }
  .cards-container.cards-container-tabs,
  .cards-container.cards-container-layouts,
  .cards-container.cards-container-themes {
    grid-template-columns: repeat(2, minmax(120px, 1fr));
    max-width: calc(220px * 2 + 32px);
  }
}
@container welcome_card_container (max-width: 860px) {
  #app .welcome-content-inner {
    font-size: 13px;
    line-height: 1.3;
    margin: 10%;
    padding: 10%;
  }
  #app h1 {
    font-size: 23px;
  }
  #app .welcome-account-media,
  #app .welcome-control-media {
    display: none;
  }
  #app .cards-container.cards-container-a11y .setting-section {
    grid-template-columns: minmax(min-content, 300px);
    gap: 18px;
  }
  .cards-container.card-blocker {
    margin-top: 12px;
  }
}
@container welcome_card_container (max-width: 420px) {
  .cards-container.cards-container-tabs,
  .cards-container.cards-container-layouts,
  .cards-container.cards-container-themes {
    grid-template-columns: minmax(120px, 1fr);
    max-width: 220px;
  }
}
.feature-cards-container {
  display: flex;
  justify-content: center;
  gap: 2.75%;
  padding: 12px 0;
}
.welcome-feature-card {
  display: flex;
  flex: 0 1 280px;
  min-width: 140px;
  flex-direction: column;
  padding: 0 0 24px 0;
  text-align: left;
  background-color: var(--colorBgLight);
  color: var(--colorFg);
  border-width: 0;
  border-radius: calc(var(--radius) * 2);
  box-shadow: 0 0 var(--colorHighlightBg), 0 0 0 4px transparent, 0 0 0 1px rgba(0, 0, 0, 0.1), 0 0 6px rgba(0, 0, 0, 0.2);
  transform: scale(1);
  transition: transform 80ms linear, border 50ms linear, box-shadow 50ms linear, border-radius 500ms;
}
.welcome-feature-card:focus-visible {
  box-shadow: 0 0 0 3px var(--colorHighlightBg), 0 0 0 4px transparent, 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.welcome-feature-card.feature-card-is-selected {
  box-shadow: 0 0 0 2px var(--colorHighlightBg), 0 0 0 4px transparent, 0 0 0 1px rgba(0, 0, 0, 0.1), 0 0 6px rgba(0, 0, 0, 0.2);
  transition-duration: 200ms, 300ms, 100ms, 500ms;
}
.welcome-feature-card.feature-card-is-selected:focus-visible {
  box-shadow: 0 0 0 2px var(--colorHighlightBg), 0 0 0 4px var(--colorHighlightBg), 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.welcome-feature-card.feature-card-is-selected > .card-outline {
  border-color: var(--colorHighlightBg);
  transition-duration: 300ms;
}
.welcome-feature-card:not(.feature-card-is-selected):hover {
  transform: scaleX(1.027) scaleY(1.023);
  box-shadow: 0 0 var(--colorHighlightBg), 0 0 0 4px transparent, 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
}
.welcome-feature-card > .card-outline {
  border: 0 solid transparent;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  transition: border 50ms;
  border-radius: calc(var(--radius) - 1px);
}
.welcome-feature-card > .card-image {
  display: flex;
  justify-content: center;
  align-items: center;
  transition: transform 600ms;
  background: var(--colorHighlightBgAlpha);
  padding: 6px 0;
  width: 100%;
  border-top-left-radius: calc((var(--radius) * 2) + 1px);
  border-top-right-radius: calc((var(--radius) * 2) + 1px);
  height: auto;
}
.welcome-feature-card > h2,
.welcome-feature-card > ul {
  padding-left: 24px;
  padding-right: 18px;
}
.welcome-feature-card > h2 {
  color: var(--colorHighlightBg);
  margin-top: 18px;
  margin-bottom: 6px;
}
.welcome-feature-card > ul {
  width: 100%;
  hyphens: auto;
}
.welcome-feature-card > ul > .welcome-feature-card-feature {
  font-size: 14px;
  color: var(--colorFgFadedMost);
  padding-bottom: 3px;
  padding-left: 20px;
}
.welcome-feature-card > ul > .welcome-feature-card-feature:before {
  content: '✓';
  position: absolute;
  color: transparent;
  margin-left: -20px;
}
.welcome-feature-card > ul > .welcome-feature-card-feature-enabled {
  color: var(--colorFg);
}
.welcome-feature-card > ul > .welcome-feature-card-feature-enabled:before {
  color: var(--colorHighlightBg);
}
.theme-test {
  display: flex;
  flex-direction: column;
  flex: 1;
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  overflow-x: auto;
  scrollbar-gutter: stable;
  padding: 18px;
  color: #000;
  background-color: #ddd;
  background-position: 0px 0px, 10px 10px;
  background-size: 20px 20px;
  background-image: linear-gradient(45deg, #eee 25%, transparent 25%, transparent 75%, #eee 75%, #eee 100%), linear-gradient(45deg, #eee 25%, transparent 25%, transparent 75%, #eee 75%, #eee 100%);
}
.theme-test h2 {
  margin-top: 24px;
  margin-bottom: 12px;
}
.theme-test .list {
  display: flex;
  flex-wrap: wrap;
}
.theme-test .list > div {
  display: flex;
  flex: 0 0 170px;
  flex-direction: column;
  align-items: flex-start;
  max-width: 150px;
  height: 70px;
  margin: 0 6px 6px 0;
  padding: 6px;
  border: 1px solid rgba(0, 0, 0, 0.3);
  background-color: var(--colorFgFaded);
  word-wrap: break-word;
}
.theme-test .list > div input {
  font-size: 11px;
  color: #000;
  background-color: rgba(255, 255, 255, 0.5);
  padding: 1px 2px 0;
  margin: 0 2px 2px 0;
  border-radius: inherit;
  border: 0;
  box-shadow: none;
  height: auto;
  width: 100%;
}
.theme-test .list > div input:focus {
  background-color: #fff;
}
.ThemePreviews {
  display: grid;
  grid-template-columns: repeat(auto-fill, 140px);
  gap: 18px;
  padding: 18px;
  position: relative;
  max-height: 640px;
  overflow: auto;
  contain: content;
}
.ThemePreviews > div:not(.ThemePreview--New, .modal-faded-background) {
  display: contents;
}
.ThemePreview {
  --innerRadius: var(--radius);
  display: inline-flex;
  flex-direction: column;
  align-items: center;
  gap: 3px;
  position: relative;
  max-width: 140px;
}
.ThemePreview-Welcome {
  background: var(--colorBg);
  width: 220px;
  max-width: 220px;
}
.ThemePreview-Welcome .ThemePreview-Label {
  margin-top: 6px;
}
.ThemePreview-Welcome .ThemePreview-Panel {
  border-bottom-left-radius: 0;
}
.ThemePreview-Welcome .ThemePreview-Image {
  height: 150px;
  width: inherit;
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  box-shadow: none;
  border: none;
}
.ThemePreview-Delete {
  position: absolute;
  z-index: 1;
  display: flex;
  top: -5px;
  right: -5px;
  width: 24px;
  height: 24px;
  border: 2px solid var(--colorBgLightIntense);
  border-width: 2px;
  background: var(--colorFg);
  color: var(--colorBg);
  border-radius: 50%;
  transform: scale(0);
}
.ThemePreview-Delete > svg {
  margin: auto;
  pointer-events: none;
}
.ThemePreview-Delete:hover {
  transform: scale(1.1);
}
.ThemePreview-Delete:active {
  transform: scale(0.95);
}
.ThemePreview:hover .ThemePreview-Delete {
  transform: scale(1);
}
.ThemePreview-Image {
  display: inline-flex;
  position: relative;
  width: 140px;
  height: 100px;
  background: transparent;
  border-radius: var(--innerRadius, var(--radius));
  overflow: hidden;
  padding: 0;
  z-index: 0;
  contain: strict;
}
.ThemePreview-Image .ThemePreview-Browser {
  background-color: var(--colorWindowBg, var(--colorBg));
  background-size: cover;
  width: inherit;
  height: inherit;
  display: inline-grid;
  grid-template-columns: 50px 1fr;
  grid-template-rows: 18px 14px 1fr;
  gap: 0 0;
  outline: unset;
  grid-template-areas: 'TabBar TabBar' 'AddressBar AddressBar' 'Panel Content';
}
.ThemePreview-Image .ThemePreview-Browser--Loading {
  position: absolute;
  grid-template: unset;
  inset: 0;
  background-color: var(--colorBg);
  z-index: 2;
}
.ThemePreview-Image .ThemePreview-Browser--Loading svg {
  width: 16px;
  height: 16px;
  place-self: center;
  animation: spin 0.8s steps(8, end) infinite;
}
.ThemePreview-Image .ThemePreview-Browser--Loading svg .spinner-part1 {
  opacity: 0.4;
}
.ThemePreview-Image .ThemePreview-Browser--Loading svg .spinner-part2 {
  opacity: 0.7;
}
.ThemePreview-Image .ThemePreview-Browser--Loading svg .spinner-part3 {
  opacity: 1;
}
.ThemePreview-Image .ThemePreview-Browser--Loading svg .spinner-part4,
.ThemePreview-Image .ThemePreview-Browser--Loading svg .spinner-part5,
.ThemePreview-Image .ThemePreview-Browser--Loading svg .spinner-part6,
.ThemePreview-Image .ThemePreview-Browser--Loading svg .spinner-part7,
.ThemePreview-Image .ThemePreview-Browser--Loading svg .spinner-part8 {
  opacity: 0.2;
}
.ThemePreview--New .ThemePreview-Image {
  display: flex;
  background-color: var(--colorBg);
}
.ThemePreview--New .ThemePreview-Image > svg {
  margin: auto;
  height: 48px;
  width: 48px;
}
.ThemePreview-Image:focus-visible {
  outline-offset: 0px;
}
.ThemePreview-Image:disabled {
  opacity: unset;
}
.ThemePreview--Selected > .ThemePreview-Label {
  color: var(--colorHighlightBg);
}
.ThemePreview--Selected:after {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
  bottom: 38px;
  border-radius: var(--innerRadius);
}
.ThemePreview-TabBar {
  position: relative;
  padding: 6px 6px 0;
  gap: 1px;
  display: flex;
  flex-direction: row;
  grid-area: TabBar;
  height: 100%;
  border-top-left-radius: var(--innerRadius);
  border-top-right-radius: var(--innerRadius);
  overflow: hidden;
}
.ThemePreview-TabBar-Tab {
  width: 50px;
  max-width: 34%;
  background-color: var(--colorBg);
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
  opacity: 0.5;
  z-index: 1;
}
.ThemePreview-Browser.ui-transparent-tabs .ThemePreview-TabBar-Tab:not(.ThemePreview-TabBar-Tab--Active) {
  opacity: 0;
}
.ThemePreview-TabBar-Tab--Active {
  opacity: 1;
}
.ThemePreview-Browser.color-behind-tabs-on .ThemePreview-AddressBar,
.ThemePreview-Browser.color-behind-tabs-on .ThemePreview-TabBar-Tab {
  background-color: var(--colorBg);
  color: var(--colorFg);
}
.ThemePreview-Browser:not(.color-behind-tabs-on.color-accent-from-page.transparent-tabbar) .ThemePreview-TabBar {
  background-color: var(--colorTabBar);
}
.ThemePreview-Browser.color-behind-tabs-on.color-accent-from-page.transparent-tabbar .ThemePreview-TabBar:before {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: var(--colorAccentBg);
  mix-blend-mode: multiply;
  z-index: 0;
}
.ThemePreview-Browser.color-behind-tabs-on .ThemePreview-AddressBar-Icon {
  border-color: var(--colorFg);
}
.ThemePreview-Browser.color-behind-tabs-on .ThemePreview-AddressBar-Input {
  border-color: var(--colorBorder);
}
.ThemePreview-Browser.color-behind-tabs-off .ThemePreview-AddressBar,
.ThemePreview-Browser.color-behind-tabs-off .ThemePreview-TabBar-Tab {
  background-color: var(--colorAccentBg);
  color: var(--colorAccentFg);
}
.ThemePreview-Browser.color-behind-tabs-off .ThemePreview-AddressBar-Icon {
  border-color: var(--colorAccentFg);
}
.ThemePreview-Image.color-behind-tabs-off .ThemePreview-AddressBar-Input {
  border-color: transparent;
}
.ThemePreview-AddressBar {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: 3px;
  grid-area: AddressBar;
  padding: 3px 6px;
  height: 100%;
  box-shadow: 0 1px #0002;
}
.ThemePreview-AddressBar-Icon {
  border: 1px solid;
  border-radius: calc(var(--radius) / 2);
  flex: 0 0 8px;
  height: 100%;
  opacity: 0.5;
}
.ThemePreview-AddressBar-Icon--Active {
  opacity: 1;
}
.ThemePreview-AddressBar-Input {
  background-color: var(--colorBgIntenser);
  border: var(--colorBorder) 1px solid;
  border-radius: calc(var(--radius) / 2);
  height: 100%;
  flex: 1;
  margin-left: 3px;
}
.ThemePreview-Panel {
  grid-area: Panel;
  display: flex;
  flex-direction: column;
  height: 100%;
  gap: 3px;
  padding: 3px 6px;
  box-shadow: 1px 0 #0002;
  background-color: var(--colorBgAlphaBlur);
  border-bottom-left-radius: var(--innerRadius);
  overflow: hidden;
}
.ThemePreview-Panel-Item {
  border: 1px solid var(--colorFg);
  border-radius: calc(var(--radius) / 2);
  height: 8px;
  width: 8px;
}
.ThemePreview-Panel-Item--Active {
  background-color: var(--colorHighlightBg);
  border-color: var(--colorHighlightBg);
}
.ThemePreview-Label {
  font-weight: 500;
  max-width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.ThemePreview-Label-Meta {
  display: flex;
  gap: 3px;
  opacity: 0.4;
  font-size: 10px;
  text-transform: uppercase;
  line-height: 1;
  margin: 0 6px 1px;
  width: 134px;
  justify-content: center;
  height: 1.35em;
}
.ThemePreview-Label-Meta > span {
  border: 1px solid;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  padding: 0 3px 1px;
  border-radius: var(--radiusRounded);
}
.UnsplashCredit {
  position: fixed;
  right: var(--scrollbarWidth);
  bottom: 12px;
  padding: 3px 12px;
  margin-right: var(--scrollbarWidth);
  border-radius: var(--radius);
  font-size: 11.5px;
  color: var(--colorImageBottomRightFgAlpha, var(--colorFgFaded));
  background-color: transparent;
  backdrop-filter: var(--backgroundBlur);
  pointer-events: all;
}
.UnsplashCredit a,
.UnsplashCredit a:hover,
.UnsplashCredit a:visited {
  color: inherit;
}
.SpeedDialView {
  pointer-events: none;
}
.SpeedDialView nav,
.SpeedDialView .modal-wrapper,
.SpeedDialView .Dashboard-Widgets,
.SpeedDialView .SpeedDial,
.SpeedDialView .SpeedDialView-Head,
.SpeedDialView .SpeedDial-Add-Buttons,
.SpeedDialView .dashboard-list-wrapper {
  pointer-events: all;
}
.sync-setup li {
  display: flex;
  padding: 12px;
}
.sync-setup li + li {
  box-shadow: inset 0 1px 0 var(--colorBorderDisabled);
}
.sync-setup label {
  gap: 6px;
}
.sync-setup label h3 {
  margin: 0;
}
.sync-setup label .icon {
  display: flex;
  grid-row: 1 / span 2;
  align-items: baseline;
}
.sync-setup label .description {
  grid-row: 2;
  grid-column-start: 2;
}
.sync-setup label.login {
  display: flex;
  flex-direction: column;
}
.sync-setup label.encryption {
  display: flex;
  align-items: baseline;
  white-space: pre;
}
.sync-setup label.encryption .PasswordInputWrapper {
  width: stretch;
}
.sync-setup label.encryption-password {
  display: flex;
  align-items: center;
  gap: 12px;
}
.sync-setup label.encryption-password .icon {
  margin: 0 !important;
  flex: 0 0 auto;
}
.sync-setup label.grid {
  display: grid;
  grid-template-columns: 16px 1fr 16px;
  grid-template-rows: auto auto;
  grid-gap: 0 6px;
  flex: 1;
}
.sync-setup label.grid input {
  grid-row: 1 / span 2;
  align-self: center;
}
.sync-setup .status {
  display: flex;
  align-items: center;
  gap: 6px;
  margin-bottom: 3px;
}
.sync-setup .status .InlineText {
  margin: 0;
  font-weight: 400;
}
.sync-setup .status .InlineText:not(:hover):not(:focus) {
  color: inherit;
}
.sync-setup .sync-error-vivaldistatus {
  text-wrap: balance;
}
.sync-setup a {
  cursor: pointer;
}
.sync-setup a:focus-visible,
.sync-setup a:hover {
  color: var(--colorHighlightBg);
}
.sync-setup .footer {
  padding: 6px 12px 12px;
  display: flex;
  justify-content: flex-end;
}
.sync-status {
  display: flex;
  flex-wrap: wrap;
  flex-basis: 100%;
  margin: 0 0 12px;
}
.sync-status.detail {
  gap: 6px;
  align-items: center;
  justify-content: flex-end;
}
.sync-status input {
  margin-top: 6px;
  margin-left: auto;
}
.sync-status .time {
  margin-right: auto;
}
.sync-status .avatar-username {
  display: flex;
  flex: 0 0 auto;
  gap: 12px;
  align-items: center;
  min-width: 150px;
  padding-right: 12px;
}
.sync-status .avatar-username .profile-picture-wrapper {
  position: relative;
  --badgeBorder: var(--colorBgLightIntense);
}
.sync-status .avatar-username .profile-picture {
  width: 40px;
  height: 40px;
  border-radius: 50%;
  background: var(--colorBg);
  cursor: pointer;
}
#browser .sync-status .avatar-username .Supporter-Badge {
  width: 16px;
  right: -6px;
}
.sync-status .avatar-username .user-info {
  display: flex;
  flex-direction: column;
}
.sync-status .avatar-username .user-info .username,
.sync-status .avatar-username .user-info .info {
  margin: 0;
}
.sync-status .avatar-username .user-info .appear {
  animation: dropfade 100ms cubic-bezier(0, 0, 0.25, 1);
  transform-origin: top;
}
.sync-status .avatar-username .user-info .username {
  display: block;
  font-weight: 600;
  font-size: 13px;
  color: var(--colorFg);
  cursor: pointer;
}
.sync-status .avatar-username .user-info input {
  height: 24px;
  margin-top: 3px;
}
.sync-status .avatar-username .device-name {
  gap: 3px;
  align-items: center;
  cursor: pointer;
}
.sync-status .avatar-username .device-name .info {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.sync-status .avatar-username .device-name .edit-device-name {
  width: 16px;
  height: 16px;
}
.sync-status .avatar-username .device-name:not(:hover) .edit-device-name {
  opacity: 0.65;
}
.sync-status .data-in,
.sync-status .data-out {
  flex: 0 1 auto;
  border-radius: var(--radiusRound);
  min-height: 18px;
  display: inline-flex;
  align-items: center;
  padding: 2px 12px 2px 3px;
  fill: var(--colorHighlightBg);
  background-color: var(--colorHighlightBgAlpha);
}
.sync-status .data-in.not_synced,
.sync-status .data-out.not_synced,
.sync-status .data-in.auth_error,
.sync-status .data-out.auth_error,
.sync-status .data-in.server_error,
.sync-status .data-out.server_error,
.sync-status .data-in.network_error,
.sync-status .data-out.network_error,
.sync-status .data-in.client_error,
.sync-status .data-out.client_error,
.sync-status .data-in.other_error,
.sync-status .data-out.other_error,
.sync-status .data-in.conflict,
.sync-status .data-out.conflict {
  fill: var(--colorErrorBg);
  background-color: var(--colorErrorBgAlpha);
}
.sync-status .data-in.throttled,
.sync-status .data-out.throttled {
  fill: var(--colorWarningBg);
  background-color: var(--colorWarningBgAlpha);
}
.sync-status .data-in.success,
.sync-status .data-out.success {
  fill: var(--colorSuccessBg);
  background-color: var(--colorSuccessBgAlpha);
}
.sync-status .data-in .icon,
.sync-status .data-out .icon {
  display: flex;
  margin-right: 3px;
  pointer-events: none;
}
.sync-status .data-in .icon svg,
.sync-status .data-out .icon svg {
  width: 16px;
  height: 16px;
}
.sync-status-confirmed {
  margin: 24px 0 0;
}
.AccountSheet {
  display: flex;
  flex: 1;
  flex-direction: column;
  gap: 6px;
  width: 360px;
  max-height: 90vh;
  overflow-y: auto;
  color: var(--colorFg);
  background-color: var(--colorBg);
  padding: 24px;
}
.AccountSheet h1 {
  font-weight: 600;
  font-size: 23px;
  margin: 0 auto 12px;
}
.AccountSheet h1,
.AccountSheet h1 + p,
.AccountSheet h3 {
  text-align: center;
}
.AccountSheet h3 {
  margin: 12px 0;
}
.AccountSheet label {
  display: flex;
  flex-direction: column;
  align-self: flex-start;
  gap: 3px 9px;
  width: 100%;
}
.AccountSheet-Logo {
  width: 64px;
  height: 64px;
  margin: 0 auto 12px;
}
.AccountSheet-FormGrid {
  display: flex;
  flex-direction: column;
  margin-bottom: 24px;
}
.AccountSheet-FormGrid input[type=text]:valid,
.AccountSheet-FormGrid input[type=email]:valid,
.AccountSheet-FormGrid input[type=password]:valid,
.AccountSheet-FormGrid input[type=number]:valid {
  background-image: url(/resources/check-selected.png);
  background-size: 16px;
  background-repeat: no-repeat;
  background-position: right 3px center;
}
@media (-webkit-min-device-pixel-ratio: 2) {
  .AccountSheet-FormGrid input[type=text]:valid,
  .AccountSheet-FormGrid input[type=email]:valid,
  .AccountSheet-FormGrid input[type=password]:valid,
  .AccountSheet-FormGrid input[type=number]:valid {
    background-image: url(/resources/check-selected@2x.png);
  }
}
.AccountSheet-FormGrid input.device:valid {
  background-image: none;
}
.AccountSheet-FormGrid .HintTooltip__content {
  position-area: top span-left;
}
.AccountSheet-FormGrid .HintTooltip__content:after {
  right: 1px;
}
.AccountSheet-Footer {
  display: flex;
  justify-content: center;
  gap: 6px;
}
.AccountSheet-Form {
  display: flex;
  flex-direction: column;
  gap: 12px 18px;
  margin: 30px auto;
}
.AccountSheet-Form label + .InlineText {
  margin: -6px 0 6px;
}
.AccountSheet-FormGrid {
  grid-gap: 12px 18px;
}
.AccountSheet-FormGrid .link {
  display: inline-flex;
  gap: 6px;
}
.AccountSheet-FormGrid .link label {
  display: inline-flex;
  flex-direction: row;
  width: auto;
}
.AccountSheet-FormGrid .link .InlineText {
  margin: 0;
}
.AccountSheet .columnRow {
  flex-direction: row;
}
.AccountSheet .columnRow + .columnRow {
  margin-top: -6px;
}
.AccountSheet-FormAgreement {
  display: flex;
  flex-direction: column;
  gap: 6px;
  margin-bottom: 18px;
}
.AccountSheet-FormAgreement label {
  flex-direction: row;
}
.AccountSheet-FormAgreement span {
  display: flex;
  align-items: center;
}
#browser .AccountSheet-Verification {
  width: 10.1ch;
  height: auto;
  margin: 6px auto;
  padding: 6px 2ch;
  font-size: 23px;
  font-variant-numeric: tabular-nums;
}
#browser .AccountSheet-Verification:valid {
  background: unset;
}
.AccountSheet .AccountSheet-Password {
  flex-direction: row;
  max-width: fit-content;
}
.AccountSheet .PasswordInputWrapper input:valid {
  background-position: calc(100% - 24px) 50%;
  padding-right: 48px;
}
.AccountSheet .FormFeedback {
  margin: -12px auto 24px;
  max-width: fit-content;
}
.AccountSheet span.FormButton {
  position: relative;
  display: inline-flex;
  height: 28px;
  color: var(--colorHighlightFg);
  background: var(--colorHighlightBg);
  border-color: var(--colorHighlightBg);
  border-radius: var(--radius);
  padding: 0 12px 0 28px;
  vertical-align: middle;
  align-items: center;
}
.AccountSheet span.FormButton.in-progress.primary:before {
  background-color: var(--colorHighlightFg);
  top: 6px;
  left: 6px;
}
.AccountSheet .sync-status {
  margin: 0 auto;
}
.AccountSheet .avatar-username {
  margin: 0 auto;
}
.sync-setup .AccountSheet {
  padding: 30px 0 0;
  max-height: unset;
  overflow: unset;
  background-color: transparent;
}
.sync-setup .AccountSheet .sync-status {
  pointer-events: none;
}
.sync-setup .AccountSheet .sync-status .edit-device-name {
  display: none;
}
.page-confirm-info-bar {
  animation: dropfade 100ms cubic-bezier(0.2, 0.9, 0.6, 1);
  z-index: 1;
  /* We hardcode these values to get the yellow warning under all themes */
  background-color: rgba(255, 198, 0, 0.16);
  display: flex;
  flex: 0 0 auto;
  border-bottom: 1px solid var(--colorBorder);
  justify-content: space-between;
  align-items: center;
  width: 100%;
  padding: 6px;
}
.theme-light .page-confirm-info-bar {
  color: #111;
}
.theme-dark .page-confirm-info-bar {
  color: #f6f6f6;
}
.page-confirm-info-bar label {
  margin-left: 6px;
  display: flex;
}
.page-confirm-info-bar .infobar-controls {
  position: relative;
  display: flex;
  justify-content: flex-end;
  align-items: center;
  gap: 6px;
}
.page-confirm-info-bar .infobar-controls svg {
  width: 34px;
  height: 34px;
  fill: rgba(0, 0, 0, 0.9);
}
.page-confirm-info-bar .infobar-controls .close {
  display: flex;
  background-color: transparent;
  margin: 6px;
}
.page-confirm-info-bar .infobar-controls .close svg {
  width: 16px;
  height: 16px;
}
.page-confirm-info-bar + .devtools-container .webpage {
  top: 34px;
  transition: top 100ms cubic-bezier(0.2, 0.9, 0.6, 1);
}
.page-confirm-info-bar + .reader-mode-toolbar {
  display: none;
}
button.inspector {
  display: inline-flex;
  position: absolute;
  padding: 3px;
  background-color: var(--colorFgFaded);
  fill: var(--colorBg);
  border: 0;
  border-radius: var(--radiusRound);
  top: 12px;
  margin-left: -48px;
}
button.inspector:hover {
  fill: var(--colorBgIntense);
}
.image-inspector {
  display: flex;
  flex-direction: column;
  color: var(--colorFgFaded);
  background-color: var(--colorBg);
  border-left: 1px solid var(--colorBorder);
  width: 300px;
  fill: var(--colorFg);
  stroke: var(--colorFg);
}
.image-inspector > header {
  display: flex;
  align-items: flex-start;
  padding: 12px;
  border-bottom: 1px solid var(--colorBorder);
}
.image-inspector > header h1 {
  color: var(--colorFg);
  margin: 0 6px 0 0;
  word-break: break-all;
}
.image-inspector > header button {
  margin-left: auto;
  margin-top: 2px;
}
.image-inspector .in-progress:before {
  filter: invert();
}
.image-inspector .image-inspector-container {
  padding: 12px;
  overflow: auto;
  flex: 1;
}
.image-inspector .image-inspector-container button {
  padding: 3px 12px;
  background-color: var(--colorBg);
}
.image-inspector .image-inspector-container button:active,
.image-inspector .image-inspector-container button:hover {
  background-color: var(--colorBgLighter);
}
.image-inspector .histogram {
  width: 100%;
  height: auto;
  border-radius: var(--radiusRounded);
  border: 1px solid var(--colorBorder);
  background-color: var(--colorBgLight);
}
.image-inspector .no-stroke {
  stroke-width: 0;
}
.image-inspector .image-metadata-device {
  display: flex;
  margin-bottom: 6px;
  margin-top: 24px;
}
.image-inspector .image-metadata-device .image-camera {
  flex: 0 0 44px;
}
.image-inspector .image-metadata-device h3 {
  margin: auto 12px;
}
.image-inspector h3 {
  color: var(--colorFgIntense);
  font-weight: 500;
}
.image-inspector .image-kelvinscale {
  background: linear-gradient(90deg, rgba(255, 150, 0, 0.75), rgba(200, 200, 200, 0.25), rgba(0, 100, 255, 0.75));
  border-radius: var(--radiusRounded);
  height: 5px;
  position: relative;
  margin-top: 6px;
  margin-bottom: 18px;
  font-size: 11.5px;
}
.image-inspector .image-kelvinscale .kelvin-indicator {
  position: absolute;
  width: 40px;
  height: 20px;
  margin-left: -20px;
  text-align: center;
  top: 10px;
}
.image-inspector .image-kelvinscale .kelvin-indicator:after {
  position: absolute;
  content: '';
  top: -10px;
  left: 50%;
  margin-left: -5px;
  border: 5px solid transparent;
  border-bottom-color: var(--colorFgFaded);
}
.image-inspector .image-metadata-core {
  display: flex;
  flex-wrap: wrap;
  margin: 6px 0 18px 0;
  fill: var(--colorFgIntense);
  color: var(--colorFgIntense);
  letter-spacing: 0.015em;
}
.image-inspector .image-metadata-core > div {
  display: flex;
  align-items: center;
  min-width: 50%;
  max-width: 140px;
  position: relative;
  padding-top: 6px;
  padding-right: 6px;
  padding-bottom: 6px;
}
.image-inspector .image-metadata-core > div > span {
  display: flex;
  margin-right: 6px;
}
.image-inspector .image-histogram {
  margin: 0 0 12px;
}
.image-inspector .image-histogram .toolbar {
  gap: 3px;
  flex-wrap: wrap;
}
.image-inspector .image-histogram span {
  display: flex;
  gap: 3px;
}
.image-inspector .image-histogram .button-selected {
  color: var(--colorFgIntense);
  background-color: var(--colorBgLighter);
}
.image-inspector .image-white-balance {
  padding: 6px 0;
}
.image-inspector .image-metadata-generic {
  padding: 6px 0;
}
.image-inspector .alldata-toolbar {
  margin-top: 18px;
}
.guest-intro {
  position: absolute;
  display: flex;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: linear-gradient(140deg, var(--colorBgLighter), var(--colorBgDarker));
  color: var(--colorFg);
  overflow: overlay;
  contain: strict;
}
.guest-intro .guest-intro-background {
  position: absolute;
  top: 0;
  bottom: 0;
  right: 0;
  width: auto;
  height: 100%;
  pointer-events: none;
}
.guest-intro .guest-intro-content {
  flex: 1;
  max-width: 700px;
  min-height: 400px;
  margin: auto;
  padding: 36px;
  padding-left: 136px;
  padding-right: 136px;
  position: relative;
}
.guest-intro .guest-intro-content h1 {
  margin-bottom: 6px;
  font-size: 33px;
  font-weight: 500;
}
.guest-intro .guest-intro-content h2 {
  margin-top: 60px;
  margin-bottom: 6px;
  font-size: 21px;
  font-weight: 500;
}
.guest-intro .guest-intro-content h3 {
  margin-top: 12px;
  margin-bottom: 6px;
}
.guest-intro .guest-intro-content .guest-intro-blurb {
  min-height: 80px;
}
.guest-intro .guest-intro-content p,
.guest-intro .guest-intro-content .guest-intro-disable > span {
  font-size: 16px;
  line-height: 1.5;
  margin-bottom: 6px;
}
.guest-intro .guest-intro-content a {
  margin-top: 6px;
  font-weight: 400;
}
.guest-intro .guest-intro-content a:focus-visible {
  outline: 1px solid;
  outline-offset: 2px;
}
.guest-intro .guest-intro-content .guest-intro-icon {
  fill: var(--colorFg);
  height: auto;
  width: 60px;
  position: absolute;
  margin-left: -90px;
  margin-top: -55px;
}
.guest-intro .guest-intro-disable {
  display: block;
  margin-top: 36px;
}
.guest-intro .guest-intro-disable > input {
  border-color: var(--colorBorderIntense);
  margin-right: 6px;
  vertical-align: -4px;
}
.private-intro {
  position: absolute;
  display: flex;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: linear-gradient(140deg, var(--colorBgLighter), var(--colorBgDarker));
  color: var(--colorFg);
  overflow: auto;
  contain: strict;
}
.private-intro .private-intro-close {
  position: absolute;
  top: 30px;
  right: 30px;
  background: transparent;
  border: none;
  fill: var(--colorAccentBg);
}
.private-intro .private-intro-close > svg {
  height: 20px;
  width: 20px;
}
.private-intro .private-window-background {
  position: absolute;
  top: 0;
  bottom: 0;
  right: 0;
  width: auto;
  height: 100%;
  pointer-events: none;
}
.private-intro .private-intro-content {
  flex: 1;
  max-width: 700px;
  min-height: 550px;
  margin: auto;
  padding: 36px;
  padding-left: 136px;
  padding-right: 136px;
}
.private-intro .private-intro-content h1 {
  margin-bottom: 6px;
  font-size: 33px;
  font-weight: 500;
}
.private-intro .private-intro-content h2 {
  margin-top: 60px;
  margin-bottom: 6px;
  font-size: 21px;
  font-weight: 500;
}
.private-intro .private-intro-content h3 {
  margin-top: 12px;
  margin-bottom: 6px;
}
.private-intro .private-intro-content .private-intro-blurb {
  min-height: 80px;
}
.private-intro .private-intro-content p,
.private-intro .private-intro-content .private-intro-disable > span {
  font-size: 16px;
  font-weight: 200;
  line-height: 1.5;
}
.private-intro .private-intro-content p {
  margin-bottom: 6px;
}
.private-intro .private-intro-content a {
  font-weight: 400;
}
.private-intro .private-intro-content a:focus-visible {
  outline-width: 1px;
  outline-offset: 2px;
}
.private-intro .private-intro-content .private-intro-ghost {
  --private-ghost-animation-y-top: 0;
  --private-ghost-animation-y-bottom: 12px;
  --private-ghost-img-height: 75px;
  --private-ghost-img-width: 65px;
  contain: strict;
  cursor: default;
  transform: translateY(var(--private-ghost-animation-y-bottom));
  height: calc(var(--private-ghost-img-height) + var(--private-ghost-animation-y-bottom));
  width: var(--private-ghost-img-width);
  position: absolute;
  margin-left: -100px;
  margin-top: -45px;
}
@media (prefers-reduced-motion: no-preference) {
  .private-intro .private-intro-content .private-intro-ghost svg {
    animation: private-ghost-movement 12s ease-in-out 25;
  }
  @keyframes private-ghost-movement {
    0%,
    2%,
    98%,
    100% {
      transform: translateY(var(--private-ghost-animation-y-bottom));
    }
    48%,
    52% {
      transform: translateY(var(--private-ghost-animation-y-top));
    }
  }
}
.private-intro .private-intro-content .private-intro-select-searchengine {
  display: flex;
  align-items: center;
  margin-bottom: 18px;
  position: relative;
}
.private-intro .private-intro-content .private-intro-select-searchengine select {
  min-width: 200px;
  padding-left: 24px;
  border-color: var(--colorBorderIntense);
}
.private-intro .private-intro-content .private-intro-select-searchengine > .private-intro-favicon {
  position: absolute;
  z-index: 1;
  pointer-events: none;
  height: 16px;
  width: 16px;
  margin-left: 6px;
}
.private-intro .private-intro-disable {
  display: flex;
  align-items: center;
  gap: 6px;
  margin-top: 36px;
}
.private-intro .private-intro-disable > input {
  border-color: var(--colorBorderIntense);
  margin-right: 6px;
}
.reader-toolbar {
  height: 40px;
  width: 100%;
  justify-content: center;
  background-color: var(--colorBgLightIntense);
  color: var(--colorFg);
  border-bottom: 1px solid var(--colorBorder);
  padding-left: 6px;
  padding-right: 6px;
  overflow: hidden;
  z-index: 1;
  margin-inline: auto;
}
.reader-toolbar.reader-toolbar-enter,
.reader-toolbar.reader-toolbar-exit-active {
  opacity: 0.01;
  height: 0;
}
.reader-toolbar.reader-toolbar-enter-active {
  opacity: 1;
  height: 40px;
  transition: height 200ms ease-out, opacity 200ms ease-out;
}
.reader-toolbar.reader-toolbar-exit-active {
  transition: height 100ms ease-out, opacity 100ms ease-out;
}
.toolbar .decrease-font-size svg {
  transform: scale(0.8);
}
.toolbar .increase-font-size svg {
  transform: scale(1.2);
}
.reader-settings-toggle {
  position: absolute;
  z-index: 1;
  right: calc(var(--scrollbarWidth) + 6px);
  top: 3px;
  width: 32px;
  height: 32px;
  fill: var(--colorFg);
}
.reader-settings-toggle > button,
.reader-settings-toggle > button:active {
  box-shadow: none;
  border: 0;
  background-color: transparent;
  padding: 0;
}
.reader-settings-toggle > button svg,
.reader-settings-toggle > button:active svg {
  fill-opacity: 0.8;
  transition: fill 200ms linear;
}
.CaptureArea {
  z-index: 1001;
  position: absolute;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.45);
  border: 0 solid rgba(0, 0, 0, 0.45);
  transition-property: border-color;
  transition-duration: 100ms;
  cursor: default;
}
.CaptureArea.Area {
  cursor: crosshair;
}
.CaptureRect {
  position: absolute;
  background: transparent;
  border: 1px dashed #000;
  box-shadow: inset 0 0 0 1px rgba(255, 255, 255, 0.2);
}
.CaptureRect.Hidden {
  display: none;
}
.CaptureRect-Corner {
  background: var(--colorBg);
  border-radius: var(--radius);
  z-index: 1002;
  position: absolute;
  width: 12px;
  height: 12px;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1);
}
.CaptureRect-Corner.TopLeft {
  cursor: nwse-resize;
  position: absolute;
  top: -6px;
  left: -6px;
}
.CaptureRect-Corner.TopMid {
  cursor: ns-resize;
  top: -6px;
  right: 0;
  left: 0;
  margin: auto;
}
.CaptureRect-Corner.TopRight {
  cursor: nesw-resize;
  top: -6px;
  right: -6px;
}
.CaptureRect-Corner.MidRight {
  cursor: ew-resize;
  right: -6px;
  top: 0;
  bottom: 0;
  margin: auto;
}
.CaptureRect-Corner.BottomRight {
  cursor: nwse-resize;
  bottom: -6px;
  right: -6px;
}
.CaptureRect-Corner.BottomMid {
  cursor: ns-resize;
  bottom: -6px;
  right: 0;
  left: 0;
  margin: auto;
}
.CaptureRect-Corner.BottomLeft {
  cursor: nesw-resize;
  bottom: -6px;
  left: -6px;
}
.CaptureRect-Corner.MidLeft {
  cursor: ew-resize;
  left: -6px;
  top: 0;
  bottom: 0;
  margin: auto;
}
.ControlPanel {
  color: var(--colorFg);
  position: absolute;
  z-index: 1001;
  background: var(--colorBg);
  display: flex;
  align-items: center;
  border-radius: calc(var(--radius) * 2);
  padding: 6px 9px;
}
.ControlPanel div:focus-visible {
  outline: unset;
}
.ControlPanel.InProgress {
  padding: 6px 12px;
}
.ControlPanel.InProgress svg {
  margin-top: 3px;
  margin-right: 6px;
  width: 18px;
}
.ControlPanel.Default {
  left: 50%;
  bottom: 30px;
  transform: translateX(-50%);
}
.ControlPanel.Default > div {
  display: contents;
}
.ControlPanel-ModeSelector {
  display: flex;
  flex: 0;
  gap: 6px;
  white-space: nowrap;
  padding-right: 12px;
  position: relative;
}
.ControlPanel-ModeSelector:after {
  content: '';
  position: absolute;
  right: 0;
  top: -6px;
  bottom: -6px;
  border-right: 1px solid var(--colorBorder);
}
.ControlPanel-ModeSelector--Option {
  display: flex;
  align-items: center;
  border-radius: var(--radius);
  padding: 0 3px;
}
.ControlPanel-ModeSelector--Option input[type=radio] {
  opacity: 0;
  width: 0;
  height: 0;
  position: absolute;
}
.ControlPanel-ModeSelector--Option svg {
  fill: var(--colorFg);
  margin-right: 6px;
  margin-top: 3px;
}
.ControlPanel-ModeSelector--Option.Active {
  color: var(--colorHighlightBg);
}
.ControlPanel-ModeSelector--Option.Active svg {
  fill: currentcolor;
}
.ControlPanel-ModeSelector--Option:focus-visible:focus-within {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.ControlPanel-Output {
  display: flex;
  align-items: center;
  padding-left: 12px;
  flex: 0;
  gap: 6px;
}
.ControlPanel-Output--Description {
  white-space: nowrap;
  overflow: hidden;
}
.ControlPanel-Output .select-wrapper {
  width: max-content;
}
.OmniDropdown {
  position: absolute;
  display: flex;
  flex-direction: column;
  top: calc(100% + 4px);
  left: -1px;
  right: -1px;
  padding: 4px;
  border-radius: var(--radiusCap);
  max-height: 60vh;
  overflow-x: hidden;
  overflow-y: hidden;
  box-shadow: 0 5px 10px rgba(0, 0, 0, 0.35);
  background-color: var(--colorBgIntense);
  color: var(--colorFg);
  line-height: 1.2;
}
.OmniDropdown:empty {
  display: none;
}
.OmniDropdown-Collection {
  overflow-y: auto;
}
.OmniDropdown-Collection + .OmniDropdown-Collection-Collection {
  border-top: 1px solid var(--colorBg);
}
.OmniDropdown-Label {
  display: flex;
  align-items: center;
  min-height: 24px;
  padding-left: 9px;
  padding-right: 9px;
  opacity: 0.45;
  border-radius: var(--radiusHalf);
  pointer-events: none;
}
.OmniDropdown-Label:hover {
  background-color: var(--colorBgDark);
}
.mac .OmniDropdown-Label:hover,
.linux .OmniDropdown-Label:hover {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
}
.below .OmniDropdown {
  top: -1px;
  padding-top: 35px;
}
.density-on .below .OmniDropdown {
  padding-top: 34px;
}
.above .OmniDropdown {
  top: unset;
  bottom: -1px;
  padding-top: 6px;
  padding-bottom: 35px;
}
.density-on .above .OmniDropdown {
  padding-bottom: 34px;
}
.OmniDropdown .search-suggestion-warning {
  display: flex;
  flex-direction: row;
  gap: 12px;
  justify-content: space-between;
  border: 1px solid var(--colorBorderSubtle);
  border-radius: var(--radiusCap);
  color: var(--colorFg);
  padding: 6px 18px 6px 6px;
  margin: 6px 0 0 0;
  z-index: 3;
  flex-basis: 100%;
  font-size: 11.5px;
}
.OmniDropdown .search-suggestion-warning h2 {
  margin-bottom: 3px;
  font-weight: 600;
}
.OmniDropdown .search-suggestion-warning > div {
  flex: 1 1 auto;
}
.OmniDropdown .search-suggestion-warning .toolbar {
  margin: 6px 0 0 0;
}
.OmniDropdown .search-suggestion-warning .toolbar input {
  border-radius: var(--radiusCap);
  height: 24px;
  padding: 0 12px;
}
.OmniLinkItem {
  --item-height: calc(24px + var(--densityGap));
  --favicon-width: 16px;
  --grid-gap: 6px;
  display: grid;
  grid-template-columns: [Favicon] var(--favicon-width) [DisplayText] 1fr [Badge] auto [Erase] 16px;
  grid-gap: var(--grid-gap);
  align-items: center;
  min-height: var(--item-height);
  border-radius: var(--radiusHalf);
  padding: 0 6px 0 9px;
}
.OmniLinkItem.OmniLinkItem--DisplayTextOnly-CanDelete {
  grid-template-columns: [Favicon] var(--favicon-width) [DisplayText] 1fr [Badge] 1fr [Erase] 16px;
}
.OmniLinkItem.OmniLinkItem--DisplayTextOnly-NoDelete {
  grid-template-columns: [Favicon] var(--favicon-width) [DisplayText] 1fr [Badge] auto;
}
.OmniLinkItem.OmniLinkItem--TabSwitch {
  grid-template-columns: [Favicon] var(--favicon-width) [DisplayText] 1fr [TabSwitch] auto [Erase] 16px;
}
.UrlBar-SearchField .OmniLinkItem {
  grid-template-columns: [DisplayText] 1fr [Badge] auto [Erase] 16px;
}
.OmniLinkItem .OmniLinkItem-EraseButton {
  border-radius: var(--radiusHalf);
  width: 16px;
}
.OmniLinkItem:not(.OmniLinkItem--Highlighted) .OmniLinkItem-EraseButton {
  visibility: hidden;
}
.OmniLinkItem:not(.OmniLinkItem--Highlighted) .OmniLinkItem-Badge--HoverOnly {
  display: none;
}
.OmniLinkItem:not(.OmniLinkItem--Highlighted):hover {
  background-color: var(--colorBgDarker);
}
.OmniLinkItem:not(.OmniLinkItem--Highlighted):hover .OmniLinkItem-Badge--HoverOnly {
  display: block;
}
.OmniLinkItem--SingleValue .OmniLinkItem-Url {
  grid-column-end: Erase;
}
.OmniLinkItem--Highlighted:not(.OmniLinkItem--ButtonFocus) {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  fill: var(--colorHighlightFg);
}
.OmniLinkItem--Highlighted:not(.OmniLinkItem--ButtonFocus) .OmniLinkItem-DisplayText .displayUrl {
  color: var(--colorHighlightFg);
}
.OmniLinkItem--Highlighted.OmniLinkItem--TabSwitch.OmniLinkItem--ButtonFocus {
  background: var(--colorHighlightBgAlpha);
}
.OmniLinkItem:hover .OmniLinkItem-EraseButton,
.OmniLinkItem--Highlighted .OmniLinkItem-EraseButton {
  visibility: visible;
}
.OmniLinkItem-Label {
  pointer-events: none;
}
.OmniLinkItem-DisplayText {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.OmniLinkItem-DisplayText b {
  font-weight: 600;
}
.OmniLinkItem-Badge {
  background: var(--colorFgAlpha);
  text-align: end;
  font-size: 11.5px;
  color: var(--colorFgFadedMore);
  border-radius: var(--radius);
  padding: 1px 6px;
  margin-left: auto;
  max-width: 100%;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.OmniLinkItem--Highlighted .OmniLinkItem-Badge {
  background: var(--colorHighlightFgAlphaHeavy);
  color: var(--colorHighlightFg);
}
.UrlBar-SearchField .OmniLinkItem--Highlighted .OmniLinkItem-Badge {
  height: auto;
  margin-right: 3px;
}
.UrlBar-SearchField .OmniLinkItem-Favicon {
  display: none;
}
.OmniLinkItem-DisplayText {
  grid-column: DisplayText;
}
.OmniLinkItem-TabSwitchLabel {
  grid-column: TabSwitch;
}
.OmniLinkItem-Favicon {
  grid-column: Favicon;
}
.OmniLinkItem-EraseButton {
  grid-column: Erase;
}
.OmniLinkItem-Badge {
  grid-column: Badge;
}
.OmniLinkItem-DisplayText,
.OmniLinkItem-Favicon,
.OmniLinkItem-Badge,
.OmniLinkItem-EraseButton {
  height: 16px;
}
.OmniLinkItem-Favicon img,
.OmniLinkItem-EraseButton img,
.OmniLinkItem-Favicon svg,
.OmniLinkItem-EraseButton svg {
  width: 16px;
  height: 16px;
  pointer-events: none;
}
.OmniLinkItem-EraseButton:hover {
  background-color: rgba(0, 0, 0, 0.15);
}
.OmniLinkItem-EraseButton:active {
  background-color: rgba(0, 0, 0, 0.25);
}
.OmniLinkItem-DisplayText {
  display: flex;
  gap: 3px;
}
.OmniLinkItem-DisplayText .displayUrl,
.OmniLinkItem-DisplayText .displayTitle {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.OmniLinkItem-DisplayText .displayTitle {
  flex: 0 0 auto;
  max-width: 60%;
}
.OmniLinkItem-DisplayText .displayTitle.fromSearchField {
  max-width: stretch;
}
.OmniLinkItem-DisplayText .displayUrl {
  flex: 0 1 auto;
  color: var(--colorHighlightBg);
}
.OmniLinkItem-TabSwitchLabel {
  display: flex;
  align-items: center;
  width: fit-content;
  padding: 0 6px;
  margin-left: auto;
  gap: 6px;
  white-space: nowrap;
  font-size: 11.5px;
  font-weight: 500;
  background: transparent;
  color: var(--colorFg);
  border: 1px solid;
  border-color: var(--colorFgFadedMost);
  border-radius: var(--radius);
}
.OmniLinkItem-TabSwitchLabel svg {
  width: 16px;
  height: 16px;
  padding: 0;
}
.OmniLinkItem-TabSwitchLabel:hover {
  background: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  border-color: var(--colorHighlightBg);
}
.OmniLinkItem--Highlighted .OmniLinkItem-TabSwitchLabel,
.OmniLinkItem--Highlighted.OmniLinkItem--ButtonFocus .OmniLinkItem-TabSwitchLabel {
  background: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  border-color: var(--colorHighlightFg);
}
.OmniLinkItem--Highlighted:not(.OmniLinkItem--ButtonFocus) .OmniLinkItem-TabSwitchLabel:hover,
.OmniLinkItem--Highlighted:not(.OmniLinkItem--ButtonFocus).modifier-pressed .OmniLinkItem-TabSwitchLabel {
  color: var(--colorHighlightBg);
  background: var(--colorHighlightFg);
  border-color: var(--colorHighlightFg);
}
.OmniLinkItem--Highlighted.OmniLinkItem--ButtonFocus .OmniLinkItem-TabSwitchLabel {
  border-color: var(--colorHighlightBg);
}
.SiteInfoButton {
  z-index: 1;
}
#app .SiteInfoButton {
  width: auto;
  min-width: 22px;
  gap: 3px;
}
.SiteInfoButton-Favicon,
.SiteInfoButton-SearchEngineFavicon,
.SiteInfoButton-SecurityBadge {
  height: 16px;
  width: 16px;
}
.SiteInfoButton .siteinfo-text {
  flex: 1;
  margin: auto;
  padding-right: 6px;
  font-size: 11.5px;
}
.SiteInfoButton.secure,
.SiteInfoButton.certified {
  fill: var(--colorFgFadedMore);
}
.SiteInfoButton.secure:hover,
.SiteInfoButton.certified:hover,
.SiteInfoButton.secure:active,
.SiteInfoButton.certified:active,
.SiteInfoButton.secure:focus-visible,
.SiteInfoButton.certified:focus-visible {
  fill: var(--colorFgFaded);
}
.SiteInfoButton.warning {
  color: var(--colorFg);
}
.SiteInfoButton.insecure {
  border-color: transparent;
  fill: #DB4437;
}
.SiteInfoButton.insecure:hover,
.SiteInfoButton.insecure:active {
  fill: #bd2e22;
}
.SiteInfoButton.internal,
.SiteInfoButton.internal[disabled] {
  opacity: 1;
}
.SiteInfoButton.internal img,
.SiteInfoButton.internal[disabled] img,
.SiteInfoButton.internal svg,
.SiteInfoButton.internal[disabled] svg {
  opacity: 1;
}
.SiteInfoButton-SecurityBadge {
  height: 20px;
  width: 20px;
  padding: 2px;
}
.addressfield.certified .SiteInfoButton-SecurityBadge {
  background-color: rgba(48, 190, 48, 0.9);
  fill: #fff;
}
.SiteInfoButton-Favicon svg {
  width: 16px;
  height: 16px;
}
@keyframes bump {
  0% {
    stroke-width: 0;
  }
  20% {
    stroke-width: 1.5px;
  }
  40% {
    stroke-width: 0;
  }
  100% {
    stroke-width: 0;
  }
}
#browser .ToolbarButton-Button.updating circle {
  animation: bump 2s linear infinite 0ms;
  transform-origin: initial;
  stroke: currentColor;
}
#browser .ToolbarButton-Button.updating circle + circle {
  animation-delay: 300ms;
}
#browser .ToolbarButton-Button.updating circle + circle + circle {
  animation-delay: 600ms;
}
#browser .ToolbarButton-Button.restart .button-icon {
  color: var(--colorErrorFg);
  background-color: var(--colorHighlightBgDark);
  background-clip: padding-box;
  border: transparent 2px solid;
  border-radius: 50%;
  max-width: 28px;
}
#browser .ToolbarButton-Button.restart svg {
  width: 22px;
  height: 22px;
}
.UpdatePopup {
  text-wrap: pretty;
}
.UpdatePopup > .popup-scrollarea {
  padding: 12px;
  gap: 6px;
}
.UpdatePopup > .popup-warning {
  background: var(--colorErrorBgAlpha);
  padding: 12px;
}
.UrlBar-SearchField,
.UrlBar-AddressField {
  --ToolbarItemGap: 3px;
  height: 26px;
  padding: 0 1px;
  position: relative;
  margin: 0 2px;
}
.density-on .UrlBar-SearchField,
.density-on .UrlBar-AddressField {
  height: 30px;
  padding: 0 3px;
}
.UrlBar-SearchField .toolbar-insideinput,
.UrlBar-AddressField .toolbar-insideinput {
  z-index: 3;
}
.UrlBar-SearchField {
  flex: 0 1;
  flex-basis: calc(var(--SearchFieldWidth, 210) * 1px);
  min-width: 170px;
}
.UrlBar-PrivateWindowIndicator {
  pointer-events: none;
  display: flex;
  align-items: center;
  color: var(--colorFg, inherit);
  border-radius: var(--radiusHalf);
  padding: 0 12px 0 6px;
  font-size: 11.5px;
  height: 22px;
}
.UrlBar-PrivateWindowIndicator > svg {
  margin-right: 3px;
}
.UrlBar-AddressField {
  flex: 1 0;
}
.toolbar-spacer-flexible ~ .UrlBar-AddressField,
.toolbar-spacer-panel ~ .UrlBar-AddressField {
  flex-grow: 4;
}
.UrlBar-AddressField .toolbar:has(.pageload) {
  z-index: 2;
}
.UrlBar-AddressField .pageload {
  display: flex;
  flex: 0 0 auto;
  pointer-events: none;
  opacity: 0;
}
.UrlBar-AddressField .pageload:not(.unstarted).progressing,
.UrlBar-AddressField .pageload:not(.unstarted).progress-done {
  opacity: 1;
}
.UrlBar-AddressField .pageload:not(.unstarted).progressing .pageload-indicator::-webkit-progress-value,
.UrlBar-AddressField .pageload:not(.unstarted).progress-done .pageload-indicator::-webkit-progress-value {
  transition: width 0.4s;
}
.UrlBar-AddressField .pageload:not(.unstarted).progressing .pageload-indicator[value='0']::-webkit-progress-value,
.UrlBar-AddressField .pageload:not(.unstarted).progress-done .pageload-indicator[value='0']::-webkit-progress-value {
  transition: none;
}
.UrlBar-AddressField .pageload:not(.unstarted).stopped {
  transition: opacity 1s;
  opacity: 0;
}
.UrlBar-AddressField .pageload.progressing .pageload-ticker {
  max-width: 50px;
  width: auto;
  opacity: 1;
  flex: 0 0 auto;
}
.UrlBar-AddressField .pageload.progressing .pageload-ticker:not(:empty) {
  padding: 0 6px;
}
.UrlBar-AddressField .pageload .pageload-indicator {
  position: absolute;
  width: auto;
  height: auto;
  inset: 1px;
  border-radius: calc(var(--radius) - 2px);
  appearance: none;
  opacity: 0.25;
  background-color: var(--colorAccentBg);
  overflow: hidden;
}
.theme-dark:not(.acc-dark) .UrlBar-AddressField .pageload .pageload-indicator {
  opacity: 0.4;
}
.theme-dark.acc-dark .UrlBar-AddressField .pageload .pageload-indicator {
  background-color: var(--colorHighlightBg);
}
.UrlBar-AddressField .pageload .pageload-indicator::-webkit-progress-inner-element {
  width: 100%;
}
.UrlBar-AddressField .pageload .pageload-indicator::-webkit-progress-bar {
  background: transparent;
}
.UrlBar-AddressField .pageload .pageload-indicator::-webkit-progress-value {
  border-radius: var(--radius);
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  background-color: var(--colorBgIntenser);
}
.UrlBar-AddressField .pageload .pageload-indicator.rainbow {
  opacity: 0.35;
  background: linear-gradient(270deg, #fd747f 0%, #f8cf3d 25%, #fee861 50%, #29f6a3 75%, #39dffd 100%);
}
.UrlBar-AddressField .pageload .pageload-indicator.rainbow .theme-dark {
  opacity: 0.5;
}
.UrlBar-AddressField .pageload .pageload-ticker {
  pointer-events: none;
  font-size: 10px;
  font-variant-numeric: tabular-nums;
  line-height: 16px;
  max-width: 0;
  height: 16px;
  font-weight: 600;
  position: relative;
  opacity: 0;
  overflow: hidden;
  text-align: center;
  background-repeat: no-repeat;
  background-position: 1px 1px, 0 0;
  background-size: 50px 14px, 100% 100%;
}
.UrlBar-AddressField .pageload .pageload-ticker:first-of-type:not(:empty) {
  border-right: 1px solid rgba(0, 0, 0, 0.1);
}
.UrlBar-AddressField .pageload.progress-done .pageload-ticker {
  transition: opacity 0.15s, max-width 0.15s, padding 0.15s, margin 0.15s;
  transition-delay: 1.8s, 1.9s, 1.9s, 1.9s;
}
.UrlBar-AddressField .pageload.progress-done .pageload-ticker + .pageload-ticker {
  transition-delay: 1.9s, 2s, 2s, 2s;
}
.UrlBar-AddressField .pageload.progress-done .pageload-indicator {
  opacity: 0;
}
.UrlBar-AddressField .private-window-indicator {
  display: flex;
  flex: 0 0 20px;
  margin-right: 2px;
  background-color: #333;
  border-radius: var(--radiusRounded);
  border-bottom-left-radius: var(--radius);
  border-top-left-radius: var(--radius);
}
.UrlBar-AddressField .private-window-indicator > svg {
  fill: var(--colorWarningBg);
  margin: auto;
  height: 16px;
  width: 16px;
}
.UrlBar-UrlFieldWrapper {
  flex: 1;
  height: 100%;
  z-index: 1;
  min-width: 80px;
}
.UrlBar-UrlFieldWrapper .observer {
  height: 100%;
}
.UrlBar-UrlField {
  width: 100%;
  background-color: transparent;
  position: relative;
  line-height: 1;
  color: inherit;
}
#app .UrlBar-UrlField {
  border: none;
  box-shadow: none;
  outline: none;
  height: 100%;
  border-radius: 0;
  padding: 0 3px;
}
.UrlBar-UrlField:not(:focus) {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
#browser.mac.theme-light .UrlBar-UrlField.pseudo-selected:first-line {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 25%, transparent);
}
#browser.mac.theme-dark .UrlBar-UrlField.pseudo-selected:first-line {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 50%, transparent);
}
#browser.win .UrlBar-UrlField.pseudo-selected:first-line,
#browser.linux .UrlBar-UrlField.pseudo-selected:first-line {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.UrlBar-UrlObfuscationWarning {
  height: 16px;
  width: 16px;
}
.toolbar-mainbar.toolbar-required .UrlBar-SearchField,
.address-top-off .toolbar-mainbar .UrlBar-SearchField,
.address-bottom-off .toolbar-mainbar .UrlBar-SearchField,
.toolbar-mainbar.toolbar-required .UrlBar-AddressField,
.address-top-off .toolbar-mainbar .UrlBar-AddressField,
.address-bottom-off .toolbar-mainbar .UrlBar-AddressField {
  z-index: 10;
  margin: 0 20%;
  width: 60%;
  border-radius: var(--radius);
  transition: transform 100ms linear, opacity 100ms cubic-bezier(0, 0, 0.25, 1);
  position: absolute;
}
.toolbar-mainbar.toolbar-required .UrlBar-SearchField:focus-within,
.address-top-off .toolbar-mainbar .UrlBar-SearchField:focus-within,
.address-bottom-off .toolbar-mainbar .UrlBar-SearchField:focus-within,
.toolbar-mainbar.toolbar-required .UrlBar-AddressField:focus-within,
.address-top-off .toolbar-mainbar .UrlBar-AddressField:focus-within,
.address-bottom-off .toolbar-mainbar .UrlBar-AddressField:focus-within {
  opacity: 1;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  flex: 1 1 auto;
}
.toolbar-mainbar.toolbar-required .UrlBar-SearchField:not(:focus-within),
.address-top-off .toolbar-mainbar .UrlBar-SearchField:not(:focus-within),
.address-bottom-off .toolbar-mainbar .UrlBar-SearchField:not(:focus-within),
.toolbar-mainbar.toolbar-required .UrlBar-AddressField:not(:focus-within),
.address-top-off .toolbar-mainbar .UrlBar-AddressField:not(:focus-within),
.address-bottom-off .toolbar-mainbar .UrlBar-AddressField:not(:focus-within) {
  opacity: 0;
  transform: scaleY(0) translateY(0);
}
.toolbar-mainbar.toolbar-required .UrlBar-SearchField .SlideBar--FullHeight,
.address-top-off .toolbar-mainbar .UrlBar-SearchField .SlideBar--FullHeight,
.address-bottom-off .toolbar-mainbar .UrlBar-SearchField .SlideBar--FullHeight,
.toolbar-mainbar.toolbar-required .UrlBar-AddressField .SlideBar--FullHeight,
.address-top-off .toolbar-mainbar .UrlBar-AddressField .SlideBar--FullHeight,
.address-bottom-off .toolbar-mainbar .UrlBar-AddressField .SlideBar--FullHeight {
  display: none;
}
.toolbar-mainbar.toolbar-required .UrlBar-AddressField .add-bookmark,
.address-top-off .toolbar-mainbar .UrlBar-AddressField .add-bookmark,
.address-bottom-off .toolbar-mainbar .UrlBar-AddressField .add-bookmark {
  opacity: 1;
}
.address-top .toolbar-mainbar.toolbar-required .UrlBar-SearchField,
.address-top-off .toolbar-mainbar .UrlBar-SearchField,
.address-top .toolbar-mainbar.toolbar-required .UrlBar-AddressField,
.address-top-off .toolbar-mainbar .UrlBar-AddressField {
  top: 6px;
  align-self: flex-start;
  transform-origin: top;
}
.address-top .toolbar-mainbar.toolbar-required .UrlBar-SearchField:focus-within,
.address-top-off .toolbar-mainbar .UrlBar-SearchField:focus-within,
.address-top .toolbar-mainbar.toolbar-required .UrlBar-AddressField:focus-within,
.address-top-off .toolbar-mainbar .UrlBar-AddressField:focus-within {
  transform: scaleY(1) translateY(4px);
  transition: transform 200ms linear, opacity 200ms ease-in;
}
.address-bottom .toolbar-mainbar.toolbar-required .UrlBar-SearchField,
.address-bottom-off .toolbar-mainbar .UrlBar-SearchField,
.address-bottom .toolbar-mainbar.toolbar-required .UrlBar-AddressField,
.address-bottom-off .toolbar-mainbar .UrlBar-AddressField {
  bottom: 6px;
  align-self: flex-end;
  transform-origin: bottom;
}
.address-bottom .toolbar-mainbar.toolbar-required .UrlBar-SearchField:focus-within,
.address-bottom-off .toolbar-mainbar .UrlBar-SearchField:focus-within,
.address-bottom .toolbar-mainbar.toolbar-required .UrlBar-AddressField:focus-within,
.address-bottom-off .toolbar-mainbar .UrlBar-AddressField:focus-within {
  transition: transform 200ms linear, opacity 200ms ease-in;
  transform: scaleY(1) translateY(-4px);
}
.toolbar-medium .SearchField,
.toolbar-medium .UrlBar-AddressField {
  max-height: 28px;
}
.vivaldi-addressfield.pseudo-selected::-webkit-textfield-decoration-container,
.vivaldi-searchfield.pseudo-selected::-webkit-textfield-decoration-container {
  display: inline-flex;
}
#browser.mac.theme-light .vivaldi-addressfield.pseudo-selected::-webkit-textfield-decoration-container,
#browser.mac.theme-light .vivaldi-searchfield.pseudo-selected::-webkit-textfield-decoration-container {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 25%, transparent);
}
#browser.mac.theme-dark .vivaldi-addressfield.pseudo-selected::-webkit-textfield-decoration-container,
#browser.mac.theme-dark .vivaldi-searchfield.pseudo-selected::-webkit-textfield-decoration-container {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 50%, transparent);
}
#browser.win .vivaldi-addressfield.pseudo-selected::-webkit-textfield-decoration-container,
#browser.win .vivaldi-searchfield.pseudo-selected::-webkit-textfield-decoration-container,
#browser.linux .vivaldi-addressfield.pseudo-selected::-webkit-textfield-decoration-container,
#browser.linux .vivaldi-searchfield.pseudo-selected::-webkit-textfield-decoration-container {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.vivaldi-addressfield.pseudo-selected::-webkit-search-cancel-button,
.vivaldi-searchfield.pseudo-selected::-webkit-search-cancel-button {
  display: none;
}
.vivaldi-addressfield[value='']::-webkit-search-cancel-button,
.vivaldi-searchfield[value='']::-webkit-search-cancel-button {
  display: none;
}
.vivaldi-addressfield:focus-visible,
.vivaldi-searchfield:focus-visible {
  outline: 0;
}
.UrlField {
  display: flex;
  align-items: center;
  height: 100%;
  position: relative;
  z-index: 3;
}
.UrlBar .UrlField {
  height: 22px;
}
.UrlField .UrlBar-UrlField {
  opacity: 0;
}
.UrlField--IsEmpty .UrlFragment-Wrapper,
.UrlField--HasEditText .UrlFragment-Wrapper,
.UrlField:focus .UrlFragment-Wrapper,
.UrlField:focus-within .UrlFragment-Wrapper {
  opacity: 0;
}
.UrlField--IsEmpty .UrlBar-UrlField,
.UrlField--HasEditText .UrlBar-UrlField,
.UrlField:focus .UrlBar-UrlField,
.UrlField:focus-within .UrlBar-UrlField {
  opacity: 1;
}
.UrlField--KeywordBadge {
  height: 18px;
  margin-top: 1px;
  border-radius: var(--radius);
  padding: 0 6px;
  background-color: var(--colorFgFaded);
  color: var(--colorBg);
}
.color-behind-tabs-off .mainbar .UrlField--KeywordBadge,
.color-behind-tabs-on #tabs-tabbar-container .UrlField--KeywordBadge {
  background-color: var(--colorAccentBgFadedMore);
  color: var(--colorAccentFg);
}
.UrlFragment-Wrapper {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  position: absolute;
  max-width: 100%;
  color: var(--LowlightColor);
  padding: 0 0 0 3px;
  height: 28px;
  line-height: 28px;
}
.UrlFragment-Wrapper--ShouldHighlight {
  --HighlightColor: var(--colorFgIntense);
  --LowlightColor: var(--colorFgFadedMost);
}
.UrlFragment-Wrapper:not(.UrlFragment-Wrapper--ShouldHighlight) {
  --HighlightColor: var(--colorFgIntense);
  --LowlightColor: var(--colorFgIntense);
}
.UrlFragment-Wrapper:not(.UrlFragment-Wrapper--Clickable) {
  pointer-events: none;
}
.UrlFragment-Wrapper--Clickable {
  pointer-events: unset;
}
.UrlFragment-Wrapper bdi,
.UrlFragment-Wrapper bdo {
  display: contents;
}
.UrlFragment--Highlight {
  color: var(--HighlightColor);
}
#browser.mac.theme-light .pseudo-selected ~ .UrlFragment-Wrapper .UrlFragment--Lowlight,
#browser.mac.theme-light .pseudo-selected ~ .UrlFragment-Wrapper .UrlFragment--Highlight {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 25%, transparent);
}
#browser.mac.theme-dark .pseudo-selected ~ .UrlFragment-Wrapper .UrlFragment--Lowlight,
#browser.mac.theme-dark .pseudo-selected ~ .UrlFragment-Wrapper .UrlFragment--Highlight {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 50%, transparent);
}
#browser.win .pseudo-selected ~ .UrlFragment-Wrapper .UrlFragment--Lowlight,
#browser.win .pseudo-selected ~ .UrlFragment-Wrapper .UrlFragment--Highlight,
#browser.linux .pseudo-selected ~ .UrlFragment-Wrapper .UrlFragment--Lowlight,
#browser.linux .pseudo-selected ~ .UrlFragment-Wrapper .UrlFragment--Highlight {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.UrlFragment-LinkWrapper:hover .UrlFragment-Link {
  color: var(--HighlightColor);
  cursor: pointer;
  text-decoration: underline;
}
.UrlFragment-LinkWrapper:hover .UrlFragment-Link:hover ~ .UrlFragment-Link {
  color: unset;
  text-decoration: unset;
}
.SingleShortcut-Toolbar .multiinput {
  width: 0;
}
.SingleShortcut-Toolbar .multiinput .multiinput-group {
  flex-wrap: wrap;
}
.SingleShortcut-Toolbar .multiinput .multiinput-group input[type=text] {
  width: 0;
}
.SingleShortcut-Error {
  padding-left: 34px;
}
.SingleShortcut-Error svg {
  height: 16px;
  width: 16px;
  position: absolute;
  margin-left: -22px;
}
/* Style for the BreakMode Button / Popup component */
#app .AutoHideButtonPopup {
  font-size: 13px;
  /* If there are TWO  elements, make icon span both rows */
}
#app .AutoHideButtonPopup header {
  display: grid;
  grid-template-columns: 36px 1fr;
  padding: 18px 12px;
  align-items: center;
}
#app .AutoHideButtonPopup header p {
  grid-column: 2 / 2;
}
#app .AutoHideButtonPopup .lightbulb {
  height: 32px;
  width: 32px;
}
#app .AutoHideButtonPopup header:has(> p + p) .lightbulb {
  grid-row: span 2;
}
#app .AutoHideButtonPopup h3 {
  padding-left: 12px;
  padding-right: 6px;
  margin: 0 0 6px;
}
#app .AutoHideButtonPopup.ToolbarButtonPopup-DefaultStyles label {
  align-items: flex-start;
}
#app .AutoHideButtonPopup .toolbar {
  padding-left: 12px;
  padding-right: 12px;
}
#app .AutoHideButtonPopup .info {
  display: flex;
  flex-direction: row;
  margin: 12px 12px 0;
  gap: 9px;
}
#app .AutoHideButtonPopup .info svg {
  height: 16px;
  width: 16px;
}
#browser:has( > .AutoHideButtonPopup):after {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background: rgba(0, 0, 0, 0.2);
}
footer#footer {
  position: relative;
}
#browser:not(.tabs-bottom) footer#footer {
  background: var(--colorBg);
  color: var(--colorFg);
  border-top: 1px solid var(--colorBorder);
}
footer#footer:empty {
  display: none;
}
footer .toolbar-statusbar {
  height: 28px;
  font-size: 11.5px;
  position: relative;
  z-index: 3;
}
.density-on footer .toolbar-statusbar {
  height: calc(28px + var(--densityGap) * 2);
  padding: var(--densityGap);
}
footer .toolbar-statusbar .sync-status {
  width: 30px;
  margin: auto;
  opacity: 0.5;
  transition: opacity 100ms linear;
}
footer .toolbar-statusbar .sync-status.user-set {
  opacity: 1;
}
footer .toolbar-statusbar .sync-status .error {
  transform: translate(8px, 3px) rotate(45deg);
  fill: var(--colorBg);
}
footer .toolbar-statusbar .sync-status .progress {
  transform: translate(3px, 8px);
  fill: var(--colorBg);
  stroke-width: 0.8px;
  stroke: var(--colorBg);
}
footer .toolbar-statusbar .sync-status .error,
footer .toolbar-statusbar .sync-status .progress {
  animation: fade 200ms linear;
}
footer .toolbar-statusbar .sync-status .button-toolbar-small {
  display: flex;
}
footer .toolbar-statusbar input.zoom-percent {
  display: inline-flex;
  padding: 0;
  height: 17px;
  text-align: center;
}
footer .toolbar-statusbar #status_info {
  position: static;
  padding: 0;
  margin: auto auto auto 6px;
  overflow: hidden;
  flex: 1;
  flex-shrink: 0;
}
footer .toolbar-statusbar #status_info > span {
  margin: 0;
  padding: 0;
  border: 0;
  background-color: transparent;
}
footer .toolbar-statusbar p.in-progress {
  padding-left: 22px;
  padding-right: 3px;
}
footer .toolbar-statusbar p.in-progress:before {
  left: 3px;
  width: 16px;
  height: 16px;
  background-size: 16px 16px;
}
.tabs-bottom footer {
  overflow: hidden;
}
.tabs-bottom footer:focus-within {
  overflow: visible;
}
.transparent-tabbar:not(.color-accent-from-page.color-behind-tabs-on).tabs-bottom footer {
  backdrop-filter: var(--backgroundBlur);
}
.tabs-bottom footer:has(.tabbar-wrapper) {
  color: var(--colorImageBottomFg, var(--colorAccentFg));
  background-color: var(--colorTabBar, transparent);
}
.transparent-tabbar.tabs-bottom footer {
  --colorImageFg: var(--colorImageBottomFg);
  --colorImageFgHeaviest: var(--colorImageBottomFgAlphaHeavy);
  --colorImageBg: var(--colorImageBottomBg);
  --colorImageBgAlpha: var(--colorImageBottomBgAlpha);
  --colorImageBgAlphaHeavy: var(--colorImageBottomBgAlphaHeavy);
}
.tabs-bottom footer #tabs-tabbar-container .button-toolbar > button:disabled > .button-title,
.tabs-bottom footer > .toolbar-statusbar .button-toolbar > button:disabled > .button-title {
  color: inherit;
  opacity: 0.5;
}
.color-behind-tabs-on.tabs-bottom footer #tabs-tabbar-container,
.color-behind-tabs-on.tabs-bottom footer > .toolbar-statusbar {
  color: var(--colorImageFg, var(--colorAccentFg));
}
.transparent-tabbar.color-accent-from-page.acc-dark.bg-dark.color-behind-tabs-on.tabs-bottom footer #tabs-tabbar-container,
.transparent-tabbar.color-accent-from-page.acc-dark.bg-dark.color-behind-tabs-on.tabs-bottom footer > .toolbar-statusbar {
  color: var(--colorAccentFg);
  fill: var(--colorAccentFg);
}
.color-behind-tabs-on.tabs-bottom footer #tabs-tabbar-container > button:not(.SlideBar):active,
.color-behind-tabs-on.tabs-bottom footer > .toolbar-statusbar > button:not(.SlideBar):active,
.color-behind-tabs-on.tabs-bottom footer #tabs-tabbar-container > button:not(.SlideBar).button-pressed,
.color-behind-tabs-on.tabs-bottom footer > .toolbar-statusbar > button:not(.SlideBar).button-pressed {
  background-color: var(--colorImageBgAlphaHeavy, var(--colorAccentBgDark));
}
.color-behind-tabs-on.tabs-bottom footer #tabs-tabbar-container > button:not(.SlideBar).button-pressed:active,
.color-behind-tabs-on.tabs-bottom footer > .toolbar-statusbar > button:not(.SlideBar).button-pressed:active {
  background-color: var(--colorImageBAlpha, var(--colorAccentBgDarker));
}
.color-behind-tabs-off.tabs-bottom footer #tabs-tabbar-container,
.color-behind-tabs-off.tabs-bottom footer > .toolbar-statusbar {
  color: var(--colorImageFg, var(--colorFg));
}
.color-behind-tabs-off.tabs-bottom footer #tabs-tabbar-container > .button-toolbar > button:active,
.color-behind-tabs-off.tabs-bottom footer > .toolbar-statusbar > .button-toolbar > button:active,
.color-behind-tabs-off.tabs-bottom footer #tabs-tabbar-container > .button-toolbar > button.button-pressed,
.color-behind-tabs-off.tabs-bottom footer > .toolbar-statusbar > .button-toolbar > button.button-pressed {
  background-color: var(--colorImageBgAlphaHeavy, var(--colorBgDark));
}
.color-behind-tabs-off.tabs-bottom footer #tabs-tabbar-container > .button-toolbar > button.button-pressed:active,
.color-behind-tabs-off.tabs-bottom footer > .toolbar-statusbar > .button-toolbar > button.button-pressed:active {
  background-color: var(--colorImageBgAlpha, var(--colorBgDarker));
}
.auto-hide-wrapper .bookmark-bar {
  padding: 0 var(--densityGap);
  overflow: hidden;
  height: auto;
}
.auto-hide-wrapper .toolbar-statusbar {
  padding: var(--densityGap);
  background: var(--colorBg);
  color: var(--colorFg);
}
#main.left ~ footer > .toolbar-statusbar > .button-toolbar:first-of-type button,
#main.right ~ footer > .toolbar-statusbar > .button-toolbar:last-of-type button {
  min-width: 34px;
}
.ProxyPopup {
  --dialogPadding: 18px;
  --turn: 500ms;
  border-radius: inherit;
  overflow: hidden;
}
.ToolbarButtonPopup-DefaultStyles.button-popup .ProxyPopup h2 {
  padding: 6px var(--dialogPadding);
}
.ToolbarButtonPopup-DefaultStyles.button-popup .ProxyPopup h3 {
  align-self: flex-start;
}
.ProxyPopup-Schema {
  position: relative;
  margin: 12px 18px 0;
}
.ProxyPopup-Login,
.ProxyPopup-Setting {
  display: flex;
  flex-direction: column;
  align-items: center;
  padding: 0 var(--dialogPadding) 12px;
}
#app .ProxyPopup-Login select,
#app .ProxyPopup-Setting select {
  height: auto;
  background-position: right top;
}
.ProxyPopup-Login .toolbar,
.ProxyPopup-Setting .toolbar {
  justify-content: flex-start;
  width: stretch;
}
.ProxyPopup-Login {
  padding: 12px var(--dialogPadding);
  gap: 12px;
  font-size: 11.5px;
}
.ProxyPopup-TitleWrapper {
  display: flex;
}
.ProxyPopup-SurveyTitle {
  flex: 1;
  font-weight: bold;
}
.ProxyPopup-SURVEY {
  margin-top: 12px;
  display: grid;
  gap: 6px;
  line-height: 1.4;
  background-color: var(--colorHighlightBgAlpha);
  border-radius: var(--radius);
  padding: 12px;
}
.ProxyPopup-CTA {
  display: grid;
  gap: 6px;
  line-height: 1.4;
  background-color: var(--colorHighlightBgAlpha);
  border-radius: var(--radius);
  padding: 12px;
}
.ProxyPopup-WEBRTC {
  display: grid;
  gap: 6px;
  line-height: 1.4;
  background-color: var(--colorHighlightBgAlpha);
  border-radius: var(--radius);
  margin-top: 6px;
  padding: 12px;
}
.ProxyPopup-BUSY {
  display: grid;
  gap: 6px;
  line-height: 1.4;
  background-color: var(--colorWarningBgAlpha);
  border-radius: var(--radius);
  padding: 12px;
}
.ProxyPopup-TIME {
  display: grid;
  color: var(--colorFgFadedMore);
  gap: 6px;
  line-height: 1.4;
  padding-left: 18px;
  padding-right: 18px;
  padding-bottom: 12px;
  font-size: 11.5px;
}
.ProxyPopup-Footer {
  align-self: flex-start;
}
.ProxyPopup .dialog-footer {
  justify-content: flex-start;
  padding: 9px var(--dialogPadding);
}
.ProxyPopup-Status {
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 6px 1em;
}
.ProxyPopup-Status-Label {
  color: var(--colorFgFadedMore);
  text-align: right;
}
.ProxyPopup-Status-Bypass {
  grid-column: 1 / -1;
}
.ProxyPopup-Status button {
  height: unset;
  min-height: 28px;
  margin-top: 6px;
}
#browser .ProxyPopup .Switch {
  margin: 48px auto;
}
#app .ClockButton .button-title {
  font-variant-numeric: tabular-nums;
}
#app .ClockButton button.button-on {
  fill: inherit;
  color: inherit;
}
#app .ClockButton button.button-on .button-title {
  color: var(--colorHighlightBg);
}
.ClockButton.ClockButton--countdown svg .ClockIcon .ClockIcon-TimeHour {
  transform: rotate(var(--hourDeg)) scale(0.01);
}
.ClockButton.ClockButton--countdown svg .ClockIcon .ClockIcon-TimeMinute {
  transform: rotate(var(--minuteDeg)) scale(0.01);
}
.ClockButton svg .ClockIcon-AlarmBell {
  transform: scale(var(--clockAlarmSet, 0));
}
.ClockButton:not(.ClockButton--countdown) svg .ClockIcon-CountdownHour,
.ClockButton:not(.ClockButton--countdown) svg .ClockIcon-CountdownMinute {
  transform: scale(0.01);
}
svg .ClockIcon-TimeHour,
svg .ClockIcon-TimeMinute {
  transform-origin: center;
  transition: transform 0.4s cubic-bezier(0.4, 2.08, 0.55, 0.44);
}
svg .ClockIcon-TimeHour {
  transform: rotate(var(--hourDeg));
}
svg .ClockIcon-TimeMinute {
  transform: rotate(var(--minuteDeg));
}
svg .ClockIcon-AlarmBell {
  transition: transform 0.4s cubic-bezier(0.4, 2.08, 0.55, 0.44);
  transform-origin: 50% 21%;
}
svg .ClockIcon-CountdownHour,
svg .ClockIcon-CountdownMinute {
  --circumference: calc(4 * 2 * 3.14);
  transform-origin: center;
  transition-duration: 0.2s;
  stroke-dasharray: var(--circumference) var(--circumference);
  stroke-width: 9px;
  fill: transparent;
}
svg .ClockIcon-CountdownHour {
  transform: rotate(calc(var(--hourDeg) - 90deg));
  stroke-dashoffset: calc(var(--circumference) - var(--countdownHourPercent) / 100 * var(--circumference));
  stroke: var(--colorHighlightBg);
}
svg .ClockIcon-CountdownMinute {
  transform: var(--countdownSeconds, rotate(calc(var(--minuteDeg) - 90deg)));
  stroke-dashoffset: calc(var(--circumference) - var(--countdownMinutePercent) / 100 * var(--circumference));
  stroke: var(--colorHighlightBg);
  opacity: 0.5;
}
svg.ClockGraphic {
  width: auto;
  height: 100%;
  contain: content;
  shape-rendering: geometricprecision;
  --radiusHour: 50;
  --radiusMinute: 50;
}
svg.ClockGraphic .ClockGraphic-Hour-Indicator,
svg.ClockGraphic .ClockGraphic-Minute-Indicator {
  stroke-width: 10;
  fill: transparent;
  transform-origin: center;
  transition: stroke-dashoffset 0.2s;
  stroke-dasharray: var(--circumference) var(--circumference);
}
svg.ClockGraphic .ClockGraphic-Hour-Indicator {
  --circumference: calc(17 * 2 * 3.14);
  transform: rotate(var(--hourDeg));
  stroke: var(--colorHighlightBg);
  stroke-dashoffset: calc(var(--circumference) - var(--hourPercent) / 100 * var(--circumference));
}
svg.ClockGraphic .ClockGraphic-Minute-Indicator {
  --circumference: calc(29 * 2 * 3.14);
  transform: rotate(calc(var(--minuteDeg) - 90deg));
  stroke: var(--colorHighlightBg);
  stroke-opacity: 0.5;
  stroke-dashoffset: calc(var(--circumference) - var(--minutePercent) / 100 * var(--circumference));
}
svg.ClockGraphic .ClockGraphic-Hour-Hand,
svg.ClockGraphic .ClockGraphic-Minute-Hand,
svg.ClockGraphic .ClockGraphic-Second-Hand {
  transform-origin: center;
  transition: transform 0.2s cubic-bezier(0.4, 2.08, 0.55, 0.44);
}
svg.ClockGraphic .ClockGraphic-Hour-Hand {
  transform: rotate(var(--hourDeg));
}
svg.ClockGraphic .ClockGraphic-Minute-Hand {
  transform: rotate(var(--minuteDeg));
}
svg.ClockGraphic .ClockGraphic-Second-Hand {
  fill: var(--colorHighlightBg);
  transform: rotate(var(--secondDeg));
}
.ClockPopup-BigClock:not(.ClockPopup-BigClock--ShowSeconds) svg.ClockGraphic .ClockGraphic-Second-Hand {
  display: none;
}
svg.ClockGraphic .ClockGraphic-CenterCutout {
  fill: var(--colorBg);
}
.ClockPopup .toolbar {
  justify-content: center;
  background-color: var(--colorBg);
  padding: 12px 12px 6px;
}
.ClockPopup .toolbar .toolbar-group {
  margin: unset;
  flex-basis: 100%;
}
.ClockPopup .toolbar .toolbar-group .button-toolbar {
  flex: auto;
  margin: unset;
}
.ClockPopup .toolbar .toolbar-group .button-toolbar button {
  height: 22px;
}
.ClockPopup-Active {
  border-bottom: 1px solid var(--colorBorder);
  padding-bottom: 6px;
}
.ClockPopup-Alarms,
.ClockPopup-Countdowns {
  background: var(--colorBg);
  padding: 0 12px 6px 12px;
}
.ClockPopup p {
  padding: 6px;
}
.ClockPopup-Custom-Line {
  display: flex;
  gap: 3px;
  margin-bottom: 6px;
  justify-content: space-between;
}
.ClockPopup-Custom-Line:not(:last-child) {
  margin-bottom: 12px;
}
.ClockPopup-Custom-Line--wrap {
  flex-wrap: wrap;
}
.ClockPopup-Spinner-Wrapper {
  display: inline-flex;
  flex-direction: column;
  vertical-align: middle;
}
.ClockPopup-Spinner {
  height: 14px;
  width: 14px;
  margin-left: -1px;
  border-radius: 0;
  position: relative;
  background: transparent;
}
.ClockPopup-Spinner--up {
  border-bottom-width: 0;
  border-top-right-radius: var(--radius);
}
.ClockPopup-Spinner--up:after {
  content: '';
  position: absolute;
  width: 16px;
  height: 16px;
  right: 6px;
  background-color: currentColor;
  mask-image: var(--svgArrow);
  mask-repeat: no-repeat;
  mask-position: 0 0;
  mask-size: 16px 16px;
  pointer-events: none;
  scale: 0.625 -0.625;
  right: -1px;
  top: -1px;
}
.ClockPopup-Spinner--down {
  border-top-width: 0;
  border-bottom-right-radius: var(--radius);
}
.ClockPopup-Spinner--down:after {
  content: '';
  position: absolute;
  width: 16px;
  height: 16px;
  right: 6px;
  background-color: currentColor;
  mask-image: var(--svgArrow);
  mask-repeat: no-repeat;
  mask-position: 0 0;
  mask-size: 16px 16px;
  pointer-events: none;
  scale: 0.625;
  right: -1px;
  top: -3px;
}
.ClockPopup-Spinner:active {
  --colorBgIntense: var(--colorBgDark);
}
.ClockPopup-DateInputField.ClockPopup-DateInputField {
  width: 2.5em;
  margin: 0;
  text-align: right;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  background-color: var(--colorBgLightIntense);
  font-variant-numeric: tabular-nums;
}
.ClockPopup-DateInputField.ClockPopup-DateInputField:focus {
  position: relative;
  z-index: 1;
}
.ClockPopup-BigClock {
  display: flex;
  justify-content: center;
  align-items: center;
  padding-top: 12px;
  padding-right: 12px;
  padding-bottom: 6px;
  padding-left: 12px;
  height: 110px;
  min-height: 110px;
}
.ClockPopup-Timer {
  display: flex;
}
.ClockPopup-Timer-Name {
  border: none;
  border-radius: 0;
  background: transparent;
  flex: 1;
  text-align: left;
  padding-left: 12px;
  padding-right: 1px;
  padding-top: 3px;
  padding-bottom: 3px;
}
.ClockPopup-Timer-Name:active,
.ClockPopup-Timer-Name:active + .ClockPopup-Timer-Clear {
  background-color: var(--colorBgDark);
}
.ClockPopup-Timer-Name:focus-visible {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  outline: unset;
}
.ClockPopup-Timer-Name:focus-visible:active,
.ClockPopup-Timer-Name:focus-visible:active + .ClockPopup-Timer-Name:focus-visible-Clear {
  background-color: var(--colorHighlightBgDark);
  border-color: var(--colorHighlightBgDark);
}
.ClockPopup-Timer-Name:focus-visible + .ClockPopup-Timer-Clear {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  border-color: var(--colorHighlightBg);
}
.ClockPopup-Timer-Name:focus-visible + .ClockPopup-Timer-Clear:active {
  background-color: var(--colorHighlightBgDark);
  border-color: var(--colorHighlightBgDark);
}
.ClockPopup-Timer-Clear {
  border: none;
  border-radius: 0;
  background: transparent;
  padding: 0 12px;
}
.ClockPopup-Timer-Clear:hover {
  background-color: var(--colorBgDark);
}
.ClockPopup-Timer-Clear:active {
  background-color: var(--colorBgDarker);
}
.ClockPopup-Timer-Clear > svg {
  width: 12px;
  height: 12px;
}
.ClockPopup h2 {
  background-color: transparent;
  border-bottom: none;
  display: flex;
}
.ClockPopup h3 {
  font-size: 10px;
  font-weight: 500;
  padding-bottom: 3px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.ClockPopup-Header {
  background-color: var(--colorBg);
  border-bottom: 1px solid var(--colorBorder);
  padding: 6px 12px;
}
.ClockPopup-Header h2 {
  padding-bottom: 2px;
}
.ClockPopup-Header .info {
  margin: 0;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.popup-scrollarea .ClockPopup-Header {
  display: flex;
  flex-wrap: wrap;
}
.popup-scrollarea .ClockPopup-Header h2 {
  margin-right: auto;
}
.popup-scrollarea .ClockPopup-Header button {
  font-size: 10px;
  border: 1px solid;
  flex: unset;
  padding: 0 6px;
  border-radius: var(--radius);
}
.ClockPopup-TimeField.ClockPopup-TimeField.ClockPopup-TimeField {
  display: block;
  white-space: nowrap;
}
.ClockPopup-Name.ClockPopup-Name {
  flex: 1 1 100%;
  width: 100%;
  background-color: var(--colorBgLightIntense);
}
.ClockPopup-Presets {
  padding-bottom: 12px;
  display: flex;
  flex-wrap: wrap;
  gap: 3px;
}
.ClockPopup-PresetWrapper {
  flex: 1 0 auto;
  display: flex;
}
.ClockPopup-Preset {
  padding-left: 6px;
  padding-right: 1px;
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  border-right-width: 0;
  background: var(--colorBg);
  flex: 0 1 calc(var(--popupWidth) - 46px);
  text-align: left;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.ClockPopup-Preset:active,
.ClockPopup-Preset:active + button {
  background-color: var(--colorBgDark);
}
.ClockPopup-Preset--selected {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  border-color: var(--colorHighlightBg);
}
.ClockPopup-Preset--selected:active,
.ClockPopup-Preset--selected:active + button {
  background-color: var(--colorHighlightBgDark);
  border-color: var(--colorHighlightBgDark);
}
.ClockPopup-Preset-Clear {
  display: inline-flex;
  padding: 0 3px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
  border-left-width: 0;
  background: var(--colorBg);
}
.ClockPopup-Preset-Clear:active {
  background-color: var(--colorBgDark);
}
.ClockPopup-Preset-Clear--selected {
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  border-color: var(--colorHighlightBg);
}
.ClockPopup-Preset-Clear--selected:active {
  background-color: var(--colorHighlightBgDark);
  border-color: var(--colorHighlightBgDark);
}
.ClockPopup-Preset-Clear > svg {
  width: 16px;
  height: 16px;
  margin: auto;
}
.vivaldi-extension-banner {
  display: flex;
  align-self: flex-start;
  color: var(--colorFg);
  background: var(--colorBg);
  flex-direction: row;
  padding: 2px;
  margin: 0;
  width: 100%;
}
.vivaldi-extension-banner label {
  margin: 6px;
  display: flex;
  flex: 1;
}
.vivaldi-extension-banner .controls {
  display: flex;
  position: relative;
  justify-content: flex-end;
  align-items: center;
  flex: 0;
}
.vivaldi-extension-banner .controls svg {
  width: calc(34px / 2);
  height: calc(34px / 2);
  fill: rgba(128, 128, 128, 0.9);
}
.vivaldi-extension-banner .controls .close {
  background-color: transparent;
  margin: 6px;
}
.vivaldi-extension-banner .controls .close :hover {
  filter: brightness(1.5);
}
.StartPage-GameButton {
  position: absolute;
  z-index: 1;
  bottom: 48px;
  right: 48px;
}
.StartPage-GameButton .GameButton > button {
  height: 56px;
  width: 56px;
  border-radius: var(--radiusRound);
  background: var(--colorBgLightIntense);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  cursor: pointer;
  border: none;
}
.StartPage-GameButton .GameButton > button.button-pressed {
  background-color: var(--colorBg);
}
.StartPage-GameButton .GameButton > button:active {
  background-color: var(--colorBgDark);
}
.StartPage-GameButton .GameButton > button > img {
  image-rendering: pixelated;
  height: 42px;
  width: 42px;
  transition: 1s;
}
.GamePreviewPopup {
  padding: 6px;
  display: grid;
  grid-template-columns: auto 26px;
  grid-template-rows: 26px auto 26px;
  gap: 6px;
}
.GamePreviewPopup-SettingsButton {
  --ButtonSize: 26px;
  border: none;
  background: transparent;
  height: var(--ButtonSize);
  width: var(--ButtonSize);
  padding: 0;
  margin: 0;
  margin-left: 6px;
}
.GamePreviewPopup-PreviewImage {
  width: 100%;
  border-radius: 3px;
  image-rendering: pixelated;
}
.GamePreviewPopup-PreviewImage,
.GamePreviewPopup-StartButton {
  grid-column: span 2;
}
h2.GamePreviewPopup-HeaderText {
  padding: 0;
  background-color: transparent;
  text-align: left;
  align-self: center;
  border: none;
}
.VivaldiDropdown {
  position: relative;
}
.VivaldiDropdown-Button {
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: var(--colorBgIntense);
  color: var(--colorFg);
  height: 28px;
  width: 100%;
}
.VivaldiDropdown-DropdownMenu {
  width: 100%;
  left: 0;
}
.VivaldiDropdown-Placeholder {
  display: flex;
  align-items: center;
}
.VivaldiDropdown-Placeholder p {
  margin: 0 !important;
  padding: 0 !important;
}
.VivaldiDropdown-SelectedValue {
  display: grid;
  flex: 1;
  grid-template-columns: [Icon] 16px [Title] auto [Arrow] 16px;
  gap: 0 6px;
  align-items: center;
}
.VivaldiDropdown-SelectedValue-Icon {
  grid-area: Icon;
  height: 16px;
  width: 16px;
}
.VivaldiDropdown-SelectedValue-Title {
  grid-area: Title;
  text-align: left;
}
.VivaldiDropdown-SelectedValue-Arrow {
  grid-area: Arrow;
  height: 16px;
  width: 16px;
}
.VivaldiDropdown-SelectedValue-Arrow svg {
  height: 16px;
  width: 16px;
}
.BookmarkButton {
  font-size: 11.5px;
  display: flex;
  border-radius: var(--radiusRoundedLess);
  border: 1px solid transparent;
  min-width: 22px;
  height: 22px;
}
.BookmarkButton:hover {
  border-color: var(--colorBorder);
}
.BookmarkButton--Active {
  background-color: var(--colorBgDark);
}
.BookmarkButton-Button {
  height: 100%;
  border-radius: inherit;
}
.BookmarkButton-Button .ToolbarButton-Button {
  border: none;
  border-radius: inherit;
  width: 100%;
  height: 100%;
  margin: 0;
  padding: 0 2px;
  gap: 2px;
}
.BookmarkButton-Button .ToolbarButton-Button:active,
.BookmarkButton-Button .ToolbarButton-Button.button-pressed {
  box-shadow: unset;
}
.BookmarkButton-Button .ToolbarButton-Button.button-pressed {
  background-color: unset;
  border-color: unset;
}
#browser .BookmarkButton-Button .ToolbarButton-Button > .button-title {
  position: static;
  width: auto;
  padding-right: 3px;
  text-shadow: unset;
  color: inherit;
  font-size: inherit;
  font-weight: inherit;
}
.BookmarkButton .bookmark-animated-fill {
  opacity: 0;
  fill: var(--colorAccentBgDark);
  transform: translateY(22px);
  transition: 500ms transform;
}
.theme-dark .BookmarkButton .bookmark-animated-fill {
  fill: var(--colorAccentBgFadedMore);
}
.theme-dark.acc-dark .BookmarkButton .bookmark-animated-fill {
  fill: var(--colorAccentFgFaded);
}
.BookmarkButton .add-bookmark-shadow {
  fill: rgba(0, 0, 0, 0.1);
  opacity: 1;
}
.BookmarkButton .button-on .bookmark-animated-fill {
  opacity: 1;
  transform: translateY(0);
}
.BookmarkButton .button-on .bookmark-outline {
  fill: rgba(0, 0, 0, 0.3);
  transition: fill 500ms cubic-bezier(0.2, 0.9, 0.6, 1);
}
.BookmarkPopup {
  --HorizontalPadding: 6px * 3;
  background-color: var(--colorBgLighter);
  display: grid;
  grid-template-columns: auto;
  grid-template-rows: auto auto 48px;
  font-size: 13px;
  overflow: hidden;
  border-radius: var(--radiusCap);
}
.BookmarkPopup .dialog-header {
  background-color: var(--colorBg);
  display: flex;
  flex-wrap: wrap;
  align-items: baseline;
  gap: 6px;
  padding: 12px 18px;
}
.BookmarkPopup .dialog-header h1 {
  margin: 0;
}
.BookmarkPopup .dialog-content {
  gap: 6px;
  padding: 6px 0 0;
  overflow-x: hidden;
  overflow-y: auto;
}
.BookmarkPopup .dialog-footer {
  padding: 9px 18px;
}
.BookmarkPopup-Footer-EditButton {
  background-color: var(--colorHighlightBg) !important;
  color: var(--colorBgIntenser) !important;
}
.BookmarkPopup-Footer-TrashButton {
  padding: 0;
  width: 28px;
}
.BookmarkPopup-TextInputWrapper {
  display: grid;
  gap: 6px;
  padding: 0 18px;
}
.BookmarkPopup-TextInputWrapper .FormFeedback {
  margin: 0;
}
.BookmarkPopup-ExpandButtonWrapper .InlineText {
  display: flex;
  gap: 6px;
  align-items: center;
}
.BookmarkPopup-LocationSelector {
  width: auto;
  max-width: var(--popupWidth);
}
.BookmarkInputField {
  border-bottom: 1px solid var(--colorBorder);
  height: 34px;
  display: flex;
  gap: 12px;
  align-items: center;
  cursor: text;
}
.BookmarkInputField > input {
  text-overflow: ellipsis;
}
.BookmarkInputField:focus-within {
  border-bottom-color: var(--colorHighlightBg);
  box-shadow: 0px 1px 0px 0px var(--colorHighlightBg);
}
.BookmarkInputField-Title {
  white-space: nowrap;
  color: var(--colorFgFadedMore);
}
#app .BookmarkInputField-Input {
  width: 100%;
  background-color: transparent;
  outline: none;
  border: none !important;
  border-radius: unset;
  box-shadow: none !important;
  color: var(--colorFg);
  padding: 0 !important;
}
.BookmarkLocationSelector {
  display: grid;
  grid-template-columns: [header checkbox search content footer] auto;
  grid-template-rows: [header] auto [checkbox] auto [search] 52px [content] minmax(auto, 162px) [footer] auto;
}
.BookmarkLocationSelector-Header {
  grid-area: header;
  color: var(--colorFgFadedMore);
  padding: 12px 18px 0;
}
.BookmarkLocationSelector-SpeedDialCheckbox {
  grid-area: checkbox;
  padding: 6px 18px 0;
}
.BookmarkLocationSelector-SpeedDialCheckbox > label {
  display: inline-flex;
  vertical-align: top;
  gap: 9px;
  width: 100%;
}
.BookmarkLocationSelector-FolderList--Loading {
  opacity: 0;
}
.BookmarkLocationSelector-SearchInput {
  --IconSpace: 21px;
  padding: 0 18px;
  grid-area: search;
  position: relative;
  display: grid;
  grid-template-columns: [icon] var(--IconSpace) [text] auto;
  grid-template-rows: auto;
  grid-gap: 6px;
  align-items: center;
}
.BookmarkLocationSelector-SearchInput-Icon {
  color: var(--colorFg);
  pointer-events: none;
  grid-column: icon;
  grid-row: 1;
  justify-self: center;
}
.BookmarkLocationSelector-SearchInput-Input {
  grid-row: 1;
  grid-column-start: 1;
  grid-column-end: 3;
  padding-left: var(--IconSpace) !important;
  background-color: var(--colorBgAlpha);
}
.BookmarkLocationSelector-SearchInput-Input:not(:focus) {
  border-color: transparent;
  box-shadow: none;
}
.BookmarkLocationSelector-FolderList {
  grid-area: content;
  margin-left: 18px;
}
.BookmarkLocationSelector-AddFolderButton {
  grid-area: footer;
  max-width: fit-content;
  padding: 12px 18px;
}
.BookmarkLocationSelector-AddFolderButton > button {
  background-image: linear-gradient(var(--colorBgLightIntense) 0%, var(--colorBg) 100%);
}
.Dashboard {
  width: 100%;
  margin-left: auto;
  margin-right: auto;
  flex: 1 1 auto;
  --dashboardGap: 6px * 4;
}
.Dashboard .empty-widget-message {
  padding: 0 12px;
  display: flex;
  flex-direction: column;
  align-items: center;
  height: 100%;
  justify-content: center;
  gap: 6px;
}
#browser .Dashboard .scrollable {
  scrollbar-gutter: stable;
  overflow: auto;
}
.Dashboard input[type='color'] {
  opacity: 0;
  margin-left: auto;
}
.Dashboard-Widgets {
  margin-top: var(--dashboardGap);
  margin-left: auto;
  margin-right: auto;
  height: var(--widgetsHeight);
  transition: width 300ms cubic-bezier(0.24, 1.56, 0.64, 1);
}
.Dashboard-Widgets .transparent {
  color: var(--colorImageCenterFg, var(--colorWindowFg));
  background-color: transparent;
}
.Dashboard-Widgets .semi-transparent {
  background-color: color-mix(in srgb, var(--colorBg), transparent 35%);
}
.Dashboard-Widgets .solid {
  background-color: var(--colorBgLight);
}
.Dashboard-Widgets .dashboard-widget {
  display: flex;
  flex-direction: column;
  backdrop-filter: var(--backgroundBlur);
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.15), 0 2px 4px 0 rgba(0, 0, 0, 0.2);
  border-radius: var(--radius);
  overflow: hidden;
}
.Dashboard-Widgets .dashboard-widget:hover,
.Dashboard-Widgets .dashboard-widget:focus-visible {
  will-change: transform;
}
.Dashboard-Widgets .dashboard-widget:focus-visible:not(.dashboard-widget--dragged) {
  outline: 2px solid color-mix(in srgb, var(--colorImageCenterFg, var(--colorFg)), var(--colorHighlightBg) 80%);
  outline-offset: 2px;
}
.Dashboard-Widgets .dashboard-widget .VivaldiList {
  overflow-y: initial;
}
.Dashboard-Widgets .dashboard-widget .tree-row {
  border-radius: var(--radius);
}
.Dashboard-Widgets .dashboard-widget-header {
  display: flex;
  flex-direction: row;
  align-items: center;
  gap: 6px;
  cursor: grab;
}
.Dashboard-Widgets .dashboard-widget-header .title {
  display: flex;
  flex: 1;
  align-items: center;
  justify-content: space-between;
  overflow: hidden;
  padding: 3px 12px;
  font-size: 11.5px;
  opacity: 0.8;
}
.Dashboard-Widgets .dashboard-widget-header .title span {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.Dashboard-Widgets .dashboard-widget-header .dashboard-widget-menubutton button {
  border: none;
  translate: 9px 0;
}
.Dashboard:has(.Dashboard-Widgets:not(.Dashboard-Widgets-Drop):empty) {
  display: none;
}
.Dashboard .dashboard-widget--dragged {
  opacity: 0.3;
  border: 1px solid var(--colorFg);
}
.Dashboard-PrivacyStatsWidget {
  display: flex;
  flex-direction: column;
  height: 180px;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-loading {
  height: 100%;
  display: grid;
  gap: 6px;
  grid-template-columns: 1fr 1fr;
  padding: 6px 12px 18px 12px;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-loading .counter {
  animation: skeletonBackground 1s infinite alternate;
  opacity: 0.5;
  border-radius: var(--radius);
}
@keyframes skeletonBackground {
  from {
    background-color: var(--colorBg);
  }
  to {
    background-color: var(--colorBgDarker);
  }
}
.Dashboard-PrivacyStatsWidget .privacy-stats-loading .stats {
  animation: skeletonBackground 1s infinite alternate;
  opacity: 0.5;
  border-radius: var(--radius);
  grid-row-start: span 2;
  grid-column-start: span 2;
}
@keyframes skeletonBackground {
  from {
    background-color: var(--colorBg);
  }
  to {
    background-color: var(--colorBgDarker);
  }
}
.Dashboard-PrivacyStatsWidget.solid .privacy-stats-loading div {
  opacity: 1;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-list {
  flex: 1 1 auto;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-wrapper {
  padding: 0 12px 12px;
  display: flex;
  flex-direction: column;
  align-items: center;
  gap: 12px;
  height: 100%;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-wrapper .TabbedView {
  flex: 1 1 auto;
  width: 100%;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-wrapper .TabbedView .TabbedView-List {
  border-top-left-radius: var(--radius);
  border-top-right-radius: var(--radius);
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
  margin: 0;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-wrapper p {
  font-weight: 600;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-wrapper .counter-wrapper {
  width: 100%;
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 6px;
  margin: auto 0;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-wrapper .counter-wrapper > div {
  display: flex;
  flex-direction: column;
  flex: 1 1;
  gap: 3px;
  padding: 9px 6px;
  border-radius: var(--radius);
}
.Dashboard-PrivacyStatsWidget .privacy-stats-wrapper .counter-wrapper > div .title {
  font-size: 13px;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-wrapper .counter-wrapper > div .counter {
  display: flex;
  align-items: center;
  font-size: 23px;
  font-weight: 600;
  gap: 3px;
}
.Dashboard-PrivacyStatsWidget .privacy-stats-wrapper .counter-wrapper > div .counter > div {
  height: 32px;
  width: 32px;
}
.Dashboard-PrivacyStatsWidget.solid .counter-wrapper > div {
  background-color: var(--colorBgAlpha);
}
.Dashboard-StickyNoteWidget .note-editor {
  height: 100%;
  resize: none;
  border: unset;
  border-top-left-radius: unset;
  border-top-right-radius: unset;
  box-shadow: unset;
  outline: unset;
  padding: 6px var(--scrollbarWidth) 12px 12px;
}
.Dashboard-StickyNoteWidget .note-editor:focus {
  background-image: unset !important;
  opacity: 1 !important;
}
.Dashboard-StickyNoteWidget .note-editor:not(:focus) {
  color: inherit;
  background: transparent;
}
.Dashboard-EmailWidget {
  overflow-y: auto;
}
.Dashboard-EmailWidget .emailrow {
  display: flex;
  flex-direction: column;
  gap: 6px;
  padding-block: 12px;
}
.Dashboard-EmailWidget .emailrow:not(:last-child) {
  border-bottom: 1px solid var(--colorBorder);
}
.Dashboard-EmailWidget .emailrow-from {
  display: flex;
  flex-direction: row;
  justify-content: space-between;
}
.Dashboard-EmailWidget .emailrow .date {
  opacity: 0.8;
}
.Dashboard-EmailWidget .emailrow-subject {
  font-weight: 600;
}
#browser .Dashboard-TasksWidget .scrollable,
#browser .Dashboard-CalendarWidget .scrollable {
  display: flex;
  flex-direction: column;
  flex: 1;
  scrollbar-gutter: unset;
}
.Dashboard-TasksWidget .calendar-grid-agenda,
.Dashboard-CalendarWidget .calendar-grid-agenda {
  scrollbar-gutter: stable;
  padding-bottom: 12px;
}
.Dashboard-TasksWidget .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-events,
.Dashboard-CalendarWidget .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-events {
  padding: 0 0 0 12px;
}
.Dashboard-TasksWidget .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date,
.Dashboard-CalendarWidget .calendar-grid-agenda .cal-tasks-row .cal-tasks-row-date {
  padding: 0 6px 6px;
}
.Dashboard-TasksWidget .calendar-viewport,
.Dashboard-CalendarWidget .calendar-viewport,
.Dashboard-TasksWidget .calendar-grid-agenda,
.Dashboard-CalendarWidget .calendar-grid-agenda {
  background-color: transparent;
  overflow-x: hidden;
}
.Dashboard-TasksWidget .widget-image-intro ~ .calendar-viewport,
.Dashboard-CalendarWidget .widget-image-intro ~ .calendar-viewport {
  /* TODO: When keyboard navigation is consistent */
}
.Dashboard-TasksWidget .widget-image-intro ~ .calendar-viewport .cal-tasks-row h2,
.Dashboard-CalendarWidget .widget-image-intro ~ .calendar-viewport .cal-tasks-row h2 {
  font-weight: normal;
  margin-bottom: 6px;
}
.Dashboard-TasksWidget .widget-image-intro ~ .calendar-viewport .calendar-add-event-button,
.Dashboard-CalendarWidget .widget-image-intro ~ .calendar-viewport .calendar-add-event-button {
  max-width: fit-content;
  padding: 6px 12px 6px 6px;
}
.Dashboard-TasksWidget .widget-image-intro ~ .calendar-viewport .calendar-grid-agenda:focus .calendar-add-event-button,
.Dashboard-CalendarWidget .widget-image-intro ~ .calendar-viewport .calendar-grid-agenda:focus .calendar-add-event-button {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.Dashboard-TasksWidget .date,
.Dashboard-CalendarWidget .date {
  opacity: 0.8;
  padding: 6px;
}
.Dashboard-TasksWidget .calendar-event,
.Dashboard-CalendarWidget .calendar-event {
  margin: 1px;
  cursor: pointer;
}
.Dashboard-TasksWidget.transparent .cal-tasks-row-date,
.Dashboard-CalendarWidget.transparent .cal-tasks-row-date,
.Dashboard-TasksWidget.transparent .calendar-add-event-button:not(:hover),
.Dashboard-CalendarWidget.transparent .calendar-add-event-button:not(:hover),
.Dashboard-TasksWidget.transparent .calendar-event,
.Dashboard-CalendarWidget.transparent .calendar-event {
  color: inherit;
}
.Dashboard .feed-wrapper,
.Dashboard .email-wrapper {
  display: flex;
  flex-direction: column;
  overflow: auto;
  padding-right: 6px;
  flex: 1;
}
.Dashboard .feed-wrapper .unread.unseen .title,
.Dashboard .email-wrapper .unread.unseen .title {
  color: var(--colorHighlightBg);
}
.Dashboard .feed-wrapper .unread .data-row .title,
.Dashboard .email-wrapper .unread .data-row .title,
.Dashboard .feed-wrapper .unread .title-row .title,
.Dashboard .email-wrapper .unread .title-row .title {
  font-weight: 600;
}
.Dashboard .feed-wrapper .unread span,
.Dashboard .email-wrapper .unread span {
  height: 16px;
}
.Dashboard .feed-wrapper .unread span svg,
.Dashboard .email-wrapper .unread span svg {
  fill: var(--colorHighlightBg);
  width: 16px;
  height: 16px;
}
.Dashboard .feed-wrapper .feed-row,
.Dashboard .email-wrapper .feed-row {
  display: grid;
  grid-template-areas: 'FeedTitle FeedImage' 'FeedSubject FeedImage' 'FeedContent FeedImage' 'FeedSeparator FeedSeparator';
  grid-template-columns: auto 1fr;
  gap: 3px 0;
  padding: 6px 12px;
  cursor: pointer;
}
.Dashboard .feed-wrapper .feed-row.title-only,
.Dashboard .email-wrapper .feed-row.title-only {
  grid-template-areas: 'FeedTitle' 'FeedSubject' 'FeedSeparator';
  grid-template-columns: auto;
}
.Dashboard .feed-wrapper .feed-row.title-only .subject-row .title,
.Dashboard .email-wrapper .feed-row.title-only .subject-row .title {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  white-space: inherit;
}
.Dashboard .feed-wrapper .feed-row.title-only .preview-image,
.Dashboard .email-wrapper .feed-row.title-only .preview-image {
  display: none;
}
.Dashboard .feed-wrapper .feed-row.title-only .content-row,
.Dashboard .email-wrapper .feed-row.title-only .content-row {
  display: none;
}
.Dashboard .feed-wrapper .feed-row:focus-visible,
.Dashboard .email-wrapper .feed-row:focus-visible {
  outline: none;
  background: var(--colorBgDark);
}
.Dashboard .feed-wrapper .feed-row.focus-first .preview-image img,
.Dashboard .email-wrapper .feed-row.focus-first .preview-image img {
  width: 128px;
  height: 128px;
}
.Dashboard .feed-wrapper .feed-row.focus-first .subject-row .title,
.Dashboard .email-wrapper .feed-row.focus-first .subject-row .title {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  white-space: inherit;
}
.Dashboard .feed-wrapper .feed-row.focus-first .content-row .content,
.Dashboard .email-wrapper .feed-row.focus-first .content-row .content {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 5;
  -webkit-box-orient: vertical;
}
.Dashboard .feed-wrapper .feed-row .preview-image,
.Dashboard .email-wrapper .feed-row .preview-image {
  grid-area: FeedImage;
  display: flex;
  margin-left: 12px;
  padding-top: 4px;
}
.Dashboard .feed-wrapper .feed-row .preview-image img,
.Dashboard .email-wrapper .feed-row .preview-image img {
  width: 64px;
  height: 64px;
  object-fit: cover;
  border: 1px var(--colorBorder) solid;
  border-radius: var(--radiusHalf);
}
.Dashboard .feed-wrapper .feed-row .preview-image:empty,
.Dashboard .email-wrapper .feed-row .preview-image:empty {
  display: none;
}
.Dashboard .feed-wrapper .feed-row .title-row,
.Dashboard .email-wrapper .feed-row .title-row {
  grid-area: FeedTitle;
  display: grid;
  grid-template-columns: 1fr auto;
  gap: 6px;
}
.Dashboard .feed-wrapper .feed-row .title-row .title,
.Dashboard .email-wrapper .feed-row .title-row .title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.Dashboard .feed-wrapper .feed-row .title-row .date,
.Dashboard .email-wrapper .feed-row .title-row .date {
  white-space: nowrap;
  font-size: 11.5px;
  opacity: 0.8;
}
.Dashboard .feed-wrapper .feed-row .subject-row,
.Dashboard .email-wrapper .feed-row .subject-row {
  grid-area: FeedSubject;
  overflow: hidden;
}
.Dashboard .feed-wrapper .feed-row .subject-row .title,
.Dashboard .email-wrapper .feed-row .subject-row .title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  font-weight: 600;
  grid-column: 1;
}
.Dashboard .feed-wrapper .feed-row .content-row,
.Dashboard .email-wrapper .feed-row .content-row {
  grid-area: FeedContent;
}
.Dashboard .feed-wrapper .feed-row .content-row .content,
.Dashboard .email-wrapper .feed-row .content-row .content {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  word-break: break-word;
  color: inherit;
  opacity: 0.8;
  font-size: 11.5px;
}
.Dashboard .feed-wrapper .feed-row hr,
.Dashboard .email-wrapper .feed-row hr {
  grid-area: FeedSeparator;
  margin-top: 6px;
}
.Dashboard .feed-wrapper .email-item,
.Dashboard .email-wrapper .email-item {
  display: flex;
  flex-direction: column;
  gap: 3px;
  padding: 6px;
  cursor: pointer;
}
.Dashboard .feed-wrapper .email-item:focus-visible,
.Dashboard .email-wrapper .email-item:focus-visible {
  color: var(--colorFg);
  background: var(--colorBgDark);
}
.theme-light .Dashboard .feed-wrapper .email-item:focus-visible,
.theme-light .Dashboard .email-wrapper .email-item:focus-visible {
  outline: none;
}
.Dashboard .feed-wrapper .email-item .data-row,
.Dashboard .email-wrapper .email-item .data-row {
  display: grid;
  grid-template-columns: 16px 1fr auto;
  gap: 6px;
}
.Dashboard .feed-wrapper .email-item .data-row .title,
.Dashboard .email-wrapper .email-item .data-row .title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.Dashboard .feed-wrapper .email-item .data-row .date,
.Dashboard .email-wrapper .email-item .data-row .date {
  font-size: 11.5px;
  opacity: 0.8;
}
.Dashboard .feed-wrapper .email-item .subject-row,
.Dashboard .email-wrapper .email-item .subject-row {
  display: grid;
  grid-template-columns: 16px 1fr auto;
  gap: 6px;
}
.Dashboard .feed-wrapper .email-item .subject-row .title,
.Dashboard .email-wrapper .email-item .subject-row .title {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  font-weight: 600;
  grid-column: 2;
}
.Dashboard .feed-wrapper .email-item .content-row,
.Dashboard .email-wrapper .email-item .content-row {
  padding-left: 22px;
}
.Dashboard .feed-wrapper .email-item .content-row .content,
.Dashboard .email-wrapper .email-item .content-row .content {
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 2;
  -webkit-box-orient: vertical;
  color: inherit;
  opacity: 0.8;
  font-size: 11.5px;
}
.Dashboard .feed-wrapper hr,
.Dashboard .email-wrapper hr {
  border: var(--colorFgAlpha) solid;
  border-width: 1px 0 0;
  margin: 0;
}
.Dashboard-TipWidget .tip {
  place-content: center;
  height: 100%;
  margin: 0 12px;
  overflow: hidden;
  text-align: center;
  cursor: pointer;
  border-radius: var(--radius);
  transition: color 200ms linear, background 200ms linear;
  margin-bottom: 12px;
}
.Dashboard-TipWidget .tip:hover {
  color: var(--colorFg);
  background-color: var(--colorBgIntense);
}
.Dashboard-TipWidget .tip h1 {
  font-size: 21px;
  padding: 0 24px;
  overflow: hidden;
  display: -webkit-box;
  -webkit-line-clamp: 4;
  -webkit-box-orient: vertical;
}
.Dashboard-TipWidget .tip h2 {
  font-size: 16px;
  font-family: serif;
  font-style: italic;
}
.Dashboard-Shortcuts section {
  display: flex;
  flex: 1;
  overflow: auto;
}
.Dashboard-Shortcuts form.widget-config {
  height: auto;
  gap: 6px;
}
.Dashboard-Shortcuts div.widget-config-content {
  grid-template-columns: 1fr;
  overflow-y: auto;
  padding-bottom: 0;
}
.Dashboard-Shortcuts .folder-list {
  margin-left: unset;
}
.Dashboard .shortcut-list,
.Dashboard .top-sites-wrapper {
  display: flex;
  flex-wrap: wrap;
  align-content: flex-start;
  overflow-y: auto;
  gap: 12px;
  height: 100%;
  padding-bottom: 3px;
}
.Dashboard .shortcut-list:empty,
.Dashboard .top-sites-wrapper:empty {
  display: none;
}
.Dashboard .shortcut-list.scrollable,
.Dashboard .top-sites-wrapper.scrollable {
  padding: 2px var(--scrollbarWidth) 12px 12px;
  border-bottom-left-radius: inherit;
  border-bottom-right-radius: inherit;
}
.Dashboard .shortcut-list .item,
.Dashboard .top-sites-wrapper .item {
  display: flex;
  flex-direction: column;
  border-radius: var(--radius);
  width: var(--shortcut-item-width);
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.2);
  color: inherit;
  background-color: var(--colorBgLighter);
  backdrop-filter: blur(2px);
}
.Dashboard .shortcut-list .item:hover .icon-wrapper img,
.Dashboard .top-sites-wrapper .item:hover .icon-wrapper img {
  scale: 1.2;
  transition-duration: 50ms;
}
.Dashboard .shortcut-list .item.semi-transparent,
.Dashboard .top-sites-wrapper .item.semi-transparent {
  background-color: color-mix(in srgb, var(--colorBgLighter), transparent);
}
.Dashboard .shortcut-list .item.transparent,
.Dashboard .top-sites-wrapper .item.transparent {
  background-color: color-mix(in srgb, var(--colorBgLighter) 20%, transparent);
}
.Dashboard .shortcut-list .item .icon-wrapper,
.Dashboard .top-sites-wrapper .item .icon-wrapper {
  display: flex;
  justify-content: center;
  align-items: center;
  flex-wrap: wrap;
  width: var(--shortcut-item-width);
  height: 64px;
  overflow: hidden;
  border-radius: inherit;
}
.Dashboard .shortcut-list .item .icon-wrapper img,
.Dashboard .top-sites-wrapper .item .icon-wrapper img {
  transition: scale 200ms linear;
}
.Dashboard .shortcut-list .item .icon-wrapper svg,
.Dashboard .top-sites-wrapper .item .icon-wrapper svg {
  width: 32px;
  height: 32px;
}
.Dashboard .shortcut-list .item .icon-wrapper.folder-back svg,
.Dashboard .top-sites-wrapper .item .icon-wrapper.folder-back svg {
  transform: scaleX(-1);
  height: 24px;
  width: 24px;
}
.Dashboard .shortcut-list .item p,
.Dashboard .top-sites-wrapper .item p {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  text-align: center;
  padding: 0 3px 3px;
  font-size: 11.5px;
}
.Dashboard .shortcut-list:has(> .item.show-title) .icon-wrapper,
.Dashboard .top-sites-wrapper:has(> .item.show-title) .icon-wrapper {
  height: 54px;
}
.Dashboard-Webpage {
  position: relative;
  overflow: hidden;
}
.Dashboard-Webpage .url-wrapper {
  margin: -6px 12px 6px;
  height: 20px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  cursor: default;
  user-select: text;
}
.Dashboard-Webpage .url-wrapper:empty {
  display: none;
}
.Dashboard-Webpage .url-wrapper .not-secure,
.Dashboard-Webpage .url-wrapper .UrlFragments,
.Dashboard-Webpage .url-wrapper .UrlFragment--Highlight {
  font-size: 11.5px;
  color: var(--colorFgFadedMore);
}
.Dashboard-Webpage .url-wrapper .not-secure {
  user-select: none;
  padding-right: 3px;
}
.Dashboard-Webpage .url-wrapper:focus {
  display: flex;
  align-items: center;
  outline: unset;
  background-color: var(--colorBgDark);
}
.Dashboard-Webpage .url-wrapper:focus .UrlFragments {
  overflow: scroll;
  text-overflow: unset;
}
.Dashboard-Webpage .url-wrapper:focus .UrlFragments::-webkit-scrollbar {
  display: none;
}
.Dashboard-Webpage .url-wrapper:not(:focus) .UrlFragments,
.Dashboard-Webpage .url-wrapper:not(:focus) .UrlFragment--Highlight {
  color: inherit;
}
.Dashboard-Webpage .url-wrapper:not(:focus) .UrlFragments {
  display: contents;
}
.Dashboard-Webpage .url-wrapper:not(:focus) .UrlFragments *::selection {
  background-color: transparent;
}
.Dashboard-Webpage section {
  position: relative;
  height: 100%;
  overflow: hidden;
  border-bottom-left-radius: inherit;
  border-bottom-right-radius: inherit;
}
.Dashboard-Webpage .widget-config {
  margin: 0 12px 12px;
}
.Dashboard-Webpage .widget-config .widget-config-content {
  padding-top: 6px;
  padding-bottom: 0;
  grid-template-areas: '. urlField' 'errorInfo errorInfo';
}
.Dashboard-Webpage .widget-config .UrlField input {
  grid-area: urlField;
  width: 100%;
}
.Dashboard-Webpage .widget-config .error {
  grid-area: errorInfo;
  padding: 6px 0;
  color: var(--colorErrorBg);
}
.Dashboard-Webpage .widget-config footer.widget-config-footer label {
  display: flex;
  gap: 6px;
}
.Dashboard-Webpage .dashboard-widget-header {
  padding: 0;
  margin: 0;
  border-top-left-radius: inherit;
  border-top-right-radius: inherit;
}
.Dashboard-Webpage .webview-placeholder {
  animation: delay_visibility 100ms linear;
  display: flex;
  padding: 12px;
  gap: 12px;
  text-align: center;
  height: 100%;
  flex-direction: column;
  justify-content: center;
}
.Dashboard-Webpage .webview-placeholder svg {
  zoom: 400%;
  opacity: 0.3;
}
.Dashboard-Date .date-content {
  display: flex;
  flex-direction: row;
  align-items: center;
  padding: 0 12px 12px;
  gap: 12px;
  flex: 1;
  justify-content: space-around;
}
.Dashboard-Date .date-wrapper {
  display: flex;
  flex-direction: column;
  gap: 9px;
  font-variation-settings: normal;
  font-size: 23px;
  font-weight: 300;
  line-height: 1;
}
.Dashboard-Date .date-wrapper .date-display {
  display: flex;
  flex-wrap: wrap;
  align-items: center;
}
.Dashboard-Date .date-wrapper .date-display .date {
  font-weight: 500;
}
.Dashboard-Date .date-wrapper .week-display {
  opacity: 0.65;
  font-size: 13px;
  padding-bottom: 6px;
}
.Dashboard-Date .month-dots {
  display: grid;
  grid-template-columns: repeat(7, 1fr);
  gap: 6px;
}
.Dashboard-Date .month-dots .dot {
  width: 10px;
  height: 10px;
  border-radius: 50%;
}
.Dashboard-Date .month-dots .dot.empty {
  visibility: hidden;
}
.Dashboard-Date .month-dots .dot.past {
  border-color: var(--colorFgAlpha);
  background-color: var(--colorFgAlpha);
}
.Dashboard-Date .month-dots .dot.current {
  background-color: var(--colorHighlightBg);
}
.Dashboard-Date .month-dots .dot.future {
  border: 1.5px solid var(--colorFgFaded);
  background-color: transparent;
}
.Dashboard-WeatherWidget section {
  display: flex;
  flex: 1;
  overflow: auto;
}
.Dashboard-WeatherWidget .temperature-label {
  height: 100%;
}
.Dashboard-WeatherWidget .widget-config {
  min-height: min-content;
  height: auto;
  flex: 1;
}
.Dashboard-WeatherWidget .weather-wrapper {
  display: flex;
  flex-direction: column;
  padding: 0 var(--scrollbarWidth) 12px 12px;
  height: 100%;
}
.Dashboard-WeatherWidget .weather-wrapper .provider {
  display: flex;
  justify-content: space-between;
  color: inherit;
  opacity: 0.6;
  font-size: 11.5px;
  margin-top: auto;
}
.Dashboard-WeatherWidget .weather-wrapper .pagination-dots {
  display: flex;
  gap: 6px;
  align-items: center;
}
.Dashboard-WeatherWidget .weather-wrapper .pagination-dots button {
  width: 10px;
  height: 10px;
  border-radius: var(--radiusRound);
  border: none;
  padding: 0;
  background-color: currentColor;
  opacity: 0.3;
  cursor: pointer;
  transition: opacity 100ms ease;
}
.Dashboard-WeatherWidget .weather-wrapper .pagination-dots button:hover {
  opacity: 0.5;
}
.Dashboard-WeatherWidget .weather-wrapper .pagination-dots button.active {
  opacity: 1;
}
.Dashboard-WeatherWidget .weather-wrapper .compact-week-forecast-wrapper {
  display: flex;
  flex-direction: column;
  margin: auto 0;
}
.Dashboard-WeatherWidget .weather-wrapper .today-forecast-wrapper {
  display: flex;
  justify-content: space-around;
  margin: auto 0;
}
.Dashboard-WeatherWidget .weather-wrapper .today-forecast-wrapper .heading {
  font-weight: 500;
  font-size: 23px;
}
.Dashboard-WeatherWidget .weather-wrapper .today-forecast-wrapper .heading.block {
  display: block;
}
.Dashboard-WeatherWidget .weather-wrapper .today-forecast-wrapper .date {
  font-size: 16px;
}
.Dashboard-WeatherWidget .weather-wrapper .today-forecast-wrapper .current-forecast {
  display: flex;
  align-items: center;
  gap: 12px;
}
.Dashboard-WeatherWidget .weather-wrapper .today-forecast-wrapper .forecast-details {
  display: grid;
  grid-template-rows: repeat(3, 16px);
  grid-template-columns: auto 1fr auto;
  row-gap: 6px;
  column-gap: 6px;
  margin-bottom: 6px;
  align-content: center;
  text-wrap: nowrap;
}
.Dashboard-WeatherWidget .weather-wrapper .hourly-forecast,
.Dashboard-WeatherWidget .weather-wrapper .week-forecast {
  width: stretch;
  line-height: 1;
}
.Dashboard-WeatherWidget .weather-wrapper .hourly-forecast td,
.Dashboard-WeatherWidget .weather-wrapper .week-forecast td {
  text-align: center;
  width: 18%;
}
.Dashboard-WeatherWidget .weather-wrapper .hourly-forecast td:nth-of-type(6),
.Dashboard-WeatherWidget .weather-wrapper .week-forecast td:nth-of-type(6) {
  width: 16px;
  text-align: left;
}
.Dashboard-WeatherWidget .weather-wrapper .hourly-forecast td span,
.Dashboard-WeatherWidget .weather-wrapper .week-forecast td span {
  display: inline-block;
}
.Dashboard-WeatherWidget .weather-wrapper .week-forecast td:first-of-type {
  text-align: left;
  padding-left: 12px;
}
.Dashboard-WeatherWidget .widget-config .widget-config-content {
  display: flex;
}
.Dashboard-WeatherWidget .widget-config .widget-config-content .setting-group,
.Dashboard-WeatherWidget .widget-config .widget-config-content .VivaldiSelector {
  width: 100%;
}
.Dashboard-CurrencyWidget {
  display: flex;
  flex-direction: column;
  padding: 0 var(--scrollbarWidth) 12px 12px;
  height: 100%;
}
.Dashboard-CurrencyWidget .dashboard-widget-header .title {
  padding-left: 0;
  padding-right: 0;
  overflow: visible;
}
.Dashboard-CurrencyWidget .dashboard-widget-header.hidden {
  visibility: hidden;
}
.Dashboard-CurrencyWidget .converter {
  display: flex;
  flex-direction: row;
  align-items: space-between;
  color: var(--colorFg);
  gap: 6px;
}
.Dashboard-CurrencyWidget .input-group {
  display: flex;
  flex: 1;
  flex-direction: column;
  gap: 6px;
}
.Dashboard-CurrencyWidget .input-group input {
  width: 0;
  min-width: 100%;
}
.Dashboard-CurrencyWidget .switch {
  display: flex;
  justify-content: center;
  align-items: center;
  margin-bottom: 10px;
}
.Dashboard-CurrencyWidget .switch button {
  border: none;
  height: 48px;
  width: 48px;
  background-color: var(--colorBgLighter);
  padding-top: 6px;
  border-radius: var(--radiusRound);
  box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.1);
}
.Dashboard-CurrencyWidget .error {
  padding: 6px 0;
  color: var(--colorErrorBg);
}
.Dashboard-CurrencyWidget .provider,
.Dashboard-CurrencyWidget .external-link {
  text-align: center;
  color: inherit;
  opacity: 0.65;
  font-size: 11.5px;
  margin-top: auto;
}
.Dashboard-CurrencyWidget .TabbedView {
  overflow: auto;
}
.Dashboard-CurrencyWidget .TabbedView.doubleHeight {
  margin-top: auto;
  height: 288px;
}
.Dashboard-CurrencyWidget .TabbedView-List {
  background-color: var(--colorBg);
  margin-bottom: 0 !important;
}
.transparent.Dashboard-CurrencyWidget .TabbedView-List,
.custom.Dashboard-CurrencyWidget .TabbedView-List,
.semi-transparent.Dashboard-CurrencyWidget .TabbedView-List {
  padding: 6px 0;
}
.Dashboard-CurrencyWidget .currency-overview {
  display: grid;
  grid-template-columns: 1fr 1fr;
  gap: 6px;
}
.Dashboard-CurrencyWidget .currency-overview li {
  display: flex;
}
.Dashboard-CurrencyWidget .currency-overview li .arrow {
  display: flex;
  align-items: center;
  justify-content: center;
  padding: 0 6px 0 6px;
}
.Dashboard-CurrencyWidget .currency-overview li .arrow span {
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: var(--colorSuccessBgAlpha);
  border-radius: var(--radiusHalf);
  width: 24px;
  height: 24px;
}
.Dashboard-CurrencyWidget .currency-overview li .arrow svg {
  fill: var(--colorSuccessBg);
}
.Dashboard-CurrencyWidget .currency-overview li .arrow.down span {
  background-color: var(--colorErrorBgAlpha);
}
.Dashboard-CurrencyWidget .currency-overview li .arrow.down svg {
  fill: var(--colorErrorBg);
  transform: rotate(180deg);
}
.Dashboard-CurrencyWidget .currency-overview li .name-and-rate {
  font-size: 11.5px;
  line-height: normal;
  flex: 1;
  display: flex;
  flex-direction: column;
}
.Dashboard-CurrencyWidget .currency-overview li .name-and-rate div:first-of-type {
  font-weight: 600;
}
.Dashboard-CurrencyWidget .currency-overview li .trend {
  font-size: 11.5px;
}
.Dashboard .TabbedView {
  height: 228px;
  overflow: visible;
  margin: 0;
  border: unset;
}
.Dashboard .transparent .TabbedView-List,
.Dashboard .semi-transparent .TabbedView-List,
.Dashboard .custom .TabbedView-List,
.Dashboard .transparent .TabbedView-Content,
.Dashboard .semi-transparent .TabbedView-Content,
.Dashboard .custom .TabbedView-Content,
.Dashboard .transparent .sortselector,
.Dashboard .semi-transparent .sortselector,
.Dashboard .custom .sortselector {
  background-color: transparent;
  border-bottom: 1px solid transparent;
}
.Dashboard .transparent .TabbedView-List button:not(.active),
.Dashboard .semi-transparent .TabbedView-List button:not(.active),
.Dashboard .custom .TabbedView-List button:not(.active),
.Dashboard .transparent .TabbedView-Content button:not(.active),
.Dashboard .semi-transparent .TabbedView-Content button:not(.active),
.Dashboard .custom .TabbedView-Content button:not(.active),
.Dashboard .transparent .sortselector button:not(.active),
.Dashboard .semi-transparent .sortselector button:not(.active),
.Dashboard .custom .sortselector button:not(.active) {
  color: inherit;
}
.Dashboard .transparent .TabbedView-List button:not(.active):hover,
.Dashboard .semi-transparent .TabbedView-List button:not(.active):hover,
.Dashboard .custom .TabbedView-List button:not(.active):hover,
.Dashboard .transparent .TabbedView-Content button:not(.active):hover,
.Dashboard .semi-transparent .TabbedView-Content button:not(.active):hover,
.Dashboard .custom .TabbedView-Content button:not(.active):hover,
.Dashboard .transparent .sortselector button:not(.active):hover,
.Dashboard .semi-transparent .sortselector button:not(.active):hover,
.Dashboard .custom .sortselector button:not(.active):hover {
  color: var(--colorFg);
  background-color: var(--colorBgAlphaHeavier);
}
.Dashboard-Widgets .TabbedView.semi-transparent {
  background-color: unset;
  border-bottom-color: transparent;
}
.Dashboard-Widgets .TabbedView:not(.Dashboard-Widgets-Drop):empty {
  display: none;
}
.Dashboard-Widgets .TabbedView-List {
  border-radius: var(--radius);
  margin-bottom: 6px;
}
.Dashboard-Widgets .TabbedView-Content {
  overflow: unset;
  height: 100%;
  align-content: center;
}
.Dashboard-Widgets .TabbedView-Content:has(.hourly-forecast) {
  overflow: auto;
  margin-right: calc(-1 * var(--scrollbarWidth));
}
.widget-list-modal-wrapper {
  display: flex;
  flex-direction: column;
  gap: 12px;
  padding: 12px 18px;
}
.widget-list-modal-wrapper .widget-list-modal-header {
  display: flex;
  justify-content: space-between;
}
.widget-list-modal-wrapper .widget-list-modal-content {
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  gap: 18px;
}
.widget-list-modal-wrapper .widget-list-modal-content .add-button {
  padding: 18px 12px;
}
.widget-list-modal-wrapper .widget-list-modal-content .add-button div {
  margin-top: 6px;
}
.widget-config-modal-wrapper {
  display: flex;
  flex-direction: column;
}
.widget-config-modal-wrapper .widget-config-modal-header {
  display: flex;
  justify-content: space-between;
  padding: 12px 18px;
}
.widget-config-modal-wrapper .widget-config-modal-content {
  padding: 12px 18px;
}
.widget-config-modal-wrapper .dialog-footer {
  flex-direction: row-reverse;
}
.widget-config-modal-wrapper form label {
  display: inline-flex;
  vertical-align: top;
  gap: 9px;
}
.empty-widget {
  opacity: 0 !important;
}
.dashboard-list-wrapper {
  position: fixed;
  bottom: 0;
  left: 0;
  right: 0;
  z-index: 1000;
  display: flex;
  flex-direction: column;
  height: 156px;
  background-color: var(--colorBgLight);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  animation: pullfade 200ms linear;
}
.dashboard-list-wrapper:focus-visible {
  outline: none;
}
.dashboard-list-wrapper .dashboard-list-header {
  padding: 12px 24px 0;
  display: flex;
  justify-content: space-between;
  padding-bottom: 6px;
}
.dashboard-list-wrapper .button-wrapper {
  display: flex;
  align-items: flex-start;
  flex: 1;
  gap: 6px;
  padding: 6px 24px 6px;
  margin: 0 auto;
  max-width: 100%;
  line-height: 1;
  overflow: auto;
}
.dashboard-list-wrapper .button-wrapper .add-button {
  display: inline-grid;
  width: 96px;
  min-width: 96px;
  height: 88px;
  padding: 12px 6px 6px;
  grid-template-rows: 32px 1fr;
  row-gap: 6px;
  border: 1px solid transparent;
  border-radius: var(--radius);
  box-shadow: 0px 2px 4px 0px #0000000f;
  background-color: var(--colorBgIntenser);
}
.dashboard-list-wrapper .button-wrapper .add-button[disabled] {
  background-color: unset;
  border: 1px dashed var(--colorBorder);
}
.dashboard-list-wrapper .button-wrapper .add-button > .icon {
  transition: scale 200ms ease-out;
}
.dashboard-list-wrapper .button-wrapper .add-button:hover {
  transition: none;
}
.dashboard-list-wrapper .button-wrapper .add-button:hover > .icon {
  scale: 1.4;
}
.dashboard-list-wrapper .button-wrapper .add-button .icon {
  width: 32px;
  height: 32px;
  scale: 1.25;
  align-self: center;
  justify-self: center;
}
.dashboard-list-wrapper .button-wrapper .add-button div {
  align-self: center;
  font-size: 11.5px;
  line-height: 1.3;
  overflow: hidden;
  text-overflow: ellipsis;
}
.widget-config {
  display: flex;
  flex-direction: column;
  flex: 1;
  height: 100%;
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
  color: var(--colorFg);
  background-color: var(--colorBgIntense);
  margin: 0 12px 12px;
}
.widget-config .widget-config-content {
  display: grid;
  grid-template-columns: auto 1fr;
  gap: 6px;
  align-items: center;
  padding: 12px;
}
.widget-config .widget-config-content label {
  display: flex;
  align-items: center;
}
.widget-config .widget-config-content label input[type=checkbox] {
  margin-right: 6px;
}
.widget-config .widget-config-content.topsites-config {
  grid-template-columns: 1fr;
}
.widget-config .widget-config-intro + .widget-config-content {
  padding-top: 0;
}
.widget-config .widget-config-footer {
  display: flex;
  align-items: center;
  margin-top: auto;
  padding: 0 12px 12px;
  border-bottom-right-radius: inherit;
  border-bottom-left-radius: inherit;
}
.mac .widget-config .widget-config-footer {
  justify-content: flex-end;
}
.widget-config-intro {
  display: flex;
  align-items: center;
  flex: 1;
  padding: 0 12px;
  gap: 6px;
}
.widget-config-intro p {
  display: flex;
  align-items: center;
  text-wrap: balance;
}
.double_height .widget-config-intro {
  flex-direction: column;
  place-content: center;
}
.double_height .widget-config-intro p {
  text-align: center;
}
.widget-config-intro .icon {
  flex: 0 0 48px;
}
.widget-config-intro .icon svg {
  max-width: 100%;
  height: auto;
}
.widget-config-intro .icon path {
  vector-effect: non-scaling-stroke;
}
.double_height .widget-config-intro .icon {
  margin: 0 auto;
  width: unset;
  height: unset;
}
.double_height .widget-config-intro p {
  text-align: center;
}
.widget-image-intro {
  margin: auto;
  flex: 1.3;
  place-content: end;
}
.regular .widget-image-intro {
  flex: 1;
}
.widget-image-intro svg {
  width: 114px;
  height: 114px;
}
.dashboard-widget.regular .widget-image-intro svg {
  width: 64px;
  height: 64px;
  opacity: 0.4;
}
.widget-drag-layer {
  position: fixed;
  pointer-events: none;
  z-index: 100;
  left: 0;
  top: 0;
}
.widget-drag-layer > div {
  display: flex;
  justify-content: center;
  align-items: center;
  border: 1px solid var(--colorBorder);
  border-radius: var(--radius);
  background-color: var(--colorBgIntense);
  opacity: 0.7;
}
.widget-drag-layer > div .icon {
  width: 32px;
  height: 32px;
  scale: 1.25;
  align-self: center;
  justify-self: center;
}
#notes-panel section {
  min-height: 130px;
}
#notes-panel .tree-item[data-cut] {
  opacity: 0.5;
}
#notes-panel .no-notes + .vivaldi-tree {
  visibility: collapse;
}
.notes-welcome {
  width: 100%;
  height: 100%;
  display: grid;
}
.notes-welcome .note-empty-state {
  margin: 18px 18px 6px 6px;
  text-align: center;
}
.notes-welcome .note-empty-state h1 {
  font-weight: 600;
  margin-top: 18px;
  padding-bottom: 12px;
}
.notes-editor {
  position: relative;
  height: 100%;
  display: flex;
  flex-direction: column;
}
.editor-wrapper {
  height: 100%;
  overflow: hidden;
  position: relative;
}
.editor-wrapper .editor {
  height: inherit;
  overflow: auto;
}
.editor-wrapper .debug {
  height: 100px !important;
  overflow: scroll !important;
}
.editor-wrapper .panel-editor img {
  max-width: 200px !important;
}
.editor-wrapper .editor-contenteditable {
  border-top: 1px solid var(--colorBorderIntense);
  border-bottom: 1px solid var(--colorBorderIntense);
  overflow: auto;
  overscroll-behavior: none;
  padding: 6px max(calc((100% - 700px) / 2), 48px);
  background-color: var(--colorBg);
  font-family: var(--sansSerifFont), sans-serif;
}
.editor-wrapper .editor-contenteditable.panel-editor {
  background-color: var(--colorBgIntenser);
  border: 1px solid var(--colorBorderIntense);
  border-radius: var(--radius);
  padding: 6px;
}
.editor-wrapper .editor-contenteditable:focus-visible {
  outline: none;
}
.editor-wrapper .placeholder {
  position: absolute;
  place-self: anchor-center;
}
.editor-wrapper .bold {
  font-weight: 600;
}
.editor-wrapper .italic {
  font-style: italic;
}
.editor-wrapper .strikethrough {
  text-decoration: line-through;
}
.editor-wrapper .underline {
  text-decoration: underline;
}
.editor-wrapper .underline-strikethrough {
  text-decoration: underline line-through;
}
.editor-wrapper .text-code {
  background-color: var(--colorBgDarker);
  color: var(--colorFgFaded);
  padding: 1px 3px;
  font-family: var(--monospaceFont), monospace;
}
.editor-wrapper .quote {
  margin: 3px 0;
  color: var(--colorFgFaded);
  border-left-color: var(--colorFgFadedMost);
  border-left-width: 6px;
  border-left-style: solid;
  padding-left: 12px;
}
.editor-wrapper .hr {
  padding: 3px;
  border: none;
  cursor: pointer;
}
.editor-wrapper .hr:after {
  content: '';
  display: block;
  height: 1px;
  background-color: var(--colorFgFadedMost);
  line-height: 1px;
}
.editor-wrapper .hr.selected {
  outline: 2px solid var(--colorHighlightBg);
  user-select: none;
}
.editor-wrapper .code-block {
  background-color: var(--colorBgDarker);
  padding: 3px;
  margin: 3px 0;
  display: block;
  position: relative;
  tab-size: 2;
  font-family: var(--monospaceFont), monospace;
}
.editor-wrapper .code-block .code-attr {
  color: #b859b5;
}
.editor-wrapper .code-block .code-property {
  color: #ac884a;
}
.editor-wrapper .code-block .code-string {
  color: #50a14f;
}
.editor-wrapper .code-block .code-variable {
  color: #d34662;
}
.editor-wrapper .code-block .code-comment {
  color: #a0a1a7;
}
.editor-wrapper .code-block .code-function {
  color: #5180e8;
}
.editor-wrapper .ulList,
.editor-wrapper .olList-1,
.editor-wrapper .olList-2,
.editor-wrapper .olList-3,
.editor-wrapper .olList-4,
.editor-wrapper .olList-5 {
  padding: 0;
  margin: 0;
  list-style-position: outside;
}
.editor-wrapper .ulList {
  list-style: unset;
}
.editor-wrapper .ulList .ulList {
  list-style: circle;
}
.editor-wrapper .ulList .ulList .ulList {
  list-style: square;
}
.editor-wrapper .olList-2 {
  list-style-type: upper-alpha;
}
.editor-wrapper .olList-3 {
  list-style-type: lower-alpha;
}
.editor-wrapper .olList-4 {
  list-style-type: upper-roman;
}
.editor-wrapper .olList-5 {
  list-style-type: lower-roman;
}
.editor-wrapper .listItem {
  margin: 3px 18px;
}
.editor-wrapper .listItemChecked,
.editor-wrapper .listItemUnchecked {
  position: relative;
  margin-left: 0;
  margin-right: 0;
  padding-left: 24px;
  padding-right: 24px;
  list-style-type: none;
  outline: none;
}
.editor-wrapper .listItemChecked {
  text-decoration: line-through;
}
.editor-wrapper .listItemChecked:before,
.editor-wrapper .listItemUnchecked:before {
  content: '';
  width: 14px;
  height: 14px;
  left: 0;
  cursor: pointer;
  display: block;
  background-size: cover;
  position: absolute;
}
.editor-wrapper .listItemChecked:before {
  border: 1px solid #3d87f5;
  border-radius: var(--radius);
  background-color: #3d87f5;
  background-repeat: no-repeat;
}
.editor-wrapper .listItemChecked:after {
  content: '';
  cursor: pointer;
  border-color: #fff;
  border-style: solid;
  position: absolute;
  display: block;
  top: 3px;
  width: 3px;
  left: 6px;
  right: 6px;
  height: 6px;
  transform: rotate(45deg);
  border-width: 0 2px 2px 0;
}
.editor-wrapper .listItemUnchecked:before {
  border: 1px solid var(--colorAccentBorder);
  border-radius: var(--radius);
}
.editor-wrapper .listItemUnchecked[dir='rtl']:before,
.editor-wrapper .listItemChecked[dir='rtl']:before {
  left: auto;
  right: 0;
}
.editor-wrapper .nestedListItem {
  list-style-type: none;
}
.editor-wrapper .nestedListItem:before,
.editor-wrapper .nestedListItem:after {
  display: none;
}
.editor-wrapper .editor-link {
  cursor: pointer;
}
.editor-wrapper .editor-image {
  position: relative;
  display: inline-block;
  padding: 0 2px;
}
.editor-wrapper .editor-image img.focused {
  outline: 2px solid #3c84f4;
  user-select: none;
  cursor: grab;
}
.editor-wrapper .editor-image .image-resizer {
  display: block;
  width: 7px;
  height: 7px;
  position: absolute;
  background-color: #3c84f4;
  border: 1px solid #fff;
}
.editor-wrapper .editor-image .image-resizer.image-resizer-n {
  top: -6px;
  left: 48%;
  cursor: n-resize;
}
.editor-wrapper .editor-image .image-resizer.image-resizer-ne {
  top: -6px;
  right: -6px;
  cursor: ne-resize;
}
.editor-wrapper .editor-image .image-resizer.image-resizer-e {
  bottom: 48%;
  right: -6px;
  cursor: e-resize;
}
.editor-wrapper .editor-image .image-resizer.image-resizer-se {
  bottom: -2px;
  right: -6px;
  cursor: nwse-resize;
}
.editor-wrapper .editor-image .image-resizer.image-resizer-s {
  bottom: -2px;
  left: 48%;
  cursor: s-resize;
}
.editor-wrapper .editor-image .image-resizer.image-resizer-sw {
  bottom: -2px;
  left: -6px;
  cursor: sw-resize;
}
.editor-wrapper .editor-image .image-resizer.image-resizer-w {
  bottom: 48%;
  left: -6px;
  cursor: w-resize;
}
.editor-wrapper .editor-image .image-resizer.image-resizer-nw {
  top: -6px;
  left: -6px;
  cursor: nw-resize;
}
.editor-wrapper .editor-table {
  border-collapse: collapse;
  border-spacing: 0;
  overflow-y: scroll;
  overflow-x: scroll;
  table-layout: fixed;
  width: max-content;
}
.editor-wrapper .editor-tableSelection *::selection {
  background-color: transparent;
}
.editor-wrapper .editor-tableCell {
  border: 1px solid var(--colorFgFadedMost);
  vertical-align: top;
  text-align: start;
  padding: 6px;
  position: relative;
  outline: none;
}
.editor-wrapper .editor-tableCellHeader {
  background-color: var(--colorBgDarker);
  text-align: start;
}
.editor-wrapper h1 {
  font-size: 1.4em;
  font-weight: 600;
  margin: 6px 0;
}
.editor-wrapper h2 {
  font-size: 1.2em;
  font-weight: 600;
  margin: 6px 0;
}
.editor-wrapper h3 {
  font-size: 1.1em;
  font-weight: 600;
  margin: 6px 0;
}
.editor-wrapper h4 {
  font-size: 1em;
  font-weight: 600;
  margin: 6px 0;
}
.toolbar-wrapper {
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  gap: 3px;
  margin: 8px 6px;
}
#browser:not(.density-on) .toolbar-wrapper {
  margin: 6px;
}
.toolbar-wrapper button {
  max-width: 28px;
  border: none;
  background-color: transparent;
}
.toolbar-wrapper .active button {
  background-color: var(--colorBgDarker);
}
.theme-dark .toolbar-wrapper .active button {
  background-color: var(--colorBgLighter);
}
.toolbar-wrapper .toolbarAnnex {
  display: flex;
  align-items: center;
  gap: 6px;
  margin-left: auto;
}
.link-dialog {
  display: flex;
  position: absolute;
  top: 0;
  left: 0;
  z-index: 10;
  max-width: 400px;
  width: 100%;
  opacity: 0;
  background-color: var(--colorBgIntense);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  border-radius: var(--radius);
}
.link-dialog .link-input {
  width: 100%;
  margin: 6px;
  padding: 3px 6px;
}
.link-dialog .link-buttons {
  display: flex;
  gap: 6px;
  padding: 6px;
  margin-left: auto;
}
.link-dialog .link-buttons button.button-textonly {
  padding: 0;
}
.link-dialog .link-view {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  padding: 6px;
  margin-left: 6px;
  align-content: center;
  cursor: pointer;
  text-decoration: underline;
  color: var(--colorHighlightBg);
}
.NotesAttachmentPopup {
  padding: 12px 6px;
}
.NotesAttachmentPopup .AttachmentButton {
  width: fit-content;
  margin: auto;
}
.NotesAttachmentPopup .AttachmentButton button {
  padding: 0 18px;
}
.NotesAttachmentPopup .NotesAttachments:not(:empty) {
  margin-bottom: 12px;
  --AttachmentSize: auto;
}
.NotesAttachmentPopup .MarkdownRender {
  flex: 1 1 10px;
  margin: 6px calc(var(--scrollbarWidth) * -1) 0 6px;
  word-break: break-word;
}
#browser.mac.theme-light .NotesAttachmentPopup .MarkdownRender *::selection {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 25%, transparent);
}
#browser.mac.theme-dark .NotesAttachmentPopup .MarkdownRender *::selection {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 50%, transparent);
}
#browser.win .NotesAttachmentPopup .MarkdownRender *::selection,
#browser.linux .NotesAttachmentPopup .MarkdownRender *::selection {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.NotesAttachments {
  --AttachmentSize: 49px;
  display: grid;
  grid-template-columns: repeat(auto-fill, var(--AttachmentSize));
  grid-gap: 6px;
  grid-auto-rows: var(--AttachmentSize);
  grid-auto-columns: var(--AttachmentSize);
}
.NotesAttachments .AttachmentItem {
  position: relative;
  border-radius: var(--radiusHalf);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05) inset;
}
.NotesAttachments .AttachmentItem-Image {
  height: 100%;
  width: 100%;
  object-fit: cover;
  border-radius: var(--radiusHalf);
  overflow: hidden;
}
.NotesAttachments .AttachmentItem-DeleteButton {
  border: 1px solid transparent;
  height: 18px;
  width: 18px;
  position: absolute;
  top: -2px;
  right: -2px;
  padding: 0;
  background-color: var(--colorErrorBg);
  border-radius: var(--radiusRound);
  scale: 0;
  z-index: 1;
  transition: scale 0.2s linear;
}
.NotesAttachments .AttachmentItem:hover .AttachmentItem-DeleteButton {
  scale: 1;
  transition-duration: 0s;
}
.NotesAttachments .AttachmentItem-ViewOverlayButton {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background-color: transparent;
  border: 1px solid var(--colorBorderDisabled);
  border-radius: var(--radiusHalf);
}
.NotesAttachments .AttachmentItem-ViewOverlayButton svg {
  scale: 1.5;
  opacity: 0;
}
.button-popup .NotesAttachments .AttachmentItem-ViewOverlayButton svg {
  scale: 4;
}
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):hover,
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):focus-visible {
  background-color: rgba(0, 0, 0, 0.5);
}
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):hover svg,
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):focus-visible svg {
  opacity: 1;
}
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):active {
  background-color: rgba(0, 0, 0, 0.6);
}
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):active svg {
  opacity: 1;
}
.NotesAttachments .AttachmentItem-ViewOverlayButton.dragging-enabled:hover,
.NotesAttachments .AttachmentItem-ViewOverlayButton.dragging-enabled:focus {
  cursor: move;
}
.NotesManager {
  display: flex;
  flex: 1;
  background-color: var(--colorBgLightIntense);
}
.NotesManager--Vertical {
  flex-direction: row;
}
.NotesManager--Vertical .NotesManager-Wrapper {
  border-right: 1px solid var(--colorBorder);
}
.NotesManager--Horizontal {
  flex-direction: column;
}
.NotesManager--Horizontal .NotesManager-Wrapper {
  border-bottom: 1px solid var(--colorBorder);
}
.NotesManager-Wrapper {
  display: flex;
  flex-direction: column;
  flex: 1;
  overflow: hidden;
}
.NotesManager-Wrapper > .toolbar {
  margin: 6px;
}
.NotesManager-Tree-Container .tree-row label {
  flex: 1 1 auto;
}
.NotesManager-EditorContainer {
  display: grid;
  grid-template-rows: auto 1fr auto;
  height: 100%;
  overflow: hidden;
}
.NotesManager .button-toolbar.push-right {
  margin-left: auto;
}
.NotesManager .layout-toggle .button-toolbar button {
  padding: 0;
}
.NotesManager img.button-icon.layout-toggle,
.NotesManager .layout-toggle .button-icon svg {
  width: 28px;
  height: 28px;
}
.NotesManager-WordCount {
  width: max-content;
  height: fit-content;
  padding: 6px;
}
.PanelEditor {
  display: flex;
  flex-direction: column;
  height: 100%;
  overflow: hidden;
}
.PanelEditor-AdditionalInfo {
  display: flex;
  flex-direction: column;
  padding: 6px 3px;
  gap: 3px;
}
.PanelEditor-Metadata {
  display: grid;
  grid-template-columns: 16px auto 1fr;
  grid-template-rows: 22px;
  grid-gap: 3px;
  align-items: center;
  padding: 6px 3px;
}
.PanelEditor-Metadata.disabled {
  display: none;
}
.PanelEditor-MetaIcon {
  height: 16px;
  width: 16px;
  background-color: transparent;
}
.PanelEditor-MetaIcon-Label {
  font-weight: 600;
  opacity: 0.65;
}
.PanelEditor .toolbar-wrapper .RightBorder button {
  border-right-width: 1px;
  border-top-right-radius: var(--radius);
  border-bottom-right-radius: var(--radius);
}
.PanelEditor-Metadata .PanelEditor-Created,
.PanelEditor-Metadata .PanelEditor-Modified {
  display: contents;
}
.StartPage-PromoteButton {
  position: absolute;
  z-index: 1;
  bottom: 48px;
  right: 48px;
}
.StartPage-PromoteButton .PromoteButton > button {
  height: 56px;
  width: 56px;
  border-radius: var(--radiusRound);
  background: var(--colorBgLightIntense);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1), 0 3px 10px rgba(0, 0, 0, 0.3);
  cursor: pointer;
  border: none;
}
.StartPage-PromoteButton .PromoteButton > button.button-pressed {
  background-color: var(--colorBg);
}
.StartPage-PromoteButton .PromoteButton > button:active {
  background-color: var(--colorBgDark);
}
.StartPage-PromoteButton .PromoteButton > button > img {
  image-rendering: pixelated;
  height: 32px;
  width: 32px;
  transition: 1s;
}
.PromotePreviewPopup {
  display: flex;
  flex-direction: column;
}
.PromotePreviewPopup-SettingsButton {
  --ButtonSize: 26px;
  border: none;
  background: transparent;
  height: var(--ButtonSize);
  width: var(--ButtonSize);
  padding: 0;
  margin: 0;
  margin-left: 6px;
}
.PromotePreviewPopup-PreviewImage {
  width: 100%;
  border-radius: 3px;
  image-rendering: pixelated;
}
.PromotePreviewPopup-PreviewImage,
.PromotePreviewPopup-StartButton {
  grid-column: span 2;
}
.button-popup.ToolbarButtonPopup-DefaultStyles h2.PromotePreviewPopup-HeaderText {
  padding: 9px 18px;
  background-color: transparent;
  text-align: left;
  border: none;
}
.PromotePreviewPopup p {
  text-wrap: pretty;
  color: var(--colorFgFaded);
  margin-bottom: 12px;
}
.PromotePreviewPopup video {
  border: 1px solid var(--colorBorderSubtle);
  border-radius: var(--radius);
  width: 100%;
  height: auto;
  margin-bottom: 12px;
}
.TabButtonPopup {
  display: flex;
  flex-direction: column;
  border-radius: calc(var(--radius) - 6px / 2);
  overflow: hidden;
  background: linear-gradient(180deg, color-mix(in srgb, var(--colorBgLight) 95%, var(--colorAccentBg) 5%) 0%, color-mix(in srgb, var(--colorBg) 90%, var(--colorAccentBorderDark) 10%) 100%);
  background-repeat: no-repeat;
  background-size: cover;
}
.TabButtonPopup > header {
  position: sticky;
  top: 0px;
  height: 50px;
  background: inherit;
  z-index: 2;
  display: flex;
  flex-direction: row;
  justify-content: space-between;
  align-items: center;
  font-size: 16px;
  font-weight: 600;
  padding: 12px;
  padding-right: 6px;
  gap: 6px;
  border-top-left-radius: inherit;
  border-top-right-radius: inherit;
}
.TabButtonPopup > header .button-toolbar > button:hover {
  background-color: var(--colorFgAlpha);
}
.TabButtonPopup > header .qc-entry {
  display: flex;
  width: 100%;
  border-radius: var(--radius);
  border: 1px solid var(--colorBorder);
  background-color: var(--colorBgIntense);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 0 0 3px transparent;
  --button-icon-width: 28px;
}
.TabButtonPopup > header .qc-entry input:focus {
  outline: 0;
  box-shadow: none;
}
.TabButtonPopup > header .qc-entry .quick-command-search {
  font-size: 13px;
  font-weight: 400;
  border: none;
  box-shadow: none;
  background-color: transparent;
  height: var(--treeRowHeight);
  appearance: none;
  width: 100%;
  padding: 0 6px 0 3px;
  anchor-name: --qcsearch;
}
.TabButtonPopup > header .qc-entry:focus-within {
  outline: 2px solid var(--colorHighlightBg);
  box-shadow: unset;
  border-color: transparent;
}
.TabButtonPopup > header .qc-entry .button-icon {
  display: flex;
  justify-content: center;
  align-items: center;
  pointer-events: none;
  width: auto;
  min-width: var(--button-icon-width);
  gap: 3px;
}
.TabButtonPopup .quick-commands,
.TabButtonPopup .dialog-content,
.TabButtonPopup .no-results {
  border-bottom-left-radius: inherit;
  border-bottom-right-radius: inherit;
  scrollbar-gutter: unset;
  overflow-x: hidden;
  gap: 6px;
  padding: 6px 6px 0;
}
.TabButtonPopup .VivaldiList-Offset {
  margin-top: -6px;
}
.TabButtonPopup .quick-commands > .VivaldiList {
  min-height: calc(var(--treeRowHeight) * 2.5);
}
.TabButtonPopup .quick-commands > .VivaldiList .VivaldiList-Offset {
  padding: 0 6px;
}
.TabButtonPopup .quick-commands > .VivaldiList .quick-command-sectionheader {
  display: flex;
  align-items: center;
}
.TabButtonPopup .quick-commands > .VivaldiList .quick-command[data-selected] {
  border-radius: var(--radius);
  background-color: var(--colorBgDarker);
}
.TabButtonPopup .quick-commands > .VivaldiList .quick-command-title {
  flex: 1;
  overflow: hidden;
}
.TabButtonPopup .quick-commands > .VivaldiList .quick-command-url {
  display: none;
}
.TabButtonPopup .quick-commands > .VivaldiList .quick-command-tip {
  display: none;
}
.TabButtonPopup .quick-commands > .VivaldiList .close {
  background-color: transparent;
  display: none;
}
.TabButtonPopup .quick-commands > .VivaldiList .item-count {
  display: none;
}
.TabButtonPopup .quick-commands > .VivaldiList .quick-command {
  display: flex;
  gap: 6px;
  align-items: center;
  padding: 0 6px;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
  font-weight: 400;
}
.TabButtonPopup .quick-commands > .VivaldiList .quick-command:hover .close {
  display: block;
}
.TabButtonPopup .no-results {
  display: flex;
  padding: 12px;
}
.TabButtonPopup .no-results .VivaldiSvgIcon {
  opacity: 0.65;
}
.TabButtonPopup .is-searching {
  display: none;
}
.TabButtonPopup .button-badge {
  flex: 0 0 auto;
  background-color: var(--colorFgAlpha);
  height: auto;
  line-height: 1.3;
  padding: 1px 4px;
  border-radius: 3px;
  font-size: 11.5px;
  font-weight: 600;
  margin: auto 0 auto auto;
  overflow: visible;
  min-width: 1.5em;
  text-align: center;
  color: var(--colorFg);
  top: unset;
  right: 7%;
  z-index: unset;
  border: none;
  isolation: isolate;
}
.counter-indicator + .TabButtonPopup .button-badge {
  margin-left: 3px;
}
.TabButtonPopup .button-badge.counter-unseen {
  color: var(--colorBgIntense);
  background-color: var(--colorFgFadedMore);
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  font-weight: 400;
}
.TabButtonPopup .button-badge.counter-unseen + .counter-unread {
  margin-left: -6px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .TabButtonPopup .button-badge {
  background-color: var(--colorHighlightFgAlphaHeavy);
  font-weight: 400;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .TabButtonPopup .button-badge.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
  font-weight: 600;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .TabButtonPopup .button-badge {
  background-color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .TabButtonPopup .button-badge.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .TabButtonPopup .button-badge.counter-unread {
  background-color: var(--colorHighlightFgAlphaHeavy);
  color: var(--colorHighlightFg);
  font-weight: 400;
}
.TabButtonPopup .workspace-name {
  flex: 0 0 auto;
  background-color: var(--colorFgAlpha);
  height: auto;
  line-height: 1.3;
  padding: 1px 4px;
  border-radius: 3px;
  font-size: 11.5px;
  font-weight: 600;
  margin: auto 0 auto auto;
  overflow: visible;
  min-width: 1.5em;
  text-align: center;
  display: flex;
  gap: 3px;
  align-items: center;
  margin-left: 6px;
  border-radius: var(--radius);
  padding: 1px 6px;
  font-weight: 400;
}
.counter-indicator + .TabButtonPopup .workspace-name {
  margin-left: 3px;
}
.TabButtonPopup .workspace-name.counter-unseen {
  color: var(--colorBgIntense);
  background-color: var(--colorFgFadedMore);
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  font-weight: 400;
}
.TabButtonPopup .workspace-name.counter-unseen + .counter-unread {
  margin-left: -6px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .TabButtonPopup .workspace-name {
  background-color: var(--colorHighlightFgAlphaHeavy);
  font-weight: 400;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .TabButtonPopup .workspace-name.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
  font-weight: 600;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .TabButtonPopup .workspace-name {
  background-color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .TabButtonPopup .workspace-name.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .TabButtonPopup .workspace-name.counter-unread {
  background-color: var(--colorHighlightFgAlphaHeavy);
  color: var(--colorHighlightFg);
  font-weight: 400;
}
.TabButtonPopup .tabs-button,
.TabButtonPopup .button-menu {
  width: 100%;
}
.TabButtonPopup .tabs-button button,
.TabButtonPopup .button-menu button {
  justify-content: flex-start;
  border: none;
}
.TabButtonPopup .tabs-button .button-icon,
.TabButtonPopup .button-menu .button-icon {
  margin-left: 3px;
  flex: unset;
}
.TabButtonPopup .ToolbarButton-Button .button-title {
  flex: 1;
}
.TabButtonPopup .ToolbarButton-Button .expand-icon {
  flex-grow: 0;
}
.TabButtonPopup-Menu button {
  border: none;
}
.TabButtonPopup .dialog-content .vivaldi-tree {
  display: flex;
}
.TabButtonPopup .vivaldi-tree .VivaldiList {
  scrollbar-gutter: unset;
}
.hasfocus .TabButtonPopup .vivaldi-tree .VivaldiList:focus-within .tree-row[data-selected] .window-entry:not(.window-entry-button) {
  background-color: var(--colorHighlightBg);
}
.TabButtonPopup .vivaldi-tree .VivaldiList .tree-item .tree-row {
  height: 100%;
  padding-inline: 3px;
  background-color: var(--colorBgLighter);
}
.theme-dark .TabButtonPopup .vivaldi-tree .VivaldiList .tree-item .tree-row {
  background-color: var(--colorBgDark);
}
.TabButtonPopup .vivaldi-tree .VivaldiList .tree-item .tree-row:not([data-selected]) .colored {
  border-radius: var(--radius);
}
.TabButtonPopup .vivaldi-tree .VivaldiList .tree-item .tree-row .colored:before {
  content: '';
  position: absolute;
  width: 8px;
  height: 8px;
  border: 1px solid var(--colorBg);
  border-radius: 50%;
}
.TabButtonPopup .tree-row[data-selected] {
  box-shadow: unset !important;
}
.TabButtonPopup .tree-item .tree-row:has(.window-parent:not(.window-child)) {
  margin-top: 7px;
  padding-block: 3px;
  height: calc(var(--treeViewRowHeight) + 6px);
  border-radius: var(--radius);
}
.TabButtonPopup .tree-item .tree-row:has(.window-parent:not(.window-child)).dragoverAbove {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.TabButtonPopup .tree-item .tree-row:has(.window-parent:not(.window-child)).dragoverBelow {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}
.TabButtonPopup .tree-item[data-expanded] .tree-row {
  border-bottom-left-radius: 0 !important;
  border-bottom-right-radius: 0 !important;
}
.TabButtonPopup input[type='button'] {
  max-height: 100%;
  max-width: fit-content;
  margin: 0;
}
.TabButtonPopup .tree-row:has(.last-window-child) {
  border-bottom-left-radius: calc(var(--radius) - 6px / 2);
  border-bottom-right-radius: calc(var(--radius) - 6px / 2);
  padding-bottom: 3px;
}
.TabButtonPopup .tree-row:has(.is-cut) {
  opacity: 0.5;
}
.TabButtonPopup .window-entry-button {
  padding: 6px;
  height: 100%;
}
.TabButtonPopup .tree-row-selected label,
.TabButtonPopup .tree-row:hover label {
  border-radius: calc(var(--radius) - 6px / 2);
}
.TabButtonPopup label.window-entry {
  display: flex;
  gap: 6px;
  align-items: center;
  padding: 0 6px;
  margin: unset !important;
  line-height: var(--treeRowHeight);
  min-height: var(--treeRowHeight);
  overflow: hidden;
  white-space: nowrap;
}
.TabButtonPopup label.window-entry .title {
  flex: 1;
  display: flex;
  overflow: hidden;
}
.TabButtonPopup label.window-entry .title .text {
  flex-shrink: 1;
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}
.TabButtonPopup label.window-entry .title .pill {
  flex: 0 0 auto;
  background-color: var(--colorFgAlpha);
  height: auto;
  line-height: 1.3;
  padding: 1px 4px;
  border-radius: 3px;
  font-size: 11.5px;
  font-weight: 600;
  margin: auto 0 auto auto;
  overflow: visible;
  min-width: 1.5em;
  text-align: center;
  margin-left: 6px;
  border-radius: var(--radius);
  padding: 1px 6px;
  font-weight: 400;
}
.counter-indicator + .TabButtonPopup label.window-entry .title .pill {
  margin-left: 3px;
}
.TabButtonPopup label.window-entry .title .pill.counter-unseen {
  color: var(--colorBgIntense);
  background-color: var(--colorFgFadedMore);
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
  font-weight: 400;
}
.TabButtonPopup label.window-entry .title .pill.counter-unseen + .counter-unread {
  margin-left: -6px;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .TabButtonPopup label.window-entry .title .pill {
  background-color: var(--colorHighlightFgAlphaHeavy);
  font-weight: 400;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .TabButtonPopup label.window-entry .title .pill.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
  font-weight: 600;
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .TabButtonPopup label.window-entry .title .pill {
  background-color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .TabButtonPopup label.window-entry .title .pill.counter-unseen {
  background-color: var(--colorHighlightFg);
  color: var(--colorHighlightBg);
}
.hasfocus .VivaldiList:focus-within .tree-row[data-selected] .mail-panel-category-container .TabButtonPopup label.window-entry .title .pill.counter-unread {
  background-color: var(--colorHighlightFgAlphaHeavy);
  color: var(--colorHighlightFg);
  font-weight: 400;
}
.TabButtonPopup label.window-entry .close {
  visibility: hidden;
}
.TabButtonPopup label.window-entry:hover .close {
  visibility: visible;
  transform: scale(1);
}
.TabButtonPopup label.window-entry .svg-icon {
  display: flex;
  justify-content: center;
}
.TabButtonPopup .button-toolbar-menu-indicator {
  transform: rotate(270deg);
}
.TabButtonPopup input[type='button'].close-button {
  margin-left: 16px;
}
@keyframes highlightEffect {
  from {
    outline: solid 2px transparent;
  }
  to {
    outline: solid 2px var(--colorHighlightBg);
  }
}
.TabButtonPopupMenu button {
  border: none;
}
.TabButtonPopupMenu.highlight button {
  animation-duration: 2s;
  animation-name: highlightEffect;
  animation-iteration-count: 6;
  animation-direction: alternate;
  animation-timing-function: ease;
}
.TabButtonPopupSuggestion {
  background-color: var(--colorHighlightBgAlpha);
  border: transparent 1px solid;
  border-radius: var(--radius);
  padding: 6px;
}
.TabButtonPopupSuggestion header {
  display: flex;
  gap: 6px;
}
.TabButtonPopupSuggestion header .icon {
  height: 16px;
  width: 16px;
  align-self: center;
  color: var(--colorHighlightBgDark);
}
.TabButtonPopupSuggestion header .title {
  flex: 1;
  display: flex;
  align-items: center;
  color: var(--colorFgFaded);
}
.TabButtonPopupSuggestion header .close {
  background-color: unset;
}
.TabButtonPopupSuggestion article {
  display: flex;
  gap: 6px;
  padding: 12px 0 0;
  align-items: flex-start;
}
.TabButtonPopupSuggestion article .icon {
  height: 16px;
  width: 16px;
}
.TabButtonPopupSuggestion article.no-icon {
  padding-left: calc(16px + 6px);
}
.TabButtonPopupSuggestion footer {
  display: flex;
  background-color: unset;
  border: none;
  padding-top: 6px;
  padding-left: 3px;
}
.TabButtonPopupSuggestion footer input[type='button'] {
  margin-left: 6px;
}
.TabButtonPopupSuggestion.hidden {
  display: none;
}
.TabButtonPopupSuggestion .suggested-reading {
  margin-block: 12px;
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: space-evenly;
}
.TabButtonPopupSuggestion .suggested-reading > div {
  display: flex;
  flex-direction: column;
  align-items: center;
  row-gap: 6px;
  font-size: 11.5px;
}
.TabButtonPopupSuggestion .suggested-reading button {
  position: relative;
  min-width: 50px;
  min-height: 50px;
  background-color: var(--colorHighlightBg);
  color: var(--colorHighlightFg);
  border: none;
  cursor: pointer;
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.15);
}
.TabButtonPopupSuggestion .suggested-reading button:hover {
  background-color: var(--colorHighlightBgDark);
}
#app #browser .TabButtonPopupSuggestion .suggested-reading button svg {
  filter: unset;
}
.TabButtonPopupSuggestion .suggested-reading button span svg {
  scale: 1.1;
}
.TabButtonPopupSuggestion .suggested-reading button svg.checkmark {
  transition: 0.4s;
  fill: var(--colorHighlightFg);
  position: absolute;
  height: 16px;
  width: 16px;
  right: -4px;
  top: -4px;
  background-color: var(--colorSuccessBg);
  color: var(--colorSuccessFg);
  border-radius: var(--radius);
  border: var(--colorBgIntense) 2px solid;
  outline: 2px solid var(--colorHighlightBgAlpha);
  outline-offset: -2px;
}
.NotesEditor {
  --ToolbarIconSize: 28px;
  --AttachmentSize: 49px;
  display: flex;
  flex-direction: column;
  flex: 1;
}
.NotesEditor > .toolbar {
  margin-top: 2px;
  margin-bottom: 6px;
}
.NotesEditor-Metadata {
  display: grid;
  grid-template-columns: 16px auto 1fr;
  grid-template-rows: 22px;
  grid-gap: 3px;
  align-items: center;
  padding: 6px 3px;
}
.NotesEditor-Metadata.disabled {
  display: none;
}
.NotesEditor-Metadata .cardview.address {
  padding: 0 var(--radiusHalf);
  height: 22px;
}
.NotesEditor-Metadata .UrlField {
  grid-column: 2 / -1;
}
.NotesEditor-MetaIcon {
  height: 16px;
  width: 16px;
  background-color: transparent;
}
.NotesEditor-MetaIcon--Url {
  border: 0;
  padding: 0;
  cursor: pointer;
}
.NotesEditor-MetaIcon-Label {
  font-weight: 600;
  opacity: 0.65;
}
.NotesEditor-Editor {
  cursor: auto;
  display: block;
  line-height: 1.3;
  max-height: unset;
  min-width: 100%;
  padding: 6px 12px;
  margin: 0;
  border-radius: unset;
  user-select: text;
  white-space: normal;
}
.cardview.cardview .NotesEditor-Editor {
  resize: none;
  background-color: transparent;
  border: none;
  box-shadow: none;
  padding: 6px;
}
.NotesEditor-Editor:focus {
  outline: unset;
}
.NotesEditor-Editor-Background {
  display: flex;
  flex: 1;
  position: relative;
}
.NotesEditor-Editor-Background:after {
  content: '';
  border-radius: var(--radius);
  background-color: var(--colorBgIntense);
  border: 1px solid var(--colorBorder);
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1) inset, 0 0 0 3px rgba(0, 0, 0, 0);
  position: absolute;
  top: 0;
  z-index: -1;
  left: 0;
  right: 1px;
  bottom: 0;
  pointer-events: none;
}
.NotesEditor-Editor-Background:focus-within:after {
  outline: 2px solid var(--colorHighlightBg);
  outline-offset: -1px;
}
.NotesEditor-EmptyPlaceholder {
  flex: 1;
  grid-area: EditorA;
  min-width: 100%;
  padding: 6px;
  opacity: 0.9;
  cursor: pointer;
}
.NotesEditor-EmptyPlaceholder:hover {
  background-color: var(--colorBg);
  outline: 1px dashed var(--colorFgFadedMore);
  outline-offset: -1px;
}
.NotesEditor-Created {
  display: contents !important;
}
.NotesEditor-Modified {
  display: contents !important;
}
.NotesEditor-Attachments:empty {
  display: none;
}
.NotesEditor .MarkdownRender {
  flex: 1 1 10px;
  margin: 6px calc(var(--scrollbarWidth) * -1) 0 6px;
  word-break: break-word;
}
#browser.mac.theme-light .NotesEditor .MarkdownRender *::selection {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 25%, transparent);
}
#browser.mac.theme-dark .NotesEditor .MarkdownRender *::selection {
  background-color: color-mix(in srgb, var(--colorHighlightBg) 50%, transparent);
}
#browser.win .NotesEditor .MarkdownRender *::selection,
#browser.linux .NotesEditor .MarkdownRender *::selection {
  color: var(--colorHighlightFg);
  background-color: var(--colorHighlightBg);
}
.NotesEditor .open-in-tab-button {
  margin-left: auto;
  margin-right: 0;
}
.NotesAttachments {
  display: grid;
  grid-template-columns: repeat(auto-fill, var(--AttachmentSize));
  grid-gap: 6px;
  grid-auto-rows: var(--AttachmentSize);
  grid-auto-columns: var(--AttachmentSize);
}
.NotesAttachments:not(:empty) {
  padding: 6px 0 3px;
}
.NotesAttachments .AttachmentItem {
  position: relative;
  border-radius: var(--radiusHalf);
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.05) inset;
}
.NotesAttachments .AttachmentItem-Image {
  height: 100%;
  width: 100%;
  object-fit: cover;
  border-radius: var(--radiusHalf);
  overflow: hidden;
}
.NotesAttachments .AttachmentItem-DeleteButton {
  border: 1px solid transparent;
  height: 18px;
  width: 18px;
  position: absolute;
  top: -2px;
  right: -2px;
  padding: 0;
  background-color: var(--colorErrorBg);
  border-radius: var(--radiusRound);
  scale: 0;
  z-index: 1;
  transition: scale 0.2s linear;
}
.NotesAttachments .AttachmentItem:hover .AttachmentItem-DeleteButton {
  scale: 1;
  transition-duration: 0s;
}
.NotesAttachments .AttachmentItem-ViewOverlayButton {
  content: '';
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  background-color: transparent;
  border: 1px solid var(--colorBorderDisabled);
  border-radius: var(--radiusHalf);
}
.NotesAttachments .AttachmentItem-ViewOverlayButton svg {
  scale: 1.5;
  opacity: 0;
}
.button-popup .NotesAttachments .AttachmentItem-ViewOverlayButton svg {
  scale: 4;
}
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):hover,
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):focus-visible {
  background-color: rgba(0, 0, 0, 0.5);
}
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):hover svg,
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):focus-visible svg {
  opacity: 1;
}
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):active {
  background-color: rgba(0, 0, 0, 0.6);
}
.NotesAttachments .AttachmentItem-ViewOverlayButton:not(.dragging-enabled):active svg {
  opacity: 1;
}
.NotesAttachments .AttachmentItem-ViewOverlayButton.dragging-enabled:hover,
.NotesAttachments .AttachmentItem-ViewOverlayButton.dragging-enabled:focus {
  cursor: move;
}
#notes-panel section {
  min-height: 130px;
}
#notes-panel .notes-editor {
  position: relative;
  height: 100%;
  display: flex;
  flex-direction: column;
}
#notes-panel .tree-item[data-cut] {
  opacity: 0.5;
}
#notes-panel .no-notes + .vivaldi-tree {
  visibility: collapse;
}
.notes-welcome {
  width: 100%;
  height: 100%;
  display: grid;
}
.notes-welcome .note-empty-state {
  margin: 18px 18px 6px 6px;
  text-align: center;
}
.notes-welcome .note-empty-state h1 {
  font-weight: 600;
  margin-top: 18px;
  padding-bottom: 12px;
}
.NotesManager {
  --AttachmentSize: 48px;
  --MinWidth: 200px;
  --MaxWidth: 700px;
  --ToolbarHeight: 41px;
  --FooterHeight: 40px;
  display: flex;
  flex: 1;
  background-color: var(--colorBgLightIntense);
}
.NotesManager--Vertical {
  flex-direction: row;
}
.NotesManager--Vertical .NotesManager-Tree {
  max-width: 70vw;
}
.NotesManager--Vertical .NotesManager-Tree:not(.NotesManager-Tree--Collapsed) {
  border-right: 1px solid var(--colorBorder);
}
.NotesManager--Horizontal {
  flex-direction: column;
}
.NotesManager--Horizontal .NotesManager-Tree {
  max-height: 70vh;
}
.NotesManager--Horizontal .NotesManager-Tree:not(.NotesManager-Tree--Collapsed) {
  border-bottom: 1px solid var(--colorBorder);
}
.NotesManager-Tree {
  display: flex;
  flex-direction: column;
  flex: 0 0 auto;
  overflow: hidden;
}
.NotesManager-Tree-Container {
  display: flex;
  flex: 1;
  flex-direction: column;
  overflow: hidden;
}
.NotesManager-Tree .tree-row label {
  flex: 1 1 auto;
}
.NotesManager-Tree > .toolbar {
  margin: 6px;
}
.NotesManager-Note {
  position: relative;
  z-index: 1;
  display: grid;
  flex: 1;
  overflow: hidden;
  grid-template-columns: minmax(12px, 1fr) minmax(var(--MinWidth), var(--MaxWidth)) minmax(12px, 1fr);
  grid-template-rows: auto 1fr var(--FooterHeight);
  grid-template-areas: 'header header header' 'content content content' '. footer .';
}
.NotesManager-Toolbar {
  display: flex;
  grid-area: header;
  flex-direction: column;
}
.NotesManager-Buttons {
  background-color: var(--colorBgLightIntense);
  border-bottom: 1px solid var(--colorBorder);
  padding: 6px;
}
.NotesManager-Footer {
  grid-area: footer;
  display: flex;
  font-size: 11.5px;
  justify-content: space-between;
  align-items: center;
  opacity: 0.54;
  width: 100%;
}
.NotesManager-Editor,
.NotesManager-RenderedContent {
  grid-area: content;
  display: flex;
}
.NotesManager-Stylingbuttons {
  display: flex;
  align-items: center;
}
.NotesManager-Editor .editor-html {
  display: contents;
}
.NotesManager-Editor .editor-webview {
  position: static;
  width: 100%;
}
.NotesManager-RenderedContent,
.NotesManager-Editor .editor-markdown {
  --EditorPadding: 6px * 2;
  margin-left: var(--EditorPadding);
  padding-left: calc(50% - calc(var(--MaxWidth) / 2) - var(--EditorPadding)) !important;
  padding-right: calc(50% - calc(var(--MaxWidth) / 2)) !important;
  padding-top: var(--EditorPadding);
  padding-bottom: var(--EditorPadding);
  width: calc(100% - var(--EditorPadding));
}
.NotesManager-Editor .editor-webview,
.NotesManager-Editor .editor-markdown {
  display: flex;
}
.NotesManager-Editor .editor-webview .editor-html,
.NotesManager-Editor .editor-markdown .editor-html {
  position: relative;
  display: flex;
  flex-direction: column;
  width: 100%;
}
.NotesManager-Editor .editor-webview .editor-webview,
.NotesManager-Editor .editor-markdown .editor-webview {
  flex: 1;
  position: relative;
}
.NotesManager-RenderMarkdownButton {
  flex: 0 0 auto;
  display: flex;
}
.NotesManager-RenderMarkdownButton .button-on {
  background-image: linear-gradient(var(--colorBgDarker), var(--colorBgDark));
  box-shadow: inset 0 1px 1px 0 rgba(0, 0, 0, 0.1);
}
.NotesManager-EmptyPlaceholder {
  flex: 1;
  opacity: 0.9;
  display: flex;
  justify-content: center;
  align-items: center;
  position: relative;
  cursor: pointer;
}
.NotesManager-EmptyPlaceholder:hover {
  background-color: var(--colorBg);
  outline: 1px dashed var(--colorFgFadedMore);
  outline-offset: -1px;
}
.NotesManager .button-toolbar.push-right {
  margin-left: auto;
}
.NotesManager .layout-toggle .button-toolbar button {
  padding: 0;
}
.NotesManager img.button-icon.layout-toggle,
.NotesManager .layout-toggle .button-icon svg {
  width: 28px;
  height: 28px;
}
.resize-triggers {
  visibility: hidden;
}
.resize-triggers,
.resize-triggers > div,
.contract-trigger:before {
  content: ' ';
  display: block;
  position: absolute;
  top: 0;
  left: 0;
  height: 100%;
  width: 100%;
  overflow: hidden;
}
.resize-triggers > div {
  overflow: hidden;
}
.contract-trigger:before {
  width: 200%;
  height: 200%;
}
/* Global overrides. If something doesn't work as expected, check here. */
/* Disabling amimation */
.animation-off *:not(.PreserveTransitions),
.animation-off *:after,
.animation-off *:before,
.animation-off ::-webkit-progress-value {
  transition-duration: 0s !important;
  transition-delay: 0s !important;
  animation-duration: 0s !important;
  animation-delay: 0s !important;
  animation-iteration-count: 1 !important;
  scroll-behavior: auto !important;
}
@media (prefers-reduced-motion) {
  *:not(.PreserveTransitions),
  *:after,
  *:before,
  ::-webkit-progress-value {
    transition-duration: 0s !important;
    transition-delay: 0s !important;
    animation-duration: 0s !important;
    animation-delay: 0s !important;
    animation-iteration-count: 1 !important;
    scroll-behavior: auto !important;
  }
}
.overlayinfobubble {
  position: absolute;
  left: 50%;
  transform: translateX(-50%);
  top: 20vh;
  min-height: 35px;
  margin: 0 auto;
  padding: 6px 12px;
  color: #fff;
  background-color: rgba(50, 50, 50, 0.8);
  border-radius: var(--radiusRounded);
  font-size: 21px;
  text-align: center;
  z-index: 100;
  opacity: 0;
  visibility: hidden;
  transition: opacity 0.5s, visibility 0.5s;
}
.overlayinfobubble.show {
  opacity: 0.9;
  visibility: visible;
  transition: opacity 0.5s, visibility 0.5s;
}

